package org.apache.commons.collections4.iterators;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.NoSuchElementException;
import org.apache.commons.collections4.OrderedMapIterator;
import java.util.Set;
import org.junit.Test;

/** 
 * Abstract class for testing the OrderedMapIterator interface.
 * <p>
 * This class provides a framework for testing an implementation of MapIterator.
 * Concrete subclasses must provide the list iterator to be tested.
 * They must also specify certain details of how the list iterator operates by
 * overriding the supportsXxx() methods if necessary.
 * 
 * @since 3.0
 * @version $Id$
 */
public abstract class AbstractOrderedMapIteratorTest<K, V> extends AbstractMapIteratorTest<K, V> {
    /** 
     * JUnit constructor.
     * 
     * @param testName  the test class name
     */
public AbstractOrderedMapIteratorTest(final String testName) {
        super(testName);
    }

    @Override
    public abstract OrderedMapIterator<K, V> makeEmptyIterator();

    @Override
    public abstract OrderedMapIterator<K, V> makeObject();

    /** 
     * Test that the empty list iterator contract is correct.
     */
@Override
    public void testEmptyMapIterator() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEmptyMapIterator");
            if (!(supportsEmptyIterator())) {
                return ;
            } 
            super.testEmptyMapIterator();
            final OrderedMapIterator<K, V> it = makeEmptyIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),518,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),517,it.hasPrevious());
            try {
                it.previous();
            } catch (final NoSuchElementException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test that the empty list iterator contract is correct.
     */
@Test(timeout = 1000)
    public void testEmptyMapIterator_add233() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEmptyMapIterator_add233");
            if (!(supportsEmptyIterator())) {
                return ;
            } 
            super.testEmptyMapIterator();
            super.testEmptyMapIterator();
            final OrderedMapIterator<K, V> it = makeEmptyIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),518,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),517,it.hasPrevious());
            try {
                it.previous();
            } catch (final NoSuchElementException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test that the empty list iterator contract is correct.
     */
@Test(timeout = 1000)
    public void testEmptyMapIterator_add234() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEmptyMapIterator_add234");
            if (!(supportsEmptyIterator())) {
                return ;
            } 
            super.testEmptyMapIterator();
            final OrderedMapIterator<K, V> it = makeEmptyIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),518,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),517,it.hasPrevious());
            try {
                it.previous();
                it.previous();
            } catch (final NoSuchElementException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test that the empty list iterator contract is correct.
     */
@Test(timeout = 1000)
    public void testEmptyMapIterator_remove178() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEmptyMapIterator_remove178");
            if (!(supportsEmptyIterator())) {
                return ;
            } 
            final OrderedMapIterator<K, V> it = makeEmptyIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),518,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),517,it.hasPrevious());
            try {
                it.previous();
            } catch (final NoSuchElementException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test that the full list iterator contract is correct.
     */
@Override
    public void testFullMapIterator() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testFullMapIterator");
            if (!(supportsFullIterator())) {
                return ;
            } 
            super.testFullMapIterator();
            final OrderedMapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),537,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),538,map);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),519,it.hasNext());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),520,it.hasPrevious());
            final Set<K> set = new HashSet<K>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),539,set);
            while (it.hasNext()) {
                final K key = it.next();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),540,key);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),521,key);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),522,it.getKey());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),523,map.containsKey(key));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),524,set.add(key));
                final V value = it.getValue();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),541,value);
                if (!(isGetStructuralModify())) {
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),525,map.get(key));
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),526,value);
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),527,map.containsValue(value));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),528,it.hasPrevious());
                verify();
            }
            while (it.hasPrevious()) {
                final Object key = it.previous();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),542,key);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),529,key);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),530,it.getKey());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),531,map.containsKey(key));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),532,set.remove(key));
                final Object value = it.getValue();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),543,value);
                if (!(isGetStructuralModify())) {
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),533,map.get(key));
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),534,value);
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),535,map.containsValue(value));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),536,it.hasNext());
                verify();
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test that the full list iterator contract is correct.
     */
@Test(timeout = 1000)
    public void testFullMapIterator_add235() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testFullMapIterator_add235");
            if (!(supportsFullIterator())) {
                return ;
            } 
            super.testFullMapIterator();
            super.testFullMapIterator();
            final OrderedMapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),537,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),538,map);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),519,it.hasNext());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),520,it.hasPrevious());
            final Set<K> set = new HashSet<K>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),539,set);
            while (it.hasNext()) {
                final K key = it.next();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),540,key);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),521,key);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),522,it.getKey());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),523,map.containsKey(key));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),524,set.add(key));
                final V value = it.getValue();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),541,value);
                if (!(isGetStructuralModify())) {
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),525,map.get(key));
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),526,value);
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),527,map.containsValue(value));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),528,it.hasPrevious());
                verify();
            }
            while (it.hasPrevious()) {
                final Object key = it.previous();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),542,key);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),529,key);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),530,it.getKey());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),531,map.containsKey(key));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),532,set.remove(key));
                final Object value = it.getValue();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),543,value);
                if (!(isGetStructuralModify())) {
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),533,map.get(key));
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),534,value);
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),535,map.containsValue(value));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),536,it.hasNext());
                verify();
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test that the full list iterator contract is correct.
     */
@Test(timeout = 1000)
    public void testFullMapIterator_add236() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testFullMapIterator_add236");
            if (!(supportsFullIterator())) {
                return ;
            } 
            super.testFullMapIterator();
            final OrderedMapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),537,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),538,map);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),519,it.hasNext());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),520,it.hasPrevious());
            final Set<K> set = new HashSet<K>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),539,set);
            while (it.hasNext()) {
                final K key = it.next();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),540,key);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),521,key);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),522,it.getKey());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),523,map.containsKey(key));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),524,set.add(key));
                final V value = it.getValue();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),541,value);
                if (!(isGetStructuralModify())) {
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),525,map.get(key));
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),526,value);
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),527,map.containsValue(value));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),528,it.hasPrevious());
                verify();
                verify();
            }
            while (it.hasPrevious()) {
                final Object key = it.previous();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),542,key);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),529,key);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),530,it.getKey());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),531,map.containsKey(key));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),532,set.remove(key));
                final Object value = it.getValue();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),543,value);
                if (!(isGetStructuralModify())) {
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),533,map.get(key));
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),534,value);
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),535,map.containsValue(value));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),536,it.hasNext());
                verify();
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test that the full list iterator contract is correct.
     */
@Test(timeout = 1000)
    public void testFullMapIterator_add237() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testFullMapIterator_add237");
            if (!(supportsFullIterator())) {
                return ;
            } 
            super.testFullMapIterator();
            final OrderedMapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),537,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),538,map);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),519,it.hasNext());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),520,it.hasPrevious());
            final Set<K> set = new HashSet<K>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),539,set);
            while (it.hasNext()) {
                final K key = it.next();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),540,key);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),521,key);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),522,it.getKey());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),523,map.containsKey(key));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),524,set.add(key));
                final V value = it.getValue();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),541,value);
                if (!(isGetStructuralModify())) {
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),525,map.get(key));
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),526,value);
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),527,map.containsValue(value));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),528,it.hasPrevious());
                verify();
            }
            while (it.hasPrevious()) {
                final Object key = it.previous();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),542,key);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),529,key);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),530,it.getKey());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),531,map.containsKey(key));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),532,set.remove(key));
                final Object value = it.getValue();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),543,value);
                if (!(isGetStructuralModify())) {
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),533,map.get(key));
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),534,value);
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),535,map.containsValue(value));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),536,it.hasNext());
                verify();
                verify();
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test that the full list iterator contract is correct.
     */
@Test(timeout = 1000)
    public void testFullMapIterator_remove179() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testFullMapIterator_remove179");
            if (!(supportsFullIterator())) {
                return ;
            } 
            final OrderedMapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),537,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),538,map);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),519,it.hasNext());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),520,it.hasPrevious());
            final Set<K> set = new HashSet<K>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),539,set);
            while (it.hasNext()) {
                final K key = it.next();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),540,key);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),521,key);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),522,it.getKey());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),523,map.containsKey(key));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),524,set.add(key));
                final V value = it.getValue();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),541,value);
                if (!(isGetStructuralModify())) {
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),525,map.get(key));
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),526,value);
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),527,map.containsValue(value));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),528,it.hasPrevious());
                verify();
            }
            while (it.hasPrevious()) {
                final Object key = it.previous();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),542,key);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),529,key);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),530,it.getKey());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),531,map.containsKey(key));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),532,set.remove(key));
                final Object value = it.getValue();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),543,value);
                if (!(isGetStructuralModify())) {
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),533,map.get(key));
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),534,value);
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),535,map.containsValue(value));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),536,it.hasNext());
                verify();
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test that the iterator order matches the keySet order.
     */
@Test(timeout = 1000)
    public void testMapIteratorOrder_add238() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorOrder_add238");
            if (!(supportsFullIterator())) {
                return ;
            } 
            final OrderedMapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),554,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),555,map);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),544,new java.util.ArrayList<K>(map.keySet()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),544,new java.util.ArrayList<K>(map.keySet()));
            final Iterator<K> it2 = map.keySet().iterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),556,it2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),545,it.hasNext());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),546,it2.hasNext());
            final List<K> list = new ArrayList<K>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),557,list);
            while (it.hasNext()) {
                final K key = it.next();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),558,key);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),547,it2.next());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),548,key);
                list.add(key);
                list.add(key);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),549,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),550,list.size());
            while (it.hasPrevious()) {
                final K key = it.previous();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),559,key);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),551,list.get(((list.size()) - 1)));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),552,key);
                list.remove(((list.size()) - 1));
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),553,list.size());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test that the iterator order matches the keySet order.
     */
@Test(timeout = 1000)
    public void testMapIteratorOrder_add239() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorOrder_add239");
            if (!(supportsFullIterator())) {
                return ;
            } 
            final OrderedMapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),554,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),555,map);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),544,new java.util.ArrayList<K>(map.keySet()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),544,new java.util.ArrayList<K>(map.keySet()));
            final Iterator<K> it2 = map.keySet().iterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),556,it2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),545,it.hasNext());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),546,it2.hasNext());
            final List<K> list = new ArrayList<K>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),557,list);
            while (it.hasNext()) {
                final K key = it.next();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),558,key);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),547,it2.next());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),548,key);
                list.add(key);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),549,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),550,list.size());
            while (it.hasPrevious()) {
                final K key = it.previous();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),559,key);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),551,list.get(((list.size()) - 1)));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),552,key);
                list.remove(((list.size()) - 1));
                list.remove(((list.size()) - 1));
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),553,list.size());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test that the iterator order matches the keySet order.
     */
public void testMapIteratorOrder() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorOrder");
            if (!(supportsFullIterator())) {
                return ;
            } 
            final OrderedMapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),554,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),555,map);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),544,new java.util.ArrayList<K>(map.keySet()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),544,new java.util.ArrayList<K>(map.keySet()));
            final Iterator<K> it2 = map.keySet().iterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),556,it2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),545,it.hasNext());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),546,it2.hasNext());
            final List<K> list = new ArrayList<K>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),557,list);
            while (it.hasNext()) {
                final K key = it.next();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),558,key);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),547,it2.next());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),548,key);
                list.add(key);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),549,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),550,list.size());
            while (it.hasPrevious()) {
                final K key = it.previous();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),559,key);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),551,list.get(((list.size()) - 1)));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),552,key);
                list.remove(((list.size()) - 2));
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),553,list.size());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test that the iterator order matches the keySet order.
     */
public void testMapIteratorOrder_literalMutation244() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorOrder_literalMutation244");
            if (!(supportsFullIterator())) {
                return ;
            } 
            final OrderedMapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),554,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),555,map);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),544,new java.util.ArrayList<K>(map.keySet()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),544,new java.util.ArrayList<K>(map.keySet()));
            final Iterator<K> it2 = map.keySet().iterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),556,it2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),545,it.hasNext());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),546,it2.hasNext());
            final List<K> list = new ArrayList<K>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),557,list);
            while (it.hasNext()) {
                final K key = it.next();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),558,key);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),547,it2.next());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),548,key);
                list.add(key);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),549,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),550,list.size());
            while (it.hasPrevious()) {
                final K key = it.previous();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),559,key);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),551,list.get(((list.size()) - 1)));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),552,key);
                list.remove(((list.size()) - 0));
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),553,list.size());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test that the iterator order matches the keySet order.
     */
public void testMapIteratorOrder_literalMutation245() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorOrder_literalMutation245");
            if (!(supportsFullIterator())) {
                return ;
            } 
            final OrderedMapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),554,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),555,map);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),544,new java.util.ArrayList<K>(map.keySet()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),544,new java.util.ArrayList<K>(map.keySet()));
            final Iterator<K> it2 = map.keySet().iterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),556,it2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),545,it.hasNext());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),546,it2.hasNext());
            final List<K> list = new ArrayList<K>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),557,list);
            while (it.hasNext()) {
                final K key = it.next();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),558,key);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),547,it2.next());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),548,key);
                list.add(key);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),549,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),550,list.size());
            while (it.hasPrevious()) {
                final K key = it.previous();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),559,key);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),551,list.get(((list.size()) - 1)));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),552,key);
                list.remove(((list.size()) - 0));
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),553,list.size());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }
}

