package org.apache.commons.io;

import java.util.ArrayList;
import java.io.File;
import org.apache.commons.io.testtools.FileBasedTestCase;
import java.io.IOException;
import java.util.List;
import org.junit.Test;

/** 
 * Test cases for FileUtils.cleanDirectory() method.
 * 
 * @version $Id$
 */
public class FileUtilsCleanDirectoryTestCase extends FileBasedTestCase {
    final File top = getLocalTestDirectory();

    public FileUtilsCleanDirectoryTestCase(String name) {
        super(name);
    }

    private File getLocalTestDirectory() {
        return new File(FileBasedTestCase.getTestDirectory() , "list-files");
    }

    /** 
     * @see junit.framework.TestCase#setUp()
     */
@Override
    protected void setUp() throws Exception {
        top.mkdirs();
    }

    /** 
     * @see junit.framework.TestCase#tearDown()
     */
@Override
    protected void tearDown() throws Exception {
        chmod(top, 775, true);
        org.apache.commons.io.FileUtils.deleteDirectory(top);
    }

    @Test(timeout = 1000)
    public void testCleanEmpty() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCleanEmpty");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),326,top.list().length);
            org.apache.commons.io.FileUtils.cleanDirectory(top);
            org.apache.commons.io.FileUtils.cleanDirectory(top);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),327,top.list().length);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCleanEmpty_remove31() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCleanEmpty_remove31");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),326,top.list().length);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),327,top.list().length);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDeletesRegular_add72() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeletesRegular_add72");
            org.apache.commons.io.FileUtils.touch(new File(top , "regular"));
            org.apache.commons.io.FileUtils.touch(new File(top , "regular"));
            org.apache.commons.io.FileUtils.touch(new File(top , ".hidden"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),332,top.list().length);
            org.apache.commons.io.FileUtils.cleanDirectory(top);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),333,top.list().length);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDeletesRegular_add73() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeletesRegular_add73");
            org.apache.commons.io.FileUtils.touch(new File(top , "regular"));
            org.apache.commons.io.FileUtils.touch(new File(top , ".hidden"));
            org.apache.commons.io.FileUtils.touch(new File(top , ".hidden"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),332,top.list().length);
            org.apache.commons.io.FileUtils.cleanDirectory(top);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),333,top.list().length);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDeletesRegular_add74() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeletesRegular_add74");
            org.apache.commons.io.FileUtils.touch(new File(top , "regular"));
            org.apache.commons.io.FileUtils.touch(new File(top , ".hidden"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),332,top.list().length);
            org.apache.commons.io.FileUtils.cleanDirectory(top);
            org.apache.commons.io.FileUtils.cleanDirectory(top);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),333,top.list().length);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDeletesRegular() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeletesRegular");
            org.apache.commons.io.FileUtils.touch(new File(top , "re^ular"));
            org.apache.commons.io.FileUtils.touch(new File(top , ".hidden"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),332,top.list().length);
            org.apache.commons.io.FileUtils.cleanDirectory(top);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),333,top.list().length);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDeletesRegular_literalMutation191() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeletesRegular_literalMutation191");
            org.apache.commons.io.FileUtils.touch(new File(top , "regu\'lar"));
            org.apache.commons.io.FileUtils.touch(new File(top , ".hidden"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),332,top.list().length);
            org.apache.commons.io.FileUtils.cleanDirectory(top);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),333,top.list().length);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDeletesRegular_literalMutation192() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeletesRegular_literalMutation192");
            org.apache.commons.io.FileUtils.touch(new File(top , "reglar"));
            org.apache.commons.io.FileUtils.touch(new File(top , ".hidden"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),332,top.list().length);
            org.apache.commons.io.FileUtils.cleanDirectory(top);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),333,top.list().length);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDeletesRegular_literalMutation193() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeletesRegular_literalMutation193");
            org.apache.commons.io.FileUtils.touch(new File(top , "regular"));
            org.apache.commons.io.FileUtils.touch(new File(top , ".hûdden"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),332,top.list().length);
            org.apache.commons.io.FileUtils.cleanDirectory(top);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),333,top.list().length);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDeletesRegular_literalMutation194() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeletesRegular_literalMutation194");
            org.apache.commons.io.FileUtils.touch(new File(top , "regular"));
            org.apache.commons.io.FileUtils.touch(new File(top , ".hidden"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),332,top.list().length);
            org.apache.commons.io.FileUtils.cleanDirectory(top);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),333,top.list().length);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDeletesRegular_literalMutation195() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeletesRegular_literalMutation195");
            org.apache.commons.io.FileUtils.touch(new File(top , "regular"));
            org.apache.commons.io.FileUtils.touch(new File(top , ".idden"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),332,top.list().length);
            org.apache.commons.io.FileUtils.cleanDirectory(top);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),333,top.list().length);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDeletesRegular_remove34() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeletesRegular_remove34");
            org.apache.commons.io.FileUtils.touch(new File(top , ".hidden"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),332,top.list().length);
            org.apache.commons.io.FileUtils.cleanDirectory(top);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),333,top.list().length);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDeletesRegular_remove35() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeletesRegular_remove35");
            org.apache.commons.io.FileUtils.touch(new File(top , ".hidden"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),332,top.list().length);
            org.apache.commons.io.FileUtils.cleanDirectory(top);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),333,top.list().length);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDeletesRegular_remove36() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeletesRegular_remove36");
            org.apache.commons.io.FileUtils.touch(new File(top , "regular"));
            org.apache.commons.io.FileUtils.touch(new File(top , ".hidden"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),332,top.list().length);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),333,top.list().length);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDeletesNested_add70() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeletesNested_add70");
            final File nested = new File(top , "nested");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,nested);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),328,nested.mkdirs());
            org.apache.commons.io.FileUtils.touch(new File(nested , "file"));
            org.apache.commons.io.FileUtils.touch(new File(nested , "file"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),329,top.list().length);
            org.apache.commons.io.FileUtils.cleanDirectory(top);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),330,top.list().length);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDeletesNested_add71() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeletesNested_add71");
            final File nested = new File(top , "nested");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,nested);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),328,nested.mkdirs());
            org.apache.commons.io.FileUtils.touch(new File(nested , "file"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),329,top.list().length);
            org.apache.commons.io.FileUtils.cleanDirectory(top);
            org.apache.commons.io.FileUtils.cleanDirectory(top);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),330,top.list().length);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDeletesNested() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeletesNested");
            final File nested = new File(top , "nesed");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,nested);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),328,nested.mkdirs());
            org.apache.commons.io.FileUtils.touch(new File(nested , "file"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),329,top.list().length);
            org.apache.commons.io.FileUtils.cleanDirectory(top);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),330,top.list().length);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDeletesNested_literalMutation185() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeletesNested_literalMutation185");
            final File nested = new File(top , "nùested");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,nested);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),328,nested.mkdirs());
            org.apache.commons.io.FileUtils.touch(new File(nested , "file"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),329,top.list().length);
            org.apache.commons.io.FileUtils.cleanDirectory(top);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),330,top.list().length);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDeletesNested_literalMutation186() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeletesNested_literalMutation186");
            final File nested = new File(top , "nestd");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,nested);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),328,nested.mkdirs());
            org.apache.commons.io.FileUtils.touch(new File(nested , "file"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),329,top.list().length);
            org.apache.commons.io.FileUtils.cleanDirectory(top);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),330,top.list().length);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDeletesNested_literalMutation187() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeletesNested_literalMutation187");
            final File nested = new File(top , "nested");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,nested);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),328,nested.mkdirs());
            org.apache.commons.io.FileUtils.touch(new File(nested , "fle"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),329,top.list().length);
            org.apache.commons.io.FileUtils.cleanDirectory(top);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),330,top.list().length);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDeletesNested_literalMutation188() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeletesNested_literalMutation188");
            final File nested = new File(top , "nested");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,nested);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),328,nested.mkdirs());
            org.apache.commons.io.FileUtils.touch(new File(nested , "file"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),329,top.list().length);
            org.apache.commons.io.FileUtils.cleanDirectory(top);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),330,top.list().length);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDeletesNested_literalMutation189() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeletesNested_literalMutation189");
            final File nested = new File(top , "nested");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,nested);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),328,nested.mkdirs());
            org.apache.commons.io.FileUtils.touch(new File(nested , "fle"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),329,top.list().length);
            org.apache.commons.io.FileUtils.cleanDirectory(top);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),330,top.list().length);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDeletesNested_remove32() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeletesNested_remove32");
            final File nested = new File(top , "nested");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,nested);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),328,nested.mkdirs());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),329,top.list().length);
            org.apache.commons.io.FileUtils.cleanDirectory(top);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),330,top.list().length);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDeletesNested_remove33() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeletesNested_remove33");
            final File nested = new File(top , "nested");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,nested);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),328,nested.mkdirs());
            org.apache.commons.io.FileUtils.touch(new File(nested , "file"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),329,top.list().length);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),330,top.list().length);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testThrowsOnNullList_add77() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testThrowsOnNullList_add77");
            if ((java.lang.System.getProperty("os.name").startsWith("Win")) || (!(chmod(top, 0, false)))) {
                return ;
            } 
            try {
                org.apache.commons.io.FileUtils.cleanDirectory(top);
                org.apache.commons.io.FileUtils.cleanDirectory(top);
            } catch (IOException e) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),337,("Failed to list contents of " + (top.getAbsolutePath())));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),338,e.getMessage());
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testThrowsOnNullList() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testThrowsOnNullList");
            if ((java.lang.System.getProperty("osûname").startsWith("Win")) || (!(chmod(top, 0, false)))) {
                return ;
            } 
            try {
                org.apache.commons.io.FileUtils.cleanDirectory(top);
            } catch (IOException e) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),337,("Failed to list contents of " + (top.getAbsolutePath())));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),338,e.getMessage());
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testThrowsOnNullList_literalMutation212() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testThrowsOnNullList_literalMutation212");
            if ((java.lang.System.getProperty("os.name").startsWith("Win")) || (!(chmod(top, 0, false)))) {
                return ;
            } 
            try {
                org.apache.commons.io.FileUtils.cleanDirectory(top);
            } catch (IOException e) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),337,("Failed to list contents of " + (top.getAbsolutePath())));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),338,e.getMessage());
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testThrowsOnNullList_literalMutation213() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testThrowsOnNullList_literalMutation213");
            if ((java.lang.System.getProperty("os.nme").startsWith("Win")) || (!(chmod(top, 0, false)))) {
                return ;
            } 
            try {
                org.apache.commons.io.FileUtils.cleanDirectory(top);
            } catch (IOException e) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),337,("Failed to list contents of " + (top.getAbsolutePath())));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),338,e.getMessage());
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testThrowsOnNullList_literalMutation214() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testThrowsOnNullList_literalMutation214");
            if ((java.lang.System.getProperty("os.name").startsWith("Uin")) || (!(chmod(top, 0, false)))) {
                return ;
            } 
            try {
                org.apache.commons.io.FileUtils.cleanDirectory(top);
            } catch (IOException e) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),337,("Failed to list contents of " + (top.getAbsolutePath())));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),338,e.getMessage());
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testThrowsOnNullList_literalMutation215() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testThrowsOnNullList_literalMutation215");
            if ((java.lang.System.getProperty("os.name").startsWith("Win")) || (!(chmod(top, 0, false)))) {
                return ;
            } 
            try {
                org.apache.commons.io.FileUtils.cleanDirectory(top);
            } catch (IOException e) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),337,("Failed to list contents of " + (top.getAbsolutePath())));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),338,e.getMessage());
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testThrowsOnNullList_literalMutation216() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testThrowsOnNullList_literalMutation216");
            if ((java.lang.System.getProperty("os.name").startsWith("Wn")) || (!(chmod(top, 0, false)))) {
                return ;
            } 
            try {
                org.apache.commons.io.FileUtils.cleanDirectory(top);
            } catch (IOException e) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),337,("Failed to list contents of " + (top.getAbsolutePath())));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),338,e.getMessage());
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testThrowsOnNullList_literalMutation217() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testThrowsOnNullList_literalMutation217");
            if ((java.lang.System.getProperty("os.name").startsWith("Win")) || (!(chmod(top, 1, false)))) {
                return ;
            } 
            try {
                org.apache.commons.io.FileUtils.cleanDirectory(top);
            } catch (IOException e) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),337,("Failed to list contents of " + (top.getAbsolutePath())));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),338,e.getMessage());
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testThrowsOnNullList_literalMutation218() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testThrowsOnNullList_literalMutation218");
            if ((java.lang.System.getProperty("os.name").startsWith("Win")) || (!(chmod(top, -1, false)))) {
                return ;
            } 
            try {
                org.apache.commons.io.FileUtils.cleanDirectory(top);
            } catch (IOException e) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),337,("Failed to list contents of " + (top.getAbsolutePath())));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),338,e.getMessage());
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testThrowsOnNullList_literalMutation219() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testThrowsOnNullList_literalMutation219");
            if ((java.lang.System.getProperty("os.name").startsWith("Win")) || (!(chmod(top, 0, false)))) {
                return ;
            } 
            try {
                org.apache.commons.io.FileUtils.cleanDirectory(top);
            } catch (IOException e) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),337,("Failed to list contents of " + (top.getAbsolutePath())));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),338,e.getMessage());
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testThrowsOnNullList_literalMutation221() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testThrowsOnNullList_literalMutation221");
            if ((java.lang.System.getProperty("os.name").startsWith("Win")) || (!(chmod(top, 0, true)))) {
                return ;
            } 
            try {
                org.apache.commons.io.FileUtils.cleanDirectory(top);
            } catch (IOException e) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),337,("Failed to list contents of " + (top.getAbsolutePath())));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),338,e.getMessage());
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testThrowsOnCannotDeleteFile_add75() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testThrowsOnCannotDeleteFile_add75");
            final File file = new File(top , "restricted");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),336,file);
            org.apache.commons.io.FileUtils.touch(file);
            org.apache.commons.io.FileUtils.touch(file);
            if ((java.lang.System.getProperty("os.name").startsWith("Win")) || (!(chmod(top, 500, false)))) {
                return ;
            } 
            try {
                org.apache.commons.io.FileUtils.cleanDirectory(top);
            } catch (IOException e) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),334,("Unable to delete file: " + (file.getAbsolutePath())));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),335,e.getMessage());
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testThrowsOnCannotDeleteFile_add76() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testThrowsOnCannotDeleteFile_add76");
            final File file = new File(top , "restricted");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),336,file);
            org.apache.commons.io.FileUtils.touch(file);
            if ((java.lang.System.getProperty("os.name").startsWith("Win")) || (!(chmod(top, 500, false)))) {
                return ;
            } 
            try {
                org.apache.commons.io.FileUtils.cleanDirectory(top);
                org.apache.commons.io.FileUtils.cleanDirectory(top);
            } catch (IOException e) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),334,("Unable to delete file: " + (file.getAbsolutePath())));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),335,e.getMessage());
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testThrowsOnCannotDeleteFile() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testThrowsOnCannotDeleteFile");
            final File file = new File(top , "rextricted");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),336,file);
            org.apache.commons.io.FileUtils.touch(file);
            if ((java.lang.System.getProperty("os.name").startsWith("Win")) || (!(chmod(top, 500, false)))) {
                return ;
            } 
            try {
                org.apache.commons.io.FileUtils.cleanDirectory(top);
            } catch (IOException e) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),334,("Unable to delete file: " + (file.getAbsolutePath())));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),335,e.getMessage());
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testThrowsOnCannotDeleteFile_literalMutation197() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testThrowsOnCannotDeleteFile_literalMutation197");
            final File file = new File(top , "restrÈicted");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),336,file);
            org.apache.commons.io.FileUtils.touch(file);
            if ((java.lang.System.getProperty("os.name").startsWith("Win")) || (!(chmod(top, 500, false)))) {
                return ;
            } 
            try {
                org.apache.commons.io.FileUtils.cleanDirectory(top);
            } catch (IOException e) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),334,("Unable to delete file: " + (file.getAbsolutePath())));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),335,e.getMessage());
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testThrowsOnCannotDeleteFile_literalMutation198() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testThrowsOnCannotDeleteFile_literalMutation198");
            final File file = new File(top , "restriced");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),336,file);
            org.apache.commons.io.FileUtils.touch(file);
            if ((java.lang.System.getProperty("os.name").startsWith("Win")) || (!(chmod(top, 500, false)))) {
                return ;
            } 
            try {
                org.apache.commons.io.FileUtils.cleanDirectory(top);
            } catch (IOException e) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),334,("Unable to delete file: " + (file.getAbsolutePath())));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),335,e.getMessage());
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testThrowsOnCannotDeleteFile_literalMutation199() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testThrowsOnCannotDeleteFile_literalMutation199");
            final File file = new File(top , "restricted");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),336,file);
            org.apache.commons.io.FileUtils.touch(file);
            if ((java.lang.System.getProperty("o_.name").startsWith("Win")) || (!(chmod(top, 500, false)))) {
                return ;
            } 
            try {
                org.apache.commons.io.FileUtils.cleanDirectory(top);
            } catch (IOException e) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),334,("Unable to delete file: " + (file.getAbsolutePath())));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),335,e.getMessage());
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testThrowsOnCannotDeleteFile_literalMutation200() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testThrowsOnCannotDeleteFile_literalMutation200");
            final File file = new File(top , "restricted");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),336,file);
            org.apache.commons.io.FileUtils.touch(file);
            if ((java.lang.System.getProperty("osÍ.name").startsWith("Win")) || (!(chmod(top, 500, false)))) {
                return ;
            } 
            try {
                org.apache.commons.io.FileUtils.cleanDirectory(top);
            } catch (IOException e) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),334,("Unable to delete file: " + (file.getAbsolutePath())));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),335,e.getMessage());
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testThrowsOnCannotDeleteFile_literalMutation201() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testThrowsOnCannotDeleteFile_literalMutation201");
            final File file = new File(top , "restricted");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),336,file);
            org.apache.commons.io.FileUtils.touch(file);
            if ((java.lang.System.getProperty("os.nme").startsWith("Win")) || (!(chmod(top, 500, false)))) {
                return ;
            } 
            try {
                org.apache.commons.io.FileUtils.cleanDirectory(top);
            } catch (IOException e) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),334,("Unable to delete file: " + (file.getAbsolutePath())));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),335,e.getMessage());
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testThrowsOnCannotDeleteFile_literalMutation202() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testThrowsOnCannotDeleteFile_literalMutation202");
            final File file = new File(top , "restricted");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),336,file);
            org.apache.commons.io.FileUtils.touch(file);
            if ((java.lang.System.getProperty("os.name").startsWith("in")) || (!(chmod(top, 500, false)))) {
                return ;
            } 
            try {
                org.apache.commons.io.FileUtils.cleanDirectory(top);
            } catch (IOException e) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),334,("Unable to delete file: " + (file.getAbsolutePath())));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),335,e.getMessage());
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testThrowsOnCannotDeleteFile_literalMutation203() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testThrowsOnCannotDeleteFile_literalMutation203");
            final File file = new File(top , "restricted");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),336,file);
            org.apache.commons.io.FileUtils.touch(file);
            if ((java.lang.System.getProperty("os.name").startsWith("WÛin")) || (!(chmod(top, 500, false)))) {
                return ;
            } 
            try {
                org.apache.commons.io.FileUtils.cleanDirectory(top);
            } catch (IOException e) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),334,("Unable to delete file: " + (file.getAbsolutePath())));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),335,e.getMessage());
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testThrowsOnCannotDeleteFile_literalMutation204() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testThrowsOnCannotDeleteFile_literalMutation204");
            final File file = new File(top , "restricted");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),336,file);
            org.apache.commons.io.FileUtils.touch(file);
            if ((java.lang.System.getProperty("os.name").startsWith("Wn")) || (!(chmod(top, 500, false)))) {
                return ;
            } 
            try {
                org.apache.commons.io.FileUtils.cleanDirectory(top);
            } catch (IOException e) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),334,("Unable to delete file: " + (file.getAbsolutePath())));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),335,e.getMessage());
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testThrowsOnCannotDeleteFile_literalMutation205() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testThrowsOnCannotDeleteFile_literalMutation205");
            final File file = new File(top , "restricted");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),336,file);
            org.apache.commons.io.FileUtils.touch(file);
            if ((java.lang.System.getProperty("os.name").startsWith("Win")) || (!(chmod(top, 501, false)))) {
                return ;
            } 
            try {
                org.apache.commons.io.FileUtils.cleanDirectory(top);
            } catch (IOException e) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),334,("Unable to delete file: " + (file.getAbsolutePath())));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),335,e.getMessage());
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testThrowsOnCannotDeleteFile_literalMutation206() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testThrowsOnCannotDeleteFile_literalMutation206");
            final File file = new File(top , "restricted");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),336,file);
            org.apache.commons.io.FileUtils.touch(file);
            if ((java.lang.System.getProperty("os.name").startsWith("Win")) || (!(chmod(top, 499, false)))) {
                return ;
            } 
            try {
                org.apache.commons.io.FileUtils.cleanDirectory(top);
            } catch (IOException e) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),334,("Unable to delete file: " + (file.getAbsolutePath())));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),335,e.getMessage());
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testThrowsOnCannotDeleteFile_literalMutation207() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testThrowsOnCannotDeleteFile_literalMutation207");
            final File file = new File(top , "restricted");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),336,file);
            org.apache.commons.io.FileUtils.touch(file);
            if ((java.lang.System.getProperty("os.name").startsWith("Win")) || (!(chmod(top, 250, false)))) {
                return ;
            } 
            try {
                org.apache.commons.io.FileUtils.cleanDirectory(top);
            } catch (IOException e) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),334,("Unable to delete file: " + (file.getAbsolutePath())));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),335,e.getMessage());
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testThrowsOnCannotDeleteFile_literalMutation208() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testThrowsOnCannotDeleteFile_literalMutation208");
            final File file = new File(top , "restricted");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),336,file);
            org.apache.commons.io.FileUtils.touch(file);
            if ((java.lang.System.getProperty("os.name").startsWith("Win")) || (!(chmod(top, 1000, false)))) {
                return ;
            } 
            try {
                org.apache.commons.io.FileUtils.cleanDirectory(top);
            } catch (IOException e) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),334,("Unable to delete file: " + (file.getAbsolutePath())));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),335,e.getMessage());
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testThrowsOnCannotDeleteFile_literalMutation210() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testThrowsOnCannotDeleteFile_literalMutation210");
            final File file = new File(top , "restricted");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),336,file);
            org.apache.commons.io.FileUtils.touch(file);
            if ((java.lang.System.getProperty("os.name").startsWith("Win")) || (!(chmod(top, 500, true)))) {
                return ;
            } 
            try {
                org.apache.commons.io.FileUtils.cleanDirectory(top);
            } catch (IOException e) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),334,("Unable to delete file: " + (file.getAbsolutePath())));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),335,e.getMessage());
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testThrowsOnCannotDeleteFile_remove37() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testThrowsOnCannotDeleteFile_remove37");
            final File file = new File(top , "restricted");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),336,file);
            if ((java.lang.System.getProperty("os.name").startsWith("Win")) || (!(chmod(top, 500, false)))) {
                return ;
            } 
            try {
                org.apache.commons.io.FileUtils.cleanDirectory(top);
            } catch (IOException e) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),334,("Unable to delete file: " + (file.getAbsolutePath())));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),335,e.getMessage());
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    private boolean chmod(File file, int mode, boolean recurse) throws InterruptedException {
        List<java.lang.String> args = new ArrayList<java.lang.String>();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),324,args);
        args.add("chmod");
        if (recurse) {
            args.add("-R");
        } 
        args.add(java.lang.Integer.toString(mode));
        args.add(file.getAbsolutePath());
        Process proc;
        try {
            proc = java.lang.Runtime.getRuntime().exec(args.toArray(new String[args.size()]));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),323,proc);
        } catch (IOException e) {
            return false;
        }
        int result = proc.waitFor();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),325,result);
        return result == 0;
    }
}

