package org.apache.commons.io;

import java.util.ArrayList;
import java.util.Collection;
import java.io.File;
import org.apache.commons.io.testtools.FileBasedTestCase;
import org.apache.commons.io.filefilter.IOFileFilter;
import java.util.Iterator;
import org.junit.Test;

/** 
 * Test cases for FileUtils.listFiles() methods.
 */
public class FileUtilsListFilesTestCase extends FileBasedTestCase {
    public FileUtilsListFilesTestCase(String name) {
        super(name);
    }

    private File getLocalTestDirectory() {
        return new File(FileBasedTestCase.getTestDirectory() , "list-files");
    }

    /** 
     * @see junit.framework.TestCase#setUp()
     */
@Override
    protected void setUp() throws Exception {
        File dir = getLocalTestDirectory();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),109,dir);
        if (dir.exists()) {
            org.apache.commons.io.FileUtils.deleteDirectory(dir);
        } 
        dir.mkdirs();
        File file = new File(dir , "dummy-build.xml");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),475,file);
        org.apache.commons.io.FileUtils.touch(file);
        file = new File(dir , "README");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),464,file);
        org.apache.commons.io.FileUtils.touch(file);
        dir = new File(dir , "subdir1");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),465,dir);
        dir.mkdirs();
        file = new File(dir , "dummy-build.xml");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),466,file);
        org.apache.commons.io.FileUtils.touch(file);
        file = new File(dir , "dummy-readme.txt");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),467,file);
        org.apache.commons.io.FileUtils.touch(file);
        dir = new File(dir , "subsubdir1");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),468,dir);
        dir.mkdirs();
        file = new File(dir , "dummy-file.txt");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),469,file);
        org.apache.commons.io.FileUtils.touch(file);
        file = new File(dir , "dummy-index.html");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),470,file);
        org.apache.commons.io.FileUtils.touch(file);
        dir = dir.getParentFile();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),471,dir);
        dir = new File(dir , "CVS");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),472,dir);
        dir.mkdirs();
        file = new File(dir , "Entries");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),473,file);
        org.apache.commons.io.FileUtils.touch(file);
        file = new File(dir , "Repository");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),474,file);
        org.apache.commons.io.FileUtils.touch(file);
    }

    /** 
     * @see junit.framework.TestCase#tearDown()
     */
@Override
    protected void tearDown() throws Exception {
        File dir = getLocalTestDirectory();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),476,dir);
        org.apache.commons.io.FileUtils.deleteDirectory(dir);
    }

    private Collection<java.lang.String> filesToFilenames(Collection<java.io.File> files) {
        Collection<java.lang.String> filenames = new ArrayList<java.lang.String>(files.size());
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),462,filenames);
        for (File file : files) {
            filenames.add(file.getName());
        }
        return filenames;
    }

    private Collection<java.lang.String> filesToFilenames(Iterator<java.io.File> files) {
        Collection<java.lang.String> filenames = new ArrayList<java.lang.String>();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),463,filenames);
        while (files.hasNext()) {
            filenames.add(files.next().getName());
        }
        return filenames;
    }

    public void testIterateFilesByExtension() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIterateFilesByExtension");
            String[] extensions = new String[]{ "Bml" , "txt" };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,extensions);
            Iterator<java.io.File> files = org.apache.commons.io.FileUtils.iterateFiles(getLocalTestDirectory(), extensions, false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,files);
            Collection<java.lang.String> filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),477,filenames.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),478,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),479,filenames.contains("README"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),480,filenames.contains("dummy-file.txt"));
            files = org.apache.commons.io.FileUtils.iterateFiles(getLocalTestDirectory(), extensions, true);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),481,filenames.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),482,filenames.contains("dummy-file.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),483,filenames.contains("dummy-index.html"));
            files = org.apache.commons.io.FileUtils.iterateFiles(getLocalTestDirectory(), null, false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,filenames.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,filenames.contains("README"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,filenames.contains("dummy-file.txt"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testIterateFilesByExtension_literalMutation404() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIterateFilesByExtension_literalMutation404");
            String[] extensions = new String[]{ "xÍml" , "txt" };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,extensions);
            Iterator<java.io.File> files = org.apache.commons.io.FileUtils.iterateFiles(getLocalTestDirectory(), extensions, false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,files);
            Collection<java.lang.String> filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),477,filenames.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),478,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),479,filenames.contains("README"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),480,filenames.contains("dummy-file.txt"));
            files = org.apache.commons.io.FileUtils.iterateFiles(getLocalTestDirectory(), extensions, true);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),481,filenames.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),482,filenames.contains("dummy-file.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),483,filenames.contains("dummy-index.html"));
            files = org.apache.commons.io.FileUtils.iterateFiles(getLocalTestDirectory(), null, false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,filenames.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,filenames.contains("README"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,filenames.contains("dummy-file.txt"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testIterateFilesByExtension_literalMutation405() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIterateFilesByExtension_literalMutation405");
            String[] extensions = new String[]{ "xl" , "txt" };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,extensions);
            Iterator<java.io.File> files = org.apache.commons.io.FileUtils.iterateFiles(getLocalTestDirectory(), extensions, false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,files);
            Collection<java.lang.String> filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),477,filenames.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),478,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),479,filenames.contains("README"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),480,filenames.contains("dummy-file.txt"));
            files = org.apache.commons.io.FileUtils.iterateFiles(getLocalTestDirectory(), extensions, true);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),481,filenames.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),482,filenames.contains("dummy-file.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),483,filenames.contains("dummy-index.html"));
            files = org.apache.commons.io.FileUtils.iterateFiles(getLocalTestDirectory(), null, false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,filenames.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,filenames.contains("README"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,filenames.contains("dummy-file.txt"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testIterateFilesByExtension_literalMutation406() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIterateFilesByExtension_literalMutation406");
            String[] extensions = new String[]{ "xml" , "Hxt" };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,extensions);
            Iterator<java.io.File> files = org.apache.commons.io.FileUtils.iterateFiles(getLocalTestDirectory(), extensions, false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,files);
            Collection<java.lang.String> filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),477,filenames.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),478,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),479,filenames.contains("README"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),480,filenames.contains("dummy-file.txt"));
            files = org.apache.commons.io.FileUtils.iterateFiles(getLocalTestDirectory(), extensions, true);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),481,filenames.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),482,filenames.contains("dummy-file.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),483,filenames.contains("dummy-index.html"));
            files = org.apache.commons.io.FileUtils.iterateFiles(getLocalTestDirectory(), null, false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,filenames.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,filenames.contains("README"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,filenames.contains("dummy-file.txt"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testIterateFilesByExtension_literalMutation407() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIterateFilesByExtension_literalMutation407");
            String[] extensions = new String[]{ "xml" , "t¨xt" };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,extensions);
            Iterator<java.io.File> files = org.apache.commons.io.FileUtils.iterateFiles(getLocalTestDirectory(), extensions, false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,files);
            Collection<java.lang.String> filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),477,filenames.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),478,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),479,filenames.contains("README"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),480,filenames.contains("dummy-file.txt"));
            files = org.apache.commons.io.FileUtils.iterateFiles(getLocalTestDirectory(), extensions, true);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),481,filenames.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),482,filenames.contains("dummy-file.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),483,filenames.contains("dummy-index.html"));
            files = org.apache.commons.io.FileUtils.iterateFiles(getLocalTestDirectory(), null, false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,filenames.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,filenames.contains("README"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,filenames.contains("dummy-file.txt"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testIterateFilesByExtension_literalMutation408() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIterateFilesByExtension_literalMutation408");
            String[] extensions = new String[]{ "xml" , "tt" };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,extensions);
            Iterator<java.io.File> files = org.apache.commons.io.FileUtils.iterateFiles(getLocalTestDirectory(), extensions, false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,files);
            Collection<java.lang.String> filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),477,filenames.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),478,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),479,filenames.contains("README"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),480,filenames.contains("dummy-file.txt"));
            files = org.apache.commons.io.FileUtils.iterateFiles(getLocalTestDirectory(), extensions, true);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),481,filenames.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),482,filenames.contains("dummy-file.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),483,filenames.contains("dummy-index.html"));
            files = org.apache.commons.io.FileUtils.iterateFiles(getLocalTestDirectory(), null, false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,filenames.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,filenames.contains("README"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,filenames.contains("dummy-file.txt"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testIterateFilesByExtension_literalMutation409() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIterateFilesByExtension_literalMutation409");
            String[] extensions = new String[]{ "xml" , "txt" };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,extensions);
            Iterator<java.io.File> files = org.apache.commons.io.FileUtils.iterateFiles(getLocalTestDirectory(), extensions, true);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,files);
            Collection<java.lang.String> filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),477,filenames.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),478,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),479,filenames.contains("README"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),480,filenames.contains("dummy-file.txt"));
            files = org.apache.commons.io.FileUtils.iterateFiles(getLocalTestDirectory(), extensions, true);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),481,filenames.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),482,filenames.contains("dummy-file.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),483,filenames.contains("dummy-index.html"));
            files = org.apache.commons.io.FileUtils.iterateFiles(getLocalTestDirectory(), null, false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,filenames.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,filenames.contains("README"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,filenames.contains("dummy-file.txt"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testIterateFilesByExtension_literalMutation412() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIterateFilesByExtension_literalMutation412");
            String[] extensions = new String[]{ "xml" , "txt" };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,extensions);
            Iterator<java.io.File> files = org.apache.commons.io.FileUtils.iterateFiles(getLocalTestDirectory(), extensions, false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,files);
            Collection<java.lang.String> filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),477,filenames.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),478,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),479,filenames.contains("README"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),480,filenames.contains("dummy-file.txt"));
            files = org.apache.commons.io.FileUtils.iterateFiles(getLocalTestDirectory(), extensions, true);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),481,filenames.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),482,filenames.contains("dummy-file.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),483,filenames.contains("dummy-index.html"));
            files = org.apache.commons.io.FileUtils.iterateFiles(getLocalTestDirectory(), null, true);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,filenames.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,filenames.contains("README"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,filenames.contains("dummy-file.txt"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testListFilesByExtension() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testListFilesByExtension");
            String[] extensions = new String[]{ "Uml" , "txt" };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,extensions);
            Collection<java.io.File> files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), extensions, false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),511,files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,files.size());
            Collection<java.lang.String> filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),512,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,filenames.contains("README"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,filenames.contains("dummy-file.txt"));
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), extensions, true);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,filenames.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,filenames.contains("dummy-file.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,filenames.contains("dummy-index.html"));
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), null, false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,files.size());
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,filenames.contains("README"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,filenames.contains("dummy-file.txt"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testListFilesByExtension_literalMutation424() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testListFilesByExtension_literalMutation424");
            String[] extensions = new String[]{ "x\'ml" , "txt" };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,extensions);
            Collection<java.io.File> files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), extensions, false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),511,files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,files.size());
            Collection<java.lang.String> filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),512,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,filenames.contains("README"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,filenames.contains("dummy-file.txt"));
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), extensions, true);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,filenames.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,filenames.contains("dummy-file.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,filenames.contains("dummy-index.html"));
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), null, false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,files.size());
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,filenames.contains("README"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,filenames.contains("dummy-file.txt"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testListFilesByExtension_literalMutation425() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testListFilesByExtension_literalMutation425");
            String[] extensions = new String[]{ "xl" , "txt" };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,extensions);
            Collection<java.io.File> files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), extensions, false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),511,files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,files.size());
            Collection<java.lang.String> filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),512,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,filenames.contains("README"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,filenames.contains("dummy-file.txt"));
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), extensions, true);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,filenames.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,filenames.contains("dummy-file.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,filenames.contains("dummy-index.html"));
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), null, false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,files.size());
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,filenames.contains("README"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,filenames.contains("dummy-file.txt"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testListFilesByExtension_literalMutation426() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testListFilesByExtension_literalMutation426");
            String[] extensions = new String[]{ "xml" , ";xt" };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,extensions);
            Collection<java.io.File> files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), extensions, false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),511,files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,files.size());
            Collection<java.lang.String> filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),512,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,filenames.contains("README"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,filenames.contains("dummy-file.txt"));
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), extensions, true);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,filenames.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,filenames.contains("dummy-file.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,filenames.contains("dummy-index.html"));
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), null, false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,files.size());
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,filenames.contains("README"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,filenames.contains("dummy-file.txt"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testListFilesByExtension_literalMutation427() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testListFilesByExtension_literalMutation427");
            String[] extensions = new String[]{ "xml" , "tÑxt" };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,extensions);
            Collection<java.io.File> files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), extensions, false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),511,files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,files.size());
            Collection<java.lang.String> filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),512,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,filenames.contains("README"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,filenames.contains("dummy-file.txt"));
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), extensions, true);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,filenames.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,filenames.contains("dummy-file.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,filenames.contains("dummy-index.html"));
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), null, false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,files.size());
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,filenames.contains("README"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,filenames.contains("dummy-file.txt"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testListFilesByExtension_literalMutation428() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testListFilesByExtension_literalMutation428");
            String[] extensions = new String[]{ "xml" , "tt" };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,extensions);
            Collection<java.io.File> files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), extensions, false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),511,files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,files.size());
            Collection<java.lang.String> filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),512,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,filenames.contains("README"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,filenames.contains("dummy-file.txt"));
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), extensions, true);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,filenames.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,filenames.contains("dummy-file.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,filenames.contains("dummy-index.html"));
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), null, false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,files.size());
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,filenames.contains("README"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,filenames.contains("dummy-file.txt"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testListFilesByExtension_literalMutation429() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testListFilesByExtension_literalMutation429");
            String[] extensions = new String[]{ "xml" , "txt" };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,extensions);
            Collection<java.io.File> files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), extensions, true);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),511,files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,files.size());
            Collection<java.lang.String> filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),512,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,filenames.contains("README"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,filenames.contains("dummy-file.txt"));
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), extensions, true);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,filenames.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,filenames.contains("dummy-file.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,filenames.contains("dummy-index.html"));
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), null, false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,files.size());
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,filenames.contains("README"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,filenames.contains("dummy-file.txt"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testListFilesByExtension_literalMutation432() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testListFilesByExtension_literalMutation432");
            String[] extensions = new String[]{ "xml" , "txt" };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,extensions);
            Collection<java.io.File> files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), extensions, false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),511,files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,files.size());
            Collection<java.lang.String> filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),512,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,filenames.contains("README"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,filenames.contains("dummy-file.txt"));
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), extensions, true);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,filenames.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,filenames.contains("dummy-file.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,filenames.contains("dummy-index.html"));
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), null, true);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,files.size());
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,filenames.contains("README"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,filenames.contains("dummy-file.txt"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testListFiles_add106() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testListFiles_add106");
            Collection<java.io.File> files;
            Collection<java.lang.String> filenames;
            IOFileFilter fileFilter;
            IOFileFilter dirFilter;
            fileFilter = org.apache.commons.io.filefilter.FileFilterUtils.trueFileFilter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),525,fileFilter);
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), fileFilter, ((IOFileFilter)(null)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),526,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),527,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),513,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),514,filenames.contains("dummy-index.html"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),515,filenames.contains("Entries"));
            fileFilter = org.apache.commons.io.filefilter.FileFilterUtils.trueFileFilter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),528,fileFilter);
            dirFilter = org.apache.commons.io.filefilter.FileFilterUtils.notFileFilter(org.apache.commons.io.filefilter.FileFilterUtils.nameFileFilter("CVS"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),529,dirFilter);
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), fileFilter, dirFilter);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),530,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),531,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),516,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),517,filenames.contains("dummy-index.html"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),518,filenames.contains("Entries"));
            fileFilter = org.apache.commons.io.filefilter.FileFilterUtils.trueFileFilter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),532,fileFilter);
            dirFilter = org.apache.commons.io.filefilter.FileFilterUtils.makeCVSAware(null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),533,dirFilter);
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), fileFilter, dirFilter);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),534,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),535,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),519,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),520,filenames.contains("dummy-index.html"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),521,filenames.contains("Entries"));
            fileFilter = org.apache.commons.io.filefilter.FileFilterUtils.trueFileFilter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),536,fileFilter);
            dirFilter = org.apache.commons.io.filefilter.FileFilterUtils.prefixFileFilter("sub");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),537,dirFilter);
            dirFilter = org.apache.commons.io.filefilter.FileFilterUtils.makeCVSAware(dirFilter);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),538,dirFilter);
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), fileFilter, dirFilter);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),539,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),540,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),522,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),523,filenames.contains("dummy-index.html"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),524,filenames.contains("Entries"));
            try {
                org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), ((IOFileFilter)(null)), ((IOFileFilter)(null)));
                org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), ((IOFileFilter)(null)), ((IOFileFilter)(null)));
            } catch (NullPointerException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testListFiles() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testListFiles");
            Collection<java.io.File> files;
            Collection<java.lang.String> filenames;
            IOFileFilter fileFilter;
            IOFileFilter dirFilter;
            fileFilter = org.apache.commons.io.filefilter.FileFilterUtils.trueFileFilter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),525,fileFilter);
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), fileFilter, ((IOFileFilter)(null)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),526,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),527,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),513,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),514,filenames.contains("dummy-index.html"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),515,filenames.contains("Entries"));
            fileFilter = org.apache.commons.io.filefilter.FileFilterUtils.trueFileFilter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),528,fileFilter);
            dirFilter = org.apache.commons.io.filefilter.FileFilterUtils.notFileFilter(org.apache.commons.io.filefilter.FileFilterUtils.nameFileFilter("pVS"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),529,dirFilter);
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), fileFilter, dirFilter);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),530,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),531,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),516,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),517,filenames.contains("dummy-index.html"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),518,filenames.contains("Entries"));
            fileFilter = org.apache.commons.io.filefilter.FileFilterUtils.trueFileFilter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),532,fileFilter);
            dirFilter = org.apache.commons.io.filefilter.FileFilterUtils.makeCVSAware(null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),533,dirFilter);
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), fileFilter, dirFilter);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),534,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),535,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),519,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),520,filenames.contains("dummy-index.html"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),521,filenames.contains("Entries"));
            fileFilter = org.apache.commons.io.filefilter.FileFilterUtils.trueFileFilter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),536,fileFilter);
            dirFilter = org.apache.commons.io.filefilter.FileFilterUtils.prefixFileFilter("sub");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),537,dirFilter);
            dirFilter = org.apache.commons.io.filefilter.FileFilterUtils.makeCVSAware(dirFilter);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),538,dirFilter);
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), fileFilter, dirFilter);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),539,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),540,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),522,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),523,filenames.contains("dummy-index.html"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),524,filenames.contains("Entries"));
            try {
                org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), ((IOFileFilter)(null)), ((IOFileFilter)(null)));
            } catch (NullPointerException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testListFiles_literalMutation415() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testListFiles_literalMutation415");
            Collection<java.io.File> files;
            Collection<java.lang.String> filenames;
            IOFileFilter fileFilter;
            IOFileFilter dirFilter;
            fileFilter = org.apache.commons.io.filefilter.FileFilterUtils.trueFileFilter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),525,fileFilter);
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), fileFilter, ((IOFileFilter)(null)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),526,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),527,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),513,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),514,filenames.contains("dummy-index.html"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),515,filenames.contains("Entries"));
            fileFilter = org.apache.commons.io.filefilter.FileFilterUtils.trueFileFilter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),528,fileFilter);
            dirFilter = org.apache.commons.io.filefilter.FileFilterUtils.notFileFilter(org.apache.commons.io.filefilter.FileFilterUtils.nameFileFilter("CõVS"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),529,dirFilter);
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), fileFilter, dirFilter);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),530,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),531,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),516,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),517,filenames.contains("dummy-index.html"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),518,filenames.contains("Entries"));
            fileFilter = org.apache.commons.io.filefilter.FileFilterUtils.trueFileFilter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),532,fileFilter);
            dirFilter = org.apache.commons.io.filefilter.FileFilterUtils.makeCVSAware(null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),533,dirFilter);
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), fileFilter, dirFilter);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),534,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),535,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),519,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),520,filenames.contains("dummy-index.html"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),521,filenames.contains("Entries"));
            fileFilter = org.apache.commons.io.filefilter.FileFilterUtils.trueFileFilter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),536,fileFilter);
            dirFilter = org.apache.commons.io.filefilter.FileFilterUtils.prefixFileFilter("sub");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),537,dirFilter);
            dirFilter = org.apache.commons.io.filefilter.FileFilterUtils.makeCVSAware(dirFilter);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),538,dirFilter);
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), fileFilter, dirFilter);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),539,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),540,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),522,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),523,filenames.contains("dummy-index.html"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),524,filenames.contains("Entries"));
            try {
                org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), ((IOFileFilter)(null)), ((IOFileFilter)(null)));
            } catch (NullPointerException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testListFiles_literalMutation416() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testListFiles_literalMutation416");
            Collection<java.io.File> files;
            Collection<java.lang.String> filenames;
            IOFileFilter fileFilter;
            IOFileFilter dirFilter;
            fileFilter = org.apache.commons.io.filefilter.FileFilterUtils.trueFileFilter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),525,fileFilter);
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), fileFilter, ((IOFileFilter)(null)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),526,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),527,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),513,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),514,filenames.contains("dummy-index.html"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),515,filenames.contains("Entries"));
            fileFilter = org.apache.commons.io.filefilter.FileFilterUtils.trueFileFilter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),528,fileFilter);
            dirFilter = org.apache.commons.io.filefilter.FileFilterUtils.notFileFilter(org.apache.commons.io.filefilter.FileFilterUtils.nameFileFilter("CS"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),529,dirFilter);
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), fileFilter, dirFilter);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),530,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),531,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),516,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),517,filenames.contains("dummy-index.html"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),518,filenames.contains("Entries"));
            fileFilter = org.apache.commons.io.filefilter.FileFilterUtils.trueFileFilter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),532,fileFilter);
            dirFilter = org.apache.commons.io.filefilter.FileFilterUtils.makeCVSAware(null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),533,dirFilter);
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), fileFilter, dirFilter);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),534,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),535,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),519,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),520,filenames.contains("dummy-index.html"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),521,filenames.contains("Entries"));
            fileFilter = org.apache.commons.io.filefilter.FileFilterUtils.trueFileFilter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),536,fileFilter);
            dirFilter = org.apache.commons.io.filefilter.FileFilterUtils.prefixFileFilter("sub");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),537,dirFilter);
            dirFilter = org.apache.commons.io.filefilter.FileFilterUtils.makeCVSAware(dirFilter);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),538,dirFilter);
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), fileFilter, dirFilter);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),539,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),540,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),522,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),523,filenames.contains("dummy-index.html"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),524,filenames.contains("Entries"));
            try {
                org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), ((IOFileFilter)(null)), ((IOFileFilter)(null)));
            } catch (NullPointerException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testListFiles_literalMutation418() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testListFiles_literalMutation418");
            Collection<java.io.File> files;
            Collection<java.lang.String> filenames;
            IOFileFilter fileFilter;
            IOFileFilter dirFilter;
            fileFilter = org.apache.commons.io.filefilter.FileFilterUtils.trueFileFilter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),525,fileFilter);
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), fileFilter, ((IOFileFilter)(null)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),526,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),527,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),513,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),514,filenames.contains("dummy-index.html"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),515,filenames.contains("Entries"));
            fileFilter = org.apache.commons.io.filefilter.FileFilterUtils.trueFileFilter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),528,fileFilter);
            dirFilter = org.apache.commons.io.filefilter.FileFilterUtils.notFileFilter(org.apache.commons.io.filefilter.FileFilterUtils.nameFileFilter("CVS"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),529,dirFilter);
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), fileFilter, dirFilter);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),530,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),531,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),516,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),517,filenames.contains("dummy-index.html"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),518,filenames.contains("Entries"));
            fileFilter = org.apache.commons.io.filefilter.FileFilterUtils.trueFileFilter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),532,fileFilter);
            dirFilter = org.apache.commons.io.filefilter.FileFilterUtils.makeCVSAware(null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),533,dirFilter);
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), fileFilter, dirFilter);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),534,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),535,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),519,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),520,filenames.contains("dummy-index.html"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),521,filenames.contains("Entries"));
            fileFilter = org.apache.commons.io.filefilter.FileFilterUtils.trueFileFilter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),536,fileFilter);
            dirFilter = org.apache.commons.io.filefilter.FileFilterUtils.prefixFileFilter("Öub");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),537,dirFilter);
            dirFilter = org.apache.commons.io.filefilter.FileFilterUtils.makeCVSAware(dirFilter);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),538,dirFilter);
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), fileFilter, dirFilter);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),539,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),540,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),522,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),523,filenames.contains("dummy-index.html"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),524,filenames.contains("Entries"));
            try {
                org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), ((IOFileFilter)(null)), ((IOFileFilter)(null)));
            } catch (NullPointerException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testListFiles_literalMutation419() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testListFiles_literalMutation419");
            Collection<java.io.File> files;
            Collection<java.lang.String> filenames;
            IOFileFilter fileFilter;
            IOFileFilter dirFilter;
            fileFilter = org.apache.commons.io.filefilter.FileFilterUtils.trueFileFilter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),525,fileFilter);
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), fileFilter, ((IOFileFilter)(null)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),526,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),527,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),513,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),514,filenames.contains("dummy-index.html"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),515,filenames.contains("Entries"));
            fileFilter = org.apache.commons.io.filefilter.FileFilterUtils.trueFileFilter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),528,fileFilter);
            dirFilter = org.apache.commons.io.filefilter.FileFilterUtils.notFileFilter(org.apache.commons.io.filefilter.FileFilterUtils.nameFileFilter("CVS"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),529,dirFilter);
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), fileFilter, dirFilter);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),530,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),531,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),516,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),517,filenames.contains("dummy-index.html"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),518,filenames.contains("Entries"));
            fileFilter = org.apache.commons.io.filefilter.FileFilterUtils.trueFileFilter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),532,fileFilter);
            dirFilter = org.apache.commons.io.filefilter.FileFilterUtils.makeCVSAware(null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),533,dirFilter);
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), fileFilter, dirFilter);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),534,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),535,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),519,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),520,filenames.contains("dummy-index.html"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),521,filenames.contains("Entries"));
            fileFilter = org.apache.commons.io.filefilter.FileFilterUtils.trueFileFilter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),536,fileFilter);
            dirFilter = org.apache.commons.io.filefilter.FileFilterUtils.prefixFileFilter("sub");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),537,dirFilter);
            dirFilter = org.apache.commons.io.filefilter.FileFilterUtils.makeCVSAware(dirFilter);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),538,dirFilter);
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), fileFilter, dirFilter);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),539,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),540,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),522,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),523,filenames.contains("dummy-index.html"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),524,filenames.contains("Entries"));
            try {
                org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), ((IOFileFilter)(null)), ((IOFileFilter)(null)));
            } catch (NullPointerException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testListFiles_literalMutation420() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testListFiles_literalMutation420");
            Collection<java.io.File> files;
            Collection<java.lang.String> filenames;
            IOFileFilter fileFilter;
            IOFileFilter dirFilter;
            fileFilter = org.apache.commons.io.filefilter.FileFilterUtils.trueFileFilter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),525,fileFilter);
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), fileFilter, ((IOFileFilter)(null)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),526,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),527,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),513,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),514,filenames.contains("dummy-index.html"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),515,filenames.contains("Entries"));
            fileFilter = org.apache.commons.io.filefilter.FileFilterUtils.trueFileFilter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),528,fileFilter);
            dirFilter = org.apache.commons.io.filefilter.FileFilterUtils.notFileFilter(org.apache.commons.io.filefilter.FileFilterUtils.nameFileFilter("CVS"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),529,dirFilter);
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), fileFilter, dirFilter);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),530,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),531,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),516,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),517,filenames.contains("dummy-index.html"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),518,filenames.contains("Entries"));
            fileFilter = org.apache.commons.io.filefilter.FileFilterUtils.trueFileFilter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),532,fileFilter);
            dirFilter = org.apache.commons.io.filefilter.FileFilterUtils.makeCVSAware(null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),533,dirFilter);
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), fileFilter, dirFilter);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),534,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),535,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),519,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),520,filenames.contains("dummy-index.html"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),521,filenames.contains("Entries"));
            fileFilter = org.apache.commons.io.filefilter.FileFilterUtils.trueFileFilter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),536,fileFilter);
            dirFilter = org.apache.commons.io.filefilter.FileFilterUtils.prefixFileFilter("sb");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),537,dirFilter);
            dirFilter = org.apache.commons.io.filefilter.FileFilterUtils.makeCVSAware(dirFilter);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),538,dirFilter);
            files = org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), fileFilter, dirFilter);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),539,files);
            filenames = filesToFilenames(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),540,filenames);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),522,filenames.contains("dummy-build.xml"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),523,filenames.contains("dummy-index.html"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),524,filenames.contains("Entries"));
            try {
                org.apache.commons.io.FileUtils.listFiles(getLocalTestDirectory(), ((IOFileFilter)(null)), ((IOFileFilter)(null)));
            } catch (NullPointerException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }
}

