package org.apache.commons.io.comparator;

import java.util.Comparator;
import java.io.File;

/** 
 * Test case for {@link ExtensionFileComparator}.
 */
public class ExtensionFileComparatorTest extends ComparatorAbstractTestCase {
    /** 
     * Construct a new test case with the specified name.
     * 
     * @param name Name of the test
     */
public ExtensionFileComparatorTest(String name) {
        super(name);
    }

    /** 
     * @see junit.framework.TestCase#setUp()
     */
@Override
    protected void setUp() throws Exception {
        super.setUp();
        comparator = ((AbstractFileComparator)(ExtensionFileComparator.EXTENSION_COMPARATOR));
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),87,comparator);
        reverse = ExtensionFileComparator.EXTENSION_REVERSE;
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),88,reverse);
        equalFile1 = new File("abc.foo");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),82,equalFile1);
        equalFile2 = new File("def.foo");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),83,equalFile2);
        lessFile = new File("abc.abc");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),84,lessFile);
        moreFile = new File("abc.xyz");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),85,moreFile);
    }

    /** 
     * Test case sensitivity
     */
public void testCaseSensitivity_literalMutation100() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCaseSensitivity_literalMutation100");
            File file3 = new File("aùbc.FOO");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),96,file3);
            Comparator<java.io.File> sensitive = new ExtensionFileComparator(null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),97,sensitive);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),89,((sensitive.compare(equalFile1, equalFile2)) == 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),90,((sensitive.compare(equalFile1, file3)) > 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),91,((sensitive.compare(equalFile1, lessFile)) > 0));
            Comparator<java.io.File> insensitive = ExtensionFileComparator.EXTENSION_INSENSITIVE_COMPARATOR;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),98,insensitive);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),92,((insensitive.compare(equalFile1, equalFile2)) == 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),93,((insensitive.compare(equalFile1, file3)) == 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),94,((insensitive.compare(equalFile1, lessFile)) > 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),95,((insensitive.compare(file3, lessFile)) > 0));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test case sensitivity
     */
public void testCaseSensitivity_literalMutation101() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCaseSensitivity_literalMutation101");
            File file3 = new File("abcFOO");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),96,file3);
            Comparator<java.io.File> sensitive = new ExtensionFileComparator(null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),97,sensitive);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),89,((sensitive.compare(equalFile1, equalFile2)) == 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),90,((sensitive.compare(equalFile1, file3)) > 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),91,((sensitive.compare(equalFile1, lessFile)) > 0));
            Comparator<java.io.File> insensitive = ExtensionFileComparator.EXTENSION_INSENSITIVE_COMPARATOR;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),98,insensitive);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),92,((insensitive.compare(equalFile1, equalFile2)) == 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),93,((insensitive.compare(equalFile1, file3)) == 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),94,((insensitive.compare(equalFile1, lessFile)) > 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),95,((insensitive.compare(file3, lessFile)) > 0));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test case sensitivity
     */
public void testCaseSensitivity() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCaseSensitivity");
            File file3 = new File("Sbc.FOO");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),96,file3);
            Comparator<java.io.File> sensitive = new ExtensionFileComparator(null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),97,sensitive);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),89,((sensitive.compare(equalFile1, equalFile2)) == 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),90,((sensitive.compare(equalFile1, file3)) > 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),91,((sensitive.compare(equalFile1, lessFile)) > 0));
            Comparator<java.io.File> insensitive = ExtensionFileComparator.EXTENSION_INSENSITIVE_COMPARATOR;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),98,insensitive);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),92,((insensitive.compare(equalFile1, equalFile2)) == 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),93,((insensitive.compare(equalFile1, file3)) == 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),94,((insensitive.compare(equalFile1, lessFile)) > 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),95,((insensitive.compare(file3, lessFile)) > 0));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }
}

