package org.apache.commons.io.comparator;

import java.util.Comparator;
import java.io.File;

/** 
 * Test case for {@link SizeFileComparator}.
 */
public class SizeFileComparatorTest extends ComparatorAbstractTestCase {
    private File smallerDir;

    private File largerDir;

    private File smallerFile;

    private File largerFile;

    /** 
     * Construct a new test case with the specified name.
     * 
     * @param name Name of the test
     */
public SizeFileComparatorTest(String name) {
        super(name);
    }

    /** 
     * @see junit.framework.TestCase#setUp()
     */
@Override
    protected void setUp() throws Exception {
        super.setUp();
        comparator = ((AbstractFileComparator)(SizeFileComparator.SIZE_COMPARATOR));
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),99,comparator);
        reverse = SizeFileComparator.SIZE_REVERSE;
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),100,reverse);
        File dir = org.apache.commons.io.testtools.FileBasedTestCase.getTestDirectory();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),109,dir);
        smallerDir = new File(dir , "smallerdir");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),101,smallerDir);
        largerDir = new File(dir , "largerdir");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),102,largerDir);
        smallerFile = new File(smallerDir , "smaller.txt");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),103,smallerFile);
        File equalFile = new File(dir , "equal.txt");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),110,equalFile);
        largerFile = new File(largerDir , "larger.txt");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),104,largerFile);
        smallerDir.mkdir();
        largerDir.mkdir();
        createFile(smallerFile, 32);
        createFile(equalFile, 48);
        createFile(largerFile, 64);
        equalFile1 = equalFile;
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),105,equalFile1);
        equalFile2 = equalFile;
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),106,equalFile2);
        lessFile = smallerFile;
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),107,lessFile);
        moreFile = largerFile;
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),108,moreFile);
    }

    /** 
     * Test a file which doesn't exist.
     */
public void testNonexistantFile() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNonexistantFile");
            File nonexistantFile = new File(new File(".") , "nonexistant.txt");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),117,nonexistantFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),115,nonexistantFile.exists());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),116,((comparator.compare(nonexistantFile, moreFile)) < 0));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test a file which doesn't exist.
     */
public void testCompareDirectorySizes() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCompareDirectorySizes");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),111,comparator.compare(smallerDir, largerDir));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),112,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),113,org.apache.commons.io.comparator.SizeFileComparator.SIZE_SUMDIR_COMPARATOR.compare(smallerDir, largerDir));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),114,org.apache.commons.io.comparator.SizeFileComparator.SIZE_SUMDIR_REVERSE.compare(smallerDir, largerDir));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }
}

