package org.apache.commons.lang3;

import java.util.Locale;
import org.junit.Test;

/** 
 * Unit tests {@link org.apache.commons.lang3.StringUtils} - Substring methods
 * 
 * @version $Id$
 */
public class StringUtilsEqualsIndexOfTest {
    private static final String BAR = "bar";

    /** 
     * Supplementary character U+20000
     * See http://www.oracle.com/technetwork/articles/javase/supplementary-142654.html
     */
private static final String CharU20000 = "𠀀";

    /** 
     * Supplementary character U+20001
     * See http://www.oracle.com/technetwork/articles/javase/supplementary-142654.html
     */
private static final String CharU20001 = "𠀁";

    /** 
     * Incomplete supplementary character U+20000, high surrogate only.
     * See http://www.oracle.com/technetwork/articles/javase/supplementary-142654.html
     */
private static final String CharUSuppCharHigh = "?";

    /** 
     * Incomplete supplementary character U+20000, low surrogate only.
     * See http://www.oracle.com/technetwork/articles/javase/supplementary-142654.html
     */
private static final String CharUSuppCharLow = "?";

    private static final String FOO = "foo";

    private static final String FOOBAR = "foobar";

    private static final String[] FOOBAR_SUB_ARRAY = new String[]{ "ob" , "ba" };

    @Test
    public void testContains_Char() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testContains_Char");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),393,org.apache.commons.lang3.StringUtils.contains(null, ' '));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),394,org.apache.commons.lang3.StringUtils.contains("", ' '));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),395,org.apache.commons.lang3.StringUtils.contains("", null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),396,org.apache.commons.lang3.StringUtils.contains(null, null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),397,org.apache.commons.lang3.StringUtils.contains("abc", 'a'));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),398,org.apache.commons.lang3.StringUtils.contains("abc", 'b'));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),399,org.apache.commons.lang3.StringUtils.contains("abc", 'c'));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,org.apache.commons.lang3.StringUtils.contains("abc", 'z'));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testContains_String() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testContains_String");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),401,org.apache.commons.lang3.StringUtils.contains(null, null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,org.apache.commons.lang3.StringUtils.contains(null, ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,org.apache.commons.lang3.StringUtils.contains(null, "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,org.apache.commons.lang3.StringUtils.contains("", null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),405,org.apache.commons.lang3.StringUtils.contains("", ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),406,org.apache.commons.lang3.StringUtils.contains("", "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),407,org.apache.commons.lang3.StringUtils.contains("abc", "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),408,org.apache.commons.lang3.StringUtils.contains("abc", "b"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),409,org.apache.commons.lang3.StringUtils.contains("abc", "c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),410,org.apache.commons.lang3.StringUtils.contains("abc", "abc"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),411,org.apache.commons.lang3.StringUtils.contains("abc", "z"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * See http://www.oracle.com/technetwork/articles/javase/supplementary-142654.html
     */
@Test
    public void testContains_StringWithBadSupplementaryChars() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testContains_StringWithBadSupplementaryChars");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),412,org.apache.commons.lang3.StringUtils.contains(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharUSuppCharHigh, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),413,org.apache.commons.lang3.StringUtils.contains(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharUSuppCharLow, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),414,org.apache.commons.lang3.StringUtils.contains(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharUSuppCharHigh));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),415,org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001.indexOf(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharUSuppCharLow));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),416,org.apache.commons.lang3.StringUtils.contains(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharUSuppCharLow));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),417,org.apache.commons.lang3.StringUtils.contains((((org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001) + (org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharUSuppCharLow)) + "a"), "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),418,org.apache.commons.lang3.StringUtils.contains((((org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001) + (org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharUSuppCharHigh)) + "a"), "a"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * See http://www.oracle.com/technetwork/articles/javase/supplementary-142654.html
     */
@Test
    public void testContains_StringWithSupplementaryChars() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testContains_StringWithSupplementaryChars");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),419,org.apache.commons.lang3.StringUtils.contains(((org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000) + (org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001)), org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),420,org.apache.commons.lang3.StringUtils.contains(((org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000) + (org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001)), org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),421,org.apache.commons.lang3.StringUtils.contains(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),422,org.apache.commons.lang3.StringUtils.contains(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testContainsAny_StringCharArray() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testContainsAny_StringCharArray");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),172,org.apache.commons.lang3.StringUtils.containsAny(null, ((char[])(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),173,org.apache.commons.lang3.StringUtils.containsAny(null, new char[0]));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),174,org.apache.commons.lang3.StringUtils.containsAny(null, new char[]{ 'a' , 'b' }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),175,org.apache.commons.lang3.StringUtils.containsAny("", ((char[])(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),176,org.apache.commons.lang3.StringUtils.containsAny("", new char[0]));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),177,org.apache.commons.lang3.StringUtils.containsAny("", new char[]{ 'a' , 'b' }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),178,org.apache.commons.lang3.StringUtils.containsAny("zzabyycdxx", ((char[])(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),179,org.apache.commons.lang3.StringUtils.containsAny("zzabyycdxx", new char[0]));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),180,org.apache.commons.lang3.StringUtils.containsAny("zzabyycdxx", new char[]{ 'z' , 'a' }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),181,org.apache.commons.lang3.StringUtils.containsAny("zzabyycdxx", new char[]{ 'b' , 'y' }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),182,org.apache.commons.lang3.StringUtils.containsAny("ab", new char[]{ 'z' }));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * See http://www.oracle.com/technetwork/articles/javase/supplementary-142654.html
     */
@Test
    public void testContainsAny_StringCharArrayWithBadSupplementaryChars() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testContainsAny_StringCharArrayWithBadSupplementaryChars");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),183,org.apache.commons.lang3.StringUtils.containsAny(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharUSuppCharHigh, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001.toCharArray()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),184,org.apache.commons.lang3.StringUtils.containsAny((("abc" + (org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharUSuppCharHigh)) + "xyz"), org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001.toCharArray()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),185,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),186,org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharUSuppCharLow.indexOf(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),187,org.apache.commons.lang3.StringUtils.containsAny(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharUSuppCharLow, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001.toCharArray()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),188,org.apache.commons.lang3.StringUtils.containsAny(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharUSuppCharHigh.toCharArray()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),189,org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001.indexOf(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharUSuppCharLow));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),190,org.apache.commons.lang3.StringUtils.containsAny(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharUSuppCharLow.toCharArray()));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * See http://www.oracle.com/technetwork/articles/javase/supplementary-142654.html
     */
@Test
    public void testContainsAny_StringCharArrayWithSupplementaryChars() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testContainsAny_StringCharArrayWithSupplementaryChars");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),191,org.apache.commons.lang3.StringUtils.containsAny(((org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000) + (org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001)), org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000.toCharArray()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),192,org.apache.commons.lang3.StringUtils.containsAny((("a" + (org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000)) + (org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001)), "a".toCharArray()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),193,org.apache.commons.lang3.StringUtils.containsAny((((org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000) + "a") + (org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001)), "a".toCharArray()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),194,org.apache.commons.lang3.StringUtils.containsAny((((org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000) + (org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001)) + "a"), "a".toCharArray()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),195,org.apache.commons.lang3.StringUtils.containsAny(((org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000) + (org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001)), org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001.toCharArray()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),196,org.apache.commons.lang3.StringUtils.containsAny(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000.toCharArray()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),197,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),198,org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000.indexOf(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),199,org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000.indexOf(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001.charAt(0)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),201,org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000.indexOf(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001.charAt(1)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),202,org.apache.commons.lang3.StringUtils.containsAny(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001.toCharArray()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),203,org.apache.commons.lang3.StringUtils.containsAny(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000.toCharArray()));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testContainsAny_StringString() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testContainsAny_StringString");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),204,org.apache.commons.lang3.StringUtils.containsAny(null, ((java.lang.String)(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),205,org.apache.commons.lang3.StringUtils.containsAny(null, ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),206,org.apache.commons.lang3.StringUtils.containsAny(null, "ab"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),207,org.apache.commons.lang3.StringUtils.containsAny("", ((java.lang.String)(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),208,org.apache.commons.lang3.StringUtils.containsAny("", ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),209,org.apache.commons.lang3.StringUtils.containsAny("", "ab"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),210,org.apache.commons.lang3.StringUtils.containsAny("zzabyycdxx", ((java.lang.String)(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),211,org.apache.commons.lang3.StringUtils.containsAny("zzabyycdxx", ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),212,org.apache.commons.lang3.StringUtils.containsAny("zzabyycdxx", "za"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),213,org.apache.commons.lang3.StringUtils.containsAny("zzabyycdxx", "by"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),214,org.apache.commons.lang3.StringUtils.containsAny("ab", "z"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * See http://www.oracle.com/technetwork/articles/javase/supplementary-142654.html
     */
@Test
    public void testContainsAny_StringWithBadSupplementaryChars() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testContainsAny_StringWithBadSupplementaryChars");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),215,org.apache.commons.lang3.StringUtils.containsAny(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharUSuppCharHigh, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),216,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),217,org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharUSuppCharLow.indexOf(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),218,org.apache.commons.lang3.StringUtils.containsAny(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharUSuppCharLow, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),219,org.apache.commons.lang3.StringUtils.containsAny(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharUSuppCharHigh));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),220,org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001.indexOf(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharUSuppCharLow));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),221,org.apache.commons.lang3.StringUtils.containsAny(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharUSuppCharLow));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * See http://www.oracle.com/technetwork/articles/javase/supplementary-142654.html
     */
@Test
    public void testContainsAny_StringWithSupplementaryChars() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testContainsAny_StringWithSupplementaryChars");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),222,org.apache.commons.lang3.StringUtils.containsAny(((org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000) + (org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001)), org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),223,org.apache.commons.lang3.StringUtils.containsAny(((org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000) + (org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001)), org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),224,org.apache.commons.lang3.StringUtils.containsAny(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),225,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),226,org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000.indexOf(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),227,org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000.indexOf(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001.charAt(0)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),228,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),229,org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000.indexOf(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001.charAt(1)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),230,org.apache.commons.lang3.StringUtils.containsAny(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),231,org.apache.commons.lang3.StringUtils.containsAny(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testContainsIgnoreCase_LocaleIndependence() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testContainsIgnoreCase_LocaleIndependence");
            final Locale orig = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),236,orig);
            final Locale[] locales = new Locale[]{ Locale.ENGLISH , new Locale("tr") , Locale.getDefault() };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),237,locales);
            final String[][] tdata = new String[][]{ new String[]{ "i" , "I" } , new String[]{ "I" , "i" } , new String[]{ "ς" , "σ" } , new String[]{ "Σ" , "ς" } , new String[]{ "Σ" , "σ" } };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),238,tdata);
            final String[][] fdata = new String[][]{ new String[]{ "ß" , "SS" } };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),239,fdata);
            try {
                for (final Locale locale : locales) {
                    Locale.setDefault(locale);
                    Locale.setDefault(locale);
                    for (int j = 0 ; j < (tdata.length) ; j++) {
                        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,(((((((java.util.Locale.getDefault()) + ": ") + j) + " ") + (tdata[j][0])) + " ") + (tdata[j][1])));
                        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),233,org.apache.commons.lang3.StringUtils.containsIgnoreCase(tdata[j][0], tdata[j][1]));
                    }
                    for (int j = 0 ; j < (fdata.length) ; j++) {
                        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),234,(((((((java.util.Locale.getDefault()) + ": ") + j) + " ") + (fdata[j][0])) + " ") + (fdata[j][1])));
                        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),235,org.apache.commons.lang3.StringUtils.containsIgnoreCase(fdata[j][0], fdata[j][1]));
                    }
                }
            } finally {
                Locale.setDefault(orig);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testContainsIgnoreCase_LocaleIndependence_add56() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testContainsIgnoreCase_LocaleIndependence_add56");
            final Locale orig = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),236,orig);
            final Locale[] locales = new Locale[]{ Locale.ENGLISH , new Locale("tr") , Locale.getDefault() };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),237,locales);
            final String[][] tdata = new String[][]{ new String[]{ "i" , "I" } , new String[]{ "I" , "i" } , new String[]{ "ς" , "σ" } , new String[]{ "Σ" , "ς" } , new String[]{ "Σ" , "σ" } };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),238,tdata);
            final String[][] fdata = new String[][]{ new String[]{ "ß" , "SS" } };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),239,fdata);
            try {
                for (final Locale locale : locales) {
                    Locale.setDefault(locale);
                    for (int j = 0 ; j < (tdata.length) ; j++) {
                        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,(((((((java.util.Locale.getDefault()) + ": ") + j) + " ") + (tdata[j][0])) + " ") + (tdata[j][1])));
                        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),233,org.apache.commons.lang3.StringUtils.containsIgnoreCase(tdata[j][0], tdata[j][1]));
                    }
                    for (int j = 0 ; j < (fdata.length) ; j++) {
                        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),234,(((((((java.util.Locale.getDefault()) + ": ") + j) + " ") + (fdata[j][0])) + " ") + (fdata[j][1])));
                        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),235,org.apache.commons.lang3.StringUtils.containsIgnoreCase(fdata[j][0], fdata[j][1]));
                    }
                }
            } finally {
                Locale.setDefault(orig);
                Locale.setDefault(orig);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testContainsIgnoreCase_StringString() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testContainsIgnoreCase_StringString");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),240,org.apache.commons.lang3.StringUtils.containsIgnoreCase(null, null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),241,org.apache.commons.lang3.StringUtils.containsIgnoreCase(null, ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),242,org.apache.commons.lang3.StringUtils.containsIgnoreCase(null, "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),243,org.apache.commons.lang3.StringUtils.containsIgnoreCase(null, "abc"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),244,org.apache.commons.lang3.StringUtils.containsIgnoreCase("", null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),245,org.apache.commons.lang3.StringUtils.containsIgnoreCase("a", null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),246,org.apache.commons.lang3.StringUtils.containsIgnoreCase("abc", null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),247,org.apache.commons.lang3.StringUtils.containsIgnoreCase("", ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),248,org.apache.commons.lang3.StringUtils.containsIgnoreCase("a", ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),249,org.apache.commons.lang3.StringUtils.containsIgnoreCase("abc", ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),250,org.apache.commons.lang3.StringUtils.containsIgnoreCase("", "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),251,org.apache.commons.lang3.StringUtils.containsIgnoreCase("a", "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),252,org.apache.commons.lang3.StringUtils.containsIgnoreCase("abc", "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),253,org.apache.commons.lang3.StringUtils.containsIgnoreCase("", "A"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),254,org.apache.commons.lang3.StringUtils.containsIgnoreCase("a", "A"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),255,org.apache.commons.lang3.StringUtils.containsIgnoreCase("abc", "A"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),256,org.apache.commons.lang3.StringUtils.containsIgnoreCase("", "abc"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),257,org.apache.commons.lang3.StringUtils.containsIgnoreCase("a", "abc"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),258,org.apache.commons.lang3.StringUtils.containsIgnoreCase("xabcz", "abc"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),259,org.apache.commons.lang3.StringUtils.containsIgnoreCase("", "ABC"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),260,org.apache.commons.lang3.StringUtils.containsIgnoreCase("a", "ABC"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),261,org.apache.commons.lang3.StringUtils.containsIgnoreCase("xabcz", "ABC"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testContainsNone_CharArray() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testContainsNone_CharArray");
            final String str1 = "a";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),277,str1);
            final String str2 = "b";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),278,str2);
            final String str3 = "ab.";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),279,str3);
            final char[] chars1 = new char[]{ 'b' };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),280,chars1);
            final char[] chars2 = new char[]{ '.' };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),281,chars2);
            final char[] chars3 = new char[]{ 'c' , 'd' };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),282,chars3);
            final char[] emptyChars = new char[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),283,emptyChars);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),262,org.apache.commons.lang3.StringUtils.containsNone(null, ((char[])(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),263,org.apache.commons.lang3.StringUtils.containsNone("", ((char[])(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),264,org.apache.commons.lang3.StringUtils.containsNone(null, emptyChars));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),265,org.apache.commons.lang3.StringUtils.containsNone(str1, emptyChars));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),266,org.apache.commons.lang3.StringUtils.containsNone("", emptyChars));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),267,org.apache.commons.lang3.StringUtils.containsNone("", chars1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),268,org.apache.commons.lang3.StringUtils.containsNone(str1, chars1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),269,org.apache.commons.lang3.StringUtils.containsNone(str1, chars2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),270,org.apache.commons.lang3.StringUtils.containsNone(str1, chars3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),271,org.apache.commons.lang3.StringUtils.containsNone(str2, chars1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),272,org.apache.commons.lang3.StringUtils.containsNone(str2, chars2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),273,org.apache.commons.lang3.StringUtils.containsNone(str2, chars3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),274,org.apache.commons.lang3.StringUtils.containsNone(str3, chars1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),275,org.apache.commons.lang3.StringUtils.containsNone(str3, chars2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),276,org.apache.commons.lang3.StringUtils.containsNone(str3, chars3));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * See http://www.oracle.com/technetwork/articles/javase/supplementary-142654.html
     */
@Test
    public void testContainsNone_CharArrayWithBadSupplementaryChars() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testContainsNone_CharArrayWithBadSupplementaryChars");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),284,org.apache.commons.lang3.StringUtils.containsNone(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharUSuppCharHigh, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001.toCharArray()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),285,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),286,org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharUSuppCharLow.indexOf(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),287,org.apache.commons.lang3.StringUtils.containsNone(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharUSuppCharLow, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001.toCharArray()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),288,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),289,org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001.indexOf(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharUSuppCharHigh));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),290,org.apache.commons.lang3.StringUtils.containsNone(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharUSuppCharHigh.toCharArray()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),291,org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001.indexOf(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharUSuppCharLow));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),292,org.apache.commons.lang3.StringUtils.containsNone(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharUSuppCharLow.toCharArray()));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * See http://www.oracle.com/technetwork/articles/javase/supplementary-142654.html
     */
@Test
    public void testContainsNone_CharArrayWithSupplementaryChars() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testContainsNone_CharArrayWithSupplementaryChars");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),293,org.apache.commons.lang3.StringUtils.containsNone(((org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000) + (org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001)), org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000.toCharArray()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),294,org.apache.commons.lang3.StringUtils.containsNone(((org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000) + (org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001)), org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001.toCharArray()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),295,org.apache.commons.lang3.StringUtils.containsNone(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000.toCharArray()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),296,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),297,org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000.indexOf(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),298,org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000.indexOf(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001.charAt(0)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),299,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),300,org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000.indexOf(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001.charAt(1)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),301,org.apache.commons.lang3.StringUtils.containsNone(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001.toCharArray()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),302,org.apache.commons.lang3.StringUtils.containsNone(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000.toCharArray()));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testContainsNone_String() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testContainsNone_String");
            final String str1 = "a";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),318,str1);
            final String str2 = "b";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),319,str2);
            final String str3 = "ab.";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),320,str3);
            final String chars1 = "b";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),321,chars1);
            final String chars2 = ".";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),322,chars2);
            final String chars3 = "cd";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),323,chars3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),303,org.apache.commons.lang3.StringUtils.containsNone(null, ((java.lang.String)(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),304,org.apache.commons.lang3.StringUtils.containsNone("", ((java.lang.String)(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),305,org.apache.commons.lang3.StringUtils.containsNone(null, ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),306,org.apache.commons.lang3.StringUtils.containsNone(str1, ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),307,org.apache.commons.lang3.StringUtils.containsNone("", ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),308,org.apache.commons.lang3.StringUtils.containsNone("", chars1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),309,org.apache.commons.lang3.StringUtils.containsNone(str1, chars1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),310,org.apache.commons.lang3.StringUtils.containsNone(str1, chars2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),311,org.apache.commons.lang3.StringUtils.containsNone(str1, chars3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),312,org.apache.commons.lang3.StringUtils.containsNone(str2, chars1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),313,org.apache.commons.lang3.StringUtils.containsNone(str2, chars2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),314,org.apache.commons.lang3.StringUtils.containsNone(str2, chars3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),315,org.apache.commons.lang3.StringUtils.containsNone(str3, chars1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),316,org.apache.commons.lang3.StringUtils.containsNone(str3, chars2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),317,org.apache.commons.lang3.StringUtils.containsNone(str3, chars3));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * See http://www.oracle.com/technetwork/articles/javase/supplementary-142654.html
     */
@Test
    public void testContainsNone_StringWithBadSupplementaryChars() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testContainsNone_StringWithBadSupplementaryChars");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),324,org.apache.commons.lang3.StringUtils.containsNone(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharUSuppCharHigh, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),325,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),326,org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharUSuppCharLow.indexOf(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),327,org.apache.commons.lang3.StringUtils.containsNone(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharUSuppCharLow, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),328,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),329,org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001.indexOf(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharUSuppCharHigh));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),330,org.apache.commons.lang3.StringUtils.containsNone(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharUSuppCharHigh));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001.indexOf(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharUSuppCharLow));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),332,org.apache.commons.lang3.StringUtils.containsNone(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharUSuppCharLow));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * See http://www.oracle.com/technetwork/articles/javase/supplementary-142654.html
     */
@Test
    public void testContainsNone_StringWithSupplementaryChars() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testContainsNone_StringWithSupplementaryChars");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),333,org.apache.commons.lang3.StringUtils.containsNone(((org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000) + (org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001)), org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),334,org.apache.commons.lang3.StringUtils.containsNone(((org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000) + (org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001)), org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),335,org.apache.commons.lang3.StringUtils.containsNone(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),336,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),337,org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000.indexOf(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),338,org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000.indexOf(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001.charAt(0)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),339,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),340,org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000.indexOf(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001.charAt(1)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),341,org.apache.commons.lang3.StringUtils.containsNone(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),342,org.apache.commons.lang3.StringUtils.containsNone(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testContainsOnly_CharArray() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testContainsOnly_CharArray");
            final String str1 = "a";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),358,str1);
            final String str2 = "b";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),359,str2);
            final String str3 = "ab";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),360,str3);
            final char[] chars1 = new char[]{ 'b' };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),361,chars1);
            final char[] chars2 = new char[]{ 'a' };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),362,chars2);
            final char[] chars3 = new char[]{ 'a' , 'b' };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),363,chars3);
            final char[] emptyChars = new char[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),364,emptyChars);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),343,org.apache.commons.lang3.StringUtils.containsOnly(null, ((char[])(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),344,org.apache.commons.lang3.StringUtils.containsOnly("", ((char[])(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),345,org.apache.commons.lang3.StringUtils.containsOnly(null, emptyChars));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),346,org.apache.commons.lang3.StringUtils.containsOnly(str1, emptyChars));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),347,org.apache.commons.lang3.StringUtils.containsOnly("", emptyChars));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),348,org.apache.commons.lang3.StringUtils.containsOnly("", chars1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),349,org.apache.commons.lang3.StringUtils.containsOnly(str1, chars1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),350,org.apache.commons.lang3.StringUtils.containsOnly(str1, chars2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),351,org.apache.commons.lang3.StringUtils.containsOnly(str1, chars3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),352,org.apache.commons.lang3.StringUtils.containsOnly(str2, chars1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),353,org.apache.commons.lang3.StringUtils.containsOnly(str2, chars2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),354,org.apache.commons.lang3.StringUtils.containsOnly(str2, chars3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),355,org.apache.commons.lang3.StringUtils.containsOnly(str3, chars1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),356,org.apache.commons.lang3.StringUtils.containsOnly(str3, chars2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),357,org.apache.commons.lang3.StringUtils.containsOnly(str3, chars3));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testContainsOnly_String() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testContainsOnly_String");
            final String str1 = "a";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),380,str1);
            final String str2 = "b";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),381,str2);
            final String str3 = "ab";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),382,str3);
            final String chars1 = "b";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),383,chars1);
            final String chars2 = "a";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),384,chars2);
            final String chars3 = "ab";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),385,chars3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),365,org.apache.commons.lang3.StringUtils.containsOnly(null, ((java.lang.String)(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),366,org.apache.commons.lang3.StringUtils.containsOnly("", ((java.lang.String)(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),367,org.apache.commons.lang3.StringUtils.containsOnly(null, ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),368,org.apache.commons.lang3.StringUtils.containsOnly(str1, ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),369,org.apache.commons.lang3.StringUtils.containsOnly("", ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),370,org.apache.commons.lang3.StringUtils.containsOnly("", chars1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),371,org.apache.commons.lang3.StringUtils.containsOnly(str1, chars1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),372,org.apache.commons.lang3.StringUtils.containsOnly(str1, chars2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),373,org.apache.commons.lang3.StringUtils.containsOnly(str1, chars3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),374,org.apache.commons.lang3.StringUtils.containsOnly(str2, chars1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),375,org.apache.commons.lang3.StringUtils.containsOnly(str2, chars2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),376,org.apache.commons.lang3.StringUtils.containsOnly(str2, chars3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),377,org.apache.commons.lang3.StringUtils.containsOnly(str3, chars1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),378,org.apache.commons.lang3.StringUtils.containsOnly(str3, chars2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),379,org.apache.commons.lang3.StringUtils.containsOnly(str3, chars3));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testContainsWhitespace() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testContainsWhitespace");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),386,org.apache.commons.lang3.StringUtils.containsWhitespace(""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),387,org.apache.commons.lang3.StringUtils.containsWhitespace(" "));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),388,org.apache.commons.lang3.StringUtils.containsWhitespace("a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),389,org.apache.commons.lang3.StringUtils.containsWhitespace("a "));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),390,org.apache.commons.lang3.StringUtils.containsWhitespace(" a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),391,org.apache.commons.lang3.StringUtils.containsWhitespace("a\t"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),392,org.apache.commons.lang3.StringUtils.containsWhitespace("\n"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    private static class CustomCharSequence implements CharSequence {
        private final CharSequence seq;

        public CustomCharSequence(final CharSequence seq) {
            this.seq = seq;
        }

        @Override
        public char charAt(final int index) {
            return seq.charAt(index);
        }

        @Override
        public int length() {
            return seq.length();
        }

        @Override
        public CharSequence subSequence(final int start, final int end) {
            return new CustomCharSequence(seq.subSequence(start, end));
        }

        @Override
        public boolean equals(final Object obj) {
            if ((obj == null) || (!(obj instanceof CustomCharSequence))) {
                return false;
            } 
            final CustomCharSequence other = ((CustomCharSequence)(obj));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),171,other);
            return seq.equals(other.seq);
        }

        @Override
        public int hashCode() {
            return seq.hashCode();
        }

        @Override
        public String toString() {
            return seq.toString();
        }
    }

    @Test
    public void testCustomCharSequence() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomCharSequence");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),423,new org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CustomCharSequence(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOO));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),424,org.hamcrest.core.IsNot.<java.lang.CharSequence>not(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOO));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),425,org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOO);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),426,org.hamcrest.core.IsNot.<java.lang.CharSequence>not(new org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CustomCharSequence(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOO)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),427,new org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CustomCharSequence(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOO));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),427,new org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CustomCharSequence(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOO));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testEquals() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEquals");
            final CharSequence fooCs = FOO;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),440,fooCs);
            final CharSequence barCs = BAR;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),441,barCs);
            final CharSequence foobarCs = FOOBAR;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),442,foobarCs);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,org.apache.commons.lang3.StringUtils.equals(null, null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),429,org.apache.commons.lang3.StringUtils.equals(fooCs, fooCs));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),430,org.apache.commons.lang3.StringUtils.equals(fooCs, new java.lang.StringBuilder(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOO)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),431,org.apache.commons.lang3.StringUtils.equals(fooCs, new java.lang.String(new char[]{ 'f' , 'o' , 'o' })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),432,org.apache.commons.lang3.StringUtils.equals(fooCs, new org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CustomCharSequence(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOO)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),433,org.apache.commons.lang3.StringUtils.equals(new org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CustomCharSequence(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOO), fooCs));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),434,org.apache.commons.lang3.StringUtils.equals(fooCs, new java.lang.String(new char[]{ 'f' , 'O' , 'O' })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),435,org.apache.commons.lang3.StringUtils.equals(fooCs, barCs));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),436,org.apache.commons.lang3.StringUtils.equals(fooCs, null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),437,org.apache.commons.lang3.StringUtils.equals(null, fooCs));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),438,org.apache.commons.lang3.StringUtils.equals(fooCs, foobarCs));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),439,org.apache.commons.lang3.StringUtils.equals(foobarCs, fooCs));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testEqualsOnStrings() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEqualsOnStrings");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),452,org.apache.commons.lang3.StringUtils.equals(null, null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),453,org.apache.commons.lang3.StringUtils.equals(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOO, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOO));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),454,org.apache.commons.lang3.StringUtils.equals(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOO, new java.lang.String(new char[]{ 'f' , 'o' , 'o' })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),455,org.apache.commons.lang3.StringUtils.equals(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOO, new java.lang.String(new char[]{ 'f' , 'O' , 'O' })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),456,org.apache.commons.lang3.StringUtils.equals(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOO, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.BAR));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),457,org.apache.commons.lang3.StringUtils.equals(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOO, null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),458,org.apache.commons.lang3.StringUtils.equals(null, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOO));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),459,org.apache.commons.lang3.StringUtils.equals(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOO, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOOBAR));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),460,org.apache.commons.lang3.StringUtils.equals(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOOBAR, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOO));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testEqualsIgnoreCase() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEqualsIgnoreCase");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),443,org.apache.commons.lang3.StringUtils.equalsIgnoreCase(null, null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),444,org.apache.commons.lang3.StringUtils.equalsIgnoreCase(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOO, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOO));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),445,org.apache.commons.lang3.StringUtils.equalsIgnoreCase(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOO, new java.lang.String(new char[]{ 'f' , 'o' , 'o' })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),446,org.apache.commons.lang3.StringUtils.equalsIgnoreCase(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOO, new java.lang.String(new char[]{ 'f' , 'O' , 'O' })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),447,org.apache.commons.lang3.StringUtils.equalsIgnoreCase(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOO, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.BAR));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),448,org.apache.commons.lang3.StringUtils.equalsIgnoreCase(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOO, null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),449,org.apache.commons.lang3.StringUtils.equalsIgnoreCase(null, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOO));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),450,org.apache.commons.lang3.StringUtils.equalsIgnoreCase("", ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),451,org.apache.commons.lang3.StringUtils.equalsIgnoreCase("abcd", "abcd "));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testIndexOf_char() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIndexOf_char");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),663,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),664,org.apache.commons.lang3.StringUtils.indexOf(null, ' '));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),665,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),666,org.apache.commons.lang3.StringUtils.indexOf("", ' '));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),667,org.apache.commons.lang3.StringUtils.indexOf("aabaabaa", 'a'));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),668,org.apache.commons.lang3.StringUtils.indexOf("aabaabaa", 'b'));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),669,org.apache.commons.lang3.StringUtils.indexOf(new java.lang.StringBuilder("aabaabaa"), 'b'));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testIndexOf_charInt() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIndexOf_charInt");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),670,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),671,org.apache.commons.lang3.StringUtils.indexOf(null, ' ', 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),672,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),673,org.apache.commons.lang3.StringUtils.indexOf(null, ' ', -1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),674,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),675,org.apache.commons.lang3.StringUtils.indexOf("", ' ', 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),676,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),677,org.apache.commons.lang3.StringUtils.indexOf("", ' ', -1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),678,org.apache.commons.lang3.StringUtils.indexOf("aabaabaa", 'a', 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),679,org.apache.commons.lang3.StringUtils.indexOf("aabaabaa", 'b', 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),680,org.apache.commons.lang3.StringUtils.indexOf("aabaabaa", 'b', 3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),681,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),682,org.apache.commons.lang3.StringUtils.indexOf("aabaabaa", 'b', 9));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),683,org.apache.commons.lang3.StringUtils.indexOf("aabaabaa", 'b', -1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),684,org.apache.commons.lang3.StringUtils.indexOf(new java.lang.StringBuilder("aabaabaa"), 'b', 3));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testIndexOf_String() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIndexOf_String");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),620,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),621,org.apache.commons.lang3.StringUtils.indexOf(null, null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),622,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),623,org.apache.commons.lang3.StringUtils.indexOf("", null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),624,org.apache.commons.lang3.StringUtils.indexOf("", ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),625,org.apache.commons.lang3.StringUtils.indexOf("aabaabaa", "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),626,org.apache.commons.lang3.StringUtils.indexOf("aabaabaa", "b"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),627,org.apache.commons.lang3.StringUtils.indexOf("aabaabaa", "ab"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),628,org.apache.commons.lang3.StringUtils.indexOf("aabaabaa", ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),629,org.apache.commons.lang3.StringUtils.indexOf(new java.lang.StringBuilder("aabaabaa"), "b"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testIndexOf_StringInt() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIndexOf_StringInt");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),630,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),631,org.apache.commons.lang3.StringUtils.indexOf(null, null, 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),632,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),633,org.apache.commons.lang3.StringUtils.indexOf(null, null, -1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),634,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),635,org.apache.commons.lang3.StringUtils.indexOf(null, "", 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),636,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),637,org.apache.commons.lang3.StringUtils.indexOf(null, "", -1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),638,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),639,org.apache.commons.lang3.StringUtils.indexOf("", null, 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),640,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),641,org.apache.commons.lang3.StringUtils.indexOf("", null, -1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),642,org.apache.commons.lang3.StringUtils.indexOf("", "", 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),643,org.apache.commons.lang3.StringUtils.indexOf("", "", -1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),644,org.apache.commons.lang3.StringUtils.indexOf("", "", 9));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),645,org.apache.commons.lang3.StringUtils.indexOf("abc", "", 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),646,org.apache.commons.lang3.StringUtils.indexOf("abc", "", -1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),647,org.apache.commons.lang3.StringUtils.indexOf("abc", "", 9));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),648,org.apache.commons.lang3.StringUtils.indexOf("abc", "", 3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),649,org.apache.commons.lang3.StringUtils.indexOf("aabaabaa", "a", 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),650,org.apache.commons.lang3.StringUtils.indexOf("aabaabaa", "b", 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),651,org.apache.commons.lang3.StringUtils.indexOf("aabaabaa", "ab", 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),652,org.apache.commons.lang3.StringUtils.indexOf("aabaabaa", "b", 3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),653,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),654,org.apache.commons.lang3.StringUtils.indexOf("aabaabaa", "b", 9));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),655,org.apache.commons.lang3.StringUtils.indexOf("aabaabaa", "b", -1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),656,org.apache.commons.lang3.StringUtils.indexOf("aabaabaa", "", 2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),657,org.apache.commons.lang3.StringUtils.indexOf("12345678", "8", 5));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),658,org.apache.commons.lang3.StringUtils.indexOf("12345678", "8", 6));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),659,org.apache.commons.lang3.StringUtils.indexOf("12345678", "8", 7));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),660,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),661,org.apache.commons.lang3.StringUtils.indexOf("12345678", "8", 8));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),662,org.apache.commons.lang3.StringUtils.indexOf(new java.lang.StringBuilder("aabaabaa"), "b", 3));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testIndexOfAny_StringCharArray() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIndexOfAny_StringCharArray");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),511,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),512,org.apache.commons.lang3.StringUtils.indexOfAny(null, ((char[])(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),513,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),514,org.apache.commons.lang3.StringUtils.indexOfAny(null, new char[0]));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),515,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),516,org.apache.commons.lang3.StringUtils.indexOfAny(null, new char[]{ 'a' , 'b' }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),517,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),518,org.apache.commons.lang3.StringUtils.indexOfAny("", ((char[])(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),519,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),520,org.apache.commons.lang3.StringUtils.indexOfAny("", new char[0]));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),521,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),522,org.apache.commons.lang3.StringUtils.indexOfAny("", new char[]{ 'a' , 'b' }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),523,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),524,org.apache.commons.lang3.StringUtils.indexOfAny("zzabyycdxx", ((char[])(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),525,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),526,org.apache.commons.lang3.StringUtils.indexOfAny("zzabyycdxx", new char[0]));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),527,org.apache.commons.lang3.StringUtils.indexOfAny("zzabyycdxx", new char[]{ 'z' , 'a' }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),528,org.apache.commons.lang3.StringUtils.indexOfAny("zzabyycdxx", new char[]{ 'b' , 'y' }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),529,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),530,org.apache.commons.lang3.StringUtils.indexOfAny("ab", new char[]{ 'z' }));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * See http://www.oracle.com/technetwork/articles/javase/supplementary-142654.html
     */
@Test
    public void testIndexOfAny_StringCharArrayWithSupplementaryChars() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIndexOfAny_StringCharArrayWithSupplementaryChars");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),531,org.apache.commons.lang3.StringUtils.indexOfAny(((org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000) + (org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001)), org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000.toCharArray()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),532,org.apache.commons.lang3.StringUtils.indexOfAny(((org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000) + (org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001)), org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001.toCharArray()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),533,org.apache.commons.lang3.StringUtils.indexOfAny(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000.toCharArray()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),534,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),535,org.apache.commons.lang3.StringUtils.indexOfAny(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001.toCharArray()));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testIndexOfAny_StringString() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIndexOfAny_StringString");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),536,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),537,org.apache.commons.lang3.StringUtils.indexOfAny(null, ((java.lang.String)(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),538,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),539,org.apache.commons.lang3.StringUtils.indexOfAny(null, ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),540,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),541,org.apache.commons.lang3.StringUtils.indexOfAny(null, "ab"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),542,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),543,org.apache.commons.lang3.StringUtils.indexOfAny("", ((java.lang.String)(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),544,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),545,org.apache.commons.lang3.StringUtils.indexOfAny("", ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),546,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),547,org.apache.commons.lang3.StringUtils.indexOfAny("", "ab"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),548,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),549,org.apache.commons.lang3.StringUtils.indexOfAny("zzabyycdxx", ((java.lang.String)(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),550,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),551,org.apache.commons.lang3.StringUtils.indexOfAny("zzabyycdxx", ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),552,org.apache.commons.lang3.StringUtils.indexOfAny("zzabyycdxx", "za"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),553,org.apache.commons.lang3.StringUtils.indexOfAny("zzabyycdxx", "by"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),554,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),555,org.apache.commons.lang3.StringUtils.indexOfAny("ab", "z"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testIndexOfAny_StringStringArray() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIndexOfAny_StringStringArray");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),556,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),557,org.apache.commons.lang3.StringUtils.indexOfAny(null, ((java.lang.String[])(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),558,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),559,org.apache.commons.lang3.StringUtils.indexOfAny(null, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOOBAR_SUB_ARRAY));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),560,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),561,org.apache.commons.lang3.StringUtils.indexOfAny(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOOBAR, ((java.lang.String[])(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),562,org.apache.commons.lang3.StringUtils.indexOfAny(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOOBAR, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOOBAR_SUB_ARRAY));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),563,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),564,org.apache.commons.lang3.StringUtils.indexOfAny(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOOBAR, new java.lang.String[0]));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),565,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),566,org.apache.commons.lang3.StringUtils.indexOfAny(null, new java.lang.String[0]));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),567,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),568,org.apache.commons.lang3.StringUtils.indexOfAny("", new java.lang.String[0]));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),569,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),570,org.apache.commons.lang3.StringUtils.indexOfAny(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOOBAR, new java.lang.String[]{ "llll" }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),571,org.apache.commons.lang3.StringUtils.indexOfAny(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOOBAR, new java.lang.String[]{ "" }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),572,org.apache.commons.lang3.StringUtils.indexOfAny("", new java.lang.String[]{ "" }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),573,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),574,org.apache.commons.lang3.StringUtils.indexOfAny("", new java.lang.String[]{ "a" }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),575,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),576,org.apache.commons.lang3.StringUtils.indexOfAny("", new java.lang.String[]{ null }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),577,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),578,org.apache.commons.lang3.StringUtils.indexOfAny(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOOBAR, new java.lang.String[]{ null }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),579,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),580,org.apache.commons.lang3.StringUtils.indexOfAny(null, new java.lang.String[]{ null }));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * See http://www.oracle.com/technetwork/articles/javase/supplementary-142654.html
     */
@Test
    public void testIndexOfAny_StringStringWithSupplementaryChars() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIndexOfAny_StringStringWithSupplementaryChars");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),581,org.apache.commons.lang3.StringUtils.indexOfAny(((org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000) + (org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001)), org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),582,org.apache.commons.lang3.StringUtils.indexOfAny(((org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000) + (org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001)), org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),583,org.apache.commons.lang3.StringUtils.indexOfAny(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),584,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),585,org.apache.commons.lang3.StringUtils.indexOfAny(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testIndexOfAnyBut_StringCharArray() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIndexOfAnyBut_StringCharArray");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),461,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),462,org.apache.commons.lang3.StringUtils.indexOfAnyBut(null, ((char[])(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),463,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),464,org.apache.commons.lang3.StringUtils.indexOfAnyBut(null, new char[0]));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),465,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),466,org.apache.commons.lang3.StringUtils.indexOfAnyBut(null, new char[]{ 'a' , 'b' }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),467,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),468,org.apache.commons.lang3.StringUtils.indexOfAnyBut("", ((char[])(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),469,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),470,org.apache.commons.lang3.StringUtils.indexOfAnyBut("", new char[0]));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),471,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),472,org.apache.commons.lang3.StringUtils.indexOfAnyBut("", new char[]{ 'a' , 'b' }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),473,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),474,org.apache.commons.lang3.StringUtils.indexOfAnyBut("zzabyycdxx", ((char[])(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),475,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),476,org.apache.commons.lang3.StringUtils.indexOfAnyBut("zzabyycdxx", new char[0]));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),477,org.apache.commons.lang3.StringUtils.indexOfAnyBut("zzabyycdxx", new char[]{ 'z' , 'a' }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),478,org.apache.commons.lang3.StringUtils.indexOfAnyBut("zzabyycdxx", new char[]{ 'b' , 'y' }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),479,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),480,org.apache.commons.lang3.StringUtils.indexOfAnyBut("aba", new char[]{ 'a' , 'b' }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),481,org.apache.commons.lang3.StringUtils.indexOfAnyBut("aba", new char[]{ 'z' }));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testIndexOfAnyBut_StringCharArrayWithSupplementaryChars() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIndexOfAnyBut_StringCharArrayWithSupplementaryChars");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),482,org.apache.commons.lang3.StringUtils.indexOfAnyBut(((org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000) + (org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001)), org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000.toCharArray()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),483,org.apache.commons.lang3.StringUtils.indexOfAnyBut(((org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000) + (org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001)), org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001.toCharArray()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,org.apache.commons.lang3.StringUtils.indexOfAnyBut(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000.toCharArray()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,org.apache.commons.lang3.StringUtils.indexOfAnyBut(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001.toCharArray()));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testIndexOfAnyBut_StringString() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIndexOfAnyBut_StringString");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,org.apache.commons.lang3.StringUtils.indexOfAnyBut(null, ((java.lang.String)(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,org.apache.commons.lang3.StringUtils.indexOfAnyBut(null, ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,org.apache.commons.lang3.StringUtils.indexOfAnyBut(null, "ab"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,org.apache.commons.lang3.StringUtils.indexOfAnyBut("", ((java.lang.String)(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,org.apache.commons.lang3.StringUtils.indexOfAnyBut("", ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,org.apache.commons.lang3.StringUtils.indexOfAnyBut("", "ab"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,org.apache.commons.lang3.StringUtils.indexOfAnyBut("zzabyycdxx", ((java.lang.String)(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,org.apache.commons.lang3.StringUtils.indexOfAnyBut("zzabyycdxx", ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,org.apache.commons.lang3.StringUtils.indexOfAnyBut("zzabyycdxx", "za"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,org.apache.commons.lang3.StringUtils.indexOfAnyBut("zzabyycdxx", "by"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,org.apache.commons.lang3.StringUtils.indexOfAnyBut("ab", "z"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testIndexOfAnyBut_StringStringWithSupplementaryChars() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIndexOfAnyBut_StringStringWithSupplementaryChars");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,org.apache.commons.lang3.StringUtils.indexOfAnyBut(((org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000) + (org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001)), org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,org.apache.commons.lang3.StringUtils.indexOfAnyBut(((org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000) + (org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001)), org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,org.apache.commons.lang3.StringUtils.indexOfAnyBut(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,org.apache.commons.lang3.StringUtils.indexOfAnyBut(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20000, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.CharU20001));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testIndexOfIgnoreCase_String() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIndexOfIgnoreCase_String");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),586,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),587,org.apache.commons.lang3.StringUtils.indexOfIgnoreCase(null, null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),588,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),589,org.apache.commons.lang3.StringUtils.indexOfIgnoreCase(null, ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),590,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),591,org.apache.commons.lang3.StringUtils.indexOfIgnoreCase("", null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),592,org.apache.commons.lang3.StringUtils.indexOfIgnoreCase("", ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),593,org.apache.commons.lang3.StringUtils.indexOfIgnoreCase("aabaabaa", "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),594,org.apache.commons.lang3.StringUtils.indexOfIgnoreCase("aabaabaa", "A"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),595,org.apache.commons.lang3.StringUtils.indexOfIgnoreCase("aabaabaa", "b"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),596,org.apache.commons.lang3.StringUtils.indexOfIgnoreCase("aabaabaa", "B"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),597,org.apache.commons.lang3.StringUtils.indexOfIgnoreCase("aabaabaa", "ab"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),598,org.apache.commons.lang3.StringUtils.indexOfIgnoreCase("aabaabaa", "AB"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),599,org.apache.commons.lang3.StringUtils.indexOfIgnoreCase("aabaabaa", ""));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testIndexOfIgnoreCase_StringInt() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIndexOfIgnoreCase_StringInt");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),600,org.apache.commons.lang3.StringUtils.indexOfIgnoreCase("aabaabaa", "AB", -1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),601,org.apache.commons.lang3.StringUtils.indexOfIgnoreCase("aabaabaa", "AB", 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),602,org.apache.commons.lang3.StringUtils.indexOfIgnoreCase("aabaabaa", "AB", 1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),603,org.apache.commons.lang3.StringUtils.indexOfIgnoreCase("aabaabaa", "AB", 2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),604,org.apache.commons.lang3.StringUtils.indexOfIgnoreCase("aabaabaa", "AB", 3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),605,org.apache.commons.lang3.StringUtils.indexOfIgnoreCase("aabaabaa", "AB", 4));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),606,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),607,org.apache.commons.lang3.StringUtils.indexOfIgnoreCase("aabaabaa", "AB", 5));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),608,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),609,org.apache.commons.lang3.StringUtils.indexOfIgnoreCase("aabaabaa", "AB", 6));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),610,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),611,org.apache.commons.lang3.StringUtils.indexOfIgnoreCase("aabaabaa", "AB", 7));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),612,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),613,org.apache.commons.lang3.StringUtils.indexOfIgnoreCase("aabaabaa", "AB", 8));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),614,org.apache.commons.lang3.StringUtils.indexOfIgnoreCase("aab", "AB", 1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),615,org.apache.commons.lang3.StringUtils.indexOfIgnoreCase("aabaabaa", "", 5));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),616,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),617,org.apache.commons.lang3.StringUtils.indexOfIgnoreCase("ab", "AAB", 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),618,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),619,org.apache.commons.lang3.StringUtils.indexOfIgnoreCase("aab", "AAB", 1));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testLastIndexOf_char() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testLastIndexOf_char");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),823,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),824,org.apache.commons.lang3.StringUtils.lastIndexOf(null, ' '));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),825,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),826,org.apache.commons.lang3.StringUtils.lastIndexOf("", ' '));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),827,org.apache.commons.lang3.StringUtils.lastIndexOf("aabaabaa", 'a'));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),828,org.apache.commons.lang3.StringUtils.lastIndexOf("aabaabaa", 'b'));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),829,org.apache.commons.lang3.StringUtils.lastIndexOf(new java.lang.StringBuilder("aabaabaa"), 'b'));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testLastIndexOf_charInt() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testLastIndexOf_charInt");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),830,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),831,org.apache.commons.lang3.StringUtils.lastIndexOf(null, ' ', 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,org.apache.commons.lang3.StringUtils.lastIndexOf(null, ' ', -1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,org.apache.commons.lang3.StringUtils.lastIndexOf("", ' ', 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,org.apache.commons.lang3.StringUtils.lastIndexOf("", ' ', -1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),838,org.apache.commons.lang3.StringUtils.lastIndexOf("aabaabaa", 'a', 8));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,org.apache.commons.lang3.StringUtils.lastIndexOf("aabaabaa", 'b', 8));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,org.apache.commons.lang3.StringUtils.lastIndexOf("aabaabaa", 'b', 3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,org.apache.commons.lang3.StringUtils.lastIndexOf("aabaabaa", 'b', 9));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,org.apache.commons.lang3.StringUtils.lastIndexOf("aabaabaa", 'b', -1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,org.apache.commons.lang3.StringUtils.lastIndexOf("aabaabaa", 'a', 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,org.apache.commons.lang3.StringUtils.lastIndexOf(new java.lang.StringBuilder("aabaabaa"), 'b', 2));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testLastIndexOf_String() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testLastIndexOf_String");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,org.apache.commons.lang3.StringUtils.lastIndexOf(null, null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),771,org.apache.commons.lang3.StringUtils.lastIndexOf("", null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),772,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),773,org.apache.commons.lang3.StringUtils.lastIndexOf("", "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),774,org.apache.commons.lang3.StringUtils.lastIndexOf("", ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),775,org.apache.commons.lang3.StringUtils.lastIndexOf("aabaabaa", ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),776,org.apache.commons.lang3.StringUtils.lastIndexOf("aabaabaa", "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),777,org.apache.commons.lang3.StringUtils.lastIndexOf("aabaabaa", "b"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),778,org.apache.commons.lang3.StringUtils.lastIndexOf("aabaabaa", "ab"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),779,org.apache.commons.lang3.StringUtils.lastIndexOf(new java.lang.StringBuilder("aabaabaa"), "ab"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testLastIndexOf_StringInt() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testLastIndexOf_StringInt");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),780,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),781,org.apache.commons.lang3.StringUtils.lastIndexOf(null, null, 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),782,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),783,org.apache.commons.lang3.StringUtils.lastIndexOf(null, null, -1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),784,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),785,org.apache.commons.lang3.StringUtils.lastIndexOf(null, "", 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),786,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),787,org.apache.commons.lang3.StringUtils.lastIndexOf(null, "", -1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),788,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),789,org.apache.commons.lang3.StringUtils.lastIndexOf("", null, 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),790,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),791,org.apache.commons.lang3.StringUtils.lastIndexOf("", null, -1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),792,org.apache.commons.lang3.StringUtils.lastIndexOf("", "", 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),793,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),794,org.apache.commons.lang3.StringUtils.lastIndexOf("", "", -1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),795,org.apache.commons.lang3.StringUtils.lastIndexOf("", "", 9));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),796,org.apache.commons.lang3.StringUtils.lastIndexOf("abc", "", 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),797,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),798,org.apache.commons.lang3.StringUtils.lastIndexOf("abc", "", -1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),799,org.apache.commons.lang3.StringUtils.lastIndexOf("abc", "", 9));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),800,org.apache.commons.lang3.StringUtils.lastIndexOf("aabaabaa", "a", 8));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),801,org.apache.commons.lang3.StringUtils.lastIndexOf("aabaabaa", "b", 8));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),802,org.apache.commons.lang3.StringUtils.lastIndexOf("aabaabaa", "ab", 8));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),803,org.apache.commons.lang3.StringUtils.lastIndexOf("aabaabaa", "b", 3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),804,org.apache.commons.lang3.StringUtils.lastIndexOf("aabaabaa", "b", 9));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),805,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),806,org.apache.commons.lang3.StringUtils.lastIndexOf("aabaabaa", "b", -1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),807,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),808,org.apache.commons.lang3.StringUtils.lastIndexOf("aabaabaa", "b", 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),809,org.apache.commons.lang3.StringUtils.lastIndexOf("aabaabaa", "a", 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),810,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),811,org.apache.commons.lang3.StringUtils.lastIndexOf("aabaabaa", "a", -1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),812,org.apache.commons.lang3.StringUtils.lastIndexOf("12345678", "8", 9));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),813,org.apache.commons.lang3.StringUtils.lastIndexOf("12345678", "8", 8));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),814,org.apache.commons.lang3.StringUtils.lastIndexOf("12345678", "8", 7));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),815,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),816,org.apache.commons.lang3.StringUtils.lastIndexOf("12345678", "8", 6));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),817,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),818,org.apache.commons.lang3.StringUtils.lastIndexOf("aabaabaa", "b", 1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),819,org.apache.commons.lang3.StringUtils.lastIndexOf("aabaabaa", "b", 2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),820,org.apache.commons.lang3.StringUtils.lastIndexOf("aabaabaa", "ba", 2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),821,org.apache.commons.lang3.StringUtils.lastIndexOf("aabaabaa", "ba", 3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),822,org.apache.commons.lang3.StringUtils.lastIndexOf(new java.lang.StringBuilder("aabaabaa"), "b", 3));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testLastIndexOfAny_StringStringArray() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testLastIndexOfAny_StringStringArray");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),685,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),686,org.apache.commons.lang3.StringUtils.lastIndexOfAny(null, ((java.lang.CharSequence)(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),687,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),688,org.apache.commons.lang3.StringUtils.lastIndexOfAny(null, ((java.lang.CharSequence[])(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),689,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),690,org.apache.commons.lang3.StringUtils.lastIndexOfAny(null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),691,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),692,org.apache.commons.lang3.StringUtils.lastIndexOfAny(null, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOOBAR_SUB_ARRAY));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),693,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),694,org.apache.commons.lang3.StringUtils.lastIndexOfAny(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOOBAR, ((java.lang.CharSequence)(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),695,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),696,org.apache.commons.lang3.StringUtils.lastIndexOfAny(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOOBAR, ((java.lang.CharSequence[])(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),697,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),698,org.apache.commons.lang3.StringUtils.lastIndexOfAny(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOOBAR));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),699,org.apache.commons.lang3.StringUtils.lastIndexOfAny(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOOBAR, org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOOBAR_SUB_ARRAY));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),700,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),701,org.apache.commons.lang3.StringUtils.lastIndexOfAny(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOOBAR, new java.lang.String[0]));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),702,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),703,org.apache.commons.lang3.StringUtils.lastIndexOfAny(null, new java.lang.String[0]));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),704,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),705,org.apache.commons.lang3.StringUtils.lastIndexOfAny("", new java.lang.String[0]));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),706,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),707,org.apache.commons.lang3.StringUtils.lastIndexOfAny(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOOBAR, new java.lang.String[]{ "llll" }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),708,org.apache.commons.lang3.StringUtils.lastIndexOfAny(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOOBAR, new java.lang.String[]{ "" }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),709,org.apache.commons.lang3.StringUtils.lastIndexOfAny("", new java.lang.String[]{ "" }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),710,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),711,org.apache.commons.lang3.StringUtils.lastIndexOfAny("", new java.lang.String[]{ "a" }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),712,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),713,org.apache.commons.lang3.StringUtils.lastIndexOfAny("", new java.lang.String[]{ null }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),714,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),715,org.apache.commons.lang3.StringUtils.lastIndexOfAny(org.apache.commons.lang3.StringUtilsEqualsIndexOfTest.FOOBAR, new java.lang.String[]{ null }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),716,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),717,org.apache.commons.lang3.StringUtils.lastIndexOfAny(null, new java.lang.String[]{ null }));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testLastIndexOfIgnoreCase_String() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testLastIndexOfIgnoreCase_String");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),718,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),719,org.apache.commons.lang3.StringUtils.lastIndexOfIgnoreCase(null, null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),720,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),721,org.apache.commons.lang3.StringUtils.lastIndexOfIgnoreCase("", null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),722,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),723,org.apache.commons.lang3.StringUtils.lastIndexOfIgnoreCase(null, ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),724,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),725,org.apache.commons.lang3.StringUtils.lastIndexOfIgnoreCase("", "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),726,org.apache.commons.lang3.StringUtils.lastIndexOfIgnoreCase("", ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),727,org.apache.commons.lang3.StringUtils.lastIndexOfIgnoreCase("aabaabaa", ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),728,org.apache.commons.lang3.StringUtils.lastIndexOfIgnoreCase("aabaabaa", "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),729,org.apache.commons.lang3.StringUtils.lastIndexOfIgnoreCase("aabaabaa", "A"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),730,org.apache.commons.lang3.StringUtils.lastIndexOfIgnoreCase("aabaabaa", "b"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),731,org.apache.commons.lang3.StringUtils.lastIndexOfIgnoreCase("aabaabaa", "B"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),732,org.apache.commons.lang3.StringUtils.lastIndexOfIgnoreCase("aabaabaa", "ab"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),733,org.apache.commons.lang3.StringUtils.lastIndexOfIgnoreCase("aabaabaa", "AB"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,org.apache.commons.lang3.StringUtils.lastIndexOfIgnoreCase("ab", "AAB"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,org.apache.commons.lang3.StringUtils.lastIndexOfIgnoreCase("aab", "AAB"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testLastIndexOfIgnoreCase_StringInt() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testLastIndexOfIgnoreCase_StringInt");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,org.apache.commons.lang3.StringUtils.lastIndexOfIgnoreCase(null, null, 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,org.apache.commons.lang3.StringUtils.lastIndexOfIgnoreCase(null, null, -1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,org.apache.commons.lang3.StringUtils.lastIndexOfIgnoreCase(null, "", 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,org.apache.commons.lang3.StringUtils.lastIndexOfIgnoreCase(null, "", -1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,org.apache.commons.lang3.StringUtils.lastIndexOfIgnoreCase("", null, 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,org.apache.commons.lang3.StringUtils.lastIndexOfIgnoreCase("", null, -1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,org.apache.commons.lang3.StringUtils.lastIndexOfIgnoreCase("", "", 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,org.apache.commons.lang3.StringUtils.lastIndexOfIgnoreCase("", "", -1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,org.apache.commons.lang3.StringUtils.lastIndexOfIgnoreCase("", "", 9));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,org.apache.commons.lang3.StringUtils.lastIndexOfIgnoreCase("abc", "", 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,org.apache.commons.lang3.StringUtils.lastIndexOfIgnoreCase("abc", "", -1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,org.apache.commons.lang3.StringUtils.lastIndexOfIgnoreCase("abc", "", 9));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,org.apache.commons.lang3.StringUtils.lastIndexOfIgnoreCase("aabaabaa", "A", 8));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,org.apache.commons.lang3.StringUtils.lastIndexOfIgnoreCase("aabaabaa", "B", 8));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,org.apache.commons.lang3.StringUtils.lastIndexOfIgnoreCase("aabaabaa", "AB", 8));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,org.apache.commons.lang3.StringUtils.lastIndexOfIgnoreCase("aabaabaa", "B", 3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,org.apache.commons.lang3.StringUtils.lastIndexOfIgnoreCase("aabaabaa", "B", 9));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,org.apache.commons.lang3.StringUtils.lastIndexOfIgnoreCase("aabaabaa", "B", -1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,org.apache.commons.lang3.StringUtils.lastIndexOfIgnoreCase("aabaabaa", "B", 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,org.apache.commons.lang3.StringUtils.lastIndexOfIgnoreCase("aabaabaa", "A", 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,org.apache.commons.lang3.StringUtils.lastIndexOfIgnoreCase("aab", "AB", 1));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testLastOrdinalIndexOf() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testLastOrdinalIndexOf");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,org.apache.commons.lang3.StringUtils.lastOrdinalIndexOf(null, "*", 42));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,org.apache.commons.lang3.StringUtils.lastOrdinalIndexOf("*", null, 42));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,org.apache.commons.lang3.StringUtils.lastOrdinalIndexOf("", "", 42));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,org.apache.commons.lang3.StringUtils.lastOrdinalIndexOf("aabaabaa", "a", 1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),852,org.apache.commons.lang3.StringUtils.lastOrdinalIndexOf("aabaabaa", "a", 2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),853,org.apache.commons.lang3.StringUtils.lastOrdinalIndexOf("aabaabaa", "b", 1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),854,org.apache.commons.lang3.StringUtils.lastOrdinalIndexOf("aabaabaa", "b", 2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),855,org.apache.commons.lang3.StringUtils.lastOrdinalIndexOf("aabaabaa", "ab", 1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),856,org.apache.commons.lang3.StringUtils.lastOrdinalIndexOf("aabaabaa", "ab", 2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),857,org.apache.commons.lang3.StringUtils.lastOrdinalIndexOf("aabaabaa", "", 1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),858,org.apache.commons.lang3.StringUtils.lastOrdinalIndexOf("aabaabaa", "", 2));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testOrdinalIndexOf() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testOrdinalIndexOf");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),859,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),860,org.apache.commons.lang3.StringUtils.ordinalIndexOf(null, null, java.lang.Integer.MIN_VALUE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),861,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),862,org.apache.commons.lang3.StringUtils.ordinalIndexOf("", null, java.lang.Integer.MIN_VALUE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),863,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),864,org.apache.commons.lang3.StringUtils.ordinalIndexOf("", "", java.lang.Integer.MIN_VALUE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),866,org.apache.commons.lang3.StringUtils.ordinalIndexOf("aabaabaa", "a", java.lang.Integer.MIN_VALUE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,org.apache.commons.lang3.StringUtils.ordinalIndexOf("aabaabaa", "b", java.lang.Integer.MIN_VALUE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,org.apache.commons.lang3.StringUtils.ordinalIndexOf("aabaabaa", "ab", java.lang.Integer.MIN_VALUE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),871,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),872,org.apache.commons.lang3.StringUtils.ordinalIndexOf("aabaabaa", "", java.lang.Integer.MIN_VALUE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),873,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),874,org.apache.commons.lang3.StringUtils.ordinalIndexOf(null, null, -1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),875,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),876,org.apache.commons.lang3.StringUtils.ordinalIndexOf("", null, -1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),877,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),878,org.apache.commons.lang3.StringUtils.ordinalIndexOf("", "", -1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),879,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),880,org.apache.commons.lang3.StringUtils.ordinalIndexOf("aabaabaa", "a", -1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),881,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),882,org.apache.commons.lang3.StringUtils.ordinalIndexOf("aabaabaa", "b", -1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),883,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),884,org.apache.commons.lang3.StringUtils.ordinalIndexOf("aabaabaa", "ab", -1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),885,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),886,org.apache.commons.lang3.StringUtils.ordinalIndexOf("aabaabaa", "", -1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),887,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),888,org.apache.commons.lang3.StringUtils.ordinalIndexOf(null, null, 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),889,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),890,org.apache.commons.lang3.StringUtils.ordinalIndexOf("", null, 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),891,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),892,org.apache.commons.lang3.StringUtils.ordinalIndexOf("", "", 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),893,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),894,org.apache.commons.lang3.StringUtils.ordinalIndexOf("aabaabaa", "a", 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),895,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),896,org.apache.commons.lang3.StringUtils.ordinalIndexOf("aabaabaa", "b", 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),897,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),898,org.apache.commons.lang3.StringUtils.ordinalIndexOf("aabaabaa", "ab", 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),899,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),900,org.apache.commons.lang3.StringUtils.ordinalIndexOf("aabaabaa", "", 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),901,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),902,org.apache.commons.lang3.StringUtils.ordinalIndexOf(null, null, 1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),903,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),904,org.apache.commons.lang3.StringUtils.ordinalIndexOf("", null, 1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),905,org.apache.commons.lang3.StringUtils.ordinalIndexOf("", "", 1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),906,org.apache.commons.lang3.StringUtils.ordinalIndexOf("aabaabaa", "a", 1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),907,org.apache.commons.lang3.StringUtils.ordinalIndexOf("aabaabaa", "b", 1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),908,org.apache.commons.lang3.StringUtils.ordinalIndexOf("aabaabaa", "ab", 1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),909,org.apache.commons.lang3.StringUtils.ordinalIndexOf("aabaabaa", "", 1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),910,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),911,org.apache.commons.lang3.StringUtils.ordinalIndexOf(null, null, 2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),912,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),913,org.apache.commons.lang3.StringUtils.ordinalIndexOf("", null, 2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),914,org.apache.commons.lang3.StringUtils.ordinalIndexOf("", "", 2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),915,org.apache.commons.lang3.StringUtils.ordinalIndexOf("aabaabaa", "a", 2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),916,org.apache.commons.lang3.StringUtils.ordinalIndexOf("aabaabaa", "b", 2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),917,org.apache.commons.lang3.StringUtils.ordinalIndexOf("aabaabaa", "ab", 2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),918,org.apache.commons.lang3.StringUtils.ordinalIndexOf("aabaabaa", "", 2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),919,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),920,org.apache.commons.lang3.StringUtils.ordinalIndexOf(null, null, java.lang.Integer.MAX_VALUE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),921,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),922,org.apache.commons.lang3.StringUtils.ordinalIndexOf("", null, java.lang.Integer.MAX_VALUE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),923,org.apache.commons.lang3.StringUtils.ordinalIndexOf("", "", java.lang.Integer.MAX_VALUE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),924,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),925,org.apache.commons.lang3.StringUtils.ordinalIndexOf("aabaabaa", "a", java.lang.Integer.MAX_VALUE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),926,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),927,org.apache.commons.lang3.StringUtils.ordinalIndexOf("aabaabaa", "b", java.lang.Integer.MAX_VALUE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),928,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),929,org.apache.commons.lang3.StringUtils.ordinalIndexOf("aabaabaa", "ab", java.lang.Integer.MAX_VALUE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),930,org.apache.commons.lang3.StringUtils.ordinalIndexOf("aabaabaa", "", java.lang.Integer.MAX_VALUE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),931,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),932,org.apache.commons.lang3.StringUtils.ordinalIndexOf("aaaaaaaaa", "a", 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),933,org.apache.commons.lang3.StringUtils.ordinalIndexOf("aaaaaaaaa", "a", 1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),934,org.apache.commons.lang3.StringUtils.ordinalIndexOf("aaaaaaaaa", "a", 2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),935,org.apache.commons.lang3.StringUtils.ordinalIndexOf("aaaaaaaaa", "a", 3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),936,org.apache.commons.lang3.StringUtils.ordinalIndexOf("aaaaaaaaa", "a", 4));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),937,org.apache.commons.lang3.StringUtils.ordinalIndexOf("aaaaaaaaa", "a", 5));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),938,org.apache.commons.lang3.StringUtils.ordinalIndexOf("aaaaaaaaa", "a", 6));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),939,org.apache.commons.lang3.StringUtils.ordinalIndexOf("aaaaaaaaa", "a", 7));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),940,org.apache.commons.lang3.StringUtils.ordinalIndexOf("aaaaaaaaa", "a", 8));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),941,org.apache.commons.lang3.StringUtils.ordinalIndexOf("aaaaaaaaa", "a", 9));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),942,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),943,org.apache.commons.lang3.StringUtils.ordinalIndexOf("aaaaaaaaa", "a", 10));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }
}

