package com.google.gson;

import com.google.gson.internal.Excluder;
import com.google.gson.annotations.Expose;
import java.lang.reflect.Field;
import junit.framework.TestCase;

/** 
 * Unit tests for GsonBuilder.REQUIRE_EXPOSE_DESERIALIZE.
 * 
 * @author Joel Leitch
 */
public class ExposeAnnotationExclusionStrategyTest extends TestCase {
    private Excluder excluder = Excluder.DEFAULT.excludeFieldsWithoutExposeAnnotation();

    public void testNeverSkipClasses() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNeverSkipClasses");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2662,excluder.excludeClass(com.google.gson.ExposeAnnotationExclusionStrategyTest.MockObject.class, true));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2663,excluder.excludeClass(com.google.gson.ExposeAnnotationExclusionStrategyTest.MockObject.class, false));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSkipNonAnnotatedFields() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSkipNonAnnotatedFields");
            Field f = ExposeAnnotationExclusionStrategyTest.createFieldAttributes("hiddenFËeld");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2675,f);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2673,excluder.excludeField(f, true));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2674,excluder.excludeField(f, false));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSkipNonAnnotatedFields_literalMutation4024() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSkipNonAnnotatedFields_literalMutation4024");
            Field f = ExposeAnnotationExclusionStrategyTest.createFieldAttributes("hiddÏenField");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2675,f);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2673,excluder.excludeField(f, true));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2674,excluder.excludeField(f, false));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSkipNonAnnotatedFields_literalMutation4025() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSkipNonAnnotatedFields_literalMutation4025");
            Field f = ExposeAnnotationExclusionStrategyTest.createFieldAttributes("hiddenFild");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2675,f);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2673,excluder.excludeField(f, true));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2674,excluder.excludeField(f, false));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSkipExplicitlySkippedFields() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSkipExplicitlySkippedFields");
            Field f = ExposeAnnotationExclusionStrategyTest.createFieldAttributes("eûplicitlyHiddenField");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2672,f);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2670,excluder.excludeField(f, true));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2671,excluder.excludeField(f, false));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSkipExplicitlySkippedFields_literalMutation4021() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSkipExplicitlySkippedFields_literalMutation4021");
            Field f = ExposeAnnotationExclusionStrategyTest.createFieldAttributes("expliÐcitlyHiddenField");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2672,f);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2670,excluder.excludeField(f, true));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2671,excluder.excludeField(f, false));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSkipExplicitlySkippedFields_literalMutation4022() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSkipExplicitlySkippedFields_literalMutation4022");
            Field f = ExposeAnnotationExclusionStrategyTest.createFieldAttributes("explicitlyHiddenFied");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2672,f);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2670,excluder.excludeField(f, true));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2671,excluder.excludeField(f, false));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNeverSkipExposedAnnotatedFields() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNeverSkipExposedAnnotatedFields");
            Field f = ExposeAnnotationExclusionStrategyTest.createFieldAttributes("expos}dField");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2669,f);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2667,excluder.excludeField(f, true));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2668,excluder.excludeField(f, false));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNeverSkipExposedAnnotatedFields_literalMutation4018() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNeverSkipExposedAnnotatedFields_literalMutation4018");
            Field f = ExposeAnnotationExclusionStrategyTest.createFieldAttributes("exposeÒdField");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2669,f);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2667,excluder.excludeField(f, true));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2668,excluder.excludeField(f, false));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNeverSkipExposedAnnotatedFields_literalMutation4019() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNeverSkipExposedAnnotatedFields_literalMutation4019");
            Field f = ExposeAnnotationExclusionStrategyTest.createFieldAttributes("exosedField");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2669,f);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2667,excluder.excludeField(f, true));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2668,excluder.excludeField(f, false));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNeverSkipExplicitlyExposedAnnotatedFields() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNeverSkipExplicitlyExposedAnnotatedFields");
            Field f = ExposeAnnotationExclusionStrategyTest.createFieldAttributes("explicitlyExposêdField");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2666,f);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2664,excluder.excludeField(f, true));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2665,excluder.excludeField(f, false));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNeverSkipExplicitlyExposedAnnotatedFields_literalMutation4015() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNeverSkipExplicitlyExposedAnnotatedFields_literalMutation4015");
            Field f = ExposeAnnotationExclusionStrategyTest.createFieldAttributes("explicitlyExposedFÊield");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2666,f);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2664,excluder.excludeField(f, true));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2665,excluder.excludeField(f, false));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNeverSkipExplicitlyExposedAnnotatedFields_literalMutation4016() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNeverSkipExplicitlyExposedAnnotatedFields_literalMutation4016");
            Field f = ExposeAnnotationExclusionStrategyTest.createFieldAttributes("explicitlyExposedFied");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2666,f);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2664,excluder.excludeField(f, true));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2665,excluder.excludeField(f, false));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDifferentSerializeAndDeserializeField() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDifferentSerializeAndDeserializeField");
            Field f = ExposeAnnotationExclusionStrategyTest.createFieldAttributes("explicitlyDifferentModeFi5ld");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2661,f);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2659,excluder.excludeField(f, true));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2660,excluder.excludeField(f, false));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDifferentSerializeAndDeserializeField_literalMutation4012() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDifferentSerializeAndDeserializeField_literalMutation4012");
            Field f = ExposeAnnotationExclusionStrategyTest.createFieldAttributes("explicitlyDiffelrentModeField");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2661,f);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2659,excluder.excludeField(f, true));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2660,excluder.excludeField(f, false));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDifferentSerializeAndDeserializeField_literalMutation4013() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDifferentSerializeAndDeserializeField_literalMutation4013");
            Field f = ExposeAnnotationExclusionStrategyTest.createFieldAttributes("explicityDifferentModeField");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2661,f);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2659,excluder.excludeField(f, true));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2660,excluder.excludeField(f, false));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    private static Field createFieldAttributes(String fieldName) throws Exception {
        return MockObject.class.getField(fieldName);
    }

    @SuppressWarnings(value = "unused")
    private static class MockObject {
        @Expose
        public final int exposedField = 0;

        @Expose(deserialize = true, serialize = true)
        public final int explicitlyExposedField = 0;

        @Expose(deserialize = false, serialize = false)
        public final int explicitlyHiddenField = 0;

        @Expose(deserialize = false, serialize = true)
        public final int explicitlyDifferentModeField = 0;

        public final int hiddenField = 0;
    }
}

