package com.google.gson;

import java.util.List;
import org.junit.Test;
import junit.framework.TestCase;
import java.lang.reflect.Type;
import com.google.gson.reflect.TypeToken;

/** 
 * Unit tests for the {@link FieldAttributes} class.
 * 
 * @author Inderjeet Singh
 * @author Joel Leitch
 */
public class FieldAttributesTest extends TestCase {
    private FieldAttributes fieldAttributes;

    @Override
    protected void setUp() throws Exception {
        super.setUp();
        fieldAttributes = new FieldAttributes(Foo.class.getField("bar"));
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2676,fieldAttributes);
    }

    public void testNullField() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullField");
            try {
                new FieldAttributes(null);
            } catch (NullPointerException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDeclaringClass() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeclaringClass");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2682,com.google.gson.FieldAttributesTest.Foo.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2683,fieldAttributes.getDeclaringClass());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testModifiers() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testModifiers");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2685,fieldAttributes.hasModifier(java.lang.reflect.Modifier.STATIC));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2686,fieldAttributes.hasModifier(java.lang.reflect.Modifier.FINAL));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2687,fieldAttributes.hasModifier(java.lang.reflect.Modifier.ABSTRACT));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2688,fieldAttributes.hasModifier(java.lang.reflect.Modifier.VOLATILE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2689,fieldAttributes.hasModifier(java.lang.reflect.Modifier.PROTECTED));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2690,fieldAttributes.hasModifier(java.lang.reflect.Modifier.PUBLIC));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2691,fieldAttributes.hasModifier(java.lang.reflect.Modifier.TRANSIENT));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testIsSynthetic() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsSynthetic");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2684,fieldAttributes.isSynthetic());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testName() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testName");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2692,fieldAttributes.getName());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDeclaredTypeAndClass() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeclaredTypeAndClass");
            Type expectedType = new TypeToken<java.util.List<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2681,expectedType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2677,expectedType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2678,fieldAttributes.getDeclaredType());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2679,java.util.List.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2680,fieldAttributes.getDeclaredClass());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDeclaredTypeAndClass_remove472() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeclaredTypeAndClass_remove472");
            Type expectedType = new TypeToken<java.util.List<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2681,expectedType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2677,expectedType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2678,fieldAttributes.getDeclaredType());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2679,java.util.List.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2680,fieldAttributes.getDeclaredClass());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    private static class Foo {
        @SuppressWarnings(value = "unused")
        public transient List<java.lang.String> bar;
    }
}

