package com.google.gson;

import com.google.gson.stream.JsonReader;
import com.google.gson.stream.JsonWriter;
import org.junit.Test;
import junit.framework.TestCase;
import java.lang.reflect.Type;

/** 
 * Unit tests for {@link GsonBuilder}.
 * 
 * @author Inderjeet Singh
 */
public class GsonBuilderTest extends TestCase {
    private static final TypeAdapter<java.lang.Object> NULL_TYPE_ADAPTER = new TypeAdapter<java.lang.Object>() {
        @Override
        public void write(JsonWriter out, Object value) {
            throw new AssertionError();
        }

        @Override
        public Object read(JsonReader in) {
            throw new AssertionError();
        }
    };

    @Test(timeout = 1000)
    public void testCreatingMoreThanOnce() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCreatingMoreThanOnce");
            GsonBuilder builder = new GsonBuilder();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2693,builder);
            builder.create();
            builder.create();
            builder.create();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCreatingMoreThanOnce_add580() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCreatingMoreThanOnce_add580");
            GsonBuilder builder = new GsonBuilder();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2693,builder);
            builder.create();
            builder.create();
            builder.create();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCreatingMoreThanOnce_remove473() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCreatingMoreThanOnce_remove473");
            GsonBuilder builder = new GsonBuilder();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2693,builder);
            builder.create();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCreatingMoreThanOnce_remove474() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCreatingMoreThanOnce_remove474");
            GsonBuilder builder = new GsonBuilder();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2693,builder);
            builder.create();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExcludeFieldsWithModifiers() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExcludeFieldsWithModifiers");
            Gson gson = new GsonBuilder().excludeFieldsWithModifiers(java.lang.reflect.Modifier.VOLATILE, java.lang.reflect.Modifier.PRIVATE).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2695,gson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2694,gson.toJson(new com.google.gson.GsonBuilderTest.HasModifiers()));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRegisterTypeAdapterForCoreType() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegisterTypeAdapterForCoreType");
            Type[] types = new Type[]{ byte.class , int.class , double.class , Short.class , Long.class , String.class };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2696,types);
            for (Type type : types) {
                new GsonBuilder().registerTypeAdapter(type, NULL_TYPE_ADAPTER);
                new GsonBuilder().registerTypeAdapter(type, NULL_TYPE_ADAPTER);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRegisterTypeAdapterForCoreType_remove475() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegisterTypeAdapterForCoreType_remove475");
            Type[] types = new Type[]{ byte.class , int.class , double.class , Short.class , Long.class , String.class };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2696,types);
            for (Type type : types) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "unused")
    static class HasModifiers {
        private String a = "a";

        volatile String b = "b";

        private volatile String c = "c";

        String d = "d";
    }

    public void testTransientFieldExclusion() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTransientFieldExclusion");
            Gson gson = new GsonBuilder().excludeFieldsWithModifiers().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1121,gson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2697,gson.toJson(new com.google.gson.GsonBuilderTest.HasTransients()));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    static class HasTransients {
        transient String a = "a";
    }
}

