package com.google.gson;

import java.io.CharArrayReader;
import java.io.CharArrayWriter;
import com.google.gson.stream.JsonReader;
import java.io.StringReader;
import org.junit.Test;
import junit.framework.TestCase;
import com.google.gson.common.TestTypes;

/** 
 * Unit test for {@link JsonParser}
 * 
 * @author Inderjeet Singh
 */
public class JsonParserTest extends TestCase {
    private JsonParser parser;

    @Override
    protected void setUp() throws Exception {
        super.setUp();
        parser = new JsonParser();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2805,parser);
    }

    public void testParseInvalidJson() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testParseInvalidJson");
            try {
                parser.parse("[[]");
            } catch (JsonSyntaxException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testParseInvalidJson_add614() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testParseInvalidJson_add614");
            try {
                parser.parse("[[]");
                parser.parse("[[]");
            } catch (JsonSyntaxException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testParseInvalidJson_literalMutation4154() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testParseInvalidJson_literalMutation4154");
            try {
                parser.parse("K[]");
            } catch (JsonSyntaxException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testParseInvalidJson_literalMutation4155() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testParseInvalidJson_literalMutation4155");
            try {
                parser.parse("[[]");
            } catch (JsonSyntaxException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testParseInvalidJson_literalMutation4156() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testParseInvalidJson_literalMutation4156");
            try {
                parser.parse("[]");
            } catch (JsonSyntaxException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testParseUnquotedStringArrayFails() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testParseUnquotedStringArrayFails");
            JsonElement element = parser.parse("[a,Ü,c]");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2832,element);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2828,element.getAsJsonArray().get(0).getAsString());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2829,element.getAsJsonArray().get(1).getAsString());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2830,element.getAsJsonArray().get(2).getAsString());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2831,element.getAsJsonArray().size());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testParseUnquotedStringArrayFails_literalMutation4170() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testParseUnquotedStringArrayFails_literalMutation4170");
            JsonElement element = parser.parse("[a,b,c]");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2832,element);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2828,element.getAsJsonArray().get(0).getAsString());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2829,element.getAsJsonArray().get(1).getAsString());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2830,element.getAsJsonArray().get(2).getAsString());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2831,element.getAsJsonArray().size());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testParseUnquotedStringArrayFails_literalMutation4171() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testParseUnquotedStringArrayFails_literalMutation4171");
            JsonElement element = parser.parse("[a,bc]");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2832,element);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2828,element.getAsJsonArray().get(0).getAsString());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2829,element.getAsJsonArray().get(1).getAsString());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2830,element.getAsJsonArray().get(2).getAsString());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2831,element.getAsJsonArray().size());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testParseString() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testParseString");
            String json = "{a:10,Á:\'c\'}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),908,json);
            JsonElement e = parser.parse(json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2825,e);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2822,e.isJsonObject());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2823,e.getAsJsonObject().get("a").getAsInt());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2824,e.getAsJsonObject().get("b").getAsString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testParseString_literalMutation4164() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testParseString_literalMutation4164");
            String json = "{a:10,b :\'c\'}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),908,json);
            JsonElement e = parser.parse(json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2825,e);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2822,e.isJsonObject());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2823,e.getAsJsonObject().get("a").getAsInt());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2824,e.getAsJsonObject().get("b").getAsString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testParseString_literalMutation4165() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testParseString_literalMutation4165");
            String json = "{a:10,:\'c\'}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),908,json);
            JsonElement e = parser.parse(json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2825,e);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2822,e.isJsonObject());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2823,e.getAsJsonObject().get("a").getAsInt());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2824,e.getAsJsonObject().get("b").getAsString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testParseEmptyString() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testParseEmptyString");
            JsonElement e = parser.parse("\"  \"");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2808,e);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2806,e.isJsonPrimitive());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2807,e.getAsString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testParseEmptyString_literalMutation4149() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testParseEmptyString_literalMutation4149");
            JsonElement e = parser.parse("\"}   \"");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2808,e);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2806,e.isJsonPrimitive());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2807,e.getAsString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testParseEmptyString_literalMutation4150() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testParseEmptyString_literalMutation4150");
            JsonElement e = parser.parse("\"  \"");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2808,e);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2806,e.isJsonPrimitive());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2807,e.getAsString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testParseEmptyWhitespaceInput() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testParseEmptyWhitespaceInput");
            JsonElement e = parser.parse("  \b  ");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2810,e);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2809,e.isJsonNull());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testParseEmptyWhitespaceInput_literalMutation4152() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testParseEmptyWhitespaceInput_literalMutation4152");
            JsonElement e = parser.parse("     ");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2810,e);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2809,e.isJsonNull());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testParseEmptyWhitespaceInput_literalMutation4153() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testParseEmptyWhitespaceInput_literalMutation4153");
            JsonElement e = parser.parse("    ");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2810,e);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2809,e.isJsonNull());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testParseUnquotedSingleWordStringFails() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testParseUnquotedSingleWordStringFails");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2827,parser.parse("Test").getAsString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testParseUnquotedMultiWordStringFails_add615() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testParseUnquotedMultiWordStringFails_add615");
            String unquotedSentence = "Test is a test..blah blah";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2826,unquotedSentence);
            try {
                parser.parse(unquotedSentence);
                parser.parse(unquotedSentence);
            } catch (JsonSyntaxException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testParseUnquotedMultiWordStringFails() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testParseUnquotedMultiWordStringFails");
            String unquotedSentence = "T&st is a test..blah blah";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2826,unquotedSentence);
            try {
                parser.parse(unquotedSentence);
            } catch (JsonSyntaxException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testParseUnquotedMultiWordStringFails_literalMutation4167() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testParseUnquotedMultiWordStringFails_literalMutation4167");
            String unquotedSentence = "Te`st is a test..blah blah";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2826,unquotedSentence);
            try {
                parser.parse(unquotedSentence);
            } catch (JsonSyntaxException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testParseUnquotedMultiWordStringFails_literalMutation4168() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testParseUnquotedMultiWordStringFails_literalMutation4168");
            String unquotedSentence = "Test is a test..blahblah";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2826,unquotedSentence);
            try {
                parser.parse(unquotedSentence);
            } catch (JsonSyntaxException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testParseMixedArray() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testParseMixedArray");
            String json = "[{}Ò13,\"stringValue\"]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),884,json);
            JsonElement e = parser.parse(json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2815,e);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2811,e.isJsonArray());
            JsonArray array = e.getAsJsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2816,array);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2812,array.get(0).toString());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2813,array.get(1).getAsInt());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2814,array.get(2).getAsString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testParseMixedArray_literalMutation4158() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testParseMixedArray_literalMutation4158");
            String json = "[{},13,\"stringVaÃlue\"]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),884,json);
            JsonElement e = parser.parse(json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2815,e);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2811,e.isJsonArray());
            JsonArray array = e.getAsJsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2816,array);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2812,array.get(0).toString());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2813,array.get(1).getAsInt());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2814,array.get(2).getAsString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testParseMixedArray_literalMutation4159() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testParseMixedArray_literalMutation4159");
            String json = "[{},1,\"stringValue\"]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),884,json);
            JsonElement e = parser.parse(json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2815,e);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2811,e.isJsonArray());
            JsonArray array = e.getAsJsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2816,array);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2812,array.get(0).toString());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2813,array.get(1).getAsInt());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2814,array.get(2).getAsString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testParseReader() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testParseReader");
            StringReader reader = new StringReader("Aa:10,b:\'c\'}");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2820,reader);
            JsonElement e = parser.parse(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2821,e);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2817,e.isJsonObject());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2818,e.getAsJsonObject().get("a").getAsInt());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2819,e.getAsJsonObject().get("b").getAsString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testParseReader_literalMutation4161() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testParseReader_literalMutation4161");
            StringReader reader = new StringReader("{a:10,b:ñ\'c\'}");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2820,reader);
            JsonElement e = parser.parse(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2821,e);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2817,e.isJsonObject());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2818,e.getAsJsonObject().get("a").getAsInt());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2819,e.getAsJsonObject().get("b").getAsString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testParseReader_literalMutation4162() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testParseReader_literalMutation4162");
            StringReader reader = new StringReader("{a:10,b:c\'}");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2820,reader);
            JsonElement e = parser.parse(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2821,e);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2817,e.isJsonObject());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2818,e.getAsJsonObject().get("a").getAsInt());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2819,e.getAsJsonObject().get("b").getAsString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoObjects() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1188,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2835,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(1 , 1 , true , "one");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2836,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(2 , 2 , false , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2837,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2838,reader);
            JsonReader parser = new JsonReader(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2839,parser);
            parser.setLenient(true);
            JsonElement element1 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2840,element1);
            JsonElement element2 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2841,element2);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(element1, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2842,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2833,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(element2, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2843,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2834,actualTwo.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testReadWriteTwoObjects_add616() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_add616");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1188,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2835,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(1 , 1 , true , "one");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2836,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(2 , 2 , false , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2837,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2838,reader);
            JsonReader parser = new JsonReader(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2839,parser);
            parser.setLenient(true);
            JsonElement element1 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2840,element1);
            JsonElement element2 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2841,element2);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(element1, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2842,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2833,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(element2, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2843,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2834,actualTwo.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testReadWriteTwoObjects_add617() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_add617");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1188,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2835,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(1 , 1 , true , "one");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2836,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(2 , 2 , false , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2837,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2838,reader);
            JsonReader parser = new JsonReader(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2839,parser);
            parser.setLenient(true);
            JsonElement element1 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2840,element1);
            JsonElement element2 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2841,element2);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(element1, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2842,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2833,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(element2, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2843,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2834,actualTwo.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testReadWriteTwoObjects_add618() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_add618");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1188,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2835,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(1 , 1 , true , "one");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2836,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(2 , 2 , false , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2837,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2838,reader);
            JsonReader parser = new JsonReader(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2839,parser);
            parser.setLenient(true);
            parser.setLenient(true);
            JsonElement element1 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2840,element1);
            JsonElement element2 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2841,element2);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(element1, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2842,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2833,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(element2, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2843,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2834,actualTwo.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoObjects_literalMutation4172() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_literalMutation4172");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1188,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2835,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(2 , 1 , true , "one");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2836,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(2 , 2 , false , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2837,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2838,reader);
            JsonReader parser = new JsonReader(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2839,parser);
            parser.setLenient(true);
            JsonElement element1 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2840,element1);
            JsonElement element2 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2841,element2);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(element1, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2842,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2833,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(element2, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2843,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2834,actualTwo.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoObjects_literalMutation4173() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_literalMutation4173");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1188,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2835,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(0 , 1 , true , "one");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2836,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(2 , 2 , false , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2837,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2838,reader);
            JsonReader parser = new JsonReader(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2839,parser);
            parser.setLenient(true);
            JsonElement element1 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2840,element1);
            JsonElement element2 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2841,element2);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(element1, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2842,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2833,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(element2, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2843,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2834,actualTwo.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoObjects_literalMutation4174() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_literalMutation4174");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1188,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2835,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(0 , 1 , true , "one");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2836,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(2 , 2 , false , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2837,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2838,reader);
            JsonReader parser = new JsonReader(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2839,parser);
            parser.setLenient(true);
            JsonElement element1 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2840,element1);
            JsonElement element2 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2841,element2);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(element1, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2842,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2833,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(element2, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2843,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2834,actualTwo.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoObjects_literalMutation4176() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_literalMutation4176");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1188,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2835,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(1 , 2 , true , "one");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2836,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(2 , 2 , false , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2837,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2838,reader);
            JsonReader parser = new JsonReader(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2839,parser);
            parser.setLenient(true);
            JsonElement element1 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2840,element1);
            JsonElement element2 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2841,element2);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(element1, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2842,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2833,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(element2, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2843,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2834,actualTwo.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoObjects_literalMutation4177() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_literalMutation4177");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1188,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2835,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(1 , 0 , true , "one");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2836,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(2 , 2 , false , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2837,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2838,reader);
            JsonReader parser = new JsonReader(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2839,parser);
            parser.setLenient(true);
            JsonElement element1 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2840,element1);
            JsonElement element2 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2841,element2);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(element1, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2842,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2833,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(element2, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2843,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2834,actualTwo.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoObjects_literalMutation4178() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_literalMutation4178");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1188,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2835,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(1 , 0 , true , "one");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2836,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(2 , 2 , false , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2837,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2838,reader);
            JsonReader parser = new JsonReader(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2839,parser);
            parser.setLenient(true);
            JsonElement element1 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2840,element1);
            JsonElement element2 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2841,element2);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(element1, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2842,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2833,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(element2, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2843,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2834,actualTwo.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoObjects_literalMutation4181() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_literalMutation4181");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1188,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2835,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(1 , 1 , true , "ne");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2836,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(2 , 2 , false , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2837,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2838,reader);
            JsonReader parser = new JsonReader(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2839,parser);
            parser.setLenient(true);
            JsonElement element1 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2840,element1);
            JsonElement element2 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2841,element2);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(element1, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2842,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2833,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(element2, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2843,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2834,actualTwo.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoObjects_literalMutation4182() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_literalMutation4182");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1188,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2835,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(1 , 1 , true , "omne");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2836,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(2 , 2 , false , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2837,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2838,reader);
            JsonReader parser = new JsonReader(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2839,parser);
            parser.setLenient(true);
            JsonElement element1 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2840,element1);
            JsonElement element2 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2841,element2);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(element1, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2842,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2833,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(element2, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2843,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2834,actualTwo.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoObjects_literalMutation4183() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_literalMutation4183");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1188,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2835,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(1 , 1 , true , "oe");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2836,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(2 , 2 , false , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2837,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2838,reader);
            JsonReader parser = new JsonReader(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2839,parser);
            parser.setLenient(true);
            JsonElement element1 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2840,element1);
            JsonElement element2 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2841,element2);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(element1, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2842,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2833,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(element2, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2843,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2834,actualTwo.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoObjects_literalMutation4184() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_literalMutation4184");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1188,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2835,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(1 , 1 , true , "one");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2836,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(1 , 2 , false , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2837,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2838,reader);
            JsonReader parser = new JsonReader(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2839,parser);
            parser.setLenient(true);
            JsonElement element1 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2840,element1);
            JsonElement element2 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2841,element2);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(element1, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2842,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2833,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(element2, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2843,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2834,actualTwo.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoObjects_literalMutation4185() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_literalMutation4185");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1188,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2835,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(1 , 1 , true , "one");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2836,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(4 , 2 , false , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2837,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2838,reader);
            JsonReader parser = new JsonReader(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2839,parser);
            parser.setLenient(true);
            JsonElement element1 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2840,element1);
            JsonElement element2 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2841,element2);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(element1, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2842,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2833,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(element2, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2843,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2834,actualTwo.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoObjects_literalMutation4186() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_literalMutation4186");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1188,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2835,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(1 , 1 , true , "one");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2836,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(3 , 2 , false , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2837,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2838,reader);
            JsonReader parser = new JsonReader(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2839,parser);
            parser.setLenient(true);
            JsonElement element1 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2840,element1);
            JsonElement element2 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2841,element2);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(element1, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2842,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2833,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(element2, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2843,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2834,actualTwo.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoObjects_literalMutation4188() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_literalMutation4188");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1188,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2835,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(1 , 1 , true , "one");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2836,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(2 , 1 , false , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2837,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2838,reader);
            JsonReader parser = new JsonReader(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2839,parser);
            parser.setLenient(true);
            JsonElement element1 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2840,element1);
            JsonElement element2 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2841,element2);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(element1, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2842,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2833,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(element2, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2843,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2834,actualTwo.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoObjects_literalMutation4189() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_literalMutation4189");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1188,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2835,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(1 , 1 , true , "one");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2836,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(2 , 4 , false , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2837,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2838,reader);
            JsonReader parser = new JsonReader(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2839,parser);
            parser.setLenient(true);
            JsonElement element1 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2840,element1);
            JsonElement element2 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2841,element2);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(element1, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2842,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2833,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(element2, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2843,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2834,actualTwo.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoObjects_literalMutation4190() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_literalMutation4190");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1188,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2835,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(1 , 1 , true , "one");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2836,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(2 , 3 , false , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2837,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2838,reader);
            JsonReader parser = new JsonReader(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2839,parser);
            parser.setLenient(true);
            JsonElement element1 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2840,element1);
            JsonElement element2 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2841,element2);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(element1, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2842,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2833,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(element2, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2843,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2834,actualTwo.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoObjects_literalMutation4192() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_literalMutation4192");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1188,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2835,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(1 , 1 , true , "one");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2836,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(2 , 2 , true , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2837,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2838,reader);
            JsonReader parser = new JsonReader(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2839,parser);
            parser.setLenient(true);
            JsonElement element1 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2840,element1);
            JsonElement element2 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2841,element2);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(element1, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2842,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2833,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(element2, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2843,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2834,actualTwo.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoObjects_literalMutation4193() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_literalMutation4193");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1188,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2835,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(1 , 1 , true , "one");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2836,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(2 , 2 , false , "¸wo");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2837,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2838,reader);
            JsonReader parser = new JsonReader(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2839,parser);
            parser.setLenient(true);
            JsonElement element1 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2840,element1);
            JsonElement element2 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2841,element2);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(element1, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2842,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2833,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(element2, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2843,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2834,actualTwo.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoObjects_literalMutation4194() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_literalMutation4194");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1188,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2835,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(1 , 1 , true , "one");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2836,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(2 , 2 , false , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2837,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2838,reader);
            JsonReader parser = new JsonReader(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2839,parser);
            parser.setLenient(true);
            JsonElement element1 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2840,element1);
            JsonElement element2 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2841,element2);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(element1, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2842,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2833,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(element2, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2843,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2834,actualTwo.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoObjects_literalMutation4195() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_literalMutation4195");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1188,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2835,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(1 , 1 , true , "one");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2836,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(2 , 2 , false , "to");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2837,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2838,reader);
            JsonReader parser = new JsonReader(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2839,parser);
            parser.setLenient(true);
            JsonElement element1 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2840,element1);
            JsonElement element2 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2841,element2);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(element1, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2842,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2833,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(element2, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2843,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2834,actualTwo.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testReadWriteTwoObjects_remove504() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_remove504");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1188,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2835,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(1 , 1 , true , "one");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2836,expectedOne);
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(2 , 2 , false , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2837,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2838,reader);
            JsonReader parser = new JsonReader(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2839,parser);
            parser.setLenient(true);
            JsonElement element1 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2840,element1);
            JsonElement element2 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2841,element2);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(element1, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2842,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2833,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(element2, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2843,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2834,actualTwo.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testReadWriteTwoObjects_remove505() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_remove505");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1188,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2835,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(1 , 1 , true , "one");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2836,expectedOne);
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(2 , 2 , false , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2837,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2838,reader);
            JsonReader parser = new JsonReader(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2839,parser);
            parser.setLenient(true);
            JsonElement element1 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2840,element1);
            JsonElement element2 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2841,element2);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(element1, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2842,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2833,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(element2, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2843,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2834,actualTwo.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testReadWriteTwoObjects_remove506() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_remove506");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1188,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2835,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(1 , 1 , true , "one");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2836,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(2 , 2 , false , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2837,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2838,reader);
            JsonReader parser = new JsonReader(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2839,parser);
            JsonElement element1 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2840,element1);
            JsonElement element2 = com.google.gson.internal.Streams.parse(parser);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2841,element2);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(element1, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2842,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2833,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(element2, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2843,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2834,actualTwo.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }
}

