package com.google.gson.functional;

import com.google.gson.Gson;
import com.google.gson.GsonBuilder;
import com.google.gson.JsonDeserializationContext;
import com.google.gson.JsonDeserializer;
import com.google.gson.JsonElement;
import com.google.gson.JsonObject;
import com.google.gson.JsonParseException;
import org.junit.Test;
import junit.framework.TestCase;
import com.google.gson.common.TestTypes;
import java.lang.reflect.Type;

/** 
 * Functional Test exercising custom deserialization only.  When test applies to both
 * serialization and deserialization then add it to CustomTypeAdapterTest.
 * 
 * @author Joel Leitch
 */
public class CustomDeserializerTest extends TestCase {
    private static final String DEFAULT_VALUE = "test123";

    private static final String SUFFIX = "blah";

    private Gson gson;

    @Override
    protected void setUp() throws Exception {
        super.setUp();
        gson = new GsonBuilder().registerTypeAdapter(DataHolder.class, new DataHolderDeserializer()).create();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),276,gson);
    }

    public void testDefaultConstructorNotCalledOnObject() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultConstructorNotCalledOnObject");
            DataHolder data = new DataHolder(DEFAULT_VALUE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),300,data);
            String json = gson.toJson(data);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),301,json);
            DataHolder actual = gson.fromJson(json, DataHolder.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),138,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),298,((com.google.gson.functional.CustomDeserializerTest.DEFAULT_VALUE) + (com.google.gson.functional.CustomDeserializerTest.SUFFIX)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),299,actual.getData());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultConstructorNotCalledOnField() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultConstructorNotCalledOnField");
            DataHolderWrapper dataWrapper = new DataHolderWrapper(new DataHolder(DEFAULT_VALUE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),296,dataWrapper);
            String json = gson.toJson(dataWrapper);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),239,json);
            DataHolderWrapper actual = gson.fromJson(json, DataHolderWrapper.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),297,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),294,((com.google.gson.functional.CustomDeserializerTest.DEFAULT_VALUE) + (com.google.gson.functional.CustomDeserializerTest.SUFFIX)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),295,actual.getWrappedData().getData());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    private static class DataHolder {
        private final String data;

        @SuppressWarnings(value = "unused")
        private DataHolder() {
            throw new IllegalStateException();
        }

        public DataHolder(String data) {
            this.data = data;
        }

        public String getData() {
            return data;
        }
    }

    private static class DataHolderWrapper {
        private final DataHolder wrappedData;

        @SuppressWarnings(value = "unused")
        private DataHolderWrapper() {
            this(new DataHolder(CustomDeserializerTest.DEFAULT_VALUE));
        }

        public DataHolderWrapper(DataHolder data) {
            this.wrappedData = data;
        }

        public DataHolder getWrappedData() {
            return wrappedData;
        }
    }

    private static class DataHolderDeserializer implements JsonDeserializer<DataHolder> {
        public DataHolder deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) throws JsonParseException {
            JsonObject jsonObj = json.getAsJsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),274,jsonObj);
            String dataString = jsonObj.get("data").getAsString();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),275,dataString);
            return new DataHolder((dataString + (CustomDeserializerTest.SUFFIX)));
        }
    }

    @Test(timeout = 1000)
    public void testJsonTypeFieldBasedDeserialization_add61() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonTypeFieldBasedDeserialization_add61");
            String json = "{field1:\'abc\',field2:\'def\',__type__:\'SUB_TYPE1\'}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,json);
            Gson gson = new GsonBuilder().registerTypeAdapter(MyBase.class, new JsonDeserializer<MyBase>() {
                public MyBase deserialize(JsonElement json, Type pojoType, JsonDeserializationContext context) throws JsonParseException {
                    String type = json.getAsJsonObject().get(MyBase.TYPE_ACCESS).getAsString();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),302,type);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),302,type);
                    return context.deserialize(json, SubTypes.valueOf(type).getSubclass());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),304,gson);
            SubType1 target = ((SubType1)(gson.fromJson(json, MyBase.class)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),76,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),303,target.field1);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonTypeFieldBasedDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonTypeFieldBasedDeserialization");
            String json = "{field1:\'abc\',field2:\'def\',__type__:\'SsB_TYPE1\'}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,json);
            Gson gson = new GsonBuilder().registerTypeAdapter(MyBase.class, new JsonDeserializer<MyBase>() {
                public MyBase deserialize(JsonElement json, Type pojoType, JsonDeserializationContext context) throws JsonParseException {
                    String type = json.getAsJsonObject().get(MyBase.TYPE_ACCESS).getAsString();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),302,type);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),302,type);
                    return context.deserialize(json, SubTypes.valueOf(type).getSubclass());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),304,gson);
            SubType1 target = ((SubType1)(gson.fromJson(json, MyBase.class)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),76,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),303,target.field1);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonTypeFieldBasedDeserialization_literalMutation713() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonTypeFieldBasedDeserialization_literalMutation713");
            String json = "{field1:\'abc\',field2:\'def\',__type_À_:\'SUB_TYPE1\'}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,json);
            Gson gson = new GsonBuilder().registerTypeAdapter(MyBase.class, new JsonDeserializer<MyBase>() {
                public MyBase deserialize(JsonElement json, Type pojoType, JsonDeserializationContext context) throws JsonParseException {
                    String type = json.getAsJsonObject().get(MyBase.TYPE_ACCESS).getAsString();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),302,type);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),302,type);
                    return context.deserialize(json, SubTypes.valueOf(type).getSubclass());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),304,gson);
            SubType1 target = ((SubType1)(gson.fromJson(json, MyBase.class)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),76,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),303,target.field1);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonTypeFieldBasedDeserialization_literalMutation714() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonTypeFieldBasedDeserialization_literalMutation714");
            String json = "{feld1:\'abc\',field2:\'def\',__type__:\'SUB_TYPE1\'}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,json);
            Gson gson = new GsonBuilder().registerTypeAdapter(MyBase.class, new JsonDeserializer<MyBase>() {
                public MyBase deserialize(JsonElement json, Type pojoType, JsonDeserializationContext context) throws JsonParseException {
                    String type = json.getAsJsonObject().get(MyBase.TYPE_ACCESS).getAsString();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),302,type);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),302,type);
                    return context.deserialize(json, SubTypes.valueOf(type).getSubclass());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),304,gson);
            SubType1 target = ((SubType1)(gson.fromJson(json, MyBase.class)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),76,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),303,target.field1);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testJsonTypeFieldBasedDeserialization_remove60() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonTypeFieldBasedDeserialization_remove60");
            String json = "{field1:\'abc\',field2:\'def\',__type__:\'SUB_TYPE1\'}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,json);
            Gson gson = new GsonBuilder().registerTypeAdapter(MyBase.class, new JsonDeserializer<MyBase>() {
                public MyBase deserialize(JsonElement json, Type pojoType, JsonDeserializationContext context) throws JsonParseException {
                    String type = json.getAsJsonObject().get(MyBase.TYPE_ACCESS).getAsString();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),302,type);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),302,type);
                    return context.deserialize(json, SubTypes.valueOf(type).getSubclass());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),304,gson);
            SubType1 target = ((SubType1)(gson.fromJson(json, MyBase.class)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),76,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),303,target.field1);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    private static class MyBase {
        static final String TYPE_ACCESS = "__type__";
    }

    private enum SubTypes {
SUB_TYPE1(com.google.gson.functional.CustomDeserializerTest.SubType1.class), SUB_TYPE2(com.google.gson.functional.CustomDeserializerTest.SubType2.class);
        private final Type subClass;
        private SubTypes(Type subClass) {
            this.subClass = subClass;
        }
        public Type getSubclass() {
            return subClass;
        }
    }

    private static class SubType1 extends MyBase {
        String field1;
    }

    private static class SubType2 extends MyBase {
        @SuppressWarnings(value = "unused")
        String field2;
    }

    public void testCustomDeserializerReturnsNullForTopLevelObject() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomDeserializerReturnsNullForTopLevelObject");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new JsonDeserializer<com.google.gson.common.TestTypes.Base>() {
                public TestTypes.Base deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) throws JsonParseException {
                    return null;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),288,gson);
            String json = "{baseName:\'Base\',subName:\'SubRevised\'}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),289,json);
            TestTypes.Base target = gson.fromJson(json, TestTypes.Base.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),290,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),287,target);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomDeserializerReturnsNullForTopLevelObject_add60() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomDeserializerReturnsNullForTopLevelObject_add60");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new JsonDeserializer<com.google.gson.common.TestTypes.Base>() {
                public TestTypes.Base deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) throws JsonParseException {
                    return null;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),288,gson);
            String json = "{baseName:\'Base\',subName:\'SubRevised\'}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),289,json);
            TestTypes.Base target = gson.fromJson(json, TestTypes.Base.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),290,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),287,target);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomDeserializerReturnsNullForTopLevelObject_literalMutation709() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomDeserializerReturnsNullForTopLevelObject_literalMutation709");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new JsonDeserializer<com.google.gson.common.TestTypes.Base>() {
                public TestTypes.Base deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) throws JsonParseException {
                    return null;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),288,gson);
            String json = "{baseNae:\'Base\',subName:\'SubRevised\'}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),289,json);
            TestTypes.Base target = gson.fromJson(json, TestTypes.Base.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),290,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),287,target);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomDeserializerReturnsNullForTopLevelObject_literalMutation710() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomDeserializerReturnsNullForTopLevelObject_literalMutation710");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new JsonDeserializer<com.google.gson.common.TestTypes.Base>() {
                public TestTypes.Base deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) throws JsonParseException {
                    return null;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),288,gson);
            String json = "{baseName:\'Base\',subNam\te:\'SubRevised\'}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),289,json);
            TestTypes.Base target = gson.fromJson(json, TestTypes.Base.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),290,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),287,target);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomDeserializerReturnsNullForTopLevelObject_literalMutation711() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomDeserializerReturnsNullForTopLevelObject_literalMutation711");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new JsonDeserializer<com.google.gson.common.TestTypes.Base>() {
                public TestTypes.Base deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) throws JsonParseException {
                    return null;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),288,gson);
            String json = "{aseName:\'Base\',subName:\'SubRevised\'}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),289,json);
            TestTypes.Base target = gson.fromJson(json, TestTypes.Base.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),290,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),287,target);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomDeserializerReturnsNullForTopLevelObject_remove59() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomDeserializerReturnsNullForTopLevelObject_remove59");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new JsonDeserializer<com.google.gson.common.TestTypes.Base>() {
                public TestTypes.Base deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) throws JsonParseException {
                    return null;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),288,gson);
            String json = "{baseName:\'Base\',subName:\'SubRevised\'}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),289,json);
            TestTypes.Base target = gson.fromJson(json, TestTypes.Base.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),290,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),287,target);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomDeserializerReturnsNull_add57() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomDeserializerReturnsNull_add57");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new JsonDeserializer<com.google.gson.common.TestTypes.Base>() {
                public TestTypes.Base deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) throws JsonParseException {
                    return null;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),292,gson);
            String json = "{base:{baseName:\'Base\',subName:\'SubRevised\'}}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),40,json);
            TestTypes.ClassWithBaseField target = gson.fromJson(json, TestTypes.ClassWithBaseField.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),293,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),291,target.base);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomDeserializerReturnsNull() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomDeserializerReturnsNull");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new JsonDeserializer<com.google.gson.common.TestTypes.Base>() {
                public TestTypes.Base deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) throws JsonParseException {
                    return null;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),292,gson);
            String json = "{base:{baseName:\'Base\',subName:\'<ubRevised\'}}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),40,json);
            TestTypes.ClassWithBaseField target = gson.fromJson(json, TestTypes.ClassWithBaseField.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),293,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),291,target.base);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomDeserializerReturnsNull_literalMutation698() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomDeserializerReturnsNull_literalMutation698");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new JsonDeserializer<com.google.gson.common.TestTypes.Base>() {
                public TestTypes.Base deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) throws JsonParseException {
                    return null;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),292,gson);
            String json = "{base:{baseName:\'Base\',subName:\'SubRevised\'}}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),40,json);
            TestTypes.ClassWithBaseField target = gson.fromJson(json, TestTypes.ClassWithBaseField.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),293,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),291,target.base);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomDeserializerReturnsNull_literalMutation699() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomDeserializerReturnsNull_literalMutation699");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new JsonDeserializer<com.google.gson.common.TestTypes.Base>() {
                public TestTypes.Base deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) throws JsonParseException {
                    return null;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),292,gson);
            String json = "{base:{baeName:\'Base\',subName:\'SubRevised\'}}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),40,json);
            TestTypes.ClassWithBaseField target = gson.fromJson(json, TestTypes.ClassWithBaseField.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),293,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),291,target.base);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomDeserializerReturnsNull_remove56() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomDeserializerReturnsNull_remove56");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new JsonDeserializer<com.google.gson.common.TestTypes.Base>() {
                public TestTypes.Base deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) throws JsonParseException {
                    return null;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),292,gson);
            String json = "{base:{baseName:\'Base\',subName:\'SubRevised\'}}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),40,json);
            TestTypes.ClassWithBaseField target = gson.fromJson(json, TestTypes.ClassWithBaseField.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),293,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),291,target.base);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomDeserializerReturnsNullForArrayElements_add58() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomDeserializerReturnsNullForArrayElements_add58");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new JsonDeserializer<com.google.gson.common.TestTypes.Base>() {
                public TestTypes.Base deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) throws JsonParseException {
                    return null;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),284,gson);
            String json = "[{baseName:\'Base\'},{baseName:\'Base\'}]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),285,json);
            TestTypes.Base[] target = gson.fromJson(json, TestTypes.Base[].class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),286,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),282,target[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),283,target[1]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomDeserializerReturnsNullForArrayElements() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomDeserializerReturnsNullForArrayElements");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new JsonDeserializer<com.google.gson.common.TestTypes.Base>() {
                public TestTypes.Base deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) throws JsonParseException {
                    return null;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),284,gson);
            String json = "[{baseõame:\'Base\'},{baseName:\'Base\'}]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),285,json);
            TestTypes.Base[] target = gson.fromJson(json, TestTypes.Base[].class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),286,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),282,target[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),283,target[1]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomDeserializerReturnsNullForArrayElements_literalMutation702() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomDeserializerReturnsNullForArrayElements_literalMutation702");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new JsonDeserializer<com.google.gson.common.TestTypes.Base>() {
                public TestTypes.Base deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) throws JsonParseException {
                    return null;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),284,gson);
            String json = "[{baseNamôe:\'Base\'},{baseName:\'Base\'}]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),285,json);
            TestTypes.Base[] target = gson.fromJson(json, TestTypes.Base[].class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),286,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),282,target[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),283,target[1]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomDeserializerReturnsNullForArrayElements_literalMutation703() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomDeserializerReturnsNullForArrayElements_literalMutation703");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new JsonDeserializer<com.google.gson.common.TestTypes.Base>() {
                public TestTypes.Base deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) throws JsonParseException {
                    return null;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),284,gson);
            String json = "[{baseName:\'Base\'},{baseName\'Base\'}]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),285,json);
            TestTypes.Base[] target = gson.fromJson(json, TestTypes.Base[].class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),286,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),282,target[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),283,target[1]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomDeserializerReturnsNullForArrayElements_remove57() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomDeserializerReturnsNullForArrayElements_remove57");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new JsonDeserializer<com.google.gson.common.TestTypes.Base>() {
                public TestTypes.Base deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) throws JsonParseException {
                    return null;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),284,gson);
            String json = "[{baseName:\'Base\'},{baseName:\'Base\'}]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),285,json);
            TestTypes.Base[] target = gson.fromJson(json, TestTypes.Base[].class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),286,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),282,target[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),283,target[1]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomDeserializerReturnsNullForArrayElementsForArrayField_add59() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomDeserializerReturnsNullForArrayElementsForArrayField_add59");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new JsonDeserializer<com.google.gson.common.TestTypes.Base>() {
                public TestTypes.Base deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) throws JsonParseException {
                    return null;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),279,gson);
            String json = "{bases:[{baseName:\'Base\'},{baseName:\'Base\'}]}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),280,json);
            ClassWithBaseArray target = gson.fromJson(json, ClassWithBaseArray.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),281,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),277,target.bases[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),278,target.bases[1]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomDeserializerReturnsNullForArrayElementsForArrayField() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomDeserializerReturnsNullForArrayElementsForArrayField");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new JsonDeserializer<com.google.gson.common.TestTypes.Base>() {
                public TestTypes.Base deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) throws JsonParseException {
                    return null;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),279,gson);
            String json = "{bases:[{baseName:\'Base\'},{baseName:\'Base\'x]}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),280,json);
            ClassWithBaseArray target = gson.fromJson(json, ClassWithBaseArray.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),281,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),277,target.bases[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),278,target.bases[1]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomDeserializerReturnsNullForArrayElementsForArrayField_literalMutation706() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomDeserializerReturnsNullForArrayElementsForArrayField_literalMutation706");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new JsonDeserializer<com.google.gson.common.TestTypes.Base>() {
                public TestTypes.Base deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) throws JsonParseException {
                    return null;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),279,gson);
            String json = "{bases:Ç[{baseName:\'Base\'},{baseName:\'Base\'}]}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),280,json);
            ClassWithBaseArray target = gson.fromJson(json, ClassWithBaseArray.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),281,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),277,target.bases[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),278,target.bases[1]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomDeserializerReturnsNullForArrayElementsForArrayField_literalMutation707() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomDeserializerReturnsNullForArrayElementsForArrayField_literalMutation707");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new JsonDeserializer<com.google.gson.common.TestTypes.Base>() {
                public TestTypes.Base deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) throws JsonParseException {
                    return null;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),279,gson);
            String json = "{bases:[{baseName:\'Base\'},{baseName:\'Bae\'}]}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),280,json);
            ClassWithBaseArray target = gson.fromJson(json, ClassWithBaseArray.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),281,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),277,target.bases[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),278,target.bases[1]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomDeserializerReturnsNullForArrayElementsForArrayField_remove58() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomDeserializerReturnsNullForArrayElementsForArrayField_remove58");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new JsonDeserializer<com.google.gson.common.TestTypes.Base>() {
                public TestTypes.Base deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) throws JsonParseException {
                    return null;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),279,gson);
            String json = "{bases:[{baseName:\'Base\'},{baseName:\'Base\'}]}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),280,json);
            ClassWithBaseArray target = gson.fromJson(json, ClassWithBaseArray.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),281,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),277,target.bases[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),278,target.bases[1]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    private static class ClassWithBaseArray {
        TestTypes.Base[] bases;
    }
}

