package com.google.gson.functional;

import java.util.ArrayList;
import com.google.gson.Gson;
import com.google.gson.GsonBuilder;
import java.io.IOException;
import com.google.gson.stream.JsonReader;
import com.google.gson.stream.JsonWriter;
import java.util.List;
import org.junit.Test;
import junit.framework.TestCase;
import com.google.gson.common.TestTypes;
import com.google.gson.TypeAdapter;
import com.google.gson.TypeAdapterFactory;
import com.google.gson.reflect.TypeToken;

/** 
 * Functional tests for {@link Gson#getDelegateAdapter(TypeAdapterFactory, TypeToken)} method.
 * 
 * @author Inderjeet Singh
 */
public class DelegateTypeAdapterTest extends TestCase {
    private StatsTypeAdapterFactory stats;

    private Gson gson;

    protected void setUp() throws Exception {
        super.setUp();
        stats = new StatsTypeAdapterFactory();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,stats);
        gson = new GsonBuilder().registerTypeAdapterFactory(stats).create();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),36,gson);
    }

    @Test(timeout = 1000)
    public void testDelegateInvoked_add162() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDelegateInvoked_add162");
            List<com.google.gson.common.TestTypes.BagOfPrimitives> bags = new ArrayList<com.google.gson.common.TestTypes.BagOfPrimitives>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,bags);
            for (int i = 0 ; i < 10 ; ++i) {
                bags.add(new TestTypes.BagOfPrimitives(i , i , ((i % 2) == 0) , String.valueOf(i)));
                bags.add(new TestTypes.BagOfPrimitives(i , i , ((i % 2) == 0) , String.valueOf(i)));
            }
            String json = gson.toJson(bags);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,json);
            bags = gson.fromJson(json, new TypeToken<java.util.List<com.google.gson.common.TestTypes.BagOfPrimitives>>() {            }.getType());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,bags);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,stats.numReads);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,stats.numWrites);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDelegateInvoked_add163() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDelegateInvoked_add163");
            List<com.google.gson.common.TestTypes.BagOfPrimitives> bags = new ArrayList<com.google.gson.common.TestTypes.BagOfPrimitives>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,bags);
            for (int i = 0 ; i < 10 ; ++i) {
                bags.add(new TestTypes.BagOfPrimitives(i , i , ((i % 2) == 0) , String.valueOf(i)));
            }
            String json = gson.toJson(bags);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,json);
            bags = gson.fromJson(json, new TypeToken<java.util.List<com.google.gson.common.TestTypes.BagOfPrimitives>>() {            }.getType());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,bags);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,stats.numReads);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,stats.numWrites);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDelegateInvoked() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDelegateInvoked");
            List<com.google.gson.common.TestTypes.BagOfPrimitives> bags = new ArrayList<com.google.gson.common.TestTypes.BagOfPrimitives>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,bags);
            for (int i = 1 ; i < 10 ; ++i) {
                bags.add(new TestTypes.BagOfPrimitives(i , i , ((i % 2) == 0) , String.valueOf(i)));
            }
            String json = gson.toJson(bags);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,json);
            bags = gson.fromJson(json, new TypeToken<java.util.List<com.google.gson.common.TestTypes.BagOfPrimitives>>() {            }.getType());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,bags);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,stats.numReads);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,stats.numWrites);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDelegateInvoked_literalMutation1284() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDelegateInvoked_literalMutation1284");
            List<com.google.gson.common.TestTypes.BagOfPrimitives> bags = new ArrayList<com.google.gson.common.TestTypes.BagOfPrimitives>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,bags);
            for (int i = -1 ; i < 10 ; ++i) {
                bags.add(new TestTypes.BagOfPrimitives(i , i , ((i % 2) == 0) , String.valueOf(i)));
            }
            String json = gson.toJson(bags);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,json);
            bags = gson.fromJson(json, new TypeToken<java.util.List<com.google.gson.common.TestTypes.BagOfPrimitives>>() {            }.getType());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,bags);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,stats.numReads);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,stats.numWrites);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDelegateInvoked_literalMutation1285() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDelegateInvoked_literalMutation1285");
            List<com.google.gson.common.TestTypes.BagOfPrimitives> bags = new ArrayList<com.google.gson.common.TestTypes.BagOfPrimitives>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,bags);
            for (int i = 0 ; i < 10 ; ++i) {
                bags.add(new TestTypes.BagOfPrimitives(i , i , ((i % 2) == 0) , String.valueOf(i)));
            }
            String json = gson.toJson(bags);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,json);
            bags = gson.fromJson(json, new TypeToken<java.util.List<com.google.gson.common.TestTypes.BagOfPrimitives>>() {            }.getType());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,bags);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,stats.numReads);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,stats.numWrites);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDelegateInvoked_literalMutation1287() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDelegateInvoked_literalMutation1287");
            List<com.google.gson.common.TestTypes.BagOfPrimitives> bags = new ArrayList<com.google.gson.common.TestTypes.BagOfPrimitives>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,bags);
            for (int i = 0 ; i < 9 ; ++i) {
                bags.add(new TestTypes.BagOfPrimitives(i , i , ((i % 2) == 0) , String.valueOf(i)));
            }
            String json = gson.toJson(bags);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,json);
            bags = gson.fromJson(json, new TypeToken<java.util.List<com.google.gson.common.TestTypes.BagOfPrimitives>>() {            }.getType());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,bags);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,stats.numReads);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,stats.numWrites);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDelegateInvoked_literalMutation1288() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDelegateInvoked_literalMutation1288");
            List<com.google.gson.common.TestTypes.BagOfPrimitives> bags = new ArrayList<com.google.gson.common.TestTypes.BagOfPrimitives>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,bags);
            for (int i = 0 ; i < 5 ; ++i) {
                bags.add(new TestTypes.BagOfPrimitives(i , i , ((i % 2) == 0) , String.valueOf(i)));
            }
            String json = gson.toJson(bags);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,json);
            bags = gson.fromJson(json, new TypeToken<java.util.List<com.google.gson.common.TestTypes.BagOfPrimitives>>() {            }.getType());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,bags);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,stats.numReads);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,stats.numWrites);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDelegateInvoked_literalMutation1289() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDelegateInvoked_literalMutation1289");
            List<com.google.gson.common.TestTypes.BagOfPrimitives> bags = new ArrayList<com.google.gson.common.TestTypes.BagOfPrimitives>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,bags);
            for (int i = 0 ; i < 20 ; ++i) {
                bags.add(new TestTypes.BagOfPrimitives(i , i , ((i % 2) == 0) , String.valueOf(i)));
            }
            String json = gson.toJson(bags);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,json);
            bags = gson.fromJson(json, new TypeToken<java.util.List<com.google.gson.common.TestTypes.BagOfPrimitives>>() {            }.getType());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,bags);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,stats.numReads);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,stats.numWrites);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDelegateInvoked_literalMutation1290() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDelegateInvoked_literalMutation1290");
            List<com.google.gson.common.TestTypes.BagOfPrimitives> bags = new ArrayList<com.google.gson.common.TestTypes.BagOfPrimitives>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,bags);
            for (int i = 0 ; i < 11 ; ++i) {
                bags.add(new TestTypes.BagOfPrimitives(i , i , ((i % 2) == 0) , String.valueOf(i)));
            }
            String json = gson.toJson(bags);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,json);
            bags = gson.fromJson(json, new TypeToken<java.util.List<com.google.gson.common.TestTypes.BagOfPrimitives>>() {            }.getType());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,bags);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,stats.numReads);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,stats.numWrites);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDelegateInvoked_literalMutation1292() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDelegateInvoked_literalMutation1292");
            List<com.google.gson.common.TestTypes.BagOfPrimitives> bags = new ArrayList<com.google.gson.common.TestTypes.BagOfPrimitives>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,bags);
            for (int i = 0 ; i < 10 ; ++i) {
                bags.add(new TestTypes.BagOfPrimitives(i , i , ((i % 1) == 0) , String.valueOf(i)));
            }
            String json = gson.toJson(bags);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,json);
            bags = gson.fromJson(json, new TypeToken<java.util.List<com.google.gson.common.TestTypes.BagOfPrimitives>>() {            }.getType());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,bags);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,stats.numReads);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,stats.numWrites);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDelegateInvoked_literalMutation1293() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDelegateInvoked_literalMutation1293");
            List<com.google.gson.common.TestTypes.BagOfPrimitives> bags = new ArrayList<com.google.gson.common.TestTypes.BagOfPrimitives>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,bags);
            for (int i = 0 ; i < 10 ; ++i) {
                bags.add(new TestTypes.BagOfPrimitives(i , i , ((i % 4) == 0) , String.valueOf(i)));
            }
            String json = gson.toJson(bags);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,json);
            bags = gson.fromJson(json, new TypeToken<java.util.List<com.google.gson.common.TestTypes.BagOfPrimitives>>() {            }.getType());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,bags);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,stats.numReads);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,stats.numWrites);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDelegateInvoked_literalMutation1294() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDelegateInvoked_literalMutation1294");
            List<com.google.gson.common.TestTypes.BagOfPrimitives> bags = new ArrayList<com.google.gson.common.TestTypes.BagOfPrimitives>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,bags);
            for (int i = 0 ; i < 10 ; ++i) {
                bags.add(new TestTypes.BagOfPrimitives(i , i , ((i % 3) == 0) , String.valueOf(i)));
            }
            String json = gson.toJson(bags);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,json);
            bags = gson.fromJson(json, new TypeToken<java.util.List<com.google.gson.common.TestTypes.BagOfPrimitives>>() {            }.getType());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,bags);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,stats.numReads);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,stats.numWrites);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDelegateInvoked_literalMutation1296() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDelegateInvoked_literalMutation1296");
            List<com.google.gson.common.TestTypes.BagOfPrimitives> bags = new ArrayList<com.google.gson.common.TestTypes.BagOfPrimitives>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,bags);
            for (int i = 0 ; i < 10 ; ++i) {
                bags.add(new TestTypes.BagOfPrimitives(i , i , ((i % 2) == 1) , String.valueOf(i)));
            }
            String json = gson.toJson(bags);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,json);
            bags = gson.fromJson(json, new TypeToken<java.util.List<com.google.gson.common.TestTypes.BagOfPrimitives>>() {            }.getType());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,bags);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,stats.numReads);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,stats.numWrites);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDelegateInvoked_literalMutation1297() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDelegateInvoked_literalMutation1297");
            List<com.google.gson.common.TestTypes.BagOfPrimitives> bags = new ArrayList<com.google.gson.common.TestTypes.BagOfPrimitives>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,bags);
            for (int i = 0 ; i < 10 ; ++i) {
                bags.add(new TestTypes.BagOfPrimitives(i , i , ((i % 2) == -1) , String.valueOf(i)));
            }
            String json = gson.toJson(bags);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,json);
            bags = gson.fromJson(json, new TypeToken<java.util.List<com.google.gson.common.TestTypes.BagOfPrimitives>>() {            }.getType());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,bags);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,stats.numReads);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,stats.numWrites);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDelegateInvoked_literalMutation1298() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDelegateInvoked_literalMutation1298");
            List<com.google.gson.common.TestTypes.BagOfPrimitives> bags = new ArrayList<com.google.gson.common.TestTypes.BagOfPrimitives>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,bags);
            for (int i = 0 ; i < 10 ; ++i) {
                bags.add(new TestTypes.BagOfPrimitives(i , i , ((i % 2) == 0) , String.valueOf(i)));
            }
            String json = gson.toJson(bags);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,json);
            bags = gson.fromJson(json, new TypeToken<java.util.List<com.google.gson.common.TestTypes.BagOfPrimitives>>() {            }.getType());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,bags);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,stats.numReads);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,stats.numWrites);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDelegateInvoked_remove152() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDelegateInvoked_remove152");
            List<com.google.gson.common.TestTypes.BagOfPrimitives> bags = new ArrayList<com.google.gson.common.TestTypes.BagOfPrimitives>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,bags);
            for (int i = 0 ; i < 10 ; ++i) {
            }
            String json = gson.toJson(bags);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,json);
            bags = gson.fromJson(json, new TypeToken<java.util.List<com.google.gson.common.TestTypes.BagOfPrimitives>>() {            }.getType());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,bags);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,stats.numReads);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,stats.numWrites);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDelegateInvoked_remove153() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDelegateInvoked_remove153");
            List<com.google.gson.common.TestTypes.BagOfPrimitives> bags = new ArrayList<com.google.gson.common.TestTypes.BagOfPrimitives>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,bags);
            for (int i = 0 ; i < 10 ; ++i) {
                bags.add(new TestTypes.BagOfPrimitives(i , i , ((i % 2) == 0) , String.valueOf(i)));
            }
            String json = gson.toJson(bags);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,json);
            bags = gson.fromJson(json, new TypeToken<java.util.List<com.google.gson.common.TestTypes.BagOfPrimitives>>() {            }.getType());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,bags);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,stats.numReads);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,stats.numWrites);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDelegateInvokedOnStrings() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDelegateInvokedOnStrings");
            String[] bags = new String[]{ "1" , "2" , "3" , "4" };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,bags);
            String json = gson.toJson(bags);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,json);
            bags = gson.fromJson(json, String[].class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,bags);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,stats.numReads);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,stats.numWrites);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    private static class StatsTypeAdapterFactory implements TypeAdapterFactory {
        public int numReads = 0;

        public int numWrites = 0;

        public <T>TypeAdapter<T> create(Gson gson, TypeToken<T> type) {
            final TypeAdapter<T> delegate = gson.getDelegateAdapter(this, type);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,delegate);
            return new TypeAdapter<T>() {
                @Override
                public void write(JsonWriter out, T value) throws IOException {
                    ++(numWrites);
                    delegate.write(out, value);
                }

                @Override
                public T read(JsonReader in) throws IOException {
                    ++(numReads);
                    return delegate.read(in);
                }
            };
        }
    }
}

