package com.google.gson.functional;

import java.util.ArrayList;
import com.google.gson.Gson;
import com.google.gson.GsonBuilder;
import java.util.List;
import org.junit.Test;
import junit.framework.TestCase;
import com.google.gson.common.TestTypes;

/** 
 * Performs some functional test involving JSON output escaping.
 * 
 * @author Inderjeet Singh
 * @author Joel Leitch
 */
public class EscapingTest extends TestCase {
    private Gson gson;

    @Override
    protected void setUp() throws Exception {
        super.setUp();
        gson = new Gson();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),823,gson);
    }

    public void testEscapingQuotesInStringArray() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapingQuotesInStringArray");
            String[] valueWithQuotes = new String[]{ "beforeQuote*afterQuote" };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,valueWithQuotes);
            String jsonRepresentation = gson.toJson(valueWithQuotes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,jsonRepresentation);
            String[] target = gson.fromJson(jsonRepresentation, String[].class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),838,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),8,target.length);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,valueWithQuotes[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,target[0]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEscapingQuotesInStringArray_literalMutation1324() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapingQuotesInStringArray_literalMutation1324");
            String[] valueWithQuotes = new String[]{ "beforeQuote\"afterQÜuote" };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,valueWithQuotes);
            String jsonRepresentation = gson.toJson(valueWithQuotes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,jsonRepresentation);
            String[] target = gson.fromJson(jsonRepresentation, String[].class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),838,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),8,target.length);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,valueWithQuotes[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,target[0]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEscapingQuotesInStringArray_literalMutation1325() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapingQuotesInStringArray_literalMutation1325");
            String[] valueWithQuotes = new String[]{ "beforeQuote\"afterQuoe" };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,valueWithQuotes);
            String jsonRepresentation = gson.toJson(valueWithQuotes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,jsonRepresentation);
            String[] target = gson.fromJson(jsonRepresentation, String[].class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),838,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),8,target.length);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,valueWithQuotes[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,target[0]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testEscapeAllHtmlCharacters() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapeAllHtmlCharacters");
            List<java.lang.String> strings = new ArrayList<java.lang.String>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),825,strings);
            strings.add("<");
            strings.add("<");
            strings.add(">");
            strings.add("=");
            strings.add("&");
            strings.add("\'");
            strings.add("\"");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),824,gson.toJson(strings));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testEscapeAllHtmlCharacters_add179() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapeAllHtmlCharacters_add179");
            List<java.lang.String> strings = new ArrayList<java.lang.String>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),825,strings);
            strings.add("<");
            strings.add(">");
            strings.add(">");
            strings.add("=");
            strings.add("&");
            strings.add("\'");
            strings.add("\"");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),824,gson.toJson(strings));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testEscapeAllHtmlCharacters_add180() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapeAllHtmlCharacters_add180");
            List<java.lang.String> strings = new ArrayList<java.lang.String>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),825,strings);
            strings.add("<");
            strings.add(">");
            strings.add("=");
            strings.add("=");
            strings.add("&");
            strings.add("\'");
            strings.add("\"");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),824,gson.toJson(strings));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testEscapeAllHtmlCharacters_add181() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapeAllHtmlCharacters_add181");
            List<java.lang.String> strings = new ArrayList<java.lang.String>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),825,strings);
            strings.add("<");
            strings.add(">");
            strings.add("=");
            strings.add("&");
            strings.add("&");
            strings.add("\'");
            strings.add("\"");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),824,gson.toJson(strings));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testEscapeAllHtmlCharacters_add182() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapeAllHtmlCharacters_add182");
            List<java.lang.String> strings = new ArrayList<java.lang.String>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),825,strings);
            strings.add("<");
            strings.add(">");
            strings.add("=");
            strings.add("&");
            strings.add("\'");
            strings.add("\'");
            strings.add("\"");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),824,gson.toJson(strings));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testEscapeAllHtmlCharacters_add183() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapeAllHtmlCharacters_add183");
            List<java.lang.String> strings = new ArrayList<java.lang.String>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),825,strings);
            strings.add("<");
            strings.add(">");
            strings.add("=");
            strings.add("&");
            strings.add("\'");
            strings.add("\"");
            strings.add("\"");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),824,gson.toJson(strings));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testEscapeAllHtmlCharacters_remove168() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapeAllHtmlCharacters_remove168");
            List<java.lang.String> strings = new ArrayList<java.lang.String>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),825,strings);
            strings.add(">");
            strings.add("=");
            strings.add("&");
            strings.add("\'");
            strings.add("\"");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),824,gson.toJson(strings));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testEscapeAllHtmlCharacters_remove169() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapeAllHtmlCharacters_remove169");
            List<java.lang.String> strings = new ArrayList<java.lang.String>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),825,strings);
            strings.add(">");
            strings.add("=");
            strings.add("&");
            strings.add("\'");
            strings.add("\"");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),824,gson.toJson(strings));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testEscapeAllHtmlCharacters_remove170() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapeAllHtmlCharacters_remove170");
            List<java.lang.String> strings = new ArrayList<java.lang.String>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),825,strings);
            strings.add(">");
            strings.add("=");
            strings.add("&");
            strings.add("\'");
            strings.add("\"");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),824,gson.toJson(strings));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testEscapeAllHtmlCharacters_remove171() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapeAllHtmlCharacters_remove171");
            List<java.lang.String> strings = new ArrayList<java.lang.String>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),825,strings);
            strings.add(">");
            strings.add("=");
            strings.add("&");
            strings.add("\'");
            strings.add("\"");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),824,gson.toJson(strings));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testEscapeAllHtmlCharacters_remove172() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapeAllHtmlCharacters_remove172");
            List<java.lang.String> strings = new ArrayList<java.lang.String>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),825,strings);
            strings.add(">");
            strings.add("=");
            strings.add("&");
            strings.add("\'");
            strings.add("\"");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),824,gson.toJson(strings));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testEscapeAllHtmlCharacters_remove173() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapeAllHtmlCharacters_remove173");
            List<java.lang.String> strings = new ArrayList<java.lang.String>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),825,strings);
            strings.add(">");
            strings.add("=");
            strings.add("&");
            strings.add("\'");
            strings.add("\"");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),824,gson.toJson(strings));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEscapingObjectFields() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapingObjectFields");
            TestTypes.BagOfPrimitives objWithPrimitives = new TestTypes.BagOfPrimitives(2L , 1 , true , "test with\" <script>");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),831,objWithPrimitives);
            String jsonRepresentation = gson.toJson(objWithPrimitives);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,jsonRepresentation);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),826,jsonRepresentation.contains("<"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),827,jsonRepresentation.contains(">"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),828,jsonRepresentation.contains("\\\""));
            TestTypes.BagOfPrimitives expectedObject = gson.fromJson(jsonRepresentation, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,expectedObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),829,objWithPrimitives.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),830,expectedObject.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEscapingObjectFields_literalMutation1312() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapingObjectFields_literalMutation1312");
            TestTypes.BagOfPrimitives objWithPrimitives = new TestTypes.BagOfPrimitives(0L , 1 , true , "test with\" <script>");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),831,objWithPrimitives);
            String jsonRepresentation = gson.toJson(objWithPrimitives);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,jsonRepresentation);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),826,jsonRepresentation.contains("<"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),827,jsonRepresentation.contains(">"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),828,jsonRepresentation.contains("\\\""));
            TestTypes.BagOfPrimitives expectedObject = gson.fromJson(jsonRepresentation, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,expectedObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),829,objWithPrimitives.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),830,expectedObject.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEscapingObjectFields_literalMutation1313() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapingObjectFields_literalMutation1313");
            TestTypes.BagOfPrimitives objWithPrimitives = new TestTypes.BagOfPrimitives(0L , 1 , true , "test with\" <script>");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),831,objWithPrimitives);
            String jsonRepresentation = gson.toJson(objWithPrimitives);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,jsonRepresentation);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),826,jsonRepresentation.contains("<"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),827,jsonRepresentation.contains(">"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),828,jsonRepresentation.contains("\\\""));
            TestTypes.BagOfPrimitives expectedObject = gson.fromJson(jsonRepresentation, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,expectedObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),829,objWithPrimitives.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),830,expectedObject.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEscapingObjectFields_literalMutation1315() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapingObjectFields_literalMutation1315");
            TestTypes.BagOfPrimitives objWithPrimitives = new TestTypes.BagOfPrimitives(1L , 2 , true , "test with\" <script>");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),831,objWithPrimitives);
            String jsonRepresentation = gson.toJson(objWithPrimitives);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,jsonRepresentation);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),826,jsonRepresentation.contains("<"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),827,jsonRepresentation.contains(">"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),828,jsonRepresentation.contains("\\\""));
            TestTypes.BagOfPrimitives expectedObject = gson.fromJson(jsonRepresentation, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,expectedObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),829,objWithPrimitives.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),830,expectedObject.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEscapingObjectFields_literalMutation1316() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapingObjectFields_literalMutation1316");
            TestTypes.BagOfPrimitives objWithPrimitives = new TestTypes.BagOfPrimitives(1L , 0 , true , "test with\" <script>");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),831,objWithPrimitives);
            String jsonRepresentation = gson.toJson(objWithPrimitives);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,jsonRepresentation);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),826,jsonRepresentation.contains("<"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),827,jsonRepresentation.contains(">"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),828,jsonRepresentation.contains("\\\""));
            TestTypes.BagOfPrimitives expectedObject = gson.fromJson(jsonRepresentation, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,expectedObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),829,objWithPrimitives.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),830,expectedObject.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEscapingObjectFields_literalMutation1317() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapingObjectFields_literalMutation1317");
            TestTypes.BagOfPrimitives objWithPrimitives = new TestTypes.BagOfPrimitives(1L , 0 , true , "test with\" <script>");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),831,objWithPrimitives);
            String jsonRepresentation = gson.toJson(objWithPrimitives);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,jsonRepresentation);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),826,jsonRepresentation.contains("<"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),827,jsonRepresentation.contains(">"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),828,jsonRepresentation.contains("\\\""));
            TestTypes.BagOfPrimitives expectedObject = gson.fromJson(jsonRepresentation, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,expectedObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),829,objWithPrimitives.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),830,expectedObject.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEscapingObjectFields_literalMutation1320() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapingObjectFields_literalMutation1320");
            TestTypes.BagOfPrimitives objWithPrimitives = new TestTypes.BagOfPrimitives(1L , 1 , true , "test with\" <scri÷t>");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),831,objWithPrimitives);
            String jsonRepresentation = gson.toJson(objWithPrimitives);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,jsonRepresentation);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),826,jsonRepresentation.contains("<"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),827,jsonRepresentation.contains(">"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),828,jsonRepresentation.contains("\\\""));
            TestTypes.BagOfPrimitives expectedObject = gson.fromJson(jsonRepresentation, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,expectedObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),829,objWithPrimitives.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),830,expectedObject.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEscapingObjectFields_literalMutation1321() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapingObjectFields_literalMutation1321");
            TestTypes.BagOfPrimitives objWithPrimitives = new TestTypes.BagOfPrimitives(1L , 1 , true , "test withµ\" <script>");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),831,objWithPrimitives);
            String jsonRepresentation = gson.toJson(objWithPrimitives);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,jsonRepresentation);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),826,jsonRepresentation.contains("<"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),827,jsonRepresentation.contains(">"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),828,jsonRepresentation.contains("\\\""));
            TestTypes.BagOfPrimitives expectedObject = gson.fromJson(jsonRepresentation, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,expectedObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),829,objWithPrimitives.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),830,expectedObject.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEscapingObjectFields_literalMutation1322() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapingObjectFields_literalMutation1322");
            TestTypes.BagOfPrimitives objWithPrimitives = new TestTypes.BagOfPrimitives(1L , 1 , true , "test with\"<script>");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),831,objWithPrimitives);
            String jsonRepresentation = gson.toJson(objWithPrimitives);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,jsonRepresentation);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),826,jsonRepresentation.contains("<"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),827,jsonRepresentation.contains(">"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),828,jsonRepresentation.contains("\\\""));
            TestTypes.BagOfPrimitives expectedObject = gson.fromJson(jsonRepresentation, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,expectedObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),829,objWithPrimitives.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),830,expectedObject.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonAcceptsEscapedAndNonEscapedJsonDeserialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonAcceptsEscapedAndNonEscapedJsonDeserialization");
            Gson escapeHtmlGson = new GsonBuilder().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,escapeHtmlGson);
            Gson noEscapeHtmlGson = new GsonBuilder().disableHtmlEscaping().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,noEscapeHtmlGson);
            TestTypes.BagOfPrimitives target = new TestTypes.BagOfPrimitives(2L , 1 , true , "test\' / w\'ith\" / \\ <script>");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),243,target);
            String escapedJsonForm = escapeHtmlGson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,escapedJsonForm);
            String nonEscapedJsonForm = noEscapeHtmlGson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,nonEscapedJsonForm);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,escapedJsonForm.equals(nonEscapedJsonForm));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,noEscapeHtmlGson.fromJson(escapedJsonForm, com.google.gson.common.TestTypes.BagOfPrimitives.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,escapeHtmlGson.fromJson(nonEscapedJsonForm, com.google.gson.common.TestTypes.BagOfPrimitives.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonAcceptsEscapedAndNonEscapedJsonDeserialization_literalMutation1327() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonAcceptsEscapedAndNonEscapedJsonDeserialization_literalMutation1327");
            Gson escapeHtmlGson = new GsonBuilder().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,escapeHtmlGson);
            Gson noEscapeHtmlGson = new GsonBuilder().disableHtmlEscaping().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,noEscapeHtmlGson);
            TestTypes.BagOfPrimitives target = new TestTypes.BagOfPrimitives(0L , 1 , true , "test\' / w\'ith\" / \\ <script>");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),243,target);
            String escapedJsonForm = escapeHtmlGson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,escapedJsonForm);
            String nonEscapedJsonForm = noEscapeHtmlGson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,nonEscapedJsonForm);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,escapedJsonForm.equals(nonEscapedJsonForm));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,noEscapeHtmlGson.fromJson(escapedJsonForm, com.google.gson.common.TestTypes.BagOfPrimitives.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,escapeHtmlGson.fromJson(nonEscapedJsonForm, com.google.gson.common.TestTypes.BagOfPrimitives.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonAcceptsEscapedAndNonEscapedJsonDeserialization_literalMutation1328() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonAcceptsEscapedAndNonEscapedJsonDeserialization_literalMutation1328");
            Gson escapeHtmlGson = new GsonBuilder().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,escapeHtmlGson);
            Gson noEscapeHtmlGson = new GsonBuilder().disableHtmlEscaping().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,noEscapeHtmlGson);
            TestTypes.BagOfPrimitives target = new TestTypes.BagOfPrimitives(0L , 1 , true , "test\' / w\'ith\" / \\ <script>");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),243,target);
            String escapedJsonForm = escapeHtmlGson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,escapedJsonForm);
            String nonEscapedJsonForm = noEscapeHtmlGson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,nonEscapedJsonForm);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,escapedJsonForm.equals(nonEscapedJsonForm));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,noEscapeHtmlGson.fromJson(escapedJsonForm, com.google.gson.common.TestTypes.BagOfPrimitives.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,escapeHtmlGson.fromJson(nonEscapedJsonForm, com.google.gson.common.TestTypes.BagOfPrimitives.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonAcceptsEscapedAndNonEscapedJsonDeserialization_literalMutation1330() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonAcceptsEscapedAndNonEscapedJsonDeserialization_literalMutation1330");
            Gson escapeHtmlGson = new GsonBuilder().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,escapeHtmlGson);
            Gson noEscapeHtmlGson = new GsonBuilder().disableHtmlEscaping().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,noEscapeHtmlGson);
            TestTypes.BagOfPrimitives target = new TestTypes.BagOfPrimitives(1L , 2 , true , "test\' / w\'ith\" / \\ <script>");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),243,target);
            String escapedJsonForm = escapeHtmlGson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,escapedJsonForm);
            String nonEscapedJsonForm = noEscapeHtmlGson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,nonEscapedJsonForm);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,escapedJsonForm.equals(nonEscapedJsonForm));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,noEscapeHtmlGson.fromJson(escapedJsonForm, com.google.gson.common.TestTypes.BagOfPrimitives.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,escapeHtmlGson.fromJson(nonEscapedJsonForm, com.google.gson.common.TestTypes.BagOfPrimitives.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonAcceptsEscapedAndNonEscapedJsonDeserialization_literalMutation1331() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonAcceptsEscapedAndNonEscapedJsonDeserialization_literalMutation1331");
            Gson escapeHtmlGson = new GsonBuilder().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,escapeHtmlGson);
            Gson noEscapeHtmlGson = new GsonBuilder().disableHtmlEscaping().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,noEscapeHtmlGson);
            TestTypes.BagOfPrimitives target = new TestTypes.BagOfPrimitives(1L , 0 , true , "test\' / w\'ith\" / \\ <script>");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),243,target);
            String escapedJsonForm = escapeHtmlGson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,escapedJsonForm);
            String nonEscapedJsonForm = noEscapeHtmlGson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,nonEscapedJsonForm);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,escapedJsonForm.equals(nonEscapedJsonForm));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,noEscapeHtmlGson.fromJson(escapedJsonForm, com.google.gson.common.TestTypes.BagOfPrimitives.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,escapeHtmlGson.fromJson(nonEscapedJsonForm, com.google.gson.common.TestTypes.BagOfPrimitives.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonAcceptsEscapedAndNonEscapedJsonDeserialization_literalMutation1332() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonAcceptsEscapedAndNonEscapedJsonDeserialization_literalMutation1332");
            Gson escapeHtmlGson = new GsonBuilder().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,escapeHtmlGson);
            Gson noEscapeHtmlGson = new GsonBuilder().disableHtmlEscaping().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,noEscapeHtmlGson);
            TestTypes.BagOfPrimitives target = new TestTypes.BagOfPrimitives(1L , 0 , true , "test\' / w\'ith\" / \\ <script>");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),243,target);
            String escapedJsonForm = escapeHtmlGson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,escapedJsonForm);
            String nonEscapedJsonForm = noEscapeHtmlGson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,nonEscapedJsonForm);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,escapedJsonForm.equals(nonEscapedJsonForm));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,noEscapeHtmlGson.fromJson(escapedJsonForm, com.google.gson.common.TestTypes.BagOfPrimitives.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,escapeHtmlGson.fromJson(nonEscapedJsonForm, com.google.gson.common.TestTypes.BagOfPrimitives.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonAcceptsEscapedAndNonEscapedJsonDeserialization_literalMutation1335() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonAcceptsEscapedAndNonEscapedJsonDeserialization_literalMutation1335");
            Gson escapeHtmlGson = new GsonBuilder().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,escapeHtmlGson);
            Gson noEscapeHtmlGson = new GsonBuilder().disableHtmlEscaping().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,noEscapeHtmlGson);
            TestTypes.BagOfPrimitives target = new TestTypes.BagOfPrimitives(1L , 1 , true , "test\' / w\'ith\" / \\ <scÐipt>");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),243,target);
            String escapedJsonForm = escapeHtmlGson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,escapedJsonForm);
            String nonEscapedJsonForm = noEscapeHtmlGson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,nonEscapedJsonForm);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,escapedJsonForm.equals(nonEscapedJsonForm));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,noEscapeHtmlGson.fromJson(escapedJsonForm, com.google.gson.common.TestTypes.BagOfPrimitives.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,escapeHtmlGson.fromJson(nonEscapedJsonForm, com.google.gson.common.TestTypes.BagOfPrimitives.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonAcceptsEscapedAndNonEscapedJsonDeserialization_literalMutation1336() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonAcceptsEscapedAndNonEscapedJsonDeserialization_literalMutation1336");
            Gson escapeHtmlGson = new GsonBuilder().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,escapeHtmlGson);
            Gson noEscapeHtmlGson = new GsonBuilder().disableHtmlEscaping().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,noEscapeHtmlGson);
            TestTypes.BagOfPrimitives target = new TestTypes.BagOfPrimitives(1L , 1 , true , "test\' / w\'ith\" / \\ <script>");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),243,target);
            String escapedJsonForm = escapeHtmlGson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,escapedJsonForm);
            String nonEscapedJsonForm = noEscapeHtmlGson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,nonEscapedJsonForm);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,escapedJsonForm.equals(nonEscapedJsonForm));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,noEscapeHtmlGson.fromJson(escapedJsonForm, com.google.gson.common.TestTypes.BagOfPrimitives.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,escapeHtmlGson.fromJson(nonEscapedJsonForm, com.google.gson.common.TestTypes.BagOfPrimitives.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonAcceptsEscapedAndNonEscapedJsonDeserialization_literalMutation1337() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonAcceptsEscapedAndNonEscapedJsonDeserialization_literalMutation1337");
            Gson escapeHtmlGson = new GsonBuilder().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,escapeHtmlGson);
            Gson noEscapeHtmlGson = new GsonBuilder().disableHtmlEscaping().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,noEscapeHtmlGson);
            TestTypes.BagOfPrimitives target = new TestTypes.BagOfPrimitives(1L , 1 , true , "test\' /w\'ith\" / \\ <script>");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),243,target);
            String escapedJsonForm = escapeHtmlGson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,escapedJsonForm);
            String nonEscapedJsonForm = noEscapeHtmlGson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,nonEscapedJsonForm);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,escapedJsonForm.equals(nonEscapedJsonForm));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,noEscapeHtmlGson.fromJson(escapedJsonForm, com.google.gson.common.TestTypes.BagOfPrimitives.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,escapeHtmlGson.fromJson(nonEscapedJsonForm, com.google.gson.common.TestTypes.BagOfPrimitives.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonDoubleDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonDoubleDeserialization");
            TestTypes.BagOfPrimitives expected = new TestTypes.BagOfPrimitives(4L , 4 , true , "value1");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),106,expected);
            String json = gson.toJson(gson.toJson(expected));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),107,json);
            String value = gson.fromJson(json, String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,value);
            TestTypes.BagOfPrimitives actual = gson.fromJson(value, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonDoubleDeserialization_literalMutation1339() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonDoubleDeserialization_literalMutation1339");
            TestTypes.BagOfPrimitives expected = new TestTypes.BagOfPrimitives(2L , 4 , true , "value1");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),106,expected);
            String json = gson.toJson(gson.toJson(expected));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),107,json);
            String value = gson.fromJson(json, String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,value);
            TestTypes.BagOfPrimitives actual = gson.fromJson(value, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonDoubleDeserialization_literalMutation1340() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonDoubleDeserialization_literalMutation1340");
            TestTypes.BagOfPrimitives expected = new TestTypes.BagOfPrimitives(1L , 4 , true , "value1");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),106,expected);
            String json = gson.toJson(gson.toJson(expected));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),107,json);
            String value = gson.fromJson(json, String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,value);
            TestTypes.BagOfPrimitives actual = gson.fromJson(value, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonDoubleDeserialization_literalMutation1341() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonDoubleDeserialization_literalMutation1341");
            TestTypes.BagOfPrimitives expected = new TestTypes.BagOfPrimitives(6L , 4 , true , "value1");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),106,expected);
            String json = gson.toJson(gson.toJson(expected));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),107,json);
            String value = gson.fromJson(json, String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,value);
            TestTypes.BagOfPrimitives actual = gson.fromJson(value, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonDoubleDeserialization_literalMutation1343() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonDoubleDeserialization_literalMutation1343");
            TestTypes.BagOfPrimitives expected = new TestTypes.BagOfPrimitives(3L , 2 , true , "value1");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),106,expected);
            String json = gson.toJson(gson.toJson(expected));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),107,json);
            String value = gson.fromJson(json, String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,value);
            TestTypes.BagOfPrimitives actual = gson.fromJson(value, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonDoubleDeserialization_literalMutation1344() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonDoubleDeserialization_literalMutation1344");
            TestTypes.BagOfPrimitives expected = new TestTypes.BagOfPrimitives(3L , 8 , true , "value1");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),106,expected);
            String json = gson.toJson(gson.toJson(expected));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),107,json);
            String value = gson.fromJson(json, String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,value);
            TestTypes.BagOfPrimitives actual = gson.fromJson(value, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonDoubleDeserialization_literalMutation1345() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonDoubleDeserialization_literalMutation1345");
            TestTypes.BagOfPrimitives expected = new TestTypes.BagOfPrimitives(3L , 5 , true , "value1");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),106,expected);
            String json = gson.toJson(gson.toJson(expected));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),107,json);
            String value = gson.fromJson(json, String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,value);
            TestTypes.BagOfPrimitives actual = gson.fromJson(value, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonDoubleDeserialization_literalMutation1346() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonDoubleDeserialization_literalMutation1346");
            TestTypes.BagOfPrimitives expected = new TestTypes.BagOfPrimitives(3L , 3 , true , "value1");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),106,expected);
            String json = gson.toJson(gson.toJson(expected));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),107,json);
            String value = gson.fromJson(json, String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,value);
            TestTypes.BagOfPrimitives actual = gson.fromJson(value, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonDoubleDeserialization_literalMutation1349() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonDoubleDeserialization_literalMutation1349");
            TestTypes.BagOfPrimitives expected = new TestTypes.BagOfPrimitives(3L , 4 , true , "v{lue1");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),106,expected);
            String json = gson.toJson(gson.toJson(expected));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),107,json);
            String value = gson.fromJson(json, String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,value);
            TestTypes.BagOfPrimitives actual = gson.fromJson(value, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonDoubleDeserialization_literalMutation1350() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonDoubleDeserialization_literalMutation1350");
            TestTypes.BagOfPrimitives expected = new TestTypes.BagOfPrimitives(3L , 4 , true , "value1");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),106,expected);
            String json = gson.toJson(gson.toJson(expected));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),107,json);
            String value = gson.fromJson(json, String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,value);
            TestTypes.BagOfPrimitives actual = gson.fromJson(value, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonDoubleDeserialization_literalMutation1351() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonDoubleDeserialization_literalMutation1351");
            TestTypes.BagOfPrimitives expected = new TestTypes.BagOfPrimitives(3L , 4 , true , "vlue1");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),106,expected);
            String json = gson.toJson(gson.toJson(expected));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),107,json);
            String value = gson.fromJson(json, String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,value);
            TestTypes.BagOfPrimitives actual = gson.fromJson(value, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }
}

