package com.google.gson.functional;

import com.google.gson.Gson;
import com.google.gson.GsonBuilder;
import junit.framework.TestCase;

/** 
 * Performs some functional testing to ensure GSON infrastructure properly serializes/deserializes
 * fields that either should or should not be included in the output based on the GSON
 * configuration.
 * 
 * @author Joel Leitch
 */
public class FieldExclusionTest extends TestCase {
    private static final String VALUE = "blah_1234";

    private Outer outer;

    @Override
    protected void setUp() throws Exception {
        super.setUp();
        outer = new Outer();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),935,outer);
    }

    public void testDefaultInnerClassExclusion() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultInnerClassExclusion");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),942,gson);
            Outer.Inner target = outer.new Inner(VALUE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),838,target);
            String result = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),943,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),936,target.toJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),937,result);
            gson = new GsonBuilder().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),276,gson);
            target = outer.new Inner(VALUE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),940,target);
            result = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),941,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),938,target.toJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),939,result);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testInnerClassExclusion() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInnerClassExclusion");
            Gson gson = new GsonBuilder().disableInnerClassSerialization().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),954,gson);
            Outer.Inner target = outer.new Inner(VALUE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),955,target);
            String result = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),822,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),821,result);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultNestedStaticClassIncluded() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultNestedStaticClassIncluded");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),951,gson);
            Outer.Inner target = outer.new Inner(VALUE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),952,target);
            String result = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),953,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),944,target.toJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),945,result);
            gson = new GsonBuilder().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),948,gson);
            target = outer.new Inner(VALUE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),949,target);
            result = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),950,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),946,target.toJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),947,result);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    private static class Outer {
        private class Inner extends NestedClass {
            public Inner(String value) {
                super(value);
            }
        }
    }

    private static class NestedClass {
        private final String value;

        public NestedClass(String value) {
            this.value = value;
        }

        public String toJson() {
            return ("{\"value\":\"" + (value)) + "\"}";
        }
    }
}

