package com.google.gson.functional;

import java.util.ArrayList;
import com.google.gson.Gson;
import com.google.gson.GsonBuilder;
import com.google.gson.InstanceCreator;
import java.util.List;
import java.util.SortedSet;
import org.junit.Test;
import junit.framework.TestCase;
import com.google.gson.common.TestTypes;
import java.util.TreeSet;
import java.lang.reflect.Type;
import com.google.gson.reflect.TypeToken;

/** 
 * Functional Test exercising custom serialization only.  When test applies to both
 * serialization and deserialization then add it to CustomTypeAdapterTest.
 * 
 * @author Inderjeet Singh
 */
public class InstanceCreatorTest extends TestCase {
    @Test(timeout = 1000)
    public void testInstanceCreatorReturnsBaseType_add211() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorReturnsBaseType_add211");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new InstanceCreator<com.google.gson.common.TestTypes.Base>() {
                public TestTypes.Base createInstance(Type type) {
                    return new TestTypes.Base();
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1046,gson);
            String json = "{baseName:\'BaseRevised\',subName:\'Sub\'}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),315,json);
            TestTypes.Base base = gson.fromJson(json, TestTypes.Base.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),316,base);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1045,base.baseName);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testInstanceCreatorReturnsBaseType() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorReturnsBaseType");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new InstanceCreator<com.google.gson.common.TestTypes.Base>() {
                public TestTypes.Base createInstance(Type type) {
                    return new TestTypes.Base();
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1046,gson);
            String json = "{baseName:\'BaseRevised\'subName:\'Sub\'}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),315,json);
            TestTypes.Base base = gson.fromJson(json, TestTypes.Base.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),316,base);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1045,base.baseName);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testInstanceCreatorReturnsBaseType_literalMutation1577() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorReturnsBaseType_literalMutation1577");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new InstanceCreator<com.google.gson.common.TestTypes.Base>() {
                public TestTypes.Base createInstance(Type type) {
                    return new TestTypes.Base();
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1046,gson);
            String json = "{baseName:\'BaseRevised\',subName:W\'Sub\'}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),315,json);
            TestTypes.Base base = gson.fromJson(json, TestTypes.Base.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),316,base);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1045,base.baseName);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testInstanceCreatorReturnsBaseType_literalMutation1578() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorReturnsBaseType_literalMutation1578");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new InstanceCreator<com.google.gson.common.TestTypes.Base>() {
                public TestTypes.Base createInstance(Type type) {
                    return new TestTypes.Base();
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1046,gson);
            String json = "{basName:\'BaseRevised\',subName:\'Sub\'}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),315,json);
            TestTypes.Base base = gson.fromJson(json, TestTypes.Base.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),316,base);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1045,base.baseName);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testInstanceCreatorReturnsBaseType_remove201() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorReturnsBaseType_remove201");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new InstanceCreator<com.google.gson.common.TestTypes.Base>() {
                public TestTypes.Base createInstance(Type type) {
                    return new TestTypes.Base();
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1046,gson);
            String json = "{baseName:\'BaseRevised\',subName:\'Sub\'}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),315,json);
            TestTypes.Base base = gson.fromJson(json, TestTypes.Base.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),316,base);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1045,base.baseName);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testInstanceCreatorReturnsSubTypeForTopLevelObject_add213() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorReturnsSubTypeForTopLevelObject_add213");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new InstanceCreator<com.google.gson.common.TestTypes.Base>() {
                public TestTypes.Base createInstance(Type type) {
                    return new TestTypes.Sub();
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),329,gson);
            String json = "{baseName:\'Base\',subName:\'SubRevised\'}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),878,json);
            TestTypes.Base base = gson.fromJson(json, TestTypes.Base.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1055,base);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1051,(base instanceof com.google.gson.common.TestTypes.Sub));
            TestTypes.Sub sub = ((TestTypes.Sub)(base));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1056,sub);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1052,"SubRevised".equals(sub.subName));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1053,com.google.gson.common.TestTypes.Sub.SUB_NAME);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1054,sub.subName);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testInstanceCreatorReturnsSubTypeForTopLevelObject() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorReturnsSubTypeForTopLevelObject");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new InstanceCreator<com.google.gson.common.TestTypes.Base>() {
                public TestTypes.Base createInstance(Type type) {
                    return new TestTypes.Sub();
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),329,gson);
            String json = "{baseName:\'Base\',subName:\'SubRevisei\'}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),878,json);
            TestTypes.Base base = gson.fromJson(json, TestTypes.Base.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1055,base);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1051,(base instanceof com.google.gson.common.TestTypes.Sub));
            TestTypes.Sub sub = ((TestTypes.Sub)(base));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1056,sub);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1052,"SubRevised".equals(sub.subName));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1053,com.google.gson.common.TestTypes.Sub.SUB_NAME);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1054,sub.subName);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testInstanceCreatorReturnsSubTypeForTopLevelObject_literalMutation1583() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorReturnsSubTypeForTopLevelObject_literalMutation1583");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new InstanceCreator<com.google.gson.common.TestTypes.Base>() {
                public TestTypes.Base createInstance(Type type) {
                    return new TestTypes.Sub();
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),329,gson);
            String json = "{baseName:\'Base\',s!ubName:\'SubRevised\'}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),878,json);
            TestTypes.Base base = gson.fromJson(json, TestTypes.Base.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1055,base);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1051,(base instanceof com.google.gson.common.TestTypes.Sub));
            TestTypes.Sub sub = ((TestTypes.Sub)(base));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1056,sub);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1052,"SubRevised".equals(sub.subName));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1053,com.google.gson.common.TestTypes.Sub.SUB_NAME);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1054,sub.subName);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testInstanceCreatorReturnsSubTypeForTopLevelObject_literalMutation1584() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorReturnsSubTypeForTopLevelObject_literalMutation1584");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new InstanceCreator<com.google.gson.common.TestTypes.Base>() {
                public TestTypes.Base createInstance(Type type) {
                    return new TestTypes.Sub();
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),329,gson);
            String json = "{baseName:\'Base\',suName:\'SubRevised\'}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),878,json);
            TestTypes.Base base = gson.fromJson(json, TestTypes.Base.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1055,base);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1051,(base instanceof com.google.gson.common.TestTypes.Sub));
            TestTypes.Sub sub = ((TestTypes.Sub)(base));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1056,sub);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1052,"SubRevised".equals(sub.subName));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1053,com.google.gson.common.TestTypes.Sub.SUB_NAME);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1054,sub.subName);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testInstanceCreatorReturnsSubTypeForTopLevelObject_remove203() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorReturnsSubTypeForTopLevelObject_remove203");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new InstanceCreator<com.google.gson.common.TestTypes.Base>() {
                public TestTypes.Base createInstance(Type type) {
                    return new TestTypes.Sub();
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),329,gson);
            String json = "{baseName:\'Base\',subName:\'SubRevised\'}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),878,json);
            TestTypes.Base base = gson.fromJson(json, TestTypes.Base.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1055,base);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1051,(base instanceof com.google.gson.common.TestTypes.Sub));
            TestTypes.Sub sub = ((TestTypes.Sub)(base));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1056,sub);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1052,"SubRevised".equals(sub.subName));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1053,com.google.gson.common.TestTypes.Sub.SUB_NAME);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1054,sub.subName);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testInstanceCreatorReturnsSubTypeForField_add212() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorReturnsSubTypeForField_add212");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new InstanceCreator<com.google.gson.common.TestTypes.Base>() {
                public TestTypes.Base createInstance(Type type) {
                    return new TestTypes.Sub();
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1049,gson);
            String json = "{base:{baseName:\'Base\',subName:\'SubRevised\'}}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1000,json);
            TestTypes.ClassWithBaseField target = gson.fromJson(json, TestTypes.ClassWithBaseField.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1050,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1047,((target.base) instanceof com.google.gson.common.TestTypes.Sub));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),996,com.google.gson.common.TestTypes.Sub.SUB_NAME);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1048,((com.google.gson.common.TestTypes.Sub)(target.base)).subName);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testInstanceCreatorReturnsSubTypeForField() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorReturnsSubTypeForField");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new InstanceCreator<com.google.gson.common.TestTypes.Base>() {
                public TestTypes.Base createInstance(Type type) {
                    return new TestTypes.Sub();
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1049,gson);
            String json = "{base:{baseName:\'Base\',subName:\'SubRevisedc}}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1000,json);
            TestTypes.ClassWithBaseField target = gson.fromJson(json, TestTypes.ClassWithBaseField.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1050,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1047,((target.base) instanceof com.google.gson.common.TestTypes.Sub));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),996,com.google.gson.common.TestTypes.Sub.SUB_NAME);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1048,((com.google.gson.common.TestTypes.Sub)(target.base)).subName);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testInstanceCreatorReturnsSubTypeForField_literalMutation1580() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorReturnsSubTypeForField_literalMutation1580");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new InstanceCreator<com.google.gson.common.TestTypes.Base>() {
                public TestTypes.Base createInstance(Type type) {
                    return new TestTypes.Sub();
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1049,gson);
            String json = "{base:{baseName:\'Base\',subName:\'SubRevised\'}}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1000,json);
            TestTypes.ClassWithBaseField target = gson.fromJson(json, TestTypes.ClassWithBaseField.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1050,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1047,((target.base) instanceof com.google.gson.common.TestTypes.Sub));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),996,com.google.gson.common.TestTypes.Sub.SUB_NAME);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1048,((com.google.gson.common.TestTypes.Sub)(target.base)).subName);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testInstanceCreatorReturnsSubTypeForField_literalMutation1581() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorReturnsSubTypeForField_literalMutation1581");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new InstanceCreator<com.google.gson.common.TestTypes.Base>() {
                public TestTypes.Base createInstance(Type type) {
                    return new TestTypes.Sub();
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1049,gson);
            String json = "{base:{baseName:\'Bas\',subName:\'SubRevised\'}}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1000,json);
            TestTypes.ClassWithBaseField target = gson.fromJson(json, TestTypes.ClassWithBaseField.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1050,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1047,((target.base) instanceof com.google.gson.common.TestTypes.Sub));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),996,com.google.gson.common.TestTypes.Sub.SUB_NAME);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1048,((com.google.gson.common.TestTypes.Sub)(target.base)).subName);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testInstanceCreatorReturnsSubTypeForField_remove202() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorReturnsSubTypeForField_remove202");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new InstanceCreator<com.google.gson.common.TestTypes.Base>() {
                public TestTypes.Base createInstance(Type type) {
                    return new TestTypes.Sub();
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1049,gson);
            String json = "{base:{baseName:\'Base\',subName:\'SubRevised\'}}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1000,json);
            TestTypes.ClassWithBaseField target = gson.fromJson(json, TestTypes.ClassWithBaseField.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1050,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1047,((target.base) instanceof com.google.gson.common.TestTypes.Sub));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),996,com.google.gson.common.TestTypes.Sub.SUB_NAME);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1048,((com.google.gson.common.TestTypes.Sub)(target.base)).subName);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testInstanceCreatorForCollectionType_add205() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorForCollectionType_add205");
            @SuppressWarnings(value = "serial")
            class SubArrayList<T> extends ArrayList<T> {            }
            InstanceCreator<java.util.List<java.lang.String>> listCreator = new InstanceCreator<java.util.List<java.lang.String>>() {
                public List<java.lang.String> createInstance(Type type) {
                    return new SubArrayList<java.lang.String>();
                }
            };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1031,listCreator);
            Type listOfStringType = new TypeToken<java.util.List<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1032,listOfStringType);
            Gson gson = new GsonBuilder().registerTypeAdapter(listOfStringType, listCreator).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1033,gson);
            List<java.lang.String> list = gson.fromJson("[\"a\"]", listOfStringType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1034,list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1029,SubArrayList.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1030,list.getClass());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testInstanceCreatorForCollectionType_add206() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorForCollectionType_add206");
            @SuppressWarnings(value = "serial")
            class SubArrayList<T> extends ArrayList<T> {            }
            InstanceCreator<java.util.List<java.lang.String>> listCreator = new InstanceCreator<java.util.List<java.lang.String>>() {
                public List<java.lang.String> createInstance(Type type) {
                    return new SubArrayList<java.lang.String>();
                }
            };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1031,listCreator);
            Type listOfStringType = new TypeToken<java.util.List<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1032,listOfStringType);
            Gson gson = new GsonBuilder().registerTypeAdapter(listOfStringType, listCreator).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1033,gson);
            List<java.lang.String> list = gson.fromJson("[\"a\"]", listOfStringType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1034,list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1029,SubArrayList.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1030,list.getClass());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testInstanceCreatorForCollectionType_add207() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorForCollectionType_add207");
            @SuppressWarnings(value = "serial")
            class SubArrayList<T> extends ArrayList<T> {            }
            InstanceCreator<java.util.List<java.lang.String>> listCreator = new InstanceCreator<java.util.List<java.lang.String>>() {
                public List<java.lang.String> createInstance(Type type) {
                    return new SubArrayList<java.lang.String>();
                }
            };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1031,listCreator);
            Type listOfStringType = new TypeToken<java.util.List<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1032,listOfStringType);
            Gson gson = new GsonBuilder().registerTypeAdapter(listOfStringType, listCreator).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1033,gson);
            List<java.lang.String> list = gson.fromJson("[\"a\"]", listOfStringType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1034,list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1029,SubArrayList.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1030,list.getClass());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testInstanceCreatorForCollectionType() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorForCollectionType");
            @SuppressWarnings(value = "ser­al")
            class SubArrayList<T> extends ArrayList<T> {            }
            InstanceCreator<java.util.List<java.lang.String>> listCreator = new InstanceCreator<java.util.List<java.lang.String>>() {
                public List<java.lang.String> createInstance(Type type) {
                    return new SubArrayList<java.lang.String>();
                }
            };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1031,listCreator);
            Type listOfStringType = new TypeToken<java.util.List<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1032,listOfStringType);
            Gson gson = new GsonBuilder().registerTypeAdapter(listOfStringType, listCreator).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1033,gson);
            List<java.lang.String> list = gson.fromJson("[\"a\"]", listOfStringType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1034,list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1029,SubArrayList.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1030,list.getClass());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testInstanceCreatorForCollectionType_literalMutation1556() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorForCollectionType_literalMutation1556");
            @SuppressWarnings(value = "serial")
            class SubArrayList<T> extends ArrayList<T> {            }
            InstanceCreator<java.util.List<java.lang.String>> listCreator = new InstanceCreator<java.util.List<java.lang.String>>() {
                public List<java.lang.String> createInstance(Type type) {
                    return new SubArrayList<java.lang.String>();
                }
            };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1031,listCreator);
            Type listOfStringType = new TypeToken<java.util.List<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1032,listOfStringType);
            Gson gson = new GsonBuilder().registerTypeAdapter(listOfStringType, listCreator).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1033,gson);
            List<java.lang.String> list = gson.fromJson("[\"a\"]", listOfStringType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1034,list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1029,SubArrayList.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1030,list.getClass());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testInstanceCreatorForCollectionType_literalMutation1557() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorForCollectionType_literalMutation1557");
            @SuppressWarnings(value = "seral")
            class SubArrayList<T> extends ArrayList<T> {            }
            InstanceCreator<java.util.List<java.lang.String>> listCreator = new InstanceCreator<java.util.List<java.lang.String>>() {
                public List<java.lang.String> createInstance(Type type) {
                    return new SubArrayList<java.lang.String>();
                }
            };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1031,listCreator);
            Type listOfStringType = new TypeToken<java.util.List<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1032,listOfStringType);
            Gson gson = new GsonBuilder().registerTypeAdapter(listOfStringType, listCreator).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1033,gson);
            List<java.lang.String> list = gson.fromJson("[\"a\"]", listOfStringType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1034,list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1029,SubArrayList.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1030,list.getClass());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testInstanceCreatorForCollectionType_literalMutation1558() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorForCollectionType_literalMutation1558");
            @SuppressWarnings(value = "serial")
            class SubArrayList<T> extends ArrayList<T> {            }
            InstanceCreator<java.util.List<java.lang.String>> listCreator = new InstanceCreator<java.util.List<java.lang.String>>() {
                public List<java.lang.String> createInstance(Type type) {
                    return new SubArrayList<java.lang.String>();
                }
            };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1031,listCreator);
            Type listOfStringType = new TypeToken<java.util.List<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1032,listOfStringType);
            Gson gson = new GsonBuilder().registerTypeAdapter(listOfStringType, listCreator).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1033,gson);
            List<java.lang.String> list = gson.fromJson("[\"y\"]", listOfStringType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1034,list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1029,SubArrayList.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1030,list.getClass());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testInstanceCreatorForCollectionType_literalMutation1559() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorForCollectionType_literalMutation1559");
            @SuppressWarnings(value = "serial")
            class SubArrayList<T> extends ArrayList<T> {            }
            InstanceCreator<java.util.List<java.lang.String>> listCreator = new InstanceCreator<java.util.List<java.lang.String>>() {
                public List<java.lang.String> createInstance(Type type) {
                    return new SubArrayList<java.lang.String>();
                }
            };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1031,listCreator);
            Type listOfStringType = new TypeToken<java.util.List<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1032,listOfStringType);
            Gson gson = new GsonBuilder().registerTypeAdapter(listOfStringType, listCreator).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1033,gson);
            List<java.lang.String> list = gson.fromJson("[\"a\"]", listOfStringType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1034,list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1029,SubArrayList.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1030,list.getClass());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testInstanceCreatorForCollectionType_literalMutation1560() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorForCollectionType_literalMutation1560");
            @SuppressWarnings(value = "serial")
            class SubArrayList<T> extends ArrayList<T> {            }
            InstanceCreator<java.util.List<java.lang.String>> listCreator = new InstanceCreator<java.util.List<java.lang.String>>() {
                public List<java.lang.String> createInstance(Type type) {
                    return new SubArrayList<java.lang.String>();
                }
            };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1031,listCreator);
            Type listOfStringType = new TypeToken<java.util.List<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1032,listOfStringType);
            Gson gson = new GsonBuilder().registerTypeAdapter(listOfStringType, listCreator).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1033,gson);
            List<java.lang.String> list = gson.fromJson("[\"a]", listOfStringType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1034,list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1029,SubArrayList.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1030,list.getClass());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testInstanceCreatorForCollectionType_remove195() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorForCollectionType_remove195");
            @SuppressWarnings(value = "serial")
            class SubArrayList<T> extends ArrayList<T> {            }
            InstanceCreator<java.util.List<java.lang.String>> listCreator = new InstanceCreator<java.util.List<java.lang.String>>() {
                public List<java.lang.String> createInstance(Type type) {
                    return new SubArrayList<java.lang.String>();
                }
            };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1031,listCreator);
            Type listOfStringType = new TypeToken<java.util.List<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1032,listOfStringType);
            Gson gson = new GsonBuilder().registerTypeAdapter(listOfStringType, listCreator).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1033,gson);
            List<java.lang.String> list = gson.fromJson("[\"a\"]", listOfStringType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1034,list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1029,SubArrayList.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1030,list.getClass());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testInstanceCreatorForCollectionType_remove196() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorForCollectionType_remove196");
            @SuppressWarnings(value = "serial")
            class SubArrayList<T> extends ArrayList<T> {            }
            InstanceCreator<java.util.List<java.lang.String>> listCreator = new InstanceCreator<java.util.List<java.lang.String>>() {
                public List<java.lang.String> createInstance(Type type) {
                    return new SubArrayList<java.lang.String>();
                }
            };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1031,listCreator);
            Type listOfStringType = new TypeToken<java.util.List<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1032,listOfStringType);
            Gson gson = new GsonBuilder().registerTypeAdapter(listOfStringType, listCreator).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1033,gson);
            List<java.lang.String> list = gson.fromJson("[\"a\"]", listOfStringType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1034,list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1029,SubArrayList.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1030,list.getClass());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testInstanceCreatorForCollectionType_remove197() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorForCollectionType_remove197");
            @SuppressWarnings(value = "serial")
            class SubArrayList<T> extends ArrayList<T> {            }
            InstanceCreator<java.util.List<java.lang.String>> listCreator = new InstanceCreator<java.util.List<java.lang.String>>() {
                public List<java.lang.String> createInstance(Type type) {
                    return new SubArrayList<java.lang.String>();
                }
            };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1031,listCreator);
            Type listOfStringType = new TypeToken<java.util.List<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1032,listOfStringType);
            Gson gson = new GsonBuilder().registerTypeAdapter(listOfStringType, listCreator).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1033,gson);
            List<java.lang.String> list = gson.fromJson("[\"a\"]", listOfStringType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1034,list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1029,SubArrayList.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1030,list.getClass());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = { "unchecked" , "rawtypes" })
    @Test(timeout = 1000)
    public void testInstanceCreatorForParametrizedType_add208() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorForParametrizedType_add208");
            @SuppressWarnings(value = "serial")
            class SubTreeSet<T> extends TreeSet<T> {            }
            InstanceCreator<java.util.SortedSet> sortedSetCreator = new InstanceCreator<java.util.SortedSet>() {
                public SortedSet createInstance(Type type) {
                    return new SubTreeSet();
                }
            };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1042,sortedSetCreator);
            Gson gson = new GsonBuilder().registerTypeAdapter(SortedSet.class, sortedSetCreator).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),304,gson);
            Type sortedSetType = new TypeToken<java.util.SortedSet<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1043,sortedSetType);
            SortedSet<java.lang.String> set = gson.fromJson("[\"a\"]", sortedSetType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1044,set);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1035,set.first());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1036,SubTreeSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1037,set.getClass());
            set = gson.fromJson("[\"b\"]", SortedSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1041,set);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1038,set.first());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1039,SubTreeSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1040,set.getClass());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = { "unchecked" , "rawtypes" })
    @Test(timeout = 1000)
    public void testInstanceCreatorForParametrizedType_add209() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorForParametrizedType_add209");
            @SuppressWarnings(value = "serial")
            class SubTreeSet<T> extends TreeSet<T> {            }
            InstanceCreator<java.util.SortedSet> sortedSetCreator = new InstanceCreator<java.util.SortedSet>() {
                public SortedSet createInstance(Type type) {
                    return new SubTreeSet();
                }
            };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1042,sortedSetCreator);
            Gson gson = new GsonBuilder().registerTypeAdapter(SortedSet.class, sortedSetCreator).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),304,gson);
            Type sortedSetType = new TypeToken<java.util.SortedSet<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1043,sortedSetType);
            SortedSet<java.lang.String> set = gson.fromJson("[\"a\"]", sortedSetType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1044,set);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1035,set.first());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1036,SubTreeSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1037,set.getClass());
            set = gson.fromJson("[\"b\"]", SortedSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1041,set);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1038,set.first());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1039,SubTreeSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1040,set.getClass());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = { "unchecked" , "rawtypes" })
    @Test(timeout = 1000)
    public void testInstanceCreatorForParametrizedType_add210() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorForParametrizedType_add210");
            @SuppressWarnings(value = "serial")
            class SubTreeSet<T> extends TreeSet<T> {            }
            InstanceCreator<java.util.SortedSet> sortedSetCreator = new InstanceCreator<java.util.SortedSet>() {
                public SortedSet createInstance(Type type) {
                    return new SubTreeSet();
                }
            };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1042,sortedSetCreator);
            Gson gson = new GsonBuilder().registerTypeAdapter(SortedSet.class, sortedSetCreator).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),304,gson);
            Type sortedSetType = new TypeToken<java.util.SortedSet<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1043,sortedSetType);
            SortedSet<java.lang.String> set = gson.fromJson("[\"a\"]", sortedSetType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1044,set);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1035,set.first());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1036,SubTreeSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1037,set.getClass());
            set = gson.fromJson("[\"b\"]", SortedSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1041,set);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1038,set.first());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1039,SubTreeSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1040,set.getClass());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = { "unchected" , "rawtypes" })
    public void testInstanceCreatorForParametrizedType() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorForParametrizedType");
            @SuppressWarnings(value = "serial")
            class SubTreeSet<T> extends TreeSet<T> {            }
            InstanceCreator<java.util.SortedSet> sortedSetCreator = new InstanceCreator<java.util.SortedSet>() {
                public SortedSet createInstance(Type type) {
                    return new SubTreeSet();
                }
            };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1042,sortedSetCreator);
            Gson gson = new GsonBuilder().registerTypeAdapter(SortedSet.class, sortedSetCreator).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),304,gson);
            Type sortedSetType = new TypeToken<java.util.SortedSet<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1043,sortedSetType);
            SortedSet<java.lang.String> set = gson.fromJson("[\"a\"]", sortedSetType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1044,set);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1035,set.first());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1036,SubTreeSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1037,set.getClass());
            set = gson.fromJson("[\"b\"]", SortedSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1041,set);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1038,set.first());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1039,SubTreeSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1040,set.getClass());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = { "uMnchecked" , "rawtypes" })
    public void testInstanceCreatorForParametrizedType_literalMutation1562() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorForParametrizedType_literalMutation1562");
            @SuppressWarnings(value = "serial")
            class SubTreeSet<T> extends TreeSet<T> {            }
            InstanceCreator<java.util.SortedSet> sortedSetCreator = new InstanceCreator<java.util.SortedSet>() {
                public SortedSet createInstance(Type type) {
                    return new SubTreeSet();
                }
            };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1042,sortedSetCreator);
            Gson gson = new GsonBuilder().registerTypeAdapter(SortedSet.class, sortedSetCreator).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),304,gson);
            Type sortedSetType = new TypeToken<java.util.SortedSet<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1043,sortedSetType);
            SortedSet<java.lang.String> set = gson.fromJson("[\"a\"]", sortedSetType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1044,set);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1035,set.first());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1036,SubTreeSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1037,set.getClass());
            set = gson.fromJson("[\"b\"]", SortedSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1041,set);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1038,set.first());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1039,SubTreeSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1040,set.getClass());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = { "uncheked" , "rawtypes" })
    public void testInstanceCreatorForParametrizedType_literalMutation1563() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorForParametrizedType_literalMutation1563");
            @SuppressWarnings(value = "serial")
            class SubTreeSet<T> extends TreeSet<T> {            }
            InstanceCreator<java.util.SortedSet> sortedSetCreator = new InstanceCreator<java.util.SortedSet>() {
                public SortedSet createInstance(Type type) {
                    return new SubTreeSet();
                }
            };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1042,sortedSetCreator);
            Gson gson = new GsonBuilder().registerTypeAdapter(SortedSet.class, sortedSetCreator).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),304,gson);
            Type sortedSetType = new TypeToken<java.util.SortedSet<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1043,sortedSetType);
            SortedSet<java.lang.String> set = gson.fromJson("[\"a\"]", sortedSetType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1044,set);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1035,set.first());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1036,SubTreeSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1037,set.getClass());
            set = gson.fromJson("[\"b\"]", SortedSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1041,set);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1038,set.first());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1039,SubTreeSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1040,set.getClass());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = { "unchecked" , "rawt[pes" })
    public void testInstanceCreatorForParametrizedType_literalMutation1564() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorForParametrizedType_literalMutation1564");
            @SuppressWarnings(value = "serial")
            class SubTreeSet<T> extends TreeSet<T> {            }
            InstanceCreator<java.util.SortedSet> sortedSetCreator = new InstanceCreator<java.util.SortedSet>() {
                public SortedSet createInstance(Type type) {
                    return new SubTreeSet();
                }
            };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1042,sortedSetCreator);
            Gson gson = new GsonBuilder().registerTypeAdapter(SortedSet.class, sortedSetCreator).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),304,gson);
            Type sortedSetType = new TypeToken<java.util.SortedSet<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1043,sortedSetType);
            SortedSet<java.lang.String> set = gson.fromJson("[\"a\"]", sortedSetType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1044,set);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1035,set.first());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1036,SubTreeSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1037,set.getClass());
            set = gson.fromJson("[\"b\"]", SortedSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1041,set);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1038,set.first());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1039,SubTreeSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1040,set.getClass());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = { "unchecked" , "ra¨wtypes" })
    public void testInstanceCreatorForParametrizedType_literalMutation1565() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorForParametrizedType_literalMutation1565");
            @SuppressWarnings(value = "serial")
            class SubTreeSet<T> extends TreeSet<T> {            }
            InstanceCreator<java.util.SortedSet> sortedSetCreator = new InstanceCreator<java.util.SortedSet>() {
                public SortedSet createInstance(Type type) {
                    return new SubTreeSet();
                }
            };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1042,sortedSetCreator);
            Gson gson = new GsonBuilder().registerTypeAdapter(SortedSet.class, sortedSetCreator).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),304,gson);
            Type sortedSetType = new TypeToken<java.util.SortedSet<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1043,sortedSetType);
            SortedSet<java.lang.String> set = gson.fromJson("[\"a\"]", sortedSetType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1044,set);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1035,set.first());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1036,SubTreeSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1037,set.getClass());
            set = gson.fromJson("[\"b\"]", SortedSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1041,set);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1038,set.first());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1039,SubTreeSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1040,set.getClass());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = { "unchecked" , "rawtpes" })
    public void testInstanceCreatorForParametrizedType_literalMutation1566() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorForParametrizedType_literalMutation1566");
            @SuppressWarnings(value = "serial")
            class SubTreeSet<T> extends TreeSet<T> {            }
            InstanceCreator<java.util.SortedSet> sortedSetCreator = new InstanceCreator<java.util.SortedSet>() {
                public SortedSet createInstance(Type type) {
                    return new SubTreeSet();
                }
            };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1042,sortedSetCreator);
            Gson gson = new GsonBuilder().registerTypeAdapter(SortedSet.class, sortedSetCreator).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),304,gson);
            Type sortedSetType = new TypeToken<java.util.SortedSet<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1043,sortedSetType);
            SortedSet<java.lang.String> set = gson.fromJson("[\"a\"]", sortedSetType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1044,set);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1035,set.first());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1036,SubTreeSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1037,set.getClass());
            set = gson.fromJson("[\"b\"]", SortedSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1041,set);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1038,set.first());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1039,SubTreeSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1040,set.getClass());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = { "unchecked" , "rawtypes" })
    public void testInstanceCreatorForParametrizedType_literalMutation1567() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorForParametrizedType_literalMutation1567");
            @SuppressWarnings(value = "seSial")
            class SubTreeSet<T> extends TreeSet<T> {            }
            InstanceCreator<java.util.SortedSet> sortedSetCreator = new InstanceCreator<java.util.SortedSet>() {
                public SortedSet createInstance(Type type) {
                    return new SubTreeSet();
                }
            };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1042,sortedSetCreator);
            Gson gson = new GsonBuilder().registerTypeAdapter(SortedSet.class, sortedSetCreator).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),304,gson);
            Type sortedSetType = new TypeToken<java.util.SortedSet<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1043,sortedSetType);
            SortedSet<java.lang.String> set = gson.fromJson("[\"a\"]", sortedSetType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1044,set);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1035,set.first());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1036,SubTreeSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1037,set.getClass());
            set = gson.fromJson("[\"b\"]", SortedSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1041,set);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1038,set.first());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1039,SubTreeSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1040,set.getClass());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = { "unchecked" , "rawtypes" })
    public void testInstanceCreatorForParametrizedType_literalMutation1568() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorForParametrizedType_literalMutation1568");
            @SuppressWarnings(value = "seri<al")
            class SubTreeSet<T> extends TreeSet<T> {            }
            InstanceCreator<java.util.SortedSet> sortedSetCreator = new InstanceCreator<java.util.SortedSet>() {
                public SortedSet createInstance(Type type) {
                    return new SubTreeSet();
                }
            };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1042,sortedSetCreator);
            Gson gson = new GsonBuilder().registerTypeAdapter(SortedSet.class, sortedSetCreator).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),304,gson);
            Type sortedSetType = new TypeToken<java.util.SortedSet<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1043,sortedSetType);
            SortedSet<java.lang.String> set = gson.fromJson("[\"a\"]", sortedSetType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1044,set);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1035,set.first());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1036,SubTreeSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1037,set.getClass());
            set = gson.fromJson("[\"b\"]", SortedSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1041,set);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1038,set.first());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1039,SubTreeSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1040,set.getClass());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = { "unchecked" , "rawtypes" })
    public void testInstanceCreatorForParametrizedType_literalMutation1569() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorForParametrizedType_literalMutation1569");
            @SuppressWarnings(value = "seril")
            class SubTreeSet<T> extends TreeSet<T> {            }
            InstanceCreator<java.util.SortedSet> sortedSetCreator = new InstanceCreator<java.util.SortedSet>() {
                public SortedSet createInstance(Type type) {
                    return new SubTreeSet();
                }
            };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1042,sortedSetCreator);
            Gson gson = new GsonBuilder().registerTypeAdapter(SortedSet.class, sortedSetCreator).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),304,gson);
            Type sortedSetType = new TypeToken<java.util.SortedSet<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1043,sortedSetType);
            SortedSet<java.lang.String> set = gson.fromJson("[\"a\"]", sortedSetType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1044,set);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1035,set.first());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1036,SubTreeSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1037,set.getClass());
            set = gson.fromJson("[\"b\"]", SortedSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1041,set);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1038,set.first());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1039,SubTreeSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1040,set.getClass());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = { "unchecked" , "rawtypes" })
    public void testInstanceCreatorForParametrizedType_literalMutation1570() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorForParametrizedType_literalMutation1570");
            @SuppressWarnings(value = "serial")
            class SubTreeSet<T> extends TreeSet<T> {            }
            InstanceCreator<java.util.SortedSet> sortedSetCreator = new InstanceCreator<java.util.SortedSet>() {
                public SortedSet createInstance(Type type) {
                    return new SubTreeSet();
                }
            };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1042,sortedSetCreator);
            Gson gson = new GsonBuilder().registerTypeAdapter(SortedSet.class, sortedSetCreator).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),304,gson);
            Type sortedSetType = new TypeToken<java.util.SortedSet<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1043,sortedSetType);
            SortedSet<java.lang.String> set = gson.fromJson("[\"G\"]", sortedSetType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1044,set);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1035,set.first());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1036,SubTreeSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1037,set.getClass());
            set = gson.fromJson("[\"b\"]", SortedSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1041,set);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1038,set.first());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1039,SubTreeSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1040,set.getClass());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = { "unchecked" , "rawtypes" })
    public void testInstanceCreatorForParametrizedType_literalMutation1571() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorForParametrizedType_literalMutation1571");
            @SuppressWarnings(value = "serial")
            class SubTreeSet<T> extends TreeSet<T> {            }
            InstanceCreator<java.util.SortedSet> sortedSetCreator = new InstanceCreator<java.util.SortedSet>() {
                public SortedSet createInstance(Type type) {
                    return new SubTreeSet();
                }
            };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1042,sortedSetCreator);
            Gson gson = new GsonBuilder().registerTypeAdapter(SortedSet.class, sortedSetCreator).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),304,gson);
            Type sortedSetType = new TypeToken<java.util.SortedSet<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1043,sortedSetType);
            SortedSet<java.lang.String> set = gson.fromJson("[\"a\"]", sortedSetType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1044,set);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1035,set.first());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1036,SubTreeSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1037,set.getClass());
            set = gson.fromJson("[\"b\"]", SortedSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1041,set);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1038,set.first());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1039,SubTreeSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1040,set.getClass());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = { "unchecked" , "rawtypes" })
    public void testInstanceCreatorForParametrizedType_literalMutation1572() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorForParametrizedType_literalMutation1572");
            @SuppressWarnings(value = "serial")
            class SubTreeSet<T> extends TreeSet<T> {            }
            InstanceCreator<java.util.SortedSet> sortedSetCreator = new InstanceCreator<java.util.SortedSet>() {
                public SortedSet createInstance(Type type) {
                    return new SubTreeSet();
                }
            };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1042,sortedSetCreator);
            Gson gson = new GsonBuilder().registerTypeAdapter(SortedSet.class, sortedSetCreator).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),304,gson);
            Type sortedSetType = new TypeToken<java.util.SortedSet<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1043,sortedSetType);
            SortedSet<java.lang.String> set = gson.fromJson("[a\"]", sortedSetType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1044,set);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1035,set.first());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1036,SubTreeSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1037,set.getClass());
            set = gson.fromJson("[\"b\"]", SortedSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1041,set);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1038,set.first());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1039,SubTreeSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1040,set.getClass());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = { "unchecked" , "rawtypes" })
    public void testInstanceCreatorForParametrizedType_literalMutation1573() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorForParametrizedType_literalMutation1573");
            @SuppressWarnings(value = "serial")
            class SubTreeSet<T> extends TreeSet<T> {            }
            InstanceCreator<java.util.SortedSet> sortedSetCreator = new InstanceCreator<java.util.SortedSet>() {
                public SortedSet createInstance(Type type) {
                    return new SubTreeSet();
                }
            };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1042,sortedSetCreator);
            Gson gson = new GsonBuilder().registerTypeAdapter(SortedSet.class, sortedSetCreator).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),304,gson);
            Type sortedSetType = new TypeToken<java.util.SortedSet<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1043,sortedSetType);
            SortedSet<java.lang.String> set = gson.fromJson("[\"a\"]", sortedSetType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1044,set);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1035,set.first());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1036,SubTreeSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1037,set.getClass());
            set = gson.fromJson("\"b\"]", SortedSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1041,set);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1038,set.first());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1039,SubTreeSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1040,set.getClass());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = { "unchecked" , "rawtypes" })
    public void testInstanceCreatorForParametrizedType_literalMutation1574() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorForParametrizedType_literalMutation1574");
            @SuppressWarnings(value = "serial")
            class SubTreeSet<T> extends TreeSet<T> {            }
            InstanceCreator<java.util.SortedSet> sortedSetCreator = new InstanceCreator<java.util.SortedSet>() {
                public SortedSet createInstance(Type type) {
                    return new SubTreeSet();
                }
            };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1042,sortedSetCreator);
            Gson gson = new GsonBuilder().registerTypeAdapter(SortedSet.class, sortedSetCreator).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),304,gson);
            Type sortedSetType = new TypeToken<java.util.SortedSet<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1043,sortedSetType);
            SortedSet<java.lang.String> set = gson.fromJson("[\"a\"]", sortedSetType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1044,set);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1035,set.first());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1036,SubTreeSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1037,set.getClass());
            set = gson.fromJson("[\"/b\"]", SortedSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1041,set);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1038,set.first());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1039,SubTreeSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1040,set.getClass());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = { "unchecked" , "rawtypes" })
    public void testInstanceCreatorForParametrizedType_literalMutation1575() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorForParametrizedType_literalMutation1575");
            @SuppressWarnings(value = "serial")
            class SubTreeSet<T> extends TreeSet<T> {            }
            InstanceCreator<java.util.SortedSet> sortedSetCreator = new InstanceCreator<java.util.SortedSet>() {
                public SortedSet createInstance(Type type) {
                    return new SubTreeSet();
                }
            };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1042,sortedSetCreator);
            Gson gson = new GsonBuilder().registerTypeAdapter(SortedSet.class, sortedSetCreator).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),304,gson);
            Type sortedSetType = new TypeToken<java.util.SortedSet<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1043,sortedSetType);
            SortedSet<java.lang.String> set = gson.fromJson("[\"a\"]", sortedSetType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1044,set);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1035,set.first());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1036,SubTreeSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1037,set.getClass());
            set = gson.fromJson("[\"b]", SortedSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1041,set);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1038,set.first());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1039,SubTreeSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1040,set.getClass());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = { "unchecked" , "rawtypes" })
    @Test(timeout = 1000)
    public void testInstanceCreatorForParametrizedType_remove198() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorForParametrizedType_remove198");
            @SuppressWarnings(value = "serial")
            class SubTreeSet<T> extends TreeSet<T> {            }
            InstanceCreator<java.util.SortedSet> sortedSetCreator = new InstanceCreator<java.util.SortedSet>() {
                public SortedSet createInstance(Type type) {
                    return new SubTreeSet();
                }
            };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1042,sortedSetCreator);
            Gson gson = new GsonBuilder().registerTypeAdapter(SortedSet.class, sortedSetCreator).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),304,gson);
            Type sortedSetType = new TypeToken<java.util.SortedSet<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1043,sortedSetType);
            SortedSet<java.lang.String> set = gson.fromJson("[\"a\"]", sortedSetType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1044,set);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1035,set.first());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1036,SubTreeSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1037,set.getClass());
            set = gson.fromJson("[\"b\"]", SortedSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1041,set);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1038,set.first());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1039,SubTreeSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1040,set.getClass());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = { "unchecked" , "rawtypes" })
    @Test(timeout = 1000)
    public void testInstanceCreatorForParametrizedType_remove199() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorForParametrizedType_remove199");
            @SuppressWarnings(value = "serial")
            class SubTreeSet<T> extends TreeSet<T> {            }
            InstanceCreator<java.util.SortedSet> sortedSetCreator = new InstanceCreator<java.util.SortedSet>() {
                public SortedSet createInstance(Type type) {
                    return new SubTreeSet();
                }
            };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1042,sortedSetCreator);
            Gson gson = new GsonBuilder().registerTypeAdapter(SortedSet.class, sortedSetCreator).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),304,gson);
            Type sortedSetType = new TypeToken<java.util.SortedSet<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1043,sortedSetType);
            SortedSet<java.lang.String> set = gson.fromJson("[\"a\"]", sortedSetType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1044,set);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1035,set.first());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1036,SubTreeSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1037,set.getClass());
            set = gson.fromJson("[\"b\"]", SortedSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1041,set);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1038,set.first());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1039,SubTreeSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1040,set.getClass());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = { "unchecked" , "rawtypes" })
    @Test(timeout = 1000)
    public void testInstanceCreatorForParametrizedType_remove200() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInstanceCreatorForParametrizedType_remove200");
            @SuppressWarnings(value = "serial")
            class SubTreeSet<T> extends TreeSet<T> {            }
            InstanceCreator<java.util.SortedSet> sortedSetCreator = new InstanceCreator<java.util.SortedSet>() {
                public SortedSet createInstance(Type type) {
                    return new SubTreeSet();
                }
            };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1042,sortedSetCreator);
            Gson gson = new GsonBuilder().registerTypeAdapter(SortedSet.class, sortedSetCreator).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),304,gson);
            Type sortedSetType = new TypeToken<java.util.SortedSet<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1043,sortedSetType);
            SortedSet<java.lang.String> set = gson.fromJson("[\"a\"]", sortedSetType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1044,set);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1035,set.first());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1036,SubTreeSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1037,set.getClass());
            set = gson.fromJson("[\"b\"]", SortedSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1041,set);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1038,set.first());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1039,SubTreeSet.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1040,set.getClass());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }
}

