package com.google.gson.functional;

import com.google.gson.Gson;
import junit.framework.TestCase;

/** 
 * Functional tests for internationalized strings.
 * 
 * @author Inderjeet Singh
 */
public class InternationalizationTest extends TestCase {
    private Gson gson;

    @Override
    protected void setUp() throws Exception {
        super.setUp();
        gson = new Gson();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1063,gson);
    }

    public void testStringsWithRawChineseCharactersDeserialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringsWithRawChineseCharactersDeserialization");
            String expected = "\r好好";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1066,expected);
            String json = ("\"" + expected) + "\"";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),934,json);
            String actual = gson.fromJson(json, String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1067,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1064,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1065,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringsWithRawChineseCharactersDeserialization_literalMutation1586() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringsWithRawChineseCharactersDeserialization_literalMutation1586");
            String expected = "好*好好";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1066,expected);
            String json = ("\"" + expected) + "\"";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),934,json);
            String actual = gson.fromJson(json, String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1067,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1064,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1065,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringsWithRawChineseCharactersDeserialization_literalMutation1587() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringsWithRawChineseCharactersDeserialization_literalMutation1587");
            String expected = "好好";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1066,expected);
            String json = ("\"" + expected) + "\"";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),934,json);
            String actual = gson.fromJson(json, String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1067,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1064,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1065,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringsWithUnicodeChineseCharactersSerialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringsWithUnicodeChineseCharactersSerialization");
            String target = "Z好好";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1075,target);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,json);
            String expected = "\"好好好\"";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1076,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1073,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1074,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringsWithUnicodeChineseCharactersSerialization_literalMutation1595() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringsWithUnicodeChineseCharactersSerialization_literalMutation1595");
            String target = "好5好好";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1075,target);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,json);
            String expected = "\"好好好\"";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1076,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1073,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1074,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringsWithUnicodeChineseCharactersSerialization_literalMutation1596() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringsWithUnicodeChineseCharactersSerialization_literalMutation1596");
            String target = "好好";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1075,target);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,json);
            String expected = "\"好好好\"";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1076,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1073,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1074,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringsWithUnicodeChineseCharactersSerialization_literalMutation1597() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringsWithUnicodeChineseCharactersSerialization_literalMutation1597");
            String target = "好好好";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1075,target);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,json);
            String expected = "\"好\\好\"";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1076,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1073,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1074,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringsWithUnicodeChineseCharactersSerialization_literalMutation1598() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringsWithUnicodeChineseCharactersSerialization_literalMutation1598");
            String target = "好好好";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1075,target);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,json);
            String expected = "\"好好\r好\"";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1076,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1073,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1074,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringsWithUnicodeChineseCharactersSerialization_literalMutation1599() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringsWithUnicodeChineseCharactersSerialization_literalMutation1599");
            String target = "好好好";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1075,target);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,json);
            String expected = "\"好好\"";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1076,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1073,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1074,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringsWithUnicodeChineseCharactersDeserialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringsWithUnicodeChineseCharactersDeserialization");
            String expected = "u好好";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1070,expected);
            String json = ("\"" + expected) + "\"";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
            String actual = gson.fromJson(json, String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),297,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1068,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1069,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringsWithUnicodeChineseCharactersDeserialization_literalMutation1589() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringsWithUnicodeChineseCharactersDeserialization_literalMutation1589");
            String expected = "好á好好";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1070,expected);
            String json = ("\"" + expected) + "\"";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
            String actual = gson.fromJson(json, String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),297,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1068,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1069,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringsWithUnicodeChineseCharactersDeserialization_literalMutation1590() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringsWithUnicodeChineseCharactersDeserialization_literalMutation1590");
            String expected = "好好";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1070,expected);
            String json = ("\"" + expected) + "\"";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
            String actual = gson.fromJson(json, String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),297,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1068,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1069,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringsWithUnicodeChineseCharactersEscapedDeserialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringsWithUnicodeChineseCharactersEscapedDeserialization");
            String actual = gson.fromJson("\'\\u597d\\u57d\\u597d\'", String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1072,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1071,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringsWithUnicodeChineseCharactersEscapedDeserialization_literalMutation1592() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringsWithUnicodeChineseCharactersEscapedDeserialization_literalMutation1592");
            String actual = gson.fromJson("\'\\uÊ597d\\u597d\\u597d\'", String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1072,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1071,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringsWithUnicodeChineseCharactersEscapedDeserialization_literalMutation1593() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringsWithUnicodeChineseCharactersEscapedDeserialization_literalMutation1593");
            String actual = gson.fromJson("\'\\u597d\\u597d\\u97d\'", String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1072,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1071,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }
}

