package com.google.gson.functional;

import com.google.gson.Gson;
import com.google.gson.JsonArray;
import com.google.gson.JsonObject;
import com.google.gson.JsonParseException;
import com.google.gson.JsonParser;
import com.google.gson.JsonSyntaxException;
import java.util.List;
import java.util.Map;
import java.io.StringReader;
import org.junit.Test;
import junit.framework.TestCase;
import com.google.gson.common.TestTypes;
import java.lang.reflect.Type;
import com.google.gson.reflect.TypeToken;

/** 
 * Functional tests for that use JsonParser and related Gson methods
 * 
 * @author Inderjeet Singh
 * @author Joel Leitch
 */
public class JsonParserTest extends TestCase {
    private Gson gson;

    @Override
    protected void setUp() throws Exception {
        super.setUp();
        gson = new Gson();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1137,gson);
    }

    @Test(timeout = 1000)
    public void testParseInvalidJson_add241() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testParseInvalidJson_add241");
            try {
                gson.fromJson("[[]", java.lang.Object[].class);
                gson.fromJson("[[]", java.lang.Object[].class);
            } catch (JsonSyntaxException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testParseInvalidJson() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testParseInvalidJson");
            try {
                gson.fromJson("[]", java.lang.Object[].class);
            } catch (JsonSyntaxException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testParseInvalidJson_literalMutation1771() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testParseInvalidJson_literalMutation1771");
            try {
                gson.fromJson("[&[]", java.lang.Object[].class);
            } catch (JsonSyntaxException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testParseInvalidJson_literalMutation1772() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testParseInvalidJson_literalMutation1772");
            try {
                gson.fromJson("[]", java.lang.Object[].class);
            } catch (JsonSyntaxException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDeserializingCustomTree_add236() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeserializingCustomTree_add236");
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1151,obj);
            obj.addProperty("stringValue", "foo");
            obj.addProperty("stringValue", "foo");
            obj.addProperty("intValue", 11);
            TestTypes.BagOfPrimitives target = gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1152,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1149,target.intValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1150,target.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDeserializingCustomTree_add237() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeserializingCustomTree_add237");
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1151,obj);
            obj.addProperty("stringValue", "foo");
            obj.addProperty("intValue", 11);
            obj.addProperty("intValue", 11);
            TestTypes.BagOfPrimitives target = gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1152,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1149,target.intValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1150,target.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDeserializingCustomTree() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeserializingCustomTree");
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1151,obj);
            obj.addProperty("striÀgValue", "foo");
            obj.addProperty("intValue", 11);
            TestTypes.BagOfPrimitives target = gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1152,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1149,target.intValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1150,target.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDeserializingCustomTree_literalMutation1754() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeserializingCustomTree_literalMutation1754");
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1151,obj);
            obj.addProperty("stringValue", "foo");
            obj.addProperty("intValue", 11);
            TestTypes.BagOfPrimitives target = gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1152,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1149,target.intValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1150,target.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDeserializingCustomTree_literalMutation1755() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeserializingCustomTree_literalMutation1755");
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1151,obj);
            obj.addProperty("stringVaue", "foo");
            obj.addProperty("intValue", 11);
            TestTypes.BagOfPrimitives target = gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1152,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1149,target.intValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1150,target.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDeserializingCustomTree_literalMutation1756() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeserializingCustomTree_literalMutation1756");
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1151,obj);
            obj.addProperty("stringValue", "æoo");
            obj.addProperty("intValue", 11);
            TestTypes.BagOfPrimitives target = gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1152,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1149,target.intValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1150,target.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDeserializingCustomTree_literalMutation1757() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeserializingCustomTree_literalMutation1757");
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1151,obj);
            obj.addProperty("stringValue", "foo");
            obj.addProperty("intValue", 11);
            TestTypes.BagOfPrimitives target = gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1152,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1149,target.intValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1150,target.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDeserializingCustomTree_literalMutation1758() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeserializingCustomTree_literalMutation1758");
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1151,obj);
            obj.addProperty("stringValue", "fo");
            obj.addProperty("intValue", 11);
            TestTypes.BagOfPrimitives target = gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1152,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1149,target.intValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1150,target.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDeserializingCustomTree_literalMutation1759() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeserializingCustomTree_literalMutation1759");
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1151,obj);
            obj.addProperty("stringValue", "foo");
            obj.addProperty("intVa(ue", 11);
            TestTypes.BagOfPrimitives target = gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1152,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1149,target.intValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1150,target.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDeserializingCustomTree_literalMutation1760() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeserializingCustomTree_literalMutation1760");
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1151,obj);
            obj.addProperty("stringValue", "foo");
            obj.addProperty("intVatlue", 11);
            TestTypes.BagOfPrimitives target = gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1152,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1149,target.intValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1150,target.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDeserializingCustomTree_literalMutation1761() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeserializingCustomTree_literalMutation1761");
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1151,obj);
            obj.addProperty("stringValue", "foo");
            obj.addProperty("intalue", 11);
            TestTypes.BagOfPrimitives target = gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1152,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1149,target.intValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1150,target.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDeserializingCustomTree_literalMutation1762() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeserializingCustomTree_literalMutation1762");
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1151,obj);
            obj.addProperty("stringValue", "foo");
            obj.addProperty("intValue", 10);
            TestTypes.BagOfPrimitives target = gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1152,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1149,target.intValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1150,target.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDeserializingCustomTree_literalMutation1763() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeserializingCustomTree_literalMutation1763");
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1151,obj);
            obj.addProperty("stringValue", "foo");
            obj.addProperty("intValue", 5);
            TestTypes.BagOfPrimitives target = gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1152,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1149,target.intValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1150,target.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDeserializingCustomTree_literalMutation1764() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeserializingCustomTree_literalMutation1764");
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1151,obj);
            obj.addProperty("stringValue", "foo");
            obj.addProperty("intValue", 22);
            TestTypes.BagOfPrimitives target = gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1152,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1149,target.intValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1150,target.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDeserializingCustomTree_literalMutation1765() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeserializingCustomTree_literalMutation1765");
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1151,obj);
            obj.addProperty("stringValue", "foo");
            obj.addProperty("intValue", 12);
            TestTypes.BagOfPrimitives target = gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1152,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1149,target.intValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1150,target.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDeserializingCustomTree_remove223() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeserializingCustomTree_remove223");
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1151,obj);
            obj.addProperty("intValue", 11);
            TestTypes.BagOfPrimitives target = gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1152,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1149,target.intValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1150,target.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDeserializingCustomTree_remove224() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeserializingCustomTree_remove224");
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1151,obj);
            obj.addProperty("intValue", 11);
            TestTypes.BagOfPrimitives target = gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1152,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1149,target.intValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1150,target.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBadTypeForDeserializingCustomTree_add230() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadTypeForDeserializingCustomTree_add230");
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1142,obj);
            obj.addProperty("stringValue", "foo");
            obj.addProperty("stringValue", "foo");
            obj.addProperty("intValue", 11);
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1143,array);
            array.add(obj);
            try {
                gson.fromJson(array, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBadTypeForDeserializingCustomTree_add231() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadTypeForDeserializingCustomTree_add231");
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1142,obj);
            obj.addProperty("stringValue", "foo");
            obj.addProperty("intValue", 11);
            obj.addProperty("intValue", 11);
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1143,array);
            array.add(obj);
            try {
                gson.fromJson(array, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBadTypeForDeserializingCustomTree_add232() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadTypeForDeserializingCustomTree_add232");
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1142,obj);
            obj.addProperty("stringValue", "foo");
            obj.addProperty("intValue", 11);
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1143,array);
            array.add(obj);
            array.add(obj);
            try {
                gson.fromJson(array, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBadTypeForDeserializingCustomTree_add233() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadTypeForDeserializingCustomTree_add233");
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1142,obj);
            obj.addProperty("stringValue", "foo");
            obj.addProperty("intValue", 11);
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1143,array);
            array.add(obj);
            try {
                gson.fromJson(array, TestTypes.BagOfPrimitives.class);
                gson.fromJson(array, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadTypeForDeserializingCustomTree() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadTypeForDeserializingCustomTree");
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1142,obj);
            obj.addProperty("stringVaÀue", "foo");
            obj.addProperty("intValue", 11);
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1143,array);
            array.add(obj);
            try {
                gson.fromJson(array, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadTypeForDeserializingCustomTree_literalMutation1728() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadTypeForDeserializingCustomTree_literalMutation1728");
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1142,obj);
            obj.addProperty("str×ingValue", "foo");
            obj.addProperty("intValue", 11);
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1143,array);
            array.add(obj);
            try {
                gson.fromJson(array, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadTypeForDeserializingCustomTree_literalMutation1729() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadTypeForDeserializingCustomTree_literalMutation1729");
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1142,obj);
            obj.addProperty("stringVlue", "foo");
            obj.addProperty("intValue", 11);
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1143,array);
            array.add(obj);
            try {
                gson.fromJson(array, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadTypeForDeserializingCustomTree_literalMutation1730() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadTypeForDeserializingCustomTree_literalMutation1730");
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1142,obj);
            obj.addProperty("stringValue", "Ãoo");
            obj.addProperty("intValue", 11);
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1143,array);
            array.add(obj);
            try {
                gson.fromJson(array, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadTypeForDeserializingCustomTree_literalMutation1731() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadTypeForDeserializingCustomTree_literalMutation1731");
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1142,obj);
            obj.addProperty("stringValue", "fpoo");
            obj.addProperty("intValue", 11);
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1143,array);
            array.add(obj);
            try {
                gson.fromJson(array, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadTypeForDeserializingCustomTree_literalMutation1732() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadTypeForDeserializingCustomTree_literalMutation1732");
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1142,obj);
            obj.addProperty("stringValue", "fo");
            obj.addProperty("intValue", 11);
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1143,array);
            array.add(obj);
            try {
                gson.fromJson(array, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadTypeForDeserializingCustomTree_literalMutation1733() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadTypeForDeserializingCustomTree_literalMutation1733");
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1142,obj);
            obj.addProperty("stringValue", "foo");
            obj.addProperty("i+tValue", 11);
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1143,array);
            array.add(obj);
            try {
                gson.fromJson(array, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadTypeForDeserializingCustomTree_literalMutation1734() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadTypeForDeserializingCustomTree_literalMutation1734");
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1142,obj);
            obj.addProperty("stringValue", "foo");
            obj.addProperty("intVaflue", 11);
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1143,array);
            array.add(obj);
            try {
                gson.fromJson(array, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadTypeForDeserializingCustomTree_literalMutation1735() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadTypeForDeserializingCustomTree_literalMutation1735");
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1142,obj);
            obj.addProperty("stringValue", "foo");
            obj.addProperty("intVlue", 11);
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1143,array);
            array.add(obj);
            try {
                gson.fromJson(array, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadTypeForDeserializingCustomTree_literalMutation1736() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadTypeForDeserializingCustomTree_literalMutation1736");
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1142,obj);
            obj.addProperty("stringValue", "foo");
            obj.addProperty("intValue", 10);
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1143,array);
            array.add(obj);
            try {
                gson.fromJson(array, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadTypeForDeserializingCustomTree_literalMutation1737() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadTypeForDeserializingCustomTree_literalMutation1737");
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1142,obj);
            obj.addProperty("stringValue", "foo");
            obj.addProperty("intValue", 5);
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1143,array);
            array.add(obj);
            try {
                gson.fromJson(array, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadTypeForDeserializingCustomTree_literalMutation1738() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadTypeForDeserializingCustomTree_literalMutation1738");
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1142,obj);
            obj.addProperty("stringValue", "foo");
            obj.addProperty("intValue", 22);
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1143,array);
            array.add(obj);
            try {
                gson.fromJson(array, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadTypeForDeserializingCustomTree_literalMutation1739() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadTypeForDeserializingCustomTree_literalMutation1739");
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1142,obj);
            obj.addProperty("stringValue", "foo");
            obj.addProperty("intValue", 12);
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1143,array);
            array.add(obj);
            try {
                gson.fromJson(array, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBadTypeForDeserializingCustomTree_remove218() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadTypeForDeserializingCustomTree_remove218");
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1142,obj);
            obj.addProperty("intValue", 11);
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1143,array);
            array.add(obj);
            try {
                gson.fromJson(array, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBadTypeForDeserializingCustomTree_remove219() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadTypeForDeserializingCustomTree_remove219");
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1142,obj);
            obj.addProperty("intValue", 11);
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1143,array);
            array.add(obj);
            try {
                gson.fromJson(array, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBadTypeForDeserializingCustomTree_remove220() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadTypeForDeserializingCustomTree_remove220");
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1142,obj);
            obj.addProperty("stringValue", "foo");
            obj.addProperty("intValue", 11);
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1143,array);
            try {
                gson.fromJson(array, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBadFieldTypeForCustomDeserializerCustomTree_add219() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForCustomDeserializerCustomTree_add219");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1138,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),929,obj);
            obj.addProperty("stringValue", "foo");
            obj.addProperty("intValue", 11);
            obj.add("longValue", array);
            try {
                gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBadFieldTypeForCustomDeserializerCustomTree_add220() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForCustomDeserializerCustomTree_add220");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1138,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),929,obj);
            obj.addProperty("stringValue", "foo");
            obj.addProperty("stringValue", "foo");
            obj.addProperty("intValue", 11);
            obj.add("longValue", array);
            try {
                gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBadFieldTypeForCustomDeserializerCustomTree_add221() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForCustomDeserializerCustomTree_add221");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1138,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),929,obj);
            obj.addProperty("stringValue", "foo");
            obj.addProperty("intValue", 11);
            obj.addProperty("intValue", 11);
            obj.add("longValue", array);
            try {
                gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBadFieldTypeForCustomDeserializerCustomTree_add222() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForCustomDeserializerCustomTree_add222");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1138,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),929,obj);
            obj.addProperty("stringValue", "foo");
            obj.addProperty("intValue", 11);
            obj.add("longValue", array);
            obj.add("longValue", array);
            try {
                gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBadFieldTypeForCustomDeserializerCustomTree_add223() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForCustomDeserializerCustomTree_add223");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1138,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),929,obj);
            obj.addProperty("stringValue", "foo");
            obj.addProperty("intValue", 11);
            obj.add("longValue", array);
            try {
                gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
                gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadFieldTypeForCustomDeserializerCustomTree() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForCustomDeserializerCustomTree");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1138,array);
            array.add(new com.google.gson.JsonPrimitive("âlah"));
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),929,obj);
            obj.addProperty("stringValue", "foo");
            obj.addProperty("intValue", 11);
            obj.add("longValue", array);
            try {
                gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadFieldTypeForCustomDeserializerCustomTree_literalMutation1685() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForCustomDeserializerCustomTree_literalMutation1685");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1138,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),929,obj);
            obj.addProperty("stringValue", "foo");
            obj.addProperty("intValue", 11);
            obj.add("longValue", array);
            try {
                gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadFieldTypeForCustomDeserializerCustomTree_literalMutation1686() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForCustomDeserializerCustomTree_literalMutation1686");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1138,array);
            array.add(new com.google.gson.JsonPrimitive("blh"));
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),929,obj);
            obj.addProperty("stringValue", "foo");
            obj.addProperty("intValue", 11);
            obj.add("longValue", array);
            try {
                gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadFieldTypeForCustomDeserializerCustomTree_literalMutation1687() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForCustomDeserializerCustomTree_literalMutation1687");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1138,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),929,obj);
            obj.addProperty("tringValue", "foo");
            obj.addProperty("intValue", 11);
            obj.add("longValue", array);
            try {
                gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadFieldTypeForCustomDeserializerCustomTree_literalMutation1688() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForCustomDeserializerCustomTree_literalMutation1688");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1138,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),929,obj);
            obj.addProperty("stringÝValue", "foo");
            obj.addProperty("intValue", 11);
            obj.add("longValue", array);
            try {
                gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadFieldTypeForCustomDeserializerCustomTree_literalMutation1689() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForCustomDeserializerCustomTree_literalMutation1689");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1138,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),929,obj);
            obj.addProperty("stringalue", "foo");
            obj.addProperty("intValue", 11);
            obj.add("longValue", array);
            try {
                gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadFieldTypeForCustomDeserializerCustomTree_literalMutation1690() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForCustomDeserializerCustomTree_literalMutation1690");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1138,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),929,obj);
            obj.addProperty("stringValue", "²oo");
            obj.addProperty("intValue", 11);
            obj.add("longValue", array);
            try {
                gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadFieldTypeForCustomDeserializerCustomTree_literalMutation1691() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForCustomDeserializerCustomTree_literalMutation1691");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1138,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),929,obj);
            obj.addProperty("stringValue", "föoo");
            obj.addProperty("intValue", 11);
            obj.add("longValue", array);
            try {
                gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadFieldTypeForCustomDeserializerCustomTree_literalMutation1692() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForCustomDeserializerCustomTree_literalMutation1692");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1138,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),929,obj);
            obj.addProperty("stringValue", "fo");
            obj.addProperty("intValue", 11);
            obj.add("longValue", array);
            try {
                gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadFieldTypeForCustomDeserializerCustomTree_literalMutation1693() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForCustomDeserializerCustomTree_literalMutation1693");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1138,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),929,obj);
            obj.addProperty("stringValue", "foo");
            obj.addProperty("intVaue", 11);
            obj.add("longValue", array);
            try {
                gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadFieldTypeForCustomDeserializerCustomTree_literalMutation1694() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForCustomDeserializerCustomTree_literalMutation1694");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1138,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),929,obj);
            obj.addProperty("stringValue", "foo");
            obj.addProperty("intValue", 11);
            obj.add("longValue", array);
            try {
                gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadFieldTypeForCustomDeserializerCustomTree_literalMutation1695() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForCustomDeserializerCustomTree_literalMutation1695");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1138,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),929,obj);
            obj.addProperty("stringValue", "foo");
            obj.addProperty("intVale", 11);
            obj.add("longValue", array);
            try {
                gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadFieldTypeForCustomDeserializerCustomTree_literalMutation1696() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForCustomDeserializerCustomTree_literalMutation1696");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1138,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),929,obj);
            obj.addProperty("stringValue", "foo");
            obj.addProperty("intValue", 10);
            obj.add("longValue", array);
            try {
                gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadFieldTypeForCustomDeserializerCustomTree_literalMutation1697() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForCustomDeserializerCustomTree_literalMutation1697");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1138,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),929,obj);
            obj.addProperty("stringValue", "foo");
            obj.addProperty("intValue", 5);
            obj.add("longValue", array);
            try {
                gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadFieldTypeForCustomDeserializerCustomTree_literalMutation1698() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForCustomDeserializerCustomTree_literalMutation1698");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1138,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),929,obj);
            obj.addProperty("stringValue", "foo");
            obj.addProperty("intValue", 22);
            obj.add("longValue", array);
            try {
                gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadFieldTypeForCustomDeserializerCustomTree_literalMutation1699() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForCustomDeserializerCustomTree_literalMutation1699");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1138,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),929,obj);
            obj.addProperty("stringValue", "foo");
            obj.addProperty("intValue", 12);
            obj.add("longValue", array);
            try {
                gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadFieldTypeForCustomDeserializerCustomTree_literalMutation1701() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForCustomDeserializerCustomTree_literalMutation1701");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1138,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),929,obj);
            obj.addProperty("stringValue", "foo");
            obj.addProperty("intValue", 11);
            obj.add("ZongValue", array);
            try {
                gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadFieldTypeForCustomDeserializerCustomTree_literalMutation1702() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForCustomDeserializerCustomTree_literalMutation1702");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1138,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),929,obj);
            obj.addProperty("stringValue", "foo");
            obj.addProperty("intValue", 11);
            obj.add("longV8alue", array);
            try {
                gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadFieldTypeForCustomDeserializerCustomTree_literalMutation1703() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForCustomDeserializerCustomTree_literalMutation1703");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1138,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),929,obj);
            obj.addProperty("stringValue", "foo");
            obj.addProperty("intValue", 11);
            obj.add("longVale", array);
            try {
                gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBadFieldTypeForCustomDeserializerCustomTree_remove209() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForCustomDeserializerCustomTree_remove209");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1138,array);
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),929,obj);
            obj.addProperty("stringValue", "foo");
            obj.addProperty("intValue", 11);
            obj.add("longValue", array);
            try {
                gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBadFieldTypeForCustomDeserializerCustomTree_remove210() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForCustomDeserializerCustomTree_remove210");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1138,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),929,obj);
            obj.addProperty("intValue", 11);
            obj.add("longValue", array);
            try {
                gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBadFieldTypeForCustomDeserializerCustomTree_remove211() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForCustomDeserializerCustomTree_remove211");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1138,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),929,obj);
            obj.addProperty("intValue", 11);
            obj.add("longValue", array);
            try {
                gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBadFieldTypeForCustomDeserializerCustomTree_remove212() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForCustomDeserializerCustomTree_remove212");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1138,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),929,obj);
            obj.addProperty("stringValue", "foo");
            obj.addProperty("intValue", 11);
            try {
                gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBadFieldTypeForDeserializingCustomTree_add224() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForDeserializingCustomTree_add224");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1139,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject primitive1 = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1140,primitive1);
            primitive1.addProperty("string", "foo");
            primitive1.addProperty("intValue", 11);
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1141,obj);
            obj.add("primitive1", primitive1);
            obj.add("primitive2", array);
            try {
                gson.fromJson(obj, TestTypes.Nested.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBadFieldTypeForDeserializingCustomTree_add225() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForDeserializingCustomTree_add225");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1139,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject primitive1 = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1140,primitive1);
            primitive1.addProperty("string", "foo");
            primitive1.addProperty("string", "foo");
            primitive1.addProperty("intValue", 11);
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1141,obj);
            obj.add("primitive1", primitive1);
            obj.add("primitive2", array);
            try {
                gson.fromJson(obj, TestTypes.Nested.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBadFieldTypeForDeserializingCustomTree_add226() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForDeserializingCustomTree_add226");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1139,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject primitive1 = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1140,primitive1);
            primitive1.addProperty("string", "foo");
            primitive1.addProperty("intValue", 11);
            primitive1.addProperty("intValue", 11);
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1141,obj);
            obj.add("primitive1", primitive1);
            obj.add("primitive2", array);
            try {
                gson.fromJson(obj, TestTypes.Nested.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBadFieldTypeForDeserializingCustomTree_add227() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForDeserializingCustomTree_add227");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1139,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject primitive1 = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1140,primitive1);
            primitive1.addProperty("string", "foo");
            primitive1.addProperty("intValue", 11);
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1141,obj);
            obj.add("primitive1", primitive1);
            obj.add("primitive1", primitive1);
            obj.add("primitive2", array);
            try {
                gson.fromJson(obj, TestTypes.Nested.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBadFieldTypeForDeserializingCustomTree_add228() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForDeserializingCustomTree_add228");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1139,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject primitive1 = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1140,primitive1);
            primitive1.addProperty("string", "foo");
            primitive1.addProperty("intValue", 11);
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1141,obj);
            obj.add("primitive1", primitive1);
            obj.add("primitive2", array);
            obj.add("primitive2", array);
            try {
                gson.fromJson(obj, TestTypes.Nested.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBadFieldTypeForDeserializingCustomTree_add229() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForDeserializingCustomTree_add229");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1139,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject primitive1 = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1140,primitive1);
            primitive1.addProperty("string", "foo");
            primitive1.addProperty("intValue", 11);
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1141,obj);
            obj.add("primitive1", primitive1);
            obj.add("primitive2", array);
            try {
                gson.fromJson(obj, TestTypes.Nested.class);
                gson.fromJson(obj, TestTypes.Nested.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadFieldTypeForDeserializingCustomTree() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForDeserializingCustomTree");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1139,array);
            array.add(new com.google.gson.JsonPrimitive("bCah"));
            JsonObject primitive1 = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1140,primitive1);
            primitive1.addProperty("string", "foo");
            primitive1.addProperty("intValue", 11);
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1141,obj);
            obj.add("primitive1", primitive1);
            obj.add("primitive2", array);
            try {
                gson.fromJson(obj, TestTypes.Nested.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadFieldTypeForDeserializingCustomTree_literalMutation1705() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForDeserializingCustomTree_literalMutation1705");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1139,array);
            array.add(new com.google.gson.JsonPrimitive("b.lah"));
            JsonObject primitive1 = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1140,primitive1);
            primitive1.addProperty("string", "foo");
            primitive1.addProperty("intValue", 11);
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1141,obj);
            obj.add("primitive1", primitive1);
            obj.add("primitive2", array);
            try {
                gson.fromJson(obj, TestTypes.Nested.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadFieldTypeForDeserializingCustomTree_literalMutation1706() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForDeserializingCustomTree_literalMutation1706");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1139,array);
            array.add(new com.google.gson.JsonPrimitive("bah"));
            JsonObject primitive1 = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1140,primitive1);
            primitive1.addProperty("string", "foo");
            primitive1.addProperty("intValue", 11);
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1141,obj);
            obj.add("primitive1", primitive1);
            obj.add("primitive2", array);
            try {
                gson.fromJson(obj, TestTypes.Nested.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadFieldTypeForDeserializingCustomTree_literalMutation1707() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForDeserializingCustomTree_literalMutation1707");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1139,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject primitive1 = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1140,primitive1);
            primitive1.addProperty("tring", "foo");
            primitive1.addProperty("intValue", 11);
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1141,obj);
            obj.add("primitive1", primitive1);
            obj.add("primitive2", array);
            try {
                gson.fromJson(obj, TestTypes.Nested.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadFieldTypeForDeserializingCustomTree_literalMutation1708() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForDeserializingCustomTree_literalMutation1708");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1139,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject primitive1 = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1140,primitive1);
            primitive1.addProperty("string", "foo");
            primitive1.addProperty("intValue", 11);
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1141,obj);
            obj.add("primitive1", primitive1);
            obj.add("primitive2", array);
            try {
                gson.fromJson(obj, TestTypes.Nested.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadFieldTypeForDeserializingCustomTree_literalMutation1709() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForDeserializingCustomTree_literalMutation1709");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1139,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject primitive1 = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1140,primitive1);
            primitive1.addProperty("strng", "foo");
            primitive1.addProperty("intValue", 11);
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1141,obj);
            obj.add("primitive1", primitive1);
            obj.add("primitive2", array);
            try {
                gson.fromJson(obj, TestTypes.Nested.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadFieldTypeForDeserializingCustomTree_literalMutation1710() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForDeserializingCustomTree_literalMutation1710");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1139,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject primitive1 = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1140,primitive1);
            primitive1.addProperty("string", "ìoo");
            primitive1.addProperty("intValue", 11);
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1141,obj);
            obj.add("primitive1", primitive1);
            obj.add("primitive2", array);
            try {
                gson.fromJson(obj, TestTypes.Nested.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadFieldTypeForDeserializingCustomTree_literalMutation1711() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForDeserializingCustomTree_literalMutation1711");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1139,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject primitive1 = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1140,primitive1);
            primitive1.addProperty("string", "fÝoo");
            primitive1.addProperty("intValue", 11);
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1141,obj);
            obj.add("primitive1", primitive1);
            obj.add("primitive2", array);
            try {
                gson.fromJson(obj, TestTypes.Nested.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadFieldTypeForDeserializingCustomTree_literalMutation1712() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForDeserializingCustomTree_literalMutation1712");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1139,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject primitive1 = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1140,primitive1);
            primitive1.addProperty("string", "fo");
            primitive1.addProperty("intValue", 11);
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1141,obj);
            obj.add("primitive1", primitive1);
            obj.add("primitive2", array);
            try {
                gson.fromJson(obj, TestTypes.Nested.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadFieldTypeForDeserializingCustomTree_literalMutation1713() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForDeserializingCustomTree_literalMutation1713");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1139,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject primitive1 = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1140,primitive1);
            primitive1.addProperty("string", "foo");
            primitive1.addProperty("intVklue", 11);
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1141,obj);
            obj.add("primitive1", primitive1);
            obj.add("primitive2", array);
            try {
                gson.fromJson(obj, TestTypes.Nested.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadFieldTypeForDeserializingCustomTree_literalMutation1714() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForDeserializingCustomTree_literalMutation1714");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1139,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject primitive1 = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1140,primitive1);
            primitive1.addProperty("string", "foo");
            primitive1.addProperty("intyValue", 11);
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1141,obj);
            obj.add("primitive1", primitive1);
            obj.add("primitive2", array);
            try {
                gson.fromJson(obj, TestTypes.Nested.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadFieldTypeForDeserializingCustomTree_literalMutation1715() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForDeserializingCustomTree_literalMutation1715");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1139,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject primitive1 = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1140,primitive1);
            primitive1.addProperty("string", "foo");
            primitive1.addProperty("intalue", 11);
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1141,obj);
            obj.add("primitive1", primitive1);
            obj.add("primitive2", array);
            try {
                gson.fromJson(obj, TestTypes.Nested.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadFieldTypeForDeserializingCustomTree_literalMutation1716() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForDeserializingCustomTree_literalMutation1716");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1139,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject primitive1 = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1140,primitive1);
            primitive1.addProperty("string", "foo");
            primitive1.addProperty("intValue", 10);
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1141,obj);
            obj.add("primitive1", primitive1);
            obj.add("primitive2", array);
            try {
                gson.fromJson(obj, TestTypes.Nested.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadFieldTypeForDeserializingCustomTree_literalMutation1717() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForDeserializingCustomTree_literalMutation1717");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1139,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject primitive1 = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1140,primitive1);
            primitive1.addProperty("string", "foo");
            primitive1.addProperty("intValue", 5);
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1141,obj);
            obj.add("primitive1", primitive1);
            obj.add("primitive2", array);
            try {
                gson.fromJson(obj, TestTypes.Nested.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadFieldTypeForDeserializingCustomTree_literalMutation1718() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForDeserializingCustomTree_literalMutation1718");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1139,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject primitive1 = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1140,primitive1);
            primitive1.addProperty("string", "foo");
            primitive1.addProperty("intValue", 22);
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1141,obj);
            obj.add("primitive1", primitive1);
            obj.add("primitive2", array);
            try {
                gson.fromJson(obj, TestTypes.Nested.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadFieldTypeForDeserializingCustomTree_literalMutation1719() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForDeserializingCustomTree_literalMutation1719");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1139,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject primitive1 = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1140,primitive1);
            primitive1.addProperty("string", "foo");
            primitive1.addProperty("intValue", 12);
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1141,obj);
            obj.add("primitive1", primitive1);
            obj.add("primitive2", array);
            try {
                gson.fromJson(obj, TestTypes.Nested.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadFieldTypeForDeserializingCustomTree_literalMutation1721() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForDeserializingCustomTree_literalMutation1721");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1139,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject primitive1 = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1140,primitive1);
            primitive1.addProperty("string", "foo");
            primitive1.addProperty("intValue", 11);
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1141,obj);
            obj.add("priíitive1", primitive1);
            obj.add("primitive2", array);
            try {
                gson.fromJson(obj, TestTypes.Nested.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadFieldTypeForDeserializingCustomTree_literalMutation1722() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForDeserializingCustomTree_literalMutation1722");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1139,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject primitive1 = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1140,primitive1);
            primitive1.addProperty("string", "foo");
            primitive1.addProperty("intValue", 11);
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1141,obj);
            obj.add("primi}tive1", primitive1);
            obj.add("primitive2", array);
            try {
                gson.fromJson(obj, TestTypes.Nested.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadFieldTypeForDeserializingCustomTree_literalMutation1723() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForDeserializingCustomTree_literalMutation1723");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1139,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject primitive1 = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1140,primitive1);
            primitive1.addProperty("string", "foo");
            primitive1.addProperty("intValue", 11);
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1141,obj);
            obj.add("primiive1", primitive1);
            obj.add("primitive2", array);
            try {
                gson.fromJson(obj, TestTypes.Nested.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadFieldTypeForDeserializingCustomTree_literalMutation1724() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForDeserializingCustomTree_literalMutation1724");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1139,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject primitive1 = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1140,primitive1);
            primitive1.addProperty("string", "foo");
            primitive1.addProperty("intValue", 11);
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1141,obj);
            obj.add("primitive1", primitive1);
            obj.add("primitie2", array);
            try {
                gson.fromJson(obj, TestTypes.Nested.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadFieldTypeForDeserializingCustomTree_literalMutation1725() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForDeserializingCustomTree_literalMutation1725");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1139,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject primitive1 = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1140,primitive1);
            primitive1.addProperty("string", "foo");
            primitive1.addProperty("intValue", 11);
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1141,obj);
            obj.add("primitive1", primitive1);
            obj.add("primitÈive2", array);
            try {
                gson.fromJson(obj, TestTypes.Nested.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadFieldTypeForDeserializingCustomTree_literalMutation1726() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForDeserializingCustomTree_literalMutation1726");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1139,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject primitive1 = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1140,primitive1);
            primitive1.addProperty("string", "foo");
            primitive1.addProperty("intValue", 11);
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1141,obj);
            obj.add("primitive1", primitive1);
            obj.add("primitiv2", array);
            try {
                gson.fromJson(obj, TestTypes.Nested.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBadFieldTypeForDeserializingCustomTree_remove213() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForDeserializingCustomTree_remove213");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1139,array);
            JsonObject primitive1 = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1140,primitive1);
            primitive1.addProperty("string", "foo");
            primitive1.addProperty("intValue", 11);
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1141,obj);
            obj.add("primitive1", primitive1);
            obj.add("primitive2", array);
            try {
                gson.fromJson(obj, TestTypes.Nested.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBadFieldTypeForDeserializingCustomTree_remove214() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForDeserializingCustomTree_remove214");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1139,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject primitive1 = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1140,primitive1);
            primitive1.addProperty("intValue", 11);
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1141,obj);
            obj.add("primitive1", primitive1);
            obj.add("primitive2", array);
            try {
                gson.fromJson(obj, TestTypes.Nested.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBadFieldTypeForDeserializingCustomTree_remove215() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForDeserializingCustomTree_remove215");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1139,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject primitive1 = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1140,primitive1);
            primitive1.addProperty("intValue", 11);
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1141,obj);
            obj.add("primitive1", primitive1);
            obj.add("primitive2", array);
            try {
                gson.fromJson(obj, TestTypes.Nested.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBadFieldTypeForDeserializingCustomTree_remove216() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForDeserializingCustomTree_remove216");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1139,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject primitive1 = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1140,primitive1);
            primitive1.addProperty("string", "foo");
            primitive1.addProperty("intValue", 11);
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1141,obj);
            obj.add("primitive2", array);
            try {
                gson.fromJson(obj, TestTypes.Nested.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBadFieldTypeForDeserializingCustomTree_remove217() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadFieldTypeForDeserializingCustomTree_remove217");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1139,array);
            array.add(new com.google.gson.JsonPrimitive("blah"));
            JsonObject primitive1 = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1140,primitive1);
            primitive1.addProperty("string", "foo");
            primitive1.addProperty("intValue", 11);
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1141,obj);
            obj.add("primitive2", array);
            try {
                gson.fromJson(obj, TestTypes.Nested.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testChangingCustomTreeAndDeserializing_add234() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testChangingCustomTreeAndDeserializing_add234");
            StringReader json = new StringReader("{\'stringValue\':\'no message\',\'intValue\':10,\'longValue\':20}");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,json);
            JsonObject obj = ((JsonObject)(new JsonParser().parse(json)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1147,obj);
            obj.remove("stringValue");
            obj.remove("stringValue");
            obj.addProperty("stringValue", "fooBar");
            TestTypes.BagOfPrimitives target = gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1148,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1144,target.intValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1145,target.longValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1146,target.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testChangingCustomTreeAndDeserializing_add235() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testChangingCustomTreeAndDeserializing_add235");
            StringReader json = new StringReader("{\'stringValue\':\'no message\',\'intValue\':10,\'longValue\':20}");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,json);
            JsonObject obj = ((JsonObject)(new JsonParser().parse(json)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1147,obj);
            obj.remove("stringValue");
            obj.addProperty("stringValue", "fooBar");
            obj.addProperty("stringValue", "fooBar");
            TestTypes.BagOfPrimitives target = gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1148,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1144,target.intValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1145,target.longValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1146,target.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testChangingCustomTreeAndDeserializing() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testChangingCustomTreeAndDeserializing");
            StringReader json = new StringReader("{\'stringValue\':\'no messag\\\',\'intValue\':10,\'longValue\':20}");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,json);
            JsonObject obj = ((JsonObject)(new JsonParser().parse(json)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1147,obj);
            obj.remove("stringValue");
            obj.addProperty("stringValue", "fooBar");
            TestTypes.BagOfPrimitives target = gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1148,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1144,target.intValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1145,target.longValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1146,target.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testChangingCustomTreeAndDeserializing_literalMutation1742() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testChangingCustomTreeAndDeserializing_literalMutation1742");
            StringReader json = new StringReader("{\'stringValue\':\'no message\',B\'intValue\':10,\'longValue\':20}");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,json);
            JsonObject obj = ((JsonObject)(new JsonParser().parse(json)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1147,obj);
            obj.remove("stringValue");
            obj.addProperty("stringValue", "fooBar");
            TestTypes.BagOfPrimitives target = gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1148,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1144,target.intValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1145,target.longValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1146,target.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testChangingCustomTreeAndDeserializing_literalMutation1743() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testChangingCustomTreeAndDeserializing_literalMutation1743");
            StringReader json = new StringReader("{\'stringValue\':\'o message\',\'intValue\':10,\'longValue\':20}");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,json);
            JsonObject obj = ((JsonObject)(new JsonParser().parse(json)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1147,obj);
            obj.remove("stringValue");
            obj.addProperty("stringValue", "fooBar");
            TestTypes.BagOfPrimitives target = gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1148,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1144,target.intValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1145,target.longValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1146,target.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testChangingCustomTreeAndDeserializing_literalMutation1744() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testChangingCustomTreeAndDeserializing_literalMutation1744");
            StringReader json = new StringReader("{\'stringValue\':\'no message\',\'intValue\':10,\'longValue\':20}");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,json);
            JsonObject obj = ((JsonObject)(new JsonParser().parse(json)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1147,obj);
            obj.remove("stringVaÀue");
            obj.addProperty("stringValue", "fooBar");
            TestTypes.BagOfPrimitives target = gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1148,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1144,target.intValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1145,target.longValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1146,target.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testChangingCustomTreeAndDeserializing_literalMutation1745() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testChangingCustomTreeAndDeserializing_literalMutation1745");
            StringReader json = new StringReader("{\'stringValue\':\'no message\',\'intValue\':10,\'longValue\':20}");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,json);
            JsonObject obj = ((JsonObject)(new JsonParser().parse(json)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1147,obj);
            obj.remove("sÈtringValue");
            obj.addProperty("stringValue", "fooBar");
            TestTypes.BagOfPrimitives target = gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1148,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1144,target.intValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1145,target.longValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1146,target.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testChangingCustomTreeAndDeserializing_literalMutation1746() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testChangingCustomTreeAndDeserializing_literalMutation1746");
            StringReader json = new StringReader("{\'stringValue\':\'no message\',\'intValue\':10,\'longValue\':20}");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,json);
            JsonObject obj = ((JsonObject)(new JsonParser().parse(json)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1147,obj);
            obj.remove("strngValue");
            obj.addProperty("stringValue", "fooBar");
            TestTypes.BagOfPrimitives target = gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1148,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1144,target.intValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1145,target.longValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1146,target.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testChangingCustomTreeAndDeserializing_literalMutation1747() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testChangingCustomTreeAndDeserializing_literalMutation1747");
            StringReader json = new StringReader("{\'stringValue\':\'no message\',\'intValue\':10,\'longValue\':20}");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,json);
            JsonObject obj = ((JsonObject)(new JsonParser().parse(json)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1147,obj);
            obj.remove("stringValue");
            obj.addProperty("sÀringValue", "fooBar");
            TestTypes.BagOfPrimitives target = gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1148,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1144,target.intValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1145,target.longValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1146,target.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testChangingCustomTreeAndDeserializing_literalMutation1748() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testChangingCustomTreeAndDeserializing_literalMutation1748");
            StringReader json = new StringReader("{\'stringValue\':\'no message\',\'intValue\':10,\'longValue\':20}");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,json);
            JsonObject obj = ((JsonObject)(new JsonParser().parse(json)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1147,obj);
            obj.remove("stringValue");
            obj.addProperty("stringValîue", "fooBar");
            TestTypes.BagOfPrimitives target = gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1148,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1144,target.intValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1145,target.longValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1146,target.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testChangingCustomTreeAndDeserializing_literalMutation1749() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testChangingCustomTreeAndDeserializing_literalMutation1749");
            StringReader json = new StringReader("{\'stringValue\':\'no message\',\'intValue\':10,\'longValue\':20}");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,json);
            JsonObject obj = ((JsonObject)(new JsonParser().parse(json)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1147,obj);
            obj.remove("stringValue");
            obj.addProperty("strigValue", "fooBar");
            TestTypes.BagOfPrimitives target = gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1148,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1144,target.intValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1145,target.longValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1146,target.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testChangingCustomTreeAndDeserializing_literalMutation1750() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testChangingCustomTreeAndDeserializing_literalMutation1750");
            StringReader json = new StringReader("{\'stringValue\':\'no message\',\'intValue\':10,\'longValue\':20}");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,json);
            JsonObject obj = ((JsonObject)(new JsonParser().parse(json)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1147,obj);
            obj.remove("stringValue");
            obj.addProperty("stringValue", "foBar");
            TestTypes.BagOfPrimitives target = gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1148,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1144,target.intValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1145,target.longValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1146,target.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testChangingCustomTreeAndDeserializing_literalMutation1751() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testChangingCustomTreeAndDeserializing_literalMutation1751");
            StringReader json = new StringReader("{\'stringValue\':\'no message\',\'intValue\':10,\'longValue\':20}");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,json);
            JsonObject obj = ((JsonObject)(new JsonParser().parse(json)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1147,obj);
            obj.remove("stringValue");
            obj.addProperty("stringValue", "fooBBar");
            TestTypes.BagOfPrimitives target = gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1148,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1144,target.intValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1145,target.longValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1146,target.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testChangingCustomTreeAndDeserializing_literalMutation1752() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testChangingCustomTreeAndDeserializing_literalMutation1752");
            StringReader json = new StringReader("{\'stringValue\':\'no message\',\'intValue\':10,\'longValue\':20}");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,json);
            JsonObject obj = ((JsonObject)(new JsonParser().parse(json)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1147,obj);
            obj.remove("stringValue");
            obj.addProperty("stringValue", "fooBr");
            TestTypes.BagOfPrimitives target = gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1148,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1144,target.intValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1145,target.longValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1146,target.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testChangingCustomTreeAndDeserializing_remove221() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testChangingCustomTreeAndDeserializing_remove221");
            StringReader json = new StringReader("{\'stringValue\':\'no message\',\'intValue\':10,\'longValue\':20}");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,json);
            JsonObject obj = ((JsonObject)(new JsonParser().parse(json)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1147,obj);
            obj.addProperty("stringValue", "fooBar");
            TestTypes.BagOfPrimitives target = gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1148,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1144,target.intValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1145,target.longValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1146,target.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testChangingCustomTreeAndDeserializing_remove222() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testChangingCustomTreeAndDeserializing_remove222");
            StringReader json = new StringReader("{\'stringValue\':\'no message\',\'intValue\':10,\'longValue\':20}");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,json);
            JsonObject obj = ((JsonObject)(new JsonParser().parse(json)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1147,obj);
            obj.remove("stringValue");
            TestTypes.BagOfPrimitives target = gson.fromJson(obj, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1148,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1144,target.intValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1145,target.longValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1146,target.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testExtraCommasInArrays() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExtraCommasInArrays");
            Type type = new TypeToken<java.util.List<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1159,type);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1153,list("a", null, "b", null, null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1154,gson.fromJson("[a,,b,,]", type));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1155,list(null, null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1156,gson.fromJson("[,]", type));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1157,list("a", null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1158,gson.fromJson("[a,]", type));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testExtraCommasInArrays_remove225() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExtraCommasInArrays_remove225");
            Type type = new TypeToken<java.util.List<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1159,type);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1153,list("a", null, "b", null, null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1154,gson.fromJson("[a,,b,,]", type));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1155,list(null, null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1156,gson.fromJson("[,]", type));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1157,list("a", null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1158,gson.fromJson("[a,]", type));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testExtraCommasInMaps_add239() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExtraCommasInMaps_add239");
            Type type = new TypeToken<java.util.Map<java.lang.String, java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1160,type);
            try {
                gson.fromJson("{a:b,}", type);
            } catch (JsonSyntaxException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testExtraCommasInMaps_add240() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExtraCommasInMaps_add240");
            Type type = new TypeToken<java.util.Map<java.lang.String, java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1160,type);
            try {
                gson.fromJson("{a:b,}", type);
                gson.fromJson("{a:b,}", type);
            } catch (JsonSyntaxException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExtraCommasInMaps() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExtraCommasInMaps");
            Type type = new TypeToken<java.util.Map<java.lang.String, java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1160,type);
            try {
                gson.fromJson("{ab,}", type);
            } catch (JsonSyntaxException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExtraCommasInMaps_literalMutation1768() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExtraCommasInMaps_literalMutation1768");
            Type type = new TypeToken<java.util.Map<java.lang.String, java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1160,type);
            try {
                gson.fromJson("{ar:b,}", type);
            } catch (JsonSyntaxException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExtraCommasInMaps_literalMutation1769() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExtraCommasInMaps_literalMutation1769");
            Type type = new TypeToken<java.util.Map<java.lang.String, java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1160,type);
            try {
                gson.fromJson("{ab,}", type);
            } catch (JsonSyntaxException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testExtraCommasInMaps_remove226() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExtraCommasInMaps_remove226");
            Type type = new TypeToken<java.util.Map<java.lang.String, java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1160,type);
            try {
                gson.fromJson("{a:b,}", type);
            } catch (JsonSyntaxException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    private <T>List<T> list(T... elements) {
        return java.util.Arrays.asList(elements);
    }
}

