package com.google.gson.functional;

import java.util.Collection;
import com.google.gson.Gson;
import com.google.gson.GsonBuilder;
import com.google.gson.JsonElement;
import com.google.gson.JsonObject;
import com.google.gson.JsonSerializationContext;
import com.google.gson.JsonSerializer;
import org.junit.Test;
import junit.framework.TestCase;
import com.google.gson.common.TestTypes;
import java.lang.reflect.Type;

/** 
 * Functional tests for the different cases for serializing (or ignoring) null fields and object.
 * 
 * @author Inderjeet Singh
 * @author Joel Leitch
 */
public class NullObjectAndFieldTest extends TestCase {
    private GsonBuilder gsonBuilder;

    @Override
    protected void setUp() throws Exception {
        super.setUp();
        gsonBuilder = new GsonBuilder().serializeNulls();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1485,gsonBuilder);
    }

    public void testTopLevelNullObjectSerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTopLevelNullObjectSerialization");
            Gson gson = gsonBuilder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1550,gson);
            String actual = gson.toJson(null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1551,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1547,actual);
            actual = gson.toJson(null, String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1549,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1548,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTopLevelNullObjectDeserialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTopLevelNullObjectDeserialization");
            Gson gson = gsonBuilder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1125,gson);
            String actual = gson.fromJson("nÓll", String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1546,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1545,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTopLevelNullObjectDeserialization_literalMutation2324() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTopLevelNullObjectDeserialization_literalMutation2324");
            Gson gson = gsonBuilder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1125,gson);
            String actual = gson.fromJson("nuìll", String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1546,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1545,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTopLevelNullObjectDeserialization_literalMutation2325() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTopLevelNullObjectDeserialization_literalMutation2325");
            Gson gson = gsonBuilder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1125,gson);
            String actual = gson.fromJson("nll", String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1546,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1545,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExplicitSerializationOfNulls() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExplicitSerializationOfNulls");
            Gson gson = gsonBuilder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1454,gson);
            TestTypes.ClassWithObjects target = new TestTypes.ClassWithObjects(null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),234,target);
            String actual = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1525,actual);
            String expected = "{\"Hag\":null}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1526,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1523,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1524,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExplicitSerializationOfNulls_literalMutation2318() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExplicitSerializationOfNulls_literalMutation2318");
            Gson gson = gsonBuilder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1454,gson);
            TestTypes.ClassWithObjects target = new TestTypes.ClassWithObjects(null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),234,target);
            String actual = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1525,actual);
            String expected = "{\"bag\":nulpl}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1526,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1523,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1524,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExplicitSerializationOfNulls_literalMutation2319() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExplicitSerializationOfNulls_literalMutation2319");
            Gson gson = gsonBuilder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1454,gson);
            TestTypes.ClassWithObjects target = new TestTypes.ClassWithObjects(null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),234,target);
            String actual = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1525,actual);
            String expected = "{\"bag\":nll}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1526,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1523,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1524,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExplicitDeserializationOfNulls() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExplicitDeserializationOfNulls");
            Gson gson = gsonBuilder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1049,gson);
            TestTypes.ClassWithObjects target = gson.fromJson("{\"bagG:null}", TestTypes.ClassWithObjects.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),243,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1510,target.bag);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExplicitDeserializationOfNulls_literalMutation2311() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExplicitDeserializationOfNulls_literalMutation2311");
            Gson gson = gsonBuilder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1049,gson);
            TestTypes.ClassWithObjects target = gson.fromJson("{*\"bag\":null}", TestTypes.ClassWithObjects.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),243,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1510,target.bag);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExplicitDeserializationOfNulls_literalMutation2312() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExplicitDeserializationOfNulls_literalMutation2312");
            Gson gson = gsonBuilder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1049,gson);
            TestTypes.ClassWithObjects target = gson.fromJson("{\"bg\":null}", TestTypes.ClassWithObjects.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),243,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1510,target.bag);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExplicitSerializationOfNullArrayMembers() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExplicitSerializationOfNullArrayMembers");
            Gson gson = gsonBuilder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1515,gson);
            ClassWithMembers target = new ClassWithMembers();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1516,target);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),414,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1514,json.contains("\"array\":null"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Added to verify http://code.google.com/p/google-gson/issues/detail?id=68
     */
public void testNullWrappedPrimitiveMemberSerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullWrappedPrimitiveMemberSerialization");
            Gson gson = gsonBuilder.serializeNulls().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1530,gson);
            ClassWithNullWrappedPrimitive target = new ClassWithNullWrappedPrimitive();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1416,target);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1531,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1529,json.contains("\"value\":null"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Added to verify http://code.google.com/p/google-gson/issues/detail?id=68
     */
public void testNullWrappedPrimitiveMemberDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullWrappedPrimitiveMemberDeserialization");
            Gson gson = gsonBuilder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),898,gson);
            String json = "{\'value\':nu\"l}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),344,json);
            ClassWithNullWrappedPrimitive target = gson.fromJson(json, ClassWithNullWrappedPrimitive.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1528,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1527,target.value);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Added to verify http://code.google.com/p/google-gson/issues/detail?id=68
     */
public void testNullWrappedPrimitiveMemberDeserialization_literalMutation2321() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullWrappedPrimitiveMemberDeserialization_literalMutation2321");
            Gson gson = gsonBuilder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),898,gson);
            String json = "{\'value\':Õnull}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),344,json);
            ClassWithNullWrappedPrimitive target = gson.fromJson(json, ClassWithNullWrappedPrimitive.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1528,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1527,target.value);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Added to verify http://code.google.com/p/google-gson/issues/detail?id=68
     */
public void testNullWrappedPrimitiveMemberDeserialization_literalMutation2322() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullWrappedPrimitiveMemberDeserialization_literalMutation2322");
            Gson gson = gsonBuilder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),898,gson);
            String json = "{value\':null}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),344,json);
            ClassWithNullWrappedPrimitive target = gson.fromJson(json, ClassWithNullWrappedPrimitive.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1528,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1527,target.value);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExplicitSerializationOfNullCollectionMembers() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExplicitSerializationOfNullCollectionMembers");
            Gson gson = gsonBuilder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1518,gson);
            ClassWithMembers target = new ClassWithMembers();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1519,target);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1189,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1517,json.contains("\"col\":null"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExplicitSerializationOfNullStringMembers() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExplicitSerializationOfNullStringMembers");
            Gson gson = gsonBuilder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1100,gson);
            ClassWithMembers target = new ClassWithMembers();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1521,target);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1522,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1520,json.contains("\"str\":null"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomSerializationOfNulls_add357() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomSerializationOfNulls_add357");
            gsonBuilder.registerTypeAdapter(TestTypes.ClassWithObjects.class, new ClassWithObjectsSerializer());
            gsonBuilder.registerTypeAdapter(TestTypes.ClassWithObjects.class, new ClassWithObjectsSerializer());
            Gson gson = gsonBuilder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,gson);
            TestTypes.ClassWithObjects target = new TestTypes.ClassWithObjects(new TestTypes.BagOfPrimitives());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1500,target);
            String actual = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1501,actual);
            String expected = "{\"bag\":null}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1502,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1498,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1499,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomSerializationOfNulls() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomSerializationOfNulls");
            gsonBuilder.registerTypeAdapter(TestTypes.ClassWithObjects.class, new ClassWithObjectsSerializer());
            Gson gson = gsonBuilder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,gson);
            TestTypes.ClassWithObjects target = new TestTypes.ClassWithObjects(new TestTypes.BagOfPrimitives());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1500,target);
            String actual = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1501,actual);
            String expected = "{\"ag\":null}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1502,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1498,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1499,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomSerializationOfNulls_literalMutation2300() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomSerializationOfNulls_literalMutation2300");
            gsonBuilder.registerTypeAdapter(TestTypes.ClassWithObjects.class, new ClassWithObjectsSerializer());
            Gson gson = gsonBuilder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,gson);
            TestTypes.ClassWithObjects target = new TestTypes.ClassWithObjects(new TestTypes.BagOfPrimitives());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1500,target);
            String actual = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1501,actual);
            String expected = "{\"bag\":nuäll}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1502,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1498,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1499,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomSerializationOfNulls_literalMutation2301() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomSerializationOfNulls_literalMutation2301");
            gsonBuilder.registerTypeAdapter(TestTypes.ClassWithObjects.class, new ClassWithObjectsSerializer());
            Gson gson = gsonBuilder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,gson);
            TestTypes.ClassWithObjects target = new TestTypes.ClassWithObjects(new TestTypes.BagOfPrimitives());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1500,target);
            String actual = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1501,actual);
            String expected = "{\"bag\":nul}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1502,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1498,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1499,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomSerializationOfNulls_remove333() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomSerializationOfNulls_remove333");
            Gson gson = gsonBuilder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,gson);
            TestTypes.ClassWithObjects target = new TestTypes.ClassWithObjects(new TestTypes.BagOfPrimitives());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1500,target);
            String actual = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1501,actual);
            String expected = "{\"bag\":null}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1502,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1498,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1499,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testPrintPrintingObjectWithNulls() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPrintPrintingObjectWithNulls");
            gsonBuilder = new GsonBuilder();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1540,gsonBuilder);
            Gson gson = gsonBuilder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1543,gson);
            String result = gson.toJson(new ClassWithMembers());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1544,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1538,result);
            gson = gsonBuilder.serializeNulls().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1541,gson);
            result = gson.toJson(new ClassWithMembers());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1542,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1539,result.contains("\"str\":null"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testPrintPrintingArraysWithNulls() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPrintPrintingArraysWithNulls");
            gsonBuilder = new GsonBuilder();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1534,gsonBuilder);
            Gson gson = gsonBuilder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),856,gson);
            String result = gson.toJson(new String[]{ "1" , null , "3" });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1537,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1532,result);
            gson = gsonBuilder.serializeNulls().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1535,gson);
            result = gson.toJson(new String[]{ "1" , null , "3" });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1536,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1533,result);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testAbsentJsonElementsAreSetToNull() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testAbsentJsonElementsAreSetToNull");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1496,gson);
            ClassWithInitializedMembers target = gson.fromJson("{arr&y:[1,2,3]}", ClassWithInitializedMembers.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1497,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1486,(((target.array.length) == 3) && ((target.array[1]) == 2)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1487,com.google.gson.functional.NullObjectAndFieldTest.ClassWithInitializedMembers.MY_STRING_DEFAULT);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1488,target.str1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1489,target.str2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1490,com.google.gson.functional.NullObjectAndFieldTest.ClassWithInitializedMembers.MY_INT_DEFAULT);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1491,target.int1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1492,target.int2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1493,com.google.gson.functional.NullObjectAndFieldTest.ClassWithInitializedMembers.MY_BOOLEAN_DEFAULT);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1494,target.bool1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1495,target.bool2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testAbsentJsonElementsAreSetToNull_literalMutation2297() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testAbsentJsonElementsAreSetToNull_literalMutation2297");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1496,gson);
            ClassWithInitializedMembers target = gson.fromJson("{array:º[1,2,3]}", ClassWithInitializedMembers.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1497,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1486,(((target.array.length) == 3) && ((target.array[1]) == 2)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1487,com.google.gson.functional.NullObjectAndFieldTest.ClassWithInitializedMembers.MY_STRING_DEFAULT);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1488,target.str1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1489,target.str2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1490,com.google.gson.functional.NullObjectAndFieldTest.ClassWithInitializedMembers.MY_INT_DEFAULT);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1491,target.int1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1492,target.int2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1493,com.google.gson.functional.NullObjectAndFieldTest.ClassWithInitializedMembers.MY_BOOLEAN_DEFAULT);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1494,target.bool1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1495,target.bool2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testAbsentJsonElementsAreSetToNull_literalMutation2298() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testAbsentJsonElementsAreSetToNull_literalMutation2298");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1496,gson);
            ClassWithInitializedMembers target = gson.fromJson("{array:[1,2,]}", ClassWithInitializedMembers.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1497,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1486,(((target.array.length) == 3) && ((target.array[1]) == 2)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1487,com.google.gson.functional.NullObjectAndFieldTest.ClassWithInitializedMembers.MY_STRING_DEFAULT);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1488,target.str1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1489,target.str2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1490,com.google.gson.functional.NullObjectAndFieldTest.ClassWithInitializedMembers.MY_INT_DEFAULT);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1491,target.int1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1492,target.int2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1493,com.google.gson.functional.NullObjectAndFieldTest.ClassWithInitializedMembers.MY_BOOLEAN_DEFAULT);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1494,target.bool1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1495,target.bool2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public static class ClassWithInitializedMembers {
        public static final String MY_STRING_DEFAULT = "string";

        private static final int MY_INT_DEFAULT = 2;

        private static final boolean MY_BOOLEAN_DEFAULT = true;

        int[] array;

        String str1;

        String str2;

        int int1 = MY_INT_DEFAULT;

        int int2;

        boolean bool1 = MY_BOOLEAN_DEFAULT;

        boolean bool2;

        public ClassWithInitializedMembers() {
            str1 = MY_STRING_DEFAULT;
        }
    }

    private static class ClassWithNullWrappedPrimitive {
        private Long value;
    }

    @SuppressWarnings(value = "unused")
    private static class ClassWithMembers {
        String str;

        int[] array;

        Collection<java.lang.String> col;
    }

    private static class ClassWithObjectsSerializer implements JsonSerializer<com.google.gson.common.TestTypes.ClassWithObjects> {
        public JsonElement serialize(TestTypes.ClassWithObjects src, Type typeOfSrc, JsonSerializationContext context) {
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1484,obj);
            obj.add("bag", com.google.gson.JsonNull.INSTANCE);
            return obj;
        }
    }

    public void testExplicitNullSetsFieldToNullDuringDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExplicitNullSetsFieldToNullDuringDeserialization");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1512,gson);
            String json = "{value:n>ll}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),121,json);
            ObjectWithField obj = gson.fromJson(json, ObjectWithField.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1513,obj);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1511,obj.value);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExplicitNullSetsFieldToNullDuringDeserialization_literalMutation2314() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExplicitNullSetsFieldToNullDuringDeserialization_literalMutation2314");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1512,gson);
            String json = "{value:null}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),121,json);
            ObjectWithField obj = gson.fromJson(json, ObjectWithField.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1513,obj);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1511,obj.value);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExplicitNullSetsFieldToNullDuringDeserialization_literalMutation2315() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExplicitNullSetsFieldToNullDuringDeserialization_literalMutation2315");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1512,gson);
            String json = "{valuenull}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),121,json);
            ObjectWithField obj = gson.fromJson(json, ObjectWithField.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1513,obj);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1511,obj.value);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomTypeAdapterPassesNullSerialization_add359() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomTypeAdapterPassesNullSerialization_add359");
            Gson gson = new GsonBuilder().registerTypeAdapter(ObjectWithField.class, new JsonSerializer<ObjectWithField>() {
                public JsonElement serialize(ObjectWithField src, Type typeOfSrc, JsonSerializationContext context) {
                    return context.serialize(null);
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1507,gson);
            ObjectWithField target = new ObjectWithField();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1508,target);
            target.value = "value1";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1506,target.value);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1509,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1505,json.contains("value1"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomTypeAdapterPassesNullSerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomTypeAdapterPassesNullSerialization");
            Gson gson = new GsonBuilder().registerTypeAdapter(ObjectWithField.class, new JsonSerializer<ObjectWithField>() {
                public JsonElement serialize(ObjectWithField src, Type typeOfSrc, JsonSerializationContext context) {
                    return context.serialize(null);
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1507,gson);
            ObjectWithField target = new ObjectWithField();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1508,target);
            target.value = "valÒe1";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1506,target.value);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1509,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1505,json.contains("value1"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomTypeAdapterPassesNullSerialization_literalMutation2308() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomTypeAdapterPassesNullSerialization_literalMutation2308");
            Gson gson = new GsonBuilder().registerTypeAdapter(ObjectWithField.class, new JsonSerializer<ObjectWithField>() {
                public JsonElement serialize(ObjectWithField src, Type typeOfSrc, JsonSerializationContext context) {
                    return context.serialize(null);
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1507,gson);
            ObjectWithField target = new ObjectWithField();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1508,target);
            target.value = "valuØe1";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1506,target.value);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1509,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1505,json.contains("value1"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomTypeAdapterPassesNullSerialization_literalMutation2309() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomTypeAdapterPassesNullSerialization_literalMutation2309");
            Gson gson = new GsonBuilder().registerTypeAdapter(ObjectWithField.class, new JsonSerializer<ObjectWithField>() {
                public JsonElement serialize(ObjectWithField src, Type typeOfSrc, JsonSerializationContext context) {
                    return context.serialize(null);
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1507,gson);
            ObjectWithField target = new ObjectWithField();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1508,target);
            target.value = "valu1";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1506,target.value);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1509,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1505,json.contains("value1"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomTypeAdapterPassesNullSerialization_remove335() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomTypeAdapterPassesNullSerialization_remove335");
            Gson gson = new GsonBuilder().registerTypeAdapter(ObjectWithField.class, new JsonSerializer<ObjectWithField>() {
                public JsonElement serialize(ObjectWithField src, Type typeOfSrc, JsonSerializationContext context) {
                    return context.serialize(null);
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1507,gson);
            ObjectWithField target = new ObjectWithField();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1508,target);
            target.value = "value1";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1506,target.value);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1509,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1505,json.contains("value1"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomTypeAdapterPassesNullDesrialization_add358() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomTypeAdapterPassesNullDesrialization_add358");
            Gson gson = new GsonBuilder().registerTypeAdapter(ObjectWithField.class, new com.google.gson.JsonDeserializer<ObjectWithField>() {
                public ObjectWithField deserialize(JsonElement json, Type type, com.google.gson.JsonDeserializationContext context) {
                    return context.deserialize(null, type);
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1504,gson);
            String json = "{value:\'value1\'}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),214,json);
            ObjectWithField target = gson.fromJson(json, ObjectWithField.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),215,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1503,target);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomTypeAdapterPassesNullDesrialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomTypeAdapterPassesNullDesrialization");
            Gson gson = new GsonBuilder().registerTypeAdapter(ObjectWithField.class, new com.google.gson.JsonDeserializer<ObjectWithField>() {
                public ObjectWithField deserialize(JsonElement json, Type type, com.google.gson.JsonDeserializationContext context) {
                    return context.deserialize(null, type);
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1504,gson);
            String json = "{value:\'valuÀ1\'}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),214,json);
            ObjectWithField target = gson.fromJson(json, ObjectWithField.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),215,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1503,target);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomTypeAdapterPassesNullDesrialization_literalMutation2304() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomTypeAdapterPassesNullDesrialization_literalMutation2304");
            Gson gson = new GsonBuilder().registerTypeAdapter(ObjectWithField.class, new com.google.gson.JsonDeserializer<ObjectWithField>() {
                public ObjectWithField deserialize(JsonElement json, Type type, com.google.gson.JsonDeserializationContext context) {
                    return context.deserialize(null, type);
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1504,gson);
            String json = "{valule:\'value1\'}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),214,json);
            ObjectWithField target = gson.fromJson(json, ObjectWithField.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),215,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1503,target);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomTypeAdapterPassesNullDesrialization_literalMutation2305() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomTypeAdapterPassesNullDesrialization_literalMutation2305");
            Gson gson = new GsonBuilder().registerTypeAdapter(ObjectWithField.class, new com.google.gson.JsonDeserializer<ObjectWithField>() {
                public ObjectWithField deserialize(JsonElement json, Type type, com.google.gson.JsonDeserializationContext context) {
                    return context.deserialize(null, type);
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1504,gson);
            String json = "{value:\'vlue1\'}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),214,json);
            ObjectWithField target = gson.fromJson(json, ObjectWithField.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),215,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1503,target);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomTypeAdapterPassesNullDesrialization_remove334() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomTypeAdapterPassesNullDesrialization_remove334");
            Gson gson = new GsonBuilder().registerTypeAdapter(ObjectWithField.class, new com.google.gson.JsonDeserializer<ObjectWithField>() {
                public ObjectWithField deserialize(JsonElement json, Type type, com.google.gson.JsonDeserializationContext context) {
                    return context.deserialize(null, type);
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1504,gson);
            String json = "{value:\'value1\'}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),214,json);
            ObjectWithField target = gson.fromJson(json, ObjectWithField.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),215,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1503,target);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    private static class ObjectWithField {
        String value = "";
    }
}

