package com.google.gson.functional;

import java.io.CharArrayReader;
import java.io.CharArrayWriter;
import com.google.gson.Gson;
import com.google.gson.GsonBuilder;
import java.io.IOException;
import com.google.gson.JsonStreamParser;
import com.google.gson.JsonSyntaxException;
import java.io.Reader;
import java.io.StringReader;
import java.io.StringWriter;
import org.junit.Test;
import junit.framework.TestCase;
import com.google.gson.common.TestTypes;
import java.io.Writer;

/** 
 * Functional tests for the support of {@link Reader}s and {@link Writer}s.
 * 
 * @author Inderjeet Singh
 * @author Joel Leitch
 */
public class ReadersWritersTest extends TestCase {
    private Gson gson;

    @Override
    protected void setUp() throws Exception {
        super.setUp();
        gson = new Gson();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),276,gson);
    }

    @Test(timeout = 1000)
    public void testWriterForSerialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriterForSerialization");
            Writer writer = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2174,writer);
            TestTypes.BagOfPrimitives src = new TestTypes.BagOfPrimitives();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2175,src);
            gson.toJson(src, writer);
            gson.toJson(src, writer);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2172,src.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2173,writer.toString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testWriterForSerialization_remove400() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriterForSerialization_remove400");
            Writer writer = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2174,writer);
            TestTypes.BagOfPrimitives src = new TestTypes.BagOfPrimitives();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2175,src);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2172,src.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2173,writer.toString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReaderForDeserialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReaderForDeserialization");
            TestTypes.BagOfPrimitives expected = new TestTypes.BagOfPrimitives();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2159,expected);
            Reader json = new StringReader(expected.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),85,json);
            TestTypes.BagOfPrimitives actual = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2160,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2157,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2158,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testTopLevelNullObjectSerializationWithWriter() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTopLevelNullObjectSerializationWithWriter");
            StringWriter writer = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2171,writer);
            gson.toJson(null, writer);
            gson.toJson(null, writer);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2170,writer.toString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testTopLevelNullObjectSerializationWithWriter_remove398() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTopLevelNullObjectSerializationWithWriter_remove398");
            StringWriter writer = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2171,writer);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2170,writer.toString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTopLevelNullObjectDeserializationWithReader() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTopLevelNullObjectDeserializationWithReader");
            StringReader reader = new StringReader("nll");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2166,reader);
            Integer nullIntObject = gson.fromJson(reader, Integer.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2167,nullIntObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2165,nullIntObject);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTopLevelNullObjectDeserializationWithReader_literalMutation3234() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTopLevelNullObjectDeserializationWithReader_literalMutation3234");
            StringReader reader = new StringReader("nu]ll");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2166,reader);
            Integer nullIntObject = gson.fromJson(reader, Integer.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2167,nullIntObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2165,nullIntObject);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTopLevelNullObjectDeserializationWithReader_literalMutation3235() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTopLevelNullObjectDeserializationWithReader_literalMutation3235");
            StringReader reader = new StringReader("nul");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2166,reader);
            Integer nullIntObject = gson.fromJson(reader, Integer.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2167,nullIntObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2165,nullIntObject);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testTopLevelNullObjectSerializationWithWriterAndSerializeNulls() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTopLevelNullObjectSerializationWithWriterAndSerializeNulls");
            Gson gson = new GsonBuilder().serializeNulls().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1121,gson);
            StringWriter writer = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2169,writer);
            gson.toJson(null, writer);
            gson.toJson(null, writer);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2168,writer.toString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testTopLevelNullObjectSerializationWithWriterAndSerializeNulls_remove399() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTopLevelNullObjectSerializationWithWriterAndSerializeNulls_remove399");
            Gson gson = new GsonBuilder().serializeNulls().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1121,gson);
            StringWriter writer = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2169,writer);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2168,writer.toString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTopLevelNullObjectDeserializationWithReaderAndSerializeNulls() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTopLevelNullObjectDeserializationWithReaderAndSerializeNulls");
            Gson gson = new GsonBuilder().serializeNulls().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2162,gson);
            StringReader reader = new StringReader("ªull");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2163,reader);
            Integer nullIntObject = gson.fromJson(reader, Integer.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2164,nullIntObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2161,nullIntObject);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTopLevelNullObjectDeserializationWithReaderAndSerializeNulls_literalMutation3237() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTopLevelNullObjectDeserializationWithReaderAndSerializeNulls_literalMutation3237");
            Gson gson = new GsonBuilder().serializeNulls().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2162,gson);
            StringReader reader = new StringReader("null");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2163,reader);
            Integer nullIntObject = gson.fromJson(reader, Integer.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2164,nullIntObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2161,nullIntObject);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTopLevelNullObjectDeserializationWithReaderAndSerializeNulls_literalMutation3238() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTopLevelNullObjectDeserializationWithReaderAndSerializeNulls_literalMutation3238");
            Gson gson = new GsonBuilder().serializeNulls().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2162,gson);
            StringReader reader = new StringReader("nll");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2163,reader);
            Integer nullIntObject = gson.fromJson(reader, Integer.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2164,nullIntObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2161,nullIntObject);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testReadWriteTwoStrings_add467() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoStrings_add467");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),318,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2152,writer);
            writer.write(gson.toJson("one").toCharArray());
            writer.write(gson.toJson("one").toCharArray());
            writer.write(gson.toJson("two").toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2153,reader);
            JsonStreamParser parser = new JsonStreamParser(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2154,parser);
            String actualOne = gson.fromJson(parser.next(), String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2155,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2150,actualOne);
            String actualTwo = gson.fromJson(parser.next(), String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2156,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2151,actualTwo);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testReadWriteTwoStrings_add468() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoStrings_add468");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),318,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2152,writer);
            writer.write(gson.toJson("one").toCharArray());
            writer.write(gson.toJson("two").toCharArray());
            writer.write(gson.toJson("two").toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2153,reader);
            JsonStreamParser parser = new JsonStreamParser(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2154,parser);
            String actualOne = gson.fromJson(parser.next(), String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2155,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2150,actualOne);
            String actualTwo = gson.fromJson(parser.next(), String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2156,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2151,actualTwo);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoStrings() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoStrings");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),318,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2152,writer);
            writer.write(gson.toJson("ëne").toCharArray());
            writer.write(gson.toJson("two").toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2153,reader);
            JsonStreamParser parser = new JsonStreamParser(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2154,parser);
            String actualOne = gson.fromJson(parser.next(), String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2155,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2150,actualOne);
            String actualTwo = gson.fromJson(parser.next(), String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2156,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2151,actualTwo);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoStrings_literalMutation3228() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoStrings_literalMutation3228");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),318,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2152,writer);
            writer.write(gson.toJson("one").toCharArray());
            writer.write(gson.toJson("two").toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2153,reader);
            JsonStreamParser parser = new JsonStreamParser(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2154,parser);
            String actualOne = gson.fromJson(parser.next(), String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2155,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2150,actualOne);
            String actualTwo = gson.fromJson(parser.next(), String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2156,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2151,actualTwo);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoStrings_literalMutation3229() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoStrings_literalMutation3229");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),318,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2152,writer);
            writer.write(gson.toJson("oe").toCharArray());
            writer.write(gson.toJson("two").toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2153,reader);
            JsonStreamParser parser = new JsonStreamParser(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2154,parser);
            String actualOne = gson.fromJson(parser.next(), String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2155,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2150,actualOne);
            String actualTwo = gson.fromJson(parser.next(), String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2156,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2151,actualTwo);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoStrings_literalMutation3230() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoStrings_literalMutation3230");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),318,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2152,writer);
            writer.write(gson.toJson("one").toCharArray());
            writer.write(gson.toJson("Âwo").toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2153,reader);
            JsonStreamParser parser = new JsonStreamParser(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2154,parser);
            String actualOne = gson.fromJson(parser.next(), String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2155,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2150,actualOne);
            String actualTwo = gson.fromJson(parser.next(), String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2156,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2151,actualTwo);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoStrings_literalMutation3231() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoStrings_literalMutation3231");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),318,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2152,writer);
            writer.write(gson.toJson("one").toCharArray());
            writer.write(gson.toJson("tÐwo").toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2153,reader);
            JsonStreamParser parser = new JsonStreamParser(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2154,parser);
            String actualOne = gson.fromJson(parser.next(), String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2155,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2150,actualOne);
            String actualTwo = gson.fromJson(parser.next(), String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2156,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2151,actualTwo);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoStrings_literalMutation3232() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoStrings_literalMutation3232");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),318,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2152,writer);
            writer.write(gson.toJson("one").toCharArray());
            writer.write(gson.toJson("to").toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2153,reader);
            JsonStreamParser parser = new JsonStreamParser(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2154,parser);
            String actualOne = gson.fromJson(parser.next(), String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2155,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2150,actualOne);
            String actualTwo = gson.fromJson(parser.next(), String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2156,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2151,actualTwo);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testReadWriteTwoStrings_remove396() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoStrings_remove396");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),318,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2152,writer);
            writer.write(gson.toJson("two").toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2153,reader);
            JsonStreamParser parser = new JsonStreamParser(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2154,parser);
            String actualOne = gson.fromJson(parser.next(), String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2155,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2150,actualOne);
            String actualTwo = gson.fromJson(parser.next(), String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2156,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2151,actualTwo);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testReadWriteTwoStrings_remove397() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoStrings_remove397");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),318,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2152,writer);
            writer.write(gson.toJson("two").toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2153,reader);
            JsonStreamParser parser = new JsonStreamParser(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2154,parser);
            String actualOne = gson.fromJson(parser.next(), String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2155,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2150,actualOne);
            String actualTwo = gson.fromJson(parser.next(), String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2156,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2151,actualTwo);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testReadWriteTwoObjects_add465() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_add465");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1452,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2143,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(1 , 1 , true , "one");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2144,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(2 , 2 , false , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2145,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2146,reader);
            JsonStreamParser parser = new JsonStreamParser(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2147,parser);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2148,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2140,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2149,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2141,actualTwo.stringValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2142,parser.hasNext());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testReadWriteTwoObjects_add466() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_add466");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1452,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2143,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(1 , 1 , true , "one");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2144,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(2 , 2 , false , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2145,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2146,reader);
            JsonStreamParser parser = new JsonStreamParser(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2147,parser);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2148,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2140,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2149,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2141,actualTwo.stringValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2142,parser.hasNext());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoObjects() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1452,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2143,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(2 , 1 , true , "one");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2144,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(2 , 2 , false , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2145,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2146,reader);
            JsonStreamParser parser = new JsonStreamParser(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2147,parser);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2148,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2140,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2149,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2141,actualTwo.stringValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2142,parser.hasNext());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoObjects_literalMutation3204() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_literalMutation3204");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1452,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2143,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(0 , 1 , true , "one");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2144,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(2 , 2 , false , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2145,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2146,reader);
            JsonStreamParser parser = new JsonStreamParser(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2147,parser);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2148,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2140,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2149,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2141,actualTwo.stringValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2142,parser.hasNext());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoObjects_literalMutation3205() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_literalMutation3205");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1452,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2143,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(0 , 1 , true , "one");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2144,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(2 , 2 , false , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2145,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2146,reader);
            JsonStreamParser parser = new JsonStreamParser(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2147,parser);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2148,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2140,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2149,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2141,actualTwo.stringValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2142,parser.hasNext());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoObjects_literalMutation3207() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_literalMutation3207");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1452,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2143,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(1 , 2 , true , "one");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2144,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(2 , 2 , false , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2145,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2146,reader);
            JsonStreamParser parser = new JsonStreamParser(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2147,parser);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2148,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2140,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2149,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2141,actualTwo.stringValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2142,parser.hasNext());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoObjects_literalMutation3208() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_literalMutation3208");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1452,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2143,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(1 , 0 , true , "one");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2144,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(2 , 2 , false , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2145,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2146,reader);
            JsonStreamParser parser = new JsonStreamParser(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2147,parser);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2148,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2140,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2149,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2141,actualTwo.stringValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2142,parser.hasNext());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoObjects_literalMutation3209() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_literalMutation3209");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1452,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2143,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(1 , 0 , true , "one");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2144,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(2 , 2 , false , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2145,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2146,reader);
            JsonStreamParser parser = new JsonStreamParser(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2147,parser);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2148,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2140,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2149,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2141,actualTwo.stringValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2142,parser.hasNext());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoObjects_literalMutation3212() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_literalMutation3212");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1452,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2143,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(1 , 1 , true , "Ine");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2144,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(2 , 2 , false , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2145,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2146,reader);
            JsonStreamParser parser = new JsonStreamParser(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2147,parser);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2148,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2140,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2149,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2141,actualTwo.stringValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2142,parser.hasNext());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoObjects_literalMutation3213() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_literalMutation3213");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1452,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2143,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(1 , 1 , true , "onne");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2144,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(2 , 2 , false , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2145,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2146,reader);
            JsonStreamParser parser = new JsonStreamParser(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2147,parser);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2148,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2140,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2149,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2141,actualTwo.stringValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2142,parser.hasNext());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoObjects_literalMutation3214() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_literalMutation3214");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1452,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2143,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(1 , 1 , true , "oe");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2144,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(2 , 2 , false , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2145,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2146,reader);
            JsonStreamParser parser = new JsonStreamParser(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2147,parser);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2148,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2140,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2149,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2141,actualTwo.stringValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2142,parser.hasNext());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoObjects_literalMutation3215() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_literalMutation3215");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1452,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2143,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(1 , 1 , true , "one");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2144,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(1 , 2 , false , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2145,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2146,reader);
            JsonStreamParser parser = new JsonStreamParser(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2147,parser);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2148,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2140,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2149,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2141,actualTwo.stringValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2142,parser.hasNext());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoObjects_literalMutation3216() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_literalMutation3216");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1452,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2143,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(1 , 1 , true , "one");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2144,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(4 , 2 , false , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2145,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2146,reader);
            JsonStreamParser parser = new JsonStreamParser(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2147,parser);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2148,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2140,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2149,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2141,actualTwo.stringValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2142,parser.hasNext());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoObjects_literalMutation3217() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_literalMutation3217");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1452,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2143,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(1 , 1 , true , "one");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2144,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(3 , 2 , false , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2145,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2146,reader);
            JsonStreamParser parser = new JsonStreamParser(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2147,parser);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2148,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2140,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2149,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2141,actualTwo.stringValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2142,parser.hasNext());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoObjects_literalMutation3219() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_literalMutation3219");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1452,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2143,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(1 , 1 , true , "one");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2144,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(2 , 1 , false , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2145,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2146,reader);
            JsonStreamParser parser = new JsonStreamParser(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2147,parser);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2148,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2140,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2149,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2141,actualTwo.stringValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2142,parser.hasNext());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoObjects_literalMutation3220() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_literalMutation3220");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1452,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2143,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(1 , 1 , true , "one");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2144,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(2 , 4 , false , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2145,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2146,reader);
            JsonStreamParser parser = new JsonStreamParser(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2147,parser);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2148,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2140,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2149,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2141,actualTwo.stringValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2142,parser.hasNext());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoObjects_literalMutation3221() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_literalMutation3221");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1452,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2143,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(1 , 1 , true , "one");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2144,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(2 , 3 , false , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2145,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2146,reader);
            JsonStreamParser parser = new JsonStreamParser(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2147,parser);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2148,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2140,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2149,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2141,actualTwo.stringValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2142,parser.hasNext());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoObjects_literalMutation3223() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_literalMutation3223");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1452,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2143,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(1 , 1 , true , "one");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2144,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(2 , 2 , true , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2145,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2146,reader);
            JsonStreamParser parser = new JsonStreamParser(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2147,parser);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2148,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2140,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2149,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2141,actualTwo.stringValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2142,parser.hasNext());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoObjects_literalMutation3224() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_literalMutation3224");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1452,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2143,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(1 , 1 , true , "one");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2144,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(2 , 2 , false , "¥wo");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2145,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2146,reader);
            JsonStreamParser parser = new JsonStreamParser(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2147,parser);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2148,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2140,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2149,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2141,actualTwo.stringValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2142,parser.hasNext());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoObjects_literalMutation3225() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_literalMutation3225");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1452,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2143,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(1 , 1 , true , "one");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2144,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(2 , 2 , false , "tÎwo");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2145,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2146,reader);
            JsonStreamParser parser = new JsonStreamParser(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2147,parser);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2148,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2140,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2149,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2141,actualTwo.stringValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2142,parser.hasNext());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testReadWriteTwoObjects_literalMutation3226() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_literalMutation3226");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1452,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2143,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(1 , 1 , true , "one");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2144,expectedOne);
            writer.write(gson.toJson(expectedOne).toCharArray());
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(2 , 2 , false , "to");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2145,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2146,reader);
            JsonStreamParser parser = new JsonStreamParser(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2147,parser);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2148,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2140,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2149,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2141,actualTwo.stringValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2142,parser.hasNext());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testReadWriteTwoObjects_remove394() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_remove394");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1452,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2143,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(1 , 1 , true , "one");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2144,expectedOne);
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(2 , 2 , false , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2145,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2146,reader);
            JsonStreamParser parser = new JsonStreamParser(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2147,parser);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2148,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2140,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2149,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2141,actualTwo.stringValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2142,parser.hasNext());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testReadWriteTwoObjects_remove395() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReadWriteTwoObjects_remove395");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1452,gson);
            CharArrayWriter writer = new CharArrayWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2143,writer);
            TestTypes.BagOfPrimitives expectedOne = new TestTypes.BagOfPrimitives(1 , 1 , true , "one");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2144,expectedOne);
            TestTypes.BagOfPrimitives expectedTwo = new TestTypes.BagOfPrimitives(2 , 2 , false , "two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2145,expectedTwo);
            writer.write(gson.toJson(expectedTwo).toCharArray());
            CharArrayReader reader = new CharArrayReader(writer.toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2146,reader);
            JsonStreamParser parser = new JsonStreamParser(reader);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2147,parser);
            TestTypes.BagOfPrimitives actualOne = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2148,actualOne);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2140,actualOne.stringValue);
            TestTypes.BagOfPrimitives actualTwo = gson.fromJson(parser.next(), TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2149,actualTwo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2141,actualTwo.stringValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2142,parser.hasNext());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testTypeMismatchThrowsJsonSyntaxExceptionForStrings_add473() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeMismatchThrowsJsonSyntaxExceptionForStrings_add473");
            try {
                gson.fromJson("true", new com.google.gson.reflect.TypeToken<java.util.Map<java.lang.String, java.lang.String>>() {                }.getType());
                gson.fromJson("true", new com.google.gson.reflect.TypeToken<java.util.Map<java.lang.String, java.lang.String>>() {                }.getType());
            } catch (JsonSyntaxException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testTypeMismatchThrowsJsonSyntaxExceptionForStrings_add474() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeMismatchThrowsJsonSyntaxExceptionForStrings_add474");
            try {
                gson.fromJson("true", new com.google.gson.reflect.TypeToken<java.util.Map<java.lang.String, java.lang.String>>() {                }.getType());
            } catch (JsonSyntaxException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeMismatchThrowsJsonSyntaxExceptionForStrings() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeMismatchThrowsJsonSyntaxExceptionForStrings");
            try {
                gson.fromJson("+rue", new com.google.gson.reflect.TypeToken<java.util.Map<java.lang.String, java.lang.String>>() {                }.getType());
            } catch (JsonSyntaxException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeMismatchThrowsJsonSyntaxExceptionForStrings_literalMutation3245() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeMismatchThrowsJsonSyntaxExceptionForStrings_literalMutation3245");
            try {
                gson.fromJson("tr\\ue", new com.google.gson.reflect.TypeToken<java.util.Map<java.lang.String, java.lang.String>>() {                }.getType());
            } catch (JsonSyntaxException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeMismatchThrowsJsonSyntaxExceptionForStrings_literalMutation3246() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeMismatchThrowsJsonSyntaxExceptionForStrings_literalMutation3246");
            try {
                gson.fromJson("tre", new com.google.gson.reflect.TypeToken<java.util.Map<java.lang.String, java.lang.String>>() {                }.getType());
            } catch (JsonSyntaxException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testTypeMismatchThrowsJsonSyntaxExceptionForReaders_add471() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeMismatchThrowsJsonSyntaxExceptionForReaders_add471");
            try {
                gson.fromJson(new StringReader("true"), new com.google.gson.reflect.TypeToken<java.util.Map<java.lang.String, java.lang.String>>() {                }.getType());
                gson.fromJson(new StringReader("true"), new com.google.gson.reflect.TypeToken<java.util.Map<java.lang.String, java.lang.String>>() {                }.getType());
            } catch (JsonSyntaxException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testTypeMismatchThrowsJsonSyntaxExceptionForReaders_add472() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeMismatchThrowsJsonSyntaxExceptionForReaders_add472");
            try {
                gson.fromJson(new StringReader("true"), new com.google.gson.reflect.TypeToken<java.util.Map<java.lang.String, java.lang.String>>() {                }.getType());
            } catch (JsonSyntaxException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeMismatchThrowsJsonSyntaxExceptionForReaders() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeMismatchThrowsJsonSyntaxExceptionForReaders");
            try {
                gson.fromJson(new StringReader("tue"), new com.google.gson.reflect.TypeToken<java.util.Map<java.lang.String, java.lang.String>>() {                }.getType());
            } catch (JsonSyntaxException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeMismatchThrowsJsonSyntaxExceptionForReaders_literalMutation3242() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeMismatchThrowsJsonSyntaxExceptionForReaders_literalMutation3242");
            try {
                gson.fromJson(new StringReader("true"), new com.google.gson.reflect.TypeToken<java.util.Map<java.lang.String, java.lang.String>>() {                }.getType());
            } catch (JsonSyntaxException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeMismatchThrowsJsonSyntaxExceptionForReaders_literalMutation3243() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeMismatchThrowsJsonSyntaxExceptionForReaders_literalMutation3243");
            try {
                gson.fromJson(new StringReader("tue"), new com.google.gson.reflect.TypeToken<java.util.Map<java.lang.String, java.lang.String>>() {                }.getType());
            } catch (JsonSyntaxException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }
}

