package com.google.gson.functional;

import com.google.gson.Gson;
import com.google.gson.GsonBuilder;
import junit.framework.TestCase;
import com.google.gson.common.TestTypes;

/** 
 * Tests for security-related aspects of Gson
 * 
 * @author Inderjeet Singh
 */
public class SecurityTest extends TestCase {
    /** 
     * Keep this in sync with Gson.JSON_NON_EXECUTABLE_PREFIX
     */
private static final String JSON_NON_EXECUTABLE_PREFIX = ")]}\'\n";

    private GsonBuilder gsonBuilder;

    @Override
    protected void setUp() throws Exception {
        super.setUp();
        gsonBuilder = new GsonBuilder();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2199,gsonBuilder);
    }

    public void testNonExecutableJsonSerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNonExecutableJsonSerialization");
            Gson gson = gsonBuilder.generateNonExecutableJson().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1090,gson);
            String json = gson.toJson(new TestTypes.BagOfPrimitives());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1091,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2206,json.startsWith(com.google.gson.functional.SecurityTest.JSON_NON_EXECUTABLE_PREFIX));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNonExecutableJsonDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNonExecutableJsonDeserialization");
            String json = (JSON_NON_EXECUTABLE_PREFIX) + "{longVaue:1}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),315,json);
            Gson gson = gsonBuilder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1550,gson);
            TestTypes.BagOfPrimitives target = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2205,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2204,target.longValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNonExecutableJsonDeserialization_literalMutation3264() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNonExecutableJsonDeserialization_literalMutation3264");
            String json = (JSON_NON_EXECUTABLE_PREFIX) + "{longValue:1}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),315,json);
            Gson gson = gsonBuilder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1550,gson);
            TestTypes.BagOfPrimitives target = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2205,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2204,target.longValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNonExecutableJsonDeserialization_literalMutation3265() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNonExecutableJsonDeserialization_literalMutation3265");
            String json = (JSON_NON_EXECUTABLE_PREFIX) + "{ongValue:1}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),315,json);
            Gson gson = gsonBuilder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1550,gson);
            TestTypes.BagOfPrimitives target = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2205,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2204,target.longValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonWithNonExectuableTokenSerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonWithNonExectuableTokenSerialization");
            Gson gson = gsonBuilder.generateNonExecutableJson().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            String json = gson.toJson(JSON_NON_EXECUTABLE_PREFIX);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),908,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2200,json.contains(")]}\'\n"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Gson should be able to deserialize a stream with non-exectuable token even if it is created
     * without {@link GsonBuilder#generateNonExecutableJson()}.
     */
public void testJsonWithNonExectuableTokenWithRegularGsonDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonWithNonExectuableTokenWithRegularGsonDeserialization");
            Gson gson = gsonBuilder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),322,gson);
            String json = (JSON_NON_EXECUTABLE_PREFIX) + "{strin¼Value:\')]}\\u0027\\n\'}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2203,json);
            TestTypes.BagOfPrimitives target = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),915,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2202,target.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Gson should be able to deserialize a stream with non-exectuable token even if it is created
     * without {@link GsonBuilder#generateNonExecutableJson()}.
     */
public void testJsonWithNonExectuableTokenWithRegularGsonDeserialization_literalMutation3261() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonWithNonExectuableTokenWithRegularGsonDeserialization_literalMutation3261");
            Gson gson = gsonBuilder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),322,gson);
            String json = (JSON_NON_EXECUTABLE_PREFIX) + "{stringValue:\')]É}\\u0027\\n\'}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2203,json);
            TestTypes.BagOfPrimitives target = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),915,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2202,target.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Gson should be able to deserialize a stream with non-exectuable token even if it is created
     * without {@link GsonBuilder#generateNonExecutableJson()}.
     */
public void testJsonWithNonExectuableTokenWithRegularGsonDeserialization_literalMutation3262() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonWithNonExectuableTokenWithRegularGsonDeserialization_literalMutation3262");
            Gson gson = gsonBuilder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),322,gson);
            String json = (JSON_NON_EXECUTABLE_PREFIX) + "{stringValue:\')]}\\u0027n\'}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2203,json);
            TestTypes.BagOfPrimitives target = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),915,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2202,target.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Gson should be able to deserialize a stream with non-exectuable token if it is created
     * with {@link GsonBuilder#generateNonExecutableJson()}.
     */
public void testJsonWithNonExectuableTokenWithConfiguredGsonDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonWithNonExectuableTokenWithConfiguredGsonDeserialization");
            Gson gson = gsonBuilder.generateNonExecutableJson().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2201,gson);
            String json = (JSON_NON_EXECUTABLE_PREFIX) + "{intValue:2,stringValuú:\')]}\\u0027\\n\'}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1631,json);
            TestTypes.BagOfPrimitives target = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1516,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1628,target.stringValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1629,target.intValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Gson should be able to deserialize a stream with non-exectuable token if it is created
     * with {@link GsonBuilder#generateNonExecutableJson()}.
     */
public void testJsonWithNonExectuableTokenWithConfiguredGsonDeserialization_literalMutation3258() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonWithNonExectuableTokenWithConfiguredGsonDeserialization_literalMutation3258");
            Gson gson = gsonBuilder.generateNonExecutableJson().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2201,gson);
            String json = (JSON_NON_EXECUTABLE_PREFIX) + "{intValue:2,stringValue:\')]n}\\u0027\\n\'}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1631,json);
            TestTypes.BagOfPrimitives target = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1516,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1628,target.stringValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1629,target.intValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Gson should be able to deserialize a stream with non-exectuable token if it is created
     * with {@link GsonBuilder#generateNonExecutableJson()}.
     */
public void testJsonWithNonExectuableTokenWithConfiguredGsonDeserialization_literalMutation3259() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonWithNonExectuableTokenWithConfiguredGsonDeserialization_literalMutation3259");
            Gson gson = gsonBuilder.generateNonExecutableJson().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2201,gson);
            String json = (JSON_NON_EXECUTABLE_PREFIX) + "{ntValue:2,stringValue:\')]}\\u0027\\n\'}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1631,json);
            TestTypes.BagOfPrimitives target = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1516,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1628,target.stringValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1629,target.intValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }
}

