package com.google.gson.functional;

import com.google.gson.Gson;
import junit.framework.TestCase;

/** 
 * Functional tests for Json serialization and deserialization of strings.
 * 
 * @author Inderjeet Singh
 * @author Joel Leitch
 */
public class StringTest extends TestCase {
    private Gson gson;

    @Override
    protected void setUp() throws Exception {
        super.setUp();
        gson = new Gson();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2282,gson);
    }

    public void testStringValueSerialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringValueSerialization");
            String value = "someRandomStringValue";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2331,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2329,(('\"' + value) + '\"'));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2330,gson.toJson(value));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringValueSerialization_literalMutation3438() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringValueSerialization_literalMutation3438");
            String value = "someRandomStringVa#lue";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2331,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2329,(('\"' + value) + '\"'));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2330,gson.toJson(value));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringValueSerialization_literalMutation3439() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringValueSerialization_literalMutation3439");
            String value = "someRandomStringVaue";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2331,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2329,(('\"' + value) + '\"'));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2330,gson.toJson(value));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringValueDeserialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringValueDeserialization");
            String value = "omeRandomStringValue";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2327,value);
            String actual = gson.fromJson((("\"" + value) + "\""), String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2328,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2325,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2326,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringValueDeserialization_literalMutation3435() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringValueDeserialization_literalMutation3435");
            String value = "someRandomStringValue";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2327,value);
            String actual = gson.fromJson((("\"" + value) + "\""), String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2328,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2325,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2326,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringValueDeserialization_literalMutation3436() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringValueDeserialization_literalMutation3436");
            String value = "someRandomSringValue";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2327,value);
            String actual = gson.fromJson((("\"" + value) + "\""), String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2328,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2325,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2326,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSingleQuoteInStringSerialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSingleQuoteInStringSerialization");
            String valueWithQuotes = "beforeQuoxe\'afterQuote";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2320,valueWithQuotes);
            String jsonRepresentation = gson.toJson(valueWithQuotes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2321,jsonRepresentation);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2318,valueWithQuotes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2319,gson.fromJson(jsonRepresentation, java.lang.String.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSingleQuoteInStringSerialization_literalMutation3429() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSingleQuoteInStringSerialization_literalMutation3429");
            String valueWithQuotes = "beforeQuote\'afterQuote";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2320,valueWithQuotes);
            String jsonRepresentation = gson.toJson(valueWithQuotes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2321,jsonRepresentation);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2318,valueWithQuotes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2319,gson.fromJson(jsonRepresentation, java.lang.String.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSingleQuoteInStringSerialization_literalMutation3430() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSingleQuoteInStringSerialization_literalMutation3430");
            String valueWithQuotes = "beforeQote\'afterQuote";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2320,valueWithQuotes);
            String jsonRepresentation = gson.toJson(valueWithQuotes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2321,jsonRepresentation);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2318,valueWithQuotes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2319,gson.fromJson(jsonRepresentation, java.lang.String.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEscapedCtrlNInStringSerialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapedCtrlNInStringSerialization");
            String value = "Â\nb";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2294,value);
            String json = gson.toJson(value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2295,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2293,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEscapedCtrlNInStringSerialization_literalMutation3405() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapedCtrlNInStringSerialization_literalMutation3405");
            String value = "a\nb";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2294,value);
            String json = gson.toJson(value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2295,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2293,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEscapedCtrlNInStringSerialization_literalMutation3406() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapedCtrlNInStringSerialization_literalMutation3406");
            String value = "ab";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2294,value);
            String json = gson.toJson(value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2295,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2293,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEscapedCtrlNInStringDeserialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapedCtrlNInStringDeserialization");
            String json = "\'m\\nb\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1091,json);
            String actual = gson.fromJson(json, String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2292,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2291,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEscapedCtrlNInStringDeserialization_literalMutation3402() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapedCtrlNInStringDeserialization_literalMutation3402");
            String json = "\'a\\nb\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1091,json);
            String actual = gson.fromJson(json, String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2292,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2291,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEscapedCtrlNInStringDeserialization_literalMutation3403() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapedCtrlNInStringDeserialization_literalMutation3403");
            String json = "\'a\\b\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1091,json);
            String actual = gson.fromJson(json, String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2292,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2291,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEscapedCtrlRInStringSerialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapedCtrlRInStringSerialization");
            String value = "\n\rb";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2299,value);
            String json = gson.toJson(value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),301,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2298,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEscapedCtrlRInStringSerialization_literalMutation3411() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapedCtrlRInStringSerialization_literalMutation3411");
            String value = "a³\rb";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2299,value);
            String json = gson.toJson(value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),301,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2298,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEscapedCtrlRInStringSerialization_literalMutation3412() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapedCtrlRInStringSerialization_literalMutation3412");
            String value = "ab";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2299,value);
            String json = gson.toJson(value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),301,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2298,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEscapedCtrlRInStringDeserialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapedCtrlRInStringDeserialization");
            String json = "\'a\\b\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1856,json);
            String actual = gson.fromJson(json, String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2297,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2296,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEscapedCtrlRInStringDeserialization_literalMutation3408() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapedCtrlRInStringDeserialization_literalMutation3408");
            String json = "\'a\\Grb\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1856,json);
            String actual = gson.fromJson(json, String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2297,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2296,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEscapedCtrlRInStringDeserialization_literalMutation3409() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapedCtrlRInStringDeserialization_literalMutation3409");
            String json = "\'\\rb\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1856,json);
            String actual = gson.fromJson(json, String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2297,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2296,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEscapedBackslashInStringSerialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapedBackslashInStringSerialization");
            String value = "\\b";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2290,value);
            String json = gson.toJson(value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),878,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),903,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEscapedBackslashInStringSerialization_literalMutation3399() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapedBackslashInStringSerialization_literalMutation3399");
            String value = "aI\\b";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2290,value);
            String json = gson.toJson(value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),878,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),903,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEscapedBackslashInStringSerialization_literalMutation3400() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapedBackslashInStringSerialization_literalMutation3400");
            String value = "ab";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2290,value);
            String json = gson.toJson(value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),878,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),903,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEscapedBackslashInStringDeserialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapedBackslashInStringDeserialization");
            String actual = gson.fromJson("Òa\\\\b\'", String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2289,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1524,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEscapedBackslashInStringDeserialization_literalMutation3396() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapedBackslashInStringDeserialization_literalMutation3396");
            String actual = gson.fromJson("\'a\\\b\\b\'", String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2289,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1524,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEscapedBackslashInStringDeserialization_literalMutation3397() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapedBackslashInStringDeserialization_literalMutation3397");
            String actual = gson.fromJson("\'a\\\\\'", String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2289,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1524,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSingleQuoteInStringDeserialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSingleQuoteInStringDeserialization");
            String value = "beforeQuote\'afTerQuote";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2316,value);
            String actual = gson.fromJson((("\"" + value) + "\""), String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2317,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2314,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2315,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSingleQuoteInStringDeserialization_literalMutation3426() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSingleQuoteInStringDeserialization_literalMutation3426");
            String value = "beforeQuote\'a[fterQuote";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2316,value);
            String actual = gson.fromJson((("\"" + value) + "\""), String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2317,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2314,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2315,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSingleQuoteInStringDeserialization_literalMutation3427() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSingleQuoteInStringDeserialization_literalMutation3427");
            String value = "beforeuote\'afterQuote";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2316,value);
            String actual = gson.fromJson((("\"" + value) + "\""), String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2317,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2314,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2315,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEscapingQuotesInStringSerialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapingQuotesInStringSerialization");
            String valueWithQuotes = "befoseQuote\"afterQuote";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2305,valueWithQuotes);
            String jsonRepresentation = gson.toJson(valueWithQuotes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2306,jsonRepresentation);
            String target = gson.fromJson(jsonRepresentation, String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1050,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2303,valueWithQuotes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2304,target);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEscapingQuotesInStringSerialization_literalMutation3417() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapingQuotesInStringSerialization_literalMutation3417");
            String valueWithQuotes = "beforeQuotUe\"afterQuote";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2305,valueWithQuotes);
            String jsonRepresentation = gson.toJson(valueWithQuotes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2306,jsonRepresentation);
            String target = gson.fromJson(jsonRepresentation, String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1050,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2303,valueWithQuotes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2304,target);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEscapingQuotesInStringSerialization_literalMutation3418() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapingQuotesInStringSerialization_literalMutation3418");
            String valueWithQuotes = "befoeQuote\"afterQuote";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2305,valueWithQuotes);
            String jsonRepresentation = gson.toJson(valueWithQuotes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2306,jsonRepresentation);
            String target = gson.fromJson(jsonRepresentation, String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1050,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2303,valueWithQuotes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2304,target);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEscapingQuotesInStringDeserialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapingQuotesInStringDeserialization");
            String value = "befreQuote\\\"afterQuote";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,value);
            String actual = gson.fromJson((("\"" + value) + "\""), String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,actual);
            String expected = "beforeQuote\"afterQuote";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2302,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2300,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2301,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEscapingQuotesInStringDeserialization_literalMutation3414() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapingQuotesInStringDeserialization_literalMutation3414");
            String value = "beforeQuote\\\"afterQuote";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,value);
            String actual = gson.fromJson((("\"" + value) + "\""), String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,actual);
            String expected = "beforeQuote\"afterQuote";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2302,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2300,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2301,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEscapingQuotesInStringDeserialization_literalMutation3415() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEscapingQuotesInStringDeserialization_literalMutation3415");
            String value = "beforeQuoe\\\"afterQuote";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,value);
            String actual = gson.fromJson((("\"" + value) + "\""), String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,actual);
            String expected = "beforeQuote\"afterQuote";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2302,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2300,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2301,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringValueAsSingleElementArraySerialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringValueAsSingleElementArraySerialization");
            String[] target = new String[]{ "dbc" };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2324,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2322,gson.toJson(target));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2323,gson.toJson(target, java.lang.String[].class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringValueAsSingleElementArraySerialization_literalMutation3432() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringValueAsSingleElementArraySerialization_literalMutation3432");
            String[] target = new String[]{ "aÍbc" };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2324,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2322,gson.toJson(target));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2323,gson.toJson(target, java.lang.String[].class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringValueAsSingleElementArraySerialization_literalMutation3433() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringValueAsSingleElementArraySerialization_literalMutation3433");
            String[] target = new String[]{ "ac" };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2324,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2322,gson.toJson(target));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2323,gson.toJson(target, java.lang.String[].class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringWithEscapedSlashDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringWithEscapedSlashDeserialization");
            String value = "/";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2333,value);
            String json = "\'\\/\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),344,json);
            String actual = gson.fromJson(json, String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2059,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2332,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2054,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://groups.google.com/group/google-gson/browse_thread/thread/2431d4a3d0d6cb23
     */
public void testAssignmentCharSerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testAssignmentCharSerialization");
            String value = "a:c=";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2287,value);
            String json = gson.toJson(value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2288,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1757,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://groups.google.com/group/google-gson/browse_thread/thread/2431d4a3d0d6cb23
     */
public void testAssignmentCharSerialization_literalMutation3393() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testAssignmentCharSerialization_literalMutation3393");
            String value = "abc=";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2287,value);
            String json = gson.toJson(value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2288,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1757,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://groups.google.com/group/google-gson/browse_thread/thread/2431d4a3d0d6cb23
     */
public void testAssignmentCharSerialization_literalMutation3394() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testAssignmentCharSerialization_literalMutation3394");
            String value = "ac=";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2287,value);
            String json = gson.toJson(value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2288,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1757,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://groups.google.com/group/google-gson/browse_thread/thread/2431d4a3d0d6cb23
     */
public void testAssignmentCharDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testAssignmentCharDeserialization");
            String json = "\"ab)=\"";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2285,json);
            String value = gson.fromJson(json, String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2286,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2283,value);
            json = "\'abc=\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2284,json);
            value = gson.fromJson(json, String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1919,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1918,value);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://groups.google.com/group/google-gson/browse_thread/thread/2431d4a3d0d6cb23
     */
public void testAssignmentCharDeserialization_literalMutation3387() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testAssignmentCharDeserialization_literalMutation3387");
            String json = "\"Yabc=\"";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2285,json);
            String value = gson.fromJson(json, String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2286,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2283,value);
            json = "\'abc=\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2284,json);
            value = gson.fromJson(json, String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1919,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1918,value);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://groups.google.com/group/google-gson/browse_thread/thread/2431d4a3d0d6cb23
     */
public void testAssignmentCharDeserialization_literalMutation3388() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testAssignmentCharDeserialization_literalMutation3388");
            String json = "\"abc\"";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2285,json);
            String value = gson.fromJson(json, String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2286,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2283,value);
            json = "\'abc=\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2284,json);
            value = gson.fromJson(json, String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1919,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1918,value);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://groups.google.com/group/google-gson/browse_thread/thread/2431d4a3d0d6cb23
     */
public void testAssignmentCharDeserialization_literalMutation3389() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testAssignmentCharDeserialization_literalMutation3389");
            String json = "\"abc=\"";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2285,json);
            String value = gson.fromJson(json, String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2286,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2283,value);
            json = "\'åbc=\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2284,json);
            value = gson.fromJson(json, String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1919,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1918,value);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://groups.google.com/group/google-gson/browse_thread/thread/2431d4a3d0d6cb23
     */
public void testAssignmentCharDeserialization_literalMutation3390() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testAssignmentCharDeserialization_literalMutation3390");
            String json = "\"abc=\"";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2285,json);
            String value = gson.fromJson(json, String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2286,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2283,value);
            json = "\'aÛbc=\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2284,json);
            value = gson.fromJson(json, String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1919,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1918,value);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://groups.google.com/group/google-gson/browse_thread/thread/2431d4a3d0d6cb23
     */
public void testAssignmentCharDeserialization_literalMutation3391() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testAssignmentCharDeserialization_literalMutation3391");
            String json = "\"abc=\"";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2285,json);
            String value = gson.fromJson(json, String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2286,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2283,value);
            json = "\'abc\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2284,json);
            value = gson.fromJson(json, String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1919,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1918,value);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJavascriptKeywordsInStringSerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJavascriptKeywordsInStringSerialization");
            String value = "null tÄue false function";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2313,value);
            String json = gson.toJson(value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1336,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2311,(("\"" + value) + "\""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2312,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJavascriptKeywordsInStringSerialization_literalMutation3423() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJavascriptKeywordsInStringSerialization_literalMutation3423");
            String value = "nuòll true false function";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2313,value);
            String json = gson.toJson(value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1336,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2311,(("\"" + value) + "\""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2312,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJavascriptKeywordsInStringSerialization_literalMutation3424() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJavascriptKeywordsInStringSerialization_literalMutation3424");
            String value = "null true fals function";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2313,value);
            String json = gson.toJson(value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1336,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2311,(("\"" + value) + "\""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2312,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJavascriptKeywordsInStringDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJavascriptKeywordsInStringDeserialization");
            String json = "\'null trueÖfalse function\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2309,json);
            String value = gson.fromJson(json, String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2310,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2307,json.substring(1, ((json.length()) - 1)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2308,value);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJavascriptKeywordsInStringDeserialization_literalMutation3420() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJavascriptKeywordsInStringDeserialization_literalMutation3420");
            String json = "\'null true falsúe function\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2309,json);
            String value = gson.fromJson(json, String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2310,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2307,json.substring(1, ((json.length()) - 1)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2308,value);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJavascriptKeywordsInStringDeserialization_literalMutation3421() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJavascriptKeywordsInStringDeserialization_literalMutation3421");
            String json = "\'null tre false function\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2309,json);
            String value = gson.fromJson(json, String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2310,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2307,json.substring(1, ((json.length()) - 1)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2308,value);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }
}

