package com.google.gson.functional;

import com.google.gson.Gson;
import com.google.gson.GsonBuilder;
import com.google.gson.annotations.Since;
import junit.framework.TestCase;
import com.google.gson.common.TestTypes;
import com.google.gson.annotations.Until;

/** 
 * Functional tests for versioning support in Gson.
 * 
 * @author Inderjeet Singh
 * @author Joel Leitch
 */
public class VersioningTest extends TestCase {
    private static final int A = 0;

    private static final int B = 1;

    private static final int C = 2;

    private static final int D = 3;

    private GsonBuilder builder;

    @Override
    protected void setUp() throws Exception {
        super.setUp();
        builder = new GsonBuilder();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2487,builder);
    }

    public void testVersionedUntilSerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedUntilSerialization");
            Version1 target = new Version1();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1468,target);
            Gson gson = builder.setVersion(2.29).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2542,gson);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2119,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2538,json.contains(("\"a\":" + (com.google.gson.functional.VersioningTest.A))));
            gson = builder.setVersion(1.3).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2540,gson);
            json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2541,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2539,json.contains(("\"a\":" + (com.google.gson.functional.VersioningTest.A))));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedUntilSerialization_literalMutation3759() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedUntilSerialization_literalMutation3759");
            Version1 target = new Version1();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1468,target);
            Gson gson = builder.setVersion(0.645).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2542,gson);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2119,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2538,json.contains(("\"a\":" + (com.google.gson.functional.VersioningTest.A))));
            gson = builder.setVersion(1.3).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2540,gson);
            json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2541,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2539,json.contains(("\"a\":" + (com.google.gson.functional.VersioningTest.A))));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedUntilSerialization_literalMutation3760() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedUntilSerialization_literalMutation3760");
            Version1 target = new Version1();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1468,target);
            Gson gson = builder.setVersion(2.58).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2542,gson);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2119,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2538,json.contains(("\"a\":" + (com.google.gson.functional.VersioningTest.A))));
            gson = builder.setVersion(1.3).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2540,gson);
            json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2541,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2539,json.contains(("\"a\":" + (com.google.gson.functional.VersioningTest.A))));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedUntilSerialization_literalMutation3761() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedUntilSerialization_literalMutation3761");
            Version1 target = new Version1();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1468,target);
            Gson gson = builder.setVersion(0.29000000000000004).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2542,gson);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2119,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2538,json.contains(("\"a\":" + (com.google.gson.functional.VersioningTest.A))));
            gson = builder.setVersion(1.3).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2540,gson);
            json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2541,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2539,json.contains(("\"a\":" + (com.google.gson.functional.VersioningTest.A))));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedUntilSerialization_literalMutation3763() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedUntilSerialization_literalMutation3763");
            Version1 target = new Version1();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1468,target);
            Gson gson = builder.setVersion(1.29).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2542,gson);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2119,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2538,json.contains(("\"a\":" + (com.google.gson.functional.VersioningTest.A))));
            gson = builder.setVersion(2.3).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2540,gson);
            json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2541,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2539,json.contains(("\"a\":" + (com.google.gson.functional.VersioningTest.A))));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedUntilSerialization_literalMutation3764() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedUntilSerialization_literalMutation3764");
            Version1 target = new Version1();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1468,target);
            Gson gson = builder.setVersion(1.29).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2542,gson);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2119,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2538,json.contains(("\"a\":" + (com.google.gson.functional.VersioningTest.A))));
            gson = builder.setVersion(0.30000000000000004).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2540,gson);
            json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2541,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2539,json.contains(("\"a\":" + (com.google.gson.functional.VersioningTest.A))));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedUntilSerialization_literalMutation3765() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedUntilSerialization_literalMutation3765");
            Version1 target = new Version1();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1468,target);
            Gson gson = builder.setVersion(1.29).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2542,gson);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2119,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2538,json.contains(("\"a\":" + (com.google.gson.functional.VersioningTest.A))));
            gson = builder.setVersion(0.65).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2540,gson);
            json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2541,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2539,json.contains(("\"a\":" + (com.google.gson.functional.VersioningTest.A))));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedUntilSerialization_literalMutation3766() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedUntilSerialization_literalMutation3766");
            Version1 target = new Version1();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1468,target);
            Gson gson = builder.setVersion(1.29).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2542,gson);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2119,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2538,json.contains(("\"a\":" + (com.google.gson.functional.VersioningTest.A))));
            gson = builder.setVersion(2.6).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2540,gson);
            json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2541,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2539,json.contains(("\"a\":" + (com.google.gson.functional.VersioningTest.A))));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedUntilDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedUntilDeserialization");
            Gson gson = builder.setVersion(2.3).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            String json = "{\"a\":3,\"b\":4,\"c\":5}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),908,json);
            Version1 version1 = gson.fromJson(json, Version1.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2537,version1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2535,com.google.gson.functional.VersioningTest.A);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2536,version1.a);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedUntilDeserialization_literalMutation3751() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedUntilDeserialization_literalMutation3751");
            Gson gson = builder.setVersion(0.30000000000000004).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            String json = "{\"a\":3,\"b\":4,\"c\":5}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),908,json);
            Version1 version1 = gson.fromJson(json, Version1.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2537,version1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2535,com.google.gson.functional.VersioningTest.A);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2536,version1.a);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedUntilDeserialization_literalMutation3752() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedUntilDeserialization_literalMutation3752");
            Gson gson = builder.setVersion(0.65).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            String json = "{\"a\":3,\"b\":4,\"c\":5}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),908,json);
            Version1 version1 = gson.fromJson(json, Version1.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2537,version1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2535,com.google.gson.functional.VersioningTest.A);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2536,version1.a);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedUntilDeserialization_literalMutation3753() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedUntilDeserialization_literalMutation3753");
            Gson gson = builder.setVersion(2.6).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            String json = "{\"a\":3,\"b\":4,\"c\":5}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),908,json);
            Version1 version1 = gson.fromJson(json, Version1.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2537,version1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2535,com.google.gson.functional.VersioningTest.A);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2536,version1.a);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedUntilDeserialization_literalMutation3755() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedUntilDeserialization_literalMutation3755");
            Gson gson = builder.setVersion(1.3).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            String json = "{\"a\":3,\"b\"«4,\"c\":5}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),908,json);
            Version1 version1 = gson.fromJson(json, Version1.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2537,version1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2535,com.google.gson.functional.VersioningTest.A);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2536,version1.a);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedUntilDeserialization_literalMutation3756() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedUntilDeserialization_literalMutation3756");
            Gson gson = builder.setVersion(1.3).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            String json = "{\"a\":3,\"b\":4,\"c\":½5}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),908,json);
            Version1 version1 = gson.fromJson(json, Version1.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2537,version1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2535,com.google.gson.functional.VersioningTest.A);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2536,version1.a);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedUntilDeserialization_literalMutation3757() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedUntilDeserialization_literalMutation3757");
            Gson gson = builder.setVersion(1.3).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            String json = "{\"a:3,\"b\":4,\"c\":5}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),908,json);
            Version1 version1 = gson.fromJson(json, Version1.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2537,version1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2535,com.google.gson.functional.VersioningTest.A);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2536,version1.a);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedClassesSerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedClassesSerialization");
            Gson gson = builder.setVersion(2.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2449,gson);
            String json1 = gson.toJson(new Version1());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2502,json1);
            String json2 = gson.toJson(new Version1_1());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2503,json2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2500,json1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2501,json2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedClassesSerialization_literalMutation3680() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedClassesSerialization_literalMutation3680");
            Gson gson = builder.setVersion(0.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2449,gson);
            String json1 = gson.toJson(new Version1());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2502,json1);
            String json2 = gson.toJson(new Version1_1());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2503,json2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2500,json1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2501,json2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedClassesSerialization_literalMutation3681() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedClassesSerialization_literalMutation3681");
            Gson gson = builder.setVersion(0.5).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2449,gson);
            String json1 = gson.toJson(new Version1());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2502,json1);
            String json2 = gson.toJson(new Version1_1());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2503,json2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2500,json1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2501,json2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedClassesDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedClassesDeserialization");
            Gson gson = builder.setVersion(2.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1217,gson);
            String json = "{\"a\":3,\"b\":4,\"c\":5}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),324,json);
            Version1 version1 = gson.fromJson(json, Version1.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2498,version1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2492,version1.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2493,version1.b);
            Version1_1 version1_1 = gson.fromJson(json, Version1_1.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2499,version1_1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2494,version1_1.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2495,version1_1.b);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2496,com.google.gson.functional.VersioningTest.C);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2497,version1_1.c);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedClassesDeserialization_literalMutation3673() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedClassesDeserialization_literalMutation3673");
            Gson gson = builder.setVersion(0.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1217,gson);
            String json = "{\"a\":3,\"b\":4,\"c\":5}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),324,json);
            Version1 version1 = gson.fromJson(json, Version1.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2498,version1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2492,version1.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2493,version1.b);
            Version1_1 version1_1 = gson.fromJson(json, Version1_1.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2499,version1_1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2494,version1_1.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2495,version1_1.b);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2496,com.google.gson.functional.VersioningTest.C);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2497,version1_1.c);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedClassesDeserialization_literalMutation3674() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedClassesDeserialization_literalMutation3674");
            Gson gson = builder.setVersion(0.5).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1217,gson);
            String json = "{\"a\":3,\"b\":4,\"c\":5}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),324,json);
            Version1 version1 = gson.fromJson(json, Version1.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2498,version1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2492,version1.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2493,version1.b);
            Version1_1 version1_1 = gson.fromJson(json, Version1_1.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2499,version1_1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2494,version1_1.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2495,version1_1.b);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2496,com.google.gson.functional.VersioningTest.C);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2497,version1_1.c);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedClassesDeserialization_literalMutation3676() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedClassesDeserialization_literalMutation3676");
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1217,gson);
            String json = "{\"a\":3,\"b:4,\"c\":5}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),324,json);
            Version1 version1 = gson.fromJson(json, Version1.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2498,version1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2492,version1.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2493,version1.b);
            Version1_1 version1_1 = gson.fromJson(json, Version1_1.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2499,version1_1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2494,version1_1.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2495,version1_1.b);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2496,com.google.gson.functional.VersioningTest.C);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2497,version1_1.c);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedClassesDeserialization_literalMutation3677() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedClassesDeserialization_literalMutation3677");
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1217,gson);
            String json = "{\"a\":3,\"b\":4,\"c\":5}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),324,json);
            Version1 version1 = gson.fromJson(json, Version1.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2498,version1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2492,version1.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2493,version1.b);
            Version1_1 version1_1 = gson.fromJson(json, Version1_1.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2499,version1_1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2494,version1_1.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2495,version1_1.b);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2496,com.google.gson.functional.VersioningTest.C);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2497,version1_1.c);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedClassesDeserialization_literalMutation3678() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedClassesDeserialization_literalMutation3678");
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1217,gson);
            String json = "{\"a\":3,\"b\":4,\"c:5}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),324,json);
            Version1 version1 = gson.fromJson(json, Version1.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2498,version1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2492,version1.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2493,version1.b);
            Version1_1 version1_1 = gson.fromJson(json, Version1_1.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2499,version1_1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2494,version1_1.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2495,version1_1.b);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2496,com.google.gson.functional.VersioningTest.C);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2497,version1_1.c);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testIgnoreLaterVersionClassSerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIgnoreLaterVersionClassSerialization");
            Gson gson = builder.setVersion(2.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2491,gson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2490,gson.toJson(new com.google.gson.functional.VersioningTest.Version1_2()));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testIgnoreLaterVersionClassSerialization_literalMutation3669() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIgnoreLaterVersionClassSerialization_literalMutation3669");
            Gson gson = builder.setVersion(0.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2491,gson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2490,gson.toJson(new com.google.gson.functional.VersioningTest.Version1_2()));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testIgnoreLaterVersionClassSerialization_literalMutation3670() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIgnoreLaterVersionClassSerialization_literalMutation3670");
            Gson gson = builder.setVersion(0.5).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2491,gson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2490,gson.toJson(new com.google.gson.functional.VersioningTest.Version1_2()));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testIgnoreLaterVersionClassDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIgnoreLaterVersionClassDeserialization");
            Gson gson = builder.setVersion(2.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),348,gson);
            String json = "{\"a\":3,\"b\":4,\"c\":5,\"d\":6}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),884,json);
            Version1_2 version1_2 = gson.fromJson(json, Version1_2.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2489,version1_2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2488,version1_2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testIgnoreLaterVersionClassDeserialization_literalMutation3662() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIgnoreLaterVersionClassDeserialization_literalMutation3662");
            Gson gson = builder.setVersion(0.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),348,gson);
            String json = "{\"a\":3,\"b\":4,\"c\":5,\"d\":6}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),884,json);
            Version1_2 version1_2 = gson.fromJson(json, Version1_2.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2489,version1_2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2488,version1_2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testIgnoreLaterVersionClassDeserialization_literalMutation3663() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIgnoreLaterVersionClassDeserialization_literalMutation3663");
            Gson gson = builder.setVersion(0.5).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),348,gson);
            String json = "{\"a\":3,\"b\":4,\"c\":5,\"d\":6}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),884,json);
            Version1_2 version1_2 = gson.fromJson(json, Version1_2.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2489,version1_2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2488,version1_2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testIgnoreLaterVersionClassDeserialization_literalMutation3665() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIgnoreLaterVersionClassDeserialization_literalMutation3665");
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),348,gson);
            String json = "{\"a\":3,\"b\":4,½c\":5,\"d\":6}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),884,json);
            Version1_2 version1_2 = gson.fromJson(json, Version1_2.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2489,version1_2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2488,version1_2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testIgnoreLaterVersionClassDeserialization_literalMutation3666() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIgnoreLaterVersionClassDeserialization_literalMutation3666");
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),348,gson);
            String json = "{\"a\":3,\"b\":4,\"c\":5,\"d\":6}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),884,json);
            Version1_2 version1_2 = gson.fromJson(json, Version1_2.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2489,version1_2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2488,version1_2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testIgnoreLaterVersionClassDeserialization_literalMutation3667() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIgnoreLaterVersionClassDeserialization_literalMutation3667");
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),348,gson);
            String json = "{\"a\":3,\"b\"4,\"c\":5,\"d\":6}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),884,json);
            Version1_2 version1_2 = gson.fromJson(json, Version1_2.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2489,version1_2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2488,version1_2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonWithUnversionedClassesSerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonWithUnversionedClassesSerialization");
            Gson gson = builder.setVersion(2.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1033,gson);
            TestTypes.BagOfPrimitives target = new TestTypes.BagOfPrimitives(10 , 20 , false , "stringValue");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2534,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2532,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2533,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonWithUnversionedClassesSerialization_literalMutation3733() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonWithUnversionedClassesSerialization_literalMutation3733");
            Gson gson = builder.setVersion(0.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1033,gson);
            TestTypes.BagOfPrimitives target = new TestTypes.BagOfPrimitives(10 , 20 , false , "stringValue");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2534,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2532,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2533,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonWithUnversionedClassesSerialization_literalMutation3734() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonWithUnversionedClassesSerialization_literalMutation3734");
            Gson gson = builder.setVersion(0.5).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1033,gson);
            TestTypes.BagOfPrimitives target = new TestTypes.BagOfPrimitives(10 , 20 , false , "stringValue");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2534,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2532,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2533,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonWithUnversionedClassesSerialization_literalMutation3736() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonWithUnversionedClassesSerialization_literalMutation3736");
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1033,gson);
            TestTypes.BagOfPrimitives target = new TestTypes.BagOfPrimitives(9 , 20 , false , "stringValue");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2534,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2532,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2533,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonWithUnversionedClassesSerialization_literalMutation3737() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonWithUnversionedClassesSerialization_literalMutation3737");
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1033,gson);
            TestTypes.BagOfPrimitives target = new TestTypes.BagOfPrimitives(5 , 20 , false , "stringValue");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2534,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2532,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2533,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonWithUnversionedClassesSerialization_literalMutation3738() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonWithUnversionedClassesSerialization_literalMutation3738");
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1033,gson);
            TestTypes.BagOfPrimitives target = new TestTypes.BagOfPrimitives(20 , 20 , false , "stringValue");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2534,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2532,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2533,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonWithUnversionedClassesSerialization_literalMutation3739() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonWithUnversionedClassesSerialization_literalMutation3739");
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1033,gson);
            TestTypes.BagOfPrimitives target = new TestTypes.BagOfPrimitives(11 , 20 , false , "stringValue");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2534,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2532,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2533,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonWithUnversionedClassesSerialization_literalMutation3741() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonWithUnversionedClassesSerialization_literalMutation3741");
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1033,gson);
            TestTypes.BagOfPrimitives target = new TestTypes.BagOfPrimitives(10 , 19 , false , "stringValue");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2534,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2532,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2533,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonWithUnversionedClassesSerialization_literalMutation3742() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonWithUnversionedClassesSerialization_literalMutation3742");
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1033,gson);
            TestTypes.BagOfPrimitives target = new TestTypes.BagOfPrimitives(10 , 10 , false , "stringValue");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2534,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2532,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2533,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonWithUnversionedClassesSerialization_literalMutation3743() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonWithUnversionedClassesSerialization_literalMutation3743");
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1033,gson);
            TestTypes.BagOfPrimitives target = new TestTypes.BagOfPrimitives(10 , 40 , false , "stringValue");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2534,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2532,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2533,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonWithUnversionedClassesSerialization_literalMutation3744() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonWithUnversionedClassesSerialization_literalMutation3744");
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1033,gson);
            TestTypes.BagOfPrimitives target = new TestTypes.BagOfPrimitives(10 , 21 , false , "stringValue");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2534,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2532,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2533,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonWithUnversionedClassesSerialization_literalMutation3746() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonWithUnversionedClassesSerialization_literalMutation3746");
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1033,gson);
            TestTypes.BagOfPrimitives target = new TestTypes.BagOfPrimitives(10 , 20 , true , "stringValue");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2534,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2532,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2533,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonWithUnversionedClassesSerialization_literalMutation3747() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonWithUnversionedClassesSerialization_literalMutation3747");
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1033,gson);
            TestTypes.BagOfPrimitives target = new TestTypes.BagOfPrimitives(10 , 20 , false , "stringVaue");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2534,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2532,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2533,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonWithUnversionedClassesSerialization_literalMutation3748() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonWithUnversionedClassesSerialization_literalMutation3748");
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1033,gson);
            TestTypes.BagOfPrimitives target = new TestTypes.BagOfPrimitives(10 , 20 , false , "strin¹gValue");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2534,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2532,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2533,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonWithUnversionedClassesSerialization_literalMutation3749() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonWithUnversionedClassesSerialization_literalMutation3749");
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1033,gson);
            TestTypes.BagOfPrimitives target = new TestTypes.BagOfPrimitives(10 , 20 , false , "strigValue");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2534,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2532,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2533,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonWithUnversionedClassesDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonWithUnversionedClassesDeserialization");
            Gson gson = builder.setVersion(2.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2528,gson);
            String json = "{\"longValue\":10,\"intValue\":20,\"booleanValue\":false}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2529,json);
            TestTypes.BagOfPrimitives expected = new TestTypes.BagOfPrimitives();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2530,expected);
            expected.longValue = 10;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2525,expected.longValue);
            expected.intValue = 20;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2526,expected.intValue);
            expected.booleanValue = false;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2527,expected.booleanValue);
            TestTypes.BagOfPrimitives actual = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2531,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2523,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2524,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonWithUnversionedClassesDeserialization_literalMutation3715() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonWithUnversionedClassesDeserialization_literalMutation3715");
            Gson gson = builder.setVersion(0.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2528,gson);
            String json = "{\"longValue\":10,\"intValue\":20,\"booleanValue\":false}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2529,json);
            TestTypes.BagOfPrimitives expected = new TestTypes.BagOfPrimitives();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2530,expected);
            expected.longValue = 10;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2525,expected.longValue);
            expected.intValue = 20;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2526,expected.intValue);
            expected.booleanValue = false;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2527,expected.booleanValue);
            TestTypes.BagOfPrimitives actual = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2531,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2523,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2524,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonWithUnversionedClassesDeserialization_literalMutation3716() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonWithUnversionedClassesDeserialization_literalMutation3716");
            Gson gson = builder.setVersion(0.5).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2528,gson);
            String json = "{\"longValue\":10,\"intValue\":20,\"booleanValue\":false}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2529,json);
            TestTypes.BagOfPrimitives expected = new TestTypes.BagOfPrimitives();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2530,expected);
            expected.longValue = 10;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2525,expected.longValue);
            expected.intValue = 20;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2526,expected.intValue);
            expected.booleanValue = false;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2527,expected.booleanValue);
            TestTypes.BagOfPrimitives actual = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2531,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2523,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2524,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonWithUnversionedClassesDeserialization_literalMutation3718() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonWithUnversionedClassesDeserialization_literalMutation3718");
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2528,gson);
            String json = "{\"longValue\":10,\"intValue\":20,\"booleanValqe\":false}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2529,json);
            TestTypes.BagOfPrimitives expected = new TestTypes.BagOfPrimitives();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2530,expected);
            expected.longValue = 10;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2525,expected.longValue);
            expected.intValue = 20;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2526,expected.intValue);
            expected.booleanValue = false;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2527,expected.booleanValue);
            TestTypes.BagOfPrimitives actual = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2531,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2523,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2524,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonWithUnversionedClassesDeserialization_literalMutation3719() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonWithUnversionedClassesDeserialization_literalMutation3719");
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2528,gson);
            String json = "{\"longValue\":10,\"intValue\":20,\"booleanValue\":false}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2529,json);
            TestTypes.BagOfPrimitives expected = new TestTypes.BagOfPrimitives();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2530,expected);
            expected.longValue = 10;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2525,expected.longValue);
            expected.intValue = 20;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2526,expected.intValue);
            expected.booleanValue = false;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2527,expected.booleanValue);
            TestTypes.BagOfPrimitives actual = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2531,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2523,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2524,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonWithUnversionedClassesDeserialization_literalMutation3720() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonWithUnversionedClassesDeserialization_literalMutation3720");
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2528,gson);
            String json = "{\"longalue\":10,\"intValue\":20,\"booleanValue\":false}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2529,json);
            TestTypes.BagOfPrimitives expected = new TestTypes.BagOfPrimitives();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2530,expected);
            expected.longValue = 10;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2525,expected.longValue);
            expected.intValue = 20;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2526,expected.intValue);
            expected.booleanValue = false;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2527,expected.booleanValue);
            TestTypes.BagOfPrimitives actual = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2531,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2523,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2524,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonWithUnversionedClassesDeserialization_literalMutation3721() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonWithUnversionedClassesDeserialization_literalMutation3721");
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2528,gson);
            String json = "{\"longValue\":10,\"intValue\":20,\"booleanValue\":false}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2529,json);
            TestTypes.BagOfPrimitives expected = new TestTypes.BagOfPrimitives();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2530,expected);
            expected.longValue = 9;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2525,expected.longValue);
            expected.intValue = 20;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2526,expected.intValue);
            expected.booleanValue = false;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2527,expected.booleanValue);
            TestTypes.BagOfPrimitives actual = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2531,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2523,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2524,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonWithUnversionedClassesDeserialization_literalMutation3722() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonWithUnversionedClassesDeserialization_literalMutation3722");
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2528,gson);
            String json = "{\"longValue\":10,\"intValue\":20,\"booleanValue\":false}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2529,json);
            TestTypes.BagOfPrimitives expected = new TestTypes.BagOfPrimitives();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2530,expected);
            expected.longValue = 5;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2525,expected.longValue);
            expected.intValue = 20;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2526,expected.intValue);
            expected.booleanValue = false;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2527,expected.booleanValue);
            TestTypes.BagOfPrimitives actual = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2531,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2523,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2524,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonWithUnversionedClassesDeserialization_literalMutation3723() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonWithUnversionedClassesDeserialization_literalMutation3723");
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2528,gson);
            String json = "{\"longValue\":10,\"intValue\":20,\"booleanValue\":false}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2529,json);
            TestTypes.BagOfPrimitives expected = new TestTypes.BagOfPrimitives();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2530,expected);
            expected.longValue = 20;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2525,expected.longValue);
            expected.intValue = 20;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2526,expected.intValue);
            expected.booleanValue = false;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2527,expected.booleanValue);
            TestTypes.BagOfPrimitives actual = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2531,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2523,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2524,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonWithUnversionedClassesDeserialization_literalMutation3724() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonWithUnversionedClassesDeserialization_literalMutation3724");
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2528,gson);
            String json = "{\"longValue\":10,\"intValue\":20,\"booleanValue\":false}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2529,json);
            TestTypes.BagOfPrimitives expected = new TestTypes.BagOfPrimitives();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2530,expected);
            expected.longValue = 11;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2525,expected.longValue);
            expected.intValue = 20;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2526,expected.intValue);
            expected.booleanValue = false;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2527,expected.booleanValue);
            TestTypes.BagOfPrimitives actual = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2531,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2523,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2524,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonWithUnversionedClassesDeserialization_literalMutation3726() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonWithUnversionedClassesDeserialization_literalMutation3726");
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2528,gson);
            String json = "{\"longValue\":10,\"intValue\":20,\"booleanValue\":false}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2529,json);
            TestTypes.BagOfPrimitives expected = new TestTypes.BagOfPrimitives();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2530,expected);
            expected.longValue = 10;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2525,expected.longValue);
            expected.intValue = 19;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2526,expected.intValue);
            expected.booleanValue = false;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2527,expected.booleanValue);
            TestTypes.BagOfPrimitives actual = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2531,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2523,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2524,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonWithUnversionedClassesDeserialization_literalMutation3727() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonWithUnversionedClassesDeserialization_literalMutation3727");
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2528,gson);
            String json = "{\"longValue\":10,\"intValue\":20,\"booleanValue\":false}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2529,json);
            TestTypes.BagOfPrimitives expected = new TestTypes.BagOfPrimitives();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2530,expected);
            expected.longValue = 10;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2525,expected.longValue);
            expected.intValue = 10;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2526,expected.intValue);
            expected.booleanValue = false;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2527,expected.booleanValue);
            TestTypes.BagOfPrimitives actual = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2531,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2523,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2524,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonWithUnversionedClassesDeserialization_literalMutation3728() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonWithUnversionedClassesDeserialization_literalMutation3728");
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2528,gson);
            String json = "{\"longValue\":10,\"intValue\":20,\"booleanValue\":false}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2529,json);
            TestTypes.BagOfPrimitives expected = new TestTypes.BagOfPrimitives();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2530,expected);
            expected.longValue = 10;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2525,expected.longValue);
            expected.intValue = 40;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2526,expected.intValue);
            expected.booleanValue = false;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2527,expected.booleanValue);
            TestTypes.BagOfPrimitives actual = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2531,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2523,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2524,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonWithUnversionedClassesDeserialization_literalMutation3729() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonWithUnversionedClassesDeserialization_literalMutation3729");
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2528,gson);
            String json = "{\"longValue\":10,\"intValue\":20,\"booleanValue\":false}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2529,json);
            TestTypes.BagOfPrimitives expected = new TestTypes.BagOfPrimitives();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2530,expected);
            expected.longValue = 10;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2525,expected.longValue);
            expected.intValue = 21;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2526,expected.intValue);
            expected.booleanValue = false;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2527,expected.booleanValue);
            TestTypes.BagOfPrimitives actual = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2531,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2523,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2524,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonWithUnversionedClassesDeserialization_literalMutation3731() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonWithUnversionedClassesDeserialization_literalMutation3731");
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2528,gson);
            String json = "{\"longValue\":10,\"intValue\":20,\"booleanValue\":false}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2529,json);
            TestTypes.BagOfPrimitives expected = new TestTypes.BagOfPrimitives();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2530,expected);
            expected.longValue = 10;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2525,expected.longValue);
            expected.intValue = 20;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2526,expected.intValue);
            expected.booleanValue = true;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2527,expected.booleanValue);
            TestTypes.BagOfPrimitives actual = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2531,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2523,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2524,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonMixingSinceAndUntilSerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonMixingSinceAndUntilSerialization");
            Gson gson = builder.setVersion(2.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2522,gson);
            SinceUntilMixing target = new SinceUntilMixing();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),423,target);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1101,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2515,json.contains(("\"b\":" + (com.google.gson.functional.VersioningTest.B))));
            gson = builder.setVersion(1.2).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2518,gson);
            json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2519,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2516,json.contains(("\"b\":" + (com.google.gson.functional.VersioningTest.B))));
            gson = builder.setVersion(1.3).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2520,gson);
            json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2521,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2517,json.contains(("\"b\":" + (com.google.gson.functional.VersioningTest.B))));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonMixingSinceAndUntilSerialization_literalMutation3701() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonMixingSinceAndUntilSerialization_literalMutation3701");
            Gson gson = builder.setVersion(0.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2522,gson);
            SinceUntilMixing target = new SinceUntilMixing();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),423,target);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1101,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2515,json.contains(("\"b\":" + (com.google.gson.functional.VersioningTest.B))));
            gson = builder.setVersion(1.2).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2518,gson);
            json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2519,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2516,json.contains(("\"b\":" + (com.google.gson.functional.VersioningTest.B))));
            gson = builder.setVersion(1.3).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2520,gson);
            json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2521,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2517,json.contains(("\"b\":" + (com.google.gson.functional.VersioningTest.B))));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonMixingSinceAndUntilSerialization_literalMutation3702() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonMixingSinceAndUntilSerialization_literalMutation3702");
            Gson gson = builder.setVersion(0.5).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2522,gson);
            SinceUntilMixing target = new SinceUntilMixing();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),423,target);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1101,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2515,json.contains(("\"b\":" + (com.google.gson.functional.VersioningTest.B))));
            gson = builder.setVersion(1.2).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2518,gson);
            json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2519,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2516,json.contains(("\"b\":" + (com.google.gson.functional.VersioningTest.B))));
            gson = builder.setVersion(1.3).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2520,gson);
            json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2521,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2517,json.contains(("\"b\":" + (com.google.gson.functional.VersioningTest.B))));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonMixingSinceAndUntilSerialization_literalMutation3704() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonMixingSinceAndUntilSerialization_literalMutation3704");
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2522,gson);
            SinceUntilMixing target = new SinceUntilMixing();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),423,target);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1101,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2515,json.contains(("\"b\":" + (com.google.gson.functional.VersioningTest.B))));
            gson = builder.setVersion(0.6).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2518,gson);
            json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2519,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2516,json.contains(("\"b\":" + (com.google.gson.functional.VersioningTest.B))));
            gson = builder.setVersion(1.3).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2520,gson);
            json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2521,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2517,json.contains(("\"b\":" + (com.google.gson.functional.VersioningTest.B))));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonMixingSinceAndUntilSerialization_literalMutation3705() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonMixingSinceAndUntilSerialization_literalMutation3705");
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2522,gson);
            SinceUntilMixing target = new SinceUntilMixing();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),423,target);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1101,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2515,json.contains(("\"b\":" + (com.google.gson.functional.VersioningTest.B))));
            gson = builder.setVersion(2.4).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2518,gson);
            json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2519,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2516,json.contains(("\"b\":" + (com.google.gson.functional.VersioningTest.B))));
            gson = builder.setVersion(1.3).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2520,gson);
            json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2521,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2517,json.contains(("\"b\":" + (com.google.gson.functional.VersioningTest.B))));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonMixingSinceAndUntilSerialization_literalMutation3706() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonMixingSinceAndUntilSerialization_literalMutation3706");
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2522,gson);
            SinceUntilMixing target = new SinceUntilMixing();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),423,target);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1101,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2515,json.contains(("\"b\":" + (com.google.gson.functional.VersioningTest.B))));
            gson = builder.setVersion(0.19999999999999996).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2518,gson);
            json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2519,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2516,json.contains(("\"b\":" + (com.google.gson.functional.VersioningTest.B))));
            gson = builder.setVersion(1.3).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2520,gson);
            json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2521,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2517,json.contains(("\"b\":" + (com.google.gson.functional.VersioningTest.B))));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonMixingSinceAndUntilSerialization_literalMutation3707() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonMixingSinceAndUntilSerialization_literalMutation3707");
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2522,gson);
            SinceUntilMixing target = new SinceUntilMixing();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),423,target);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1101,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2515,json.contains(("\"b\":" + (com.google.gson.functional.VersioningTest.B))));
            gson = builder.setVersion(2.2).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2518,gson);
            json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2519,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2516,json.contains(("\"b\":" + (com.google.gson.functional.VersioningTest.B))));
            gson = builder.setVersion(1.3).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2520,gson);
            json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2521,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2517,json.contains(("\"b\":" + (com.google.gson.functional.VersioningTest.B))));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonMixingSinceAndUntilSerialization_literalMutation3709() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonMixingSinceAndUntilSerialization_literalMutation3709");
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2522,gson);
            SinceUntilMixing target = new SinceUntilMixing();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),423,target);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1101,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2515,json.contains(("\"b\":" + (com.google.gson.functional.VersioningTest.B))));
            gson = builder.setVersion(1.2).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2518,gson);
            json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2519,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2516,json.contains(("\"b\":" + (com.google.gson.functional.VersioningTest.B))));
            gson = builder.setVersion(2.3).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2520,gson);
            json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2521,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2517,json.contains(("\"b\":" + (com.google.gson.functional.VersioningTest.B))));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonMixingSinceAndUntilSerialization_literalMutation3710() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonMixingSinceAndUntilSerialization_literalMutation3710");
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2522,gson);
            SinceUntilMixing target = new SinceUntilMixing();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),423,target);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1101,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2515,json.contains(("\"b\":" + (com.google.gson.functional.VersioningTest.B))));
            gson = builder.setVersion(1.2).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2518,gson);
            json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2519,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2516,json.contains(("\"b\":" + (com.google.gson.functional.VersioningTest.B))));
            gson = builder.setVersion(0.30000000000000004).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2520,gson);
            json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2521,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2517,json.contains(("\"b\":" + (com.google.gson.functional.VersioningTest.B))));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonMixingSinceAndUntilSerialization_literalMutation3711() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonMixingSinceAndUntilSerialization_literalMutation3711");
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2522,gson);
            SinceUntilMixing target = new SinceUntilMixing();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),423,target);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1101,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2515,json.contains(("\"b\":" + (com.google.gson.functional.VersioningTest.B))));
            gson = builder.setVersion(1.2).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2518,gson);
            json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2519,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2516,json.contains(("\"b\":" + (com.google.gson.functional.VersioningTest.B))));
            gson = builder.setVersion(0.65).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2520,gson);
            json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2521,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2517,json.contains(("\"b\":" + (com.google.gson.functional.VersioningTest.B))));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonMixingSinceAndUntilSerialization_literalMutation3712() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonMixingSinceAndUntilSerialization_literalMutation3712");
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2522,gson);
            SinceUntilMixing target = new SinceUntilMixing();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),423,target);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1101,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2515,json.contains(("\"b\":" + (com.google.gson.functional.VersioningTest.B))));
            gson = builder.setVersion(1.2).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2518,gson);
            json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2519,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2516,json.contains(("\"b\":" + (com.google.gson.functional.VersioningTest.B))));
            gson = builder.setVersion(2.6).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2520,gson);
            json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2521,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2517,json.contains(("\"b\":" + (com.google.gson.functional.VersioningTest.B))));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonMixingSinceAndUntilDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonMixingSinceAndUntilDeserialization");
            String json = "{\"a\":5,\"b^:6}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1336,json);
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1543,gson);
            SinceUntilMixing result = gson.fromJson(json, SinceUntilMixing.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1544,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2504,result.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2505,com.google.gson.functional.VersioningTest.B);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2506,result.b);
            gson = builder.setVersion(1.2).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2512,gson);
            result = gson.fromJson(json, SinceUntilMixing.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2513,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2507,result.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2508,result.b);
            gson = builder.setVersion(1.3).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2514,gson);
            result = gson.fromJson(json, SinceUntilMixing.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),25,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2509,result.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2510,com.google.gson.functional.VersioningTest.B);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2511,result.b);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonMixingSinceAndUntilDeserialization_literalMutation3684() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonMixingSinceAndUntilDeserialization_literalMutation3684");
            String json = "{\"a\":5,\"b\":6}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1336,json);
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1543,gson);
            SinceUntilMixing result = gson.fromJson(json, SinceUntilMixing.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1544,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2504,result.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2505,com.google.gson.functional.VersioningTest.B);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2506,result.b);
            gson = builder.setVersion(1.2).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2512,gson);
            result = gson.fromJson(json, SinceUntilMixing.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2513,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2507,result.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2508,result.b);
            gson = builder.setVersion(1.3).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2514,gson);
            result = gson.fromJson(json, SinceUntilMixing.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),25,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2509,result.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2510,com.google.gson.functional.VersioningTest.B);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2511,result.b);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonMixingSinceAndUntilDeserialization_literalMutation3685() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonMixingSinceAndUntilDeserialization_literalMutation3685");
            String json = "{\"\":5,\"b\":6}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1336,json);
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1543,gson);
            SinceUntilMixing result = gson.fromJson(json, SinceUntilMixing.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1544,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2504,result.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2505,com.google.gson.functional.VersioningTest.B);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2506,result.b);
            gson = builder.setVersion(1.2).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2512,gson);
            result = gson.fromJson(json, SinceUntilMixing.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2513,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2507,result.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2508,result.b);
            gson = builder.setVersion(1.3).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2514,gson);
            result = gson.fromJson(json, SinceUntilMixing.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),25,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2509,result.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2510,com.google.gson.functional.VersioningTest.B);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2511,result.b);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonMixingSinceAndUntilDeserialization_literalMutation3686() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonMixingSinceAndUntilDeserialization_literalMutation3686");
            String json = "{\"a\":5,\"b\":6}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1336,json);
            Gson gson = builder.setVersion(2.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1543,gson);
            SinceUntilMixing result = gson.fromJson(json, SinceUntilMixing.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1544,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2504,result.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2505,com.google.gson.functional.VersioningTest.B);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2506,result.b);
            gson = builder.setVersion(1.2).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2512,gson);
            result = gson.fromJson(json, SinceUntilMixing.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2513,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2507,result.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2508,result.b);
            gson = builder.setVersion(1.3).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2514,gson);
            result = gson.fromJson(json, SinceUntilMixing.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),25,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2509,result.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2510,com.google.gson.functional.VersioningTest.B);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2511,result.b);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonMixingSinceAndUntilDeserialization_literalMutation3687() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonMixingSinceAndUntilDeserialization_literalMutation3687");
            String json = "{\"a\":5,\"b\":6}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1336,json);
            Gson gson = builder.setVersion(0.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1543,gson);
            SinceUntilMixing result = gson.fromJson(json, SinceUntilMixing.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1544,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2504,result.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2505,com.google.gson.functional.VersioningTest.B);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2506,result.b);
            gson = builder.setVersion(1.2).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2512,gson);
            result = gson.fromJson(json, SinceUntilMixing.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2513,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2507,result.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2508,result.b);
            gson = builder.setVersion(1.3).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2514,gson);
            result = gson.fromJson(json, SinceUntilMixing.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),25,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2509,result.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2510,com.google.gson.functional.VersioningTest.B);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2511,result.b);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonMixingSinceAndUntilDeserialization_literalMutation3688() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonMixingSinceAndUntilDeserialization_literalMutation3688");
            String json = "{\"a\":5,\"b\":6}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1336,json);
            Gson gson = builder.setVersion(0.5).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1543,gson);
            SinceUntilMixing result = gson.fromJson(json, SinceUntilMixing.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1544,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2504,result.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2505,com.google.gson.functional.VersioningTest.B);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2506,result.b);
            gson = builder.setVersion(1.2).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2512,gson);
            result = gson.fromJson(json, SinceUntilMixing.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2513,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2507,result.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2508,result.b);
            gson = builder.setVersion(1.3).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2514,gson);
            result = gson.fromJson(json, SinceUntilMixing.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),25,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2509,result.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2510,com.google.gson.functional.VersioningTest.B);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2511,result.b);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonMixingSinceAndUntilDeserialization_literalMutation3690() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonMixingSinceAndUntilDeserialization_literalMutation3690");
            String json = "{\"a\":5,\"b\":6}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1336,json);
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1543,gson);
            SinceUntilMixing result = gson.fromJson(json, SinceUntilMixing.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1544,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2504,result.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2505,com.google.gson.functional.VersioningTest.B);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2506,result.b);
            gson = builder.setVersion(0.6).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2512,gson);
            result = gson.fromJson(json, SinceUntilMixing.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2513,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2507,result.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2508,result.b);
            gson = builder.setVersion(1.3).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2514,gson);
            result = gson.fromJson(json, SinceUntilMixing.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),25,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2509,result.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2510,com.google.gson.functional.VersioningTest.B);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2511,result.b);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonMixingSinceAndUntilDeserialization_literalMutation3691() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonMixingSinceAndUntilDeserialization_literalMutation3691");
            String json = "{\"a\":5,\"b\":6}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1336,json);
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1543,gson);
            SinceUntilMixing result = gson.fromJson(json, SinceUntilMixing.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1544,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2504,result.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2505,com.google.gson.functional.VersioningTest.B);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2506,result.b);
            gson = builder.setVersion(2.4).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2512,gson);
            result = gson.fromJson(json, SinceUntilMixing.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2513,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2507,result.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2508,result.b);
            gson = builder.setVersion(1.3).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2514,gson);
            result = gson.fromJson(json, SinceUntilMixing.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),25,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2509,result.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2510,com.google.gson.functional.VersioningTest.B);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2511,result.b);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonMixingSinceAndUntilDeserialization_literalMutation3692() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonMixingSinceAndUntilDeserialization_literalMutation3692");
            String json = "{\"a\":5,\"b\":6}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1336,json);
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1543,gson);
            SinceUntilMixing result = gson.fromJson(json, SinceUntilMixing.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1544,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2504,result.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2505,com.google.gson.functional.VersioningTest.B);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2506,result.b);
            gson = builder.setVersion(0.19999999999999996).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2512,gson);
            result = gson.fromJson(json, SinceUntilMixing.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2513,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2507,result.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2508,result.b);
            gson = builder.setVersion(1.3).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2514,gson);
            result = gson.fromJson(json, SinceUntilMixing.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),25,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2509,result.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2510,com.google.gson.functional.VersioningTest.B);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2511,result.b);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonMixingSinceAndUntilDeserialization_literalMutation3693() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonMixingSinceAndUntilDeserialization_literalMutation3693");
            String json = "{\"a\":5,\"b\":6}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1336,json);
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1543,gson);
            SinceUntilMixing result = gson.fromJson(json, SinceUntilMixing.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1544,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2504,result.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2505,com.google.gson.functional.VersioningTest.B);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2506,result.b);
            gson = builder.setVersion(2.2).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2512,gson);
            result = gson.fromJson(json, SinceUntilMixing.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2513,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2507,result.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2508,result.b);
            gson = builder.setVersion(1.3).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2514,gson);
            result = gson.fromJson(json, SinceUntilMixing.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),25,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2509,result.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2510,com.google.gson.functional.VersioningTest.B);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2511,result.b);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonMixingSinceAndUntilDeserialization_literalMutation3695() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonMixingSinceAndUntilDeserialization_literalMutation3695");
            String json = "{\"a\":5,\"b\":6}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1336,json);
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1543,gson);
            SinceUntilMixing result = gson.fromJson(json, SinceUntilMixing.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1544,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2504,result.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2505,com.google.gson.functional.VersioningTest.B);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2506,result.b);
            gson = builder.setVersion(1.2).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2512,gson);
            result = gson.fromJson(json, SinceUntilMixing.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2513,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2507,result.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2508,result.b);
            gson = builder.setVersion(2.3).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2514,gson);
            result = gson.fromJson(json, SinceUntilMixing.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),25,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2509,result.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2510,com.google.gson.functional.VersioningTest.B);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2511,result.b);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonMixingSinceAndUntilDeserialization_literalMutation3696() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonMixingSinceAndUntilDeserialization_literalMutation3696");
            String json = "{\"a\":5,\"b\":6}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1336,json);
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1543,gson);
            SinceUntilMixing result = gson.fromJson(json, SinceUntilMixing.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1544,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2504,result.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2505,com.google.gson.functional.VersioningTest.B);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2506,result.b);
            gson = builder.setVersion(1.2).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2512,gson);
            result = gson.fromJson(json, SinceUntilMixing.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2513,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2507,result.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2508,result.b);
            gson = builder.setVersion(0.30000000000000004).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2514,gson);
            result = gson.fromJson(json, SinceUntilMixing.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),25,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2509,result.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2510,com.google.gson.functional.VersioningTest.B);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2511,result.b);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonMixingSinceAndUntilDeserialization_literalMutation3697() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonMixingSinceAndUntilDeserialization_literalMutation3697");
            String json = "{\"a\":5,\"b\":6}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1336,json);
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1543,gson);
            SinceUntilMixing result = gson.fromJson(json, SinceUntilMixing.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1544,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2504,result.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2505,com.google.gson.functional.VersioningTest.B);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2506,result.b);
            gson = builder.setVersion(1.2).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2512,gson);
            result = gson.fromJson(json, SinceUntilMixing.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2513,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2507,result.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2508,result.b);
            gson = builder.setVersion(0.65).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2514,gson);
            result = gson.fromJson(json, SinceUntilMixing.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),25,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2509,result.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2510,com.google.gson.functional.VersioningTest.B);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2511,result.b);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testVersionedGsonMixingSinceAndUntilDeserialization_literalMutation3698() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testVersionedGsonMixingSinceAndUntilDeserialization_literalMutation3698");
            String json = "{\"a\":5,\"b\":6}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1336,json);
            Gson gson = builder.setVersion(1.0).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1543,gson);
            SinceUntilMixing result = gson.fromJson(json, SinceUntilMixing.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1544,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2504,result.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2505,com.google.gson.functional.VersioningTest.B);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2506,result.b);
            gson = builder.setVersion(1.2).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2512,gson);
            result = gson.fromJson(json, SinceUntilMixing.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2513,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2507,result.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2508,result.b);
            gson = builder.setVersion(2.6).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2514,gson);
            result = gson.fromJson(json, SinceUntilMixing.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),25,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2509,result.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2510,com.google.gson.functional.VersioningTest.B);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2511,result.b);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    private static class Version1 {
        @Until(value = 1.3)
        int a = VersioningTest.A;

        @Since(value = 1.0)
        int b = VersioningTest.B;
    }

    private static class Version1_1 extends Version1 {
        @Since(value = 1.1)
        int c = VersioningTest.C;
    }

    @Since(value = 1.2)
    private static class Version1_2 extends Version1_1 {
        @SuppressWarnings(value = "unused")
        int d = VersioningTest.D;
    }

    private static class SinceUntilMixing {
        int a = VersioningTest.A;

        @Since(value = 1.1)
        @Until(value = 1.3)
        int b = VersioningTest.B;
    }
}

