package org.eclipse.jgit.transport;

import org.eclipse.jgit.util.FS;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.InputStream;
import org.eclipse.jgit.internal.JGitText;
import org.eclipse.jgit.errors.NotSupportedException;
import org.eclipse.jgit.lib.Repository;
import java.util.Set;
import org.eclipse.jgit.errors.TransportException;

class TransportBundleFile extends Transport implements TransportBundle {
    static final TransportProtocol PROTO_BUNDLE = new TransportProtocol() {
        private final String[] schemeNames = new String[]{ "bundle" , "file" };

        private final Set<java.lang.String> schemeSet = java.util.Collections.unmodifiableSet(new java.util.LinkedHashSet<java.lang.String>(java.util.Arrays.asList(schemeNames)));

        @Override
        public String getName() {
            return JGitText.get().transportProtoBundleFile;
        }

        public Set<java.lang.String> getSchemes() {
            return schemeSet;
        }

        @Override
        public boolean canHandle(URIish uri, Repository local, String remoteName) {
            if (((((((uri.getPath()) == null) || ((uri.getPort()) > 0)) || ((uri.getUser()) != null)) || ((uri.getPass()) != null)) || ((uri.getHost()) != null)) || (((uri.getScheme()) != null) && (!(getSchemes().contains(uri.getScheme())))))
                return false;
            
            return true;
        }

        @Override
        public Transport open(URIish uri, Repository local, String remoteName) throws NotSupportedException, TransportException {
            if ("bundle".equals(uri.getScheme())) {
                File path = local.getFS().resolve(new File("."), uri.getPath());
                return new TransportBundleFile(local , uri , path);
            } 
            return TransportLocal.PROTO_LOCAL.open(uri, local, remoteName);
        }

        public Transport open(URIish uri) throws NotSupportedException, TransportException {
            if ("bundle".equals(uri.getScheme())) {
                File path = FS.DETECTED.resolve(new File("."), uri.getPath());
                return new TransportBundleFile(uri , path);
            } 
            return TransportLocal.PROTO_LOCAL.open(uri);
        }
    };

    private final File bundle;

    TransportBundleFile(Repository local ,URIish uri ,File bundlePath) {
        super(local, uri);
        bundle = bundlePath;
    }

    public TransportBundleFile(URIish uri ,File bundlePath) {
        super(uri);
        bundle = bundlePath;
    }

    @Override
    public FetchConnection openFetch() throws NotSupportedException, TransportException {
        final InputStream src;
        try {
            src = new FileInputStream(bundle);
        } catch (final FileNotFoundException e) {
            throw new TransportException(uri , JGitText.get().notFound);
        }
        return new BundleFetchConnection(this , src);
    }

    @Override
    public PushConnection openPush() throws NotSupportedException {
        throw new NotSupportedException(JGitText.get().pushIsNotSupportedForBundleTransport);
    }

    @Override
    public void close() {
    }
}

