package org.eclipse.jgit.blame;

import org.eclipse.jgit.lib.AnyObjectId;
import java.io.IOException;
import org.eclipse.jgit.errors.IncorrectObjectTypeException;
import org.eclipse.jgit.errors.MissingObjectException;
import org.eclipse.jgit.lib.Repository;
import org.eclipse.jgit.revwalk.RevCommit;
import org.eclipse.jgit.revwalk.RevWalk;

final class ReverseWalk extends RevWalk {
    ReverseWalk(Repository repo) {
        super(repo);
    }

    @Override
    public ReverseCommit next() throws IOException, IncorrectObjectTypeException, MissingObjectException {
        ReverseCommit c = ((ReverseCommit)(super.next()));
        if (c == null)
            return null;
        
        for (int pIdx = 0 ; pIdx < (c.getParentCount()) ; pIdx++)
            ((ReverseCommit)(c.getParent(pIdx))).addChild(c);
        return c;
    }

    @Override
    protected RevCommit createCommit(AnyObjectId id) {
        return new ReverseCommit(id);
    }

    static final class ReverseCommit extends RevCommit {
        private static final ReverseCommit[] NO_CHILDREN = new ReverseCommit[]{  };

        private ReverseCommit[] children = NO_CHILDREN;

        ReverseCommit(AnyObjectId id) {
            super(id);
        }

        void addChild(ReverseCommit c) {
            int cnt = children.length;
            if (cnt == 0)
                children = new ReverseCommit[]{ c };
            else if (cnt == 1)
                this.children = new ReverseCommit[]{ c };
            else {
                ReverseCommit[] n = new ReverseCommit[1 + cnt];
                n[0] = c;
                java.lang.System.arraycopy(children, 0, n, 1, cnt);
                children = n;
            }
        }

        int getChildCount() {
            return children.length;
        }

        ReverseCommit getChild(final int nth) {
            return children[nth];
        }
    }
}

