package org.eclipse.jgit.api;

import org.junit.Before;
import java.io.File;
import org.eclipse.jgit.api.errors.GitAPIException;
import java.io.IOException;
import org.eclipse.jgit.api.errors.JGitInternalException;
import org.eclipse.jgit.junit.RepositoryTestCase;
import org.junit.Test;

public class RmCommandTest extends RepositoryTestCase {
    private Git git;

    private static final String FILE = "test.txt";

    @Override
    @Before
    public void setUp() throws Exception {
        super.setUp();
        git = new Git(db);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),692,git);
        writeTrashFile(FILE, "Hello world");
        git.add().addFilepattern(FILE).call();
        git.commit().setMessage("Initial commit").call();
    }

    @Test(timeout = 1000)
    public void testRemove_add574() throws IOException, IllegalStateException, GitAPIException, JGitInternalException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRemove_add574");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),697,indexState(org.eclipse.jgit.junit.RepositoryTestCase.CONTENT));
            RmCommand command = git.rm();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),699,command);
            command.addFilepattern(FILE);
            command.addFilepattern(FILE);
            command.call();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),698,indexState(org.eclipse.jgit.junit.RepositoryTestCase.CONTENT));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRemove_add575() throws IOException, IllegalStateException, GitAPIException, JGitInternalException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRemove_add575");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),697,indexState(org.eclipse.jgit.junit.RepositoryTestCase.CONTENT));
            RmCommand command = git.rm();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),699,command);
            command.addFilepattern(FILE);
            command.call();
            command.call();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),698,indexState(org.eclipse.jgit.junit.RepositoryTestCase.CONTENT));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRemove_remove570() throws IOException, IllegalStateException, GitAPIException, JGitInternalException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRemove_remove570");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),697,indexState(org.eclipse.jgit.junit.RepositoryTestCase.CONTENT));
            RmCommand command = git.rm();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),699,command);
            command.call();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),698,indexState(org.eclipse.jgit.junit.RepositoryTestCase.CONTENT));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRemove_remove571() throws IOException, IllegalStateException, GitAPIException, JGitInternalException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRemove_remove571");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),697,indexState(org.eclipse.jgit.junit.RepositoryTestCase.CONTENT));
            RmCommand command = git.rm();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),699,command);
            command.addFilepattern(FILE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),698,indexState(org.eclipse.jgit.junit.RepositoryTestCase.CONTENT));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRemoveCached_add576() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRemoveCached_add576");
            File newFile = writeTrashFile("new.txt", "new");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),696,newFile);
            git.add().addFilepattern(newFile.getName()).call();
            git.add().addFilepattern(newFile.getName()).call();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),693,indexState(0));
            git.rm().setCached(true).addFilepattern(newFile.getName()).call();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),694,indexState(0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),695,newFile.exists());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRemoveCached_add577() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRemoveCached_add577");
            File newFile = writeTrashFile("new.txt", "new");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),696,newFile);
            git.add().addFilepattern(newFile.getName()).call();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),693,indexState(0));
            git.rm().setCached(true).addFilepattern(newFile.getName()).call();
            git.rm().setCached(true).addFilepattern(newFile.getName()).call();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),694,indexState(0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),695,newFile.exists());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testRemoveCached_literalMutation1000() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRemoveCached_literalMutation1000");
            File newFile = writeTrashFile("new.txt", "new");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),696,newFile);
            git.add().addFilepattern(newFile.getName()).call();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),693,indexState(0));
            git.rm().setCached(true).addFilepattern(newFile.getName()).call();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),694,indexState(0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),695,newFile.exists());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testRemoveCached_literalMutation1001() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRemoveCached_literalMutation1001");
            File newFile = writeTrashFile("new.txt", "nw");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),696,newFile);
            git.add().addFilepattern(newFile.getName()).call();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),693,indexState(0));
            git.rm().setCached(true).addFilepattern(newFile.getName()).call();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),694,indexState(0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),695,newFile.exists());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testRemove() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRemove");
            File newFile = writeTrashFile("ne\'.txt", "new");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),696,newFile);
            git.add().addFilepattern(newFile.getName()).call();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),693,indexState(0));
            git.rm().setCached(true).addFilepattern(newFile.getName()).call();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),694,indexState(0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),695,newFile.exists());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testRemoveCached() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRemoveCached");
            File newFile = writeTrashFile("new.t¥xt", "new");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),696,newFile);
            git.add().addFilepattern(newFile.getName()).call();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),693,indexState(0));
            git.rm().setCached(true).addFilepattern(newFile.getName()).call();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),694,indexState(0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),695,newFile.exists());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testRemoveCached_literalMutation998() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRemoveCached_literalMutation998");
            File newFile = writeTrashFile("newtxt", "new");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),696,newFile);
            git.add().addFilepattern(newFile.getName()).call();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),693,indexState(0));
            git.rm().setCached(true).addFilepattern(newFile.getName()).call();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),694,indexState(0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),695,newFile.exists());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testRemoveCached_literalMutation999() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRemoveCached_literalMutation999");
            File newFile = writeTrashFile("new.txt", "ëew");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),696,newFile);
            git.add().addFilepattern(newFile.getName()).call();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),693,indexState(0));
            git.rm().setCached(true).addFilepattern(newFile.getName()).call();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),694,indexState(0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),695,newFile.exists());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRemoveCached_remove572() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRemoveCached_remove572");
            File newFile = writeTrashFile("new.txt", "new");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),696,newFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),693,indexState(0));
            git.rm().setCached(true).addFilepattern(newFile.getName()).call();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),694,indexState(0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),695,newFile.exists());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRemoveCached_remove573() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRemoveCached_remove573");
            File newFile = writeTrashFile("new.txt", "new");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),696,newFile);
            git.add().addFilepattern(newFile.getName()).call();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),693,indexState(0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),694,indexState(0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),695,newFile.exists());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }
}

