package org.apache.commons.codec.binary;

import java.io.ByteArrayOutputStream;
import java.io.OutputStream;
import org.junit.Test;

/** 
 * @version $Id $
 * @since 1.4
 */
public class Base64OutputStreamTest {
    private static final byte[] CRLF = new byte[]{ ((byte)('\r')) , ((byte)('\n')) };

    private static final byte[] LF = new byte[]{ ((byte)('\n')) };

    private static final String STRING_FIXTURE = "Hello World";

    /** 
     * Test the Base64OutputStream implementation against the special NPE inducing input
     * identified in the CODEC-98 bug.
     * 
     * @throws Exception for some failure scenarios.
     */
@Test(timeout = 1000)
    public void testCodec98NPE_add15() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodec98NPE_add15");
            final byte[] codec98 = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.CODEC_98_NPE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),134,codec98);
            final byte[] codec98_1024 = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),135,codec98_1024);
            java.lang.System.arraycopy(codec98, 0, codec98_1024, 0, codec98.length);
            java.lang.System.arraycopy(codec98, 0, codec98_1024, 0, codec98.length);
            final ByteArrayOutputStream data = new ByteArrayOutputStream(1024);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),136,data);
            final Base64OutputStream stream = new Base64OutputStream(data , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),137,stream);
            stream.write(codec98_1024, 0, 1024);
            stream.close();
            final byte[] decodedBytes = data.toByteArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),138,decodedBytes);
            final String decoded = org.apache.commons.codec.binary.StringUtils.newStringUtf8(decodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),139,decoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),132,org.apache.commons.codec.binary.Base64TestData.CODEC_98_NPE_DECODED);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),133,decoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation against the special NPE inducing input
     * identified in the CODEC-98 bug.
     * 
     * @throws Exception for some failure scenarios.
     */
@Test(timeout = 1000)
    public void testCodec98NPE_add16() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodec98NPE_add16");
            final byte[] codec98 = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.CODEC_98_NPE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),134,codec98);
            final byte[] codec98_1024 = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),135,codec98_1024);
            java.lang.System.arraycopy(codec98, 0, codec98_1024, 0, codec98.length);
            final ByteArrayOutputStream data = new ByteArrayOutputStream(1024);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),136,data);
            final Base64OutputStream stream = new Base64OutputStream(data , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),137,stream);
            stream.write(codec98_1024, 0, 1024);
            stream.write(codec98_1024, 0, 1024);
            stream.close();
            final byte[] decodedBytes = data.toByteArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),138,decodedBytes);
            final String decoded = org.apache.commons.codec.binary.StringUtils.newStringUtf8(decodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),139,decoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),132,org.apache.commons.codec.binary.Base64TestData.CODEC_98_NPE_DECODED);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),133,decoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation against the special NPE inducing input
     * identified in the CODEC-98 bug.
     * 
     * @throws Exception for some failure scenarios.
     */
@Test(timeout = 1000)
    public void testCodec98NPE_add17() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodec98NPE_add17");
            final byte[] codec98 = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.CODEC_98_NPE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),134,codec98);
            final byte[] codec98_1024 = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),135,codec98_1024);
            java.lang.System.arraycopy(codec98, 0, codec98_1024, 0, codec98.length);
            final ByteArrayOutputStream data = new ByteArrayOutputStream(1024);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),136,data);
            final Base64OutputStream stream = new Base64OutputStream(data , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),137,stream);
            stream.write(codec98_1024, 0, 1024);
            stream.close();
            stream.close();
            final byte[] decodedBytes = data.toByteArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),138,decodedBytes);
            final String decoded = org.apache.commons.codec.binary.StringUtils.newStringUtf8(decodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),139,decoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),132,org.apache.commons.codec.binary.Base64TestData.CODEC_98_NPE_DECODED);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),133,decoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation against the special NPE inducing input
     * identified in the CODEC-98 bug.
     * 
     * @throws Exception for some failure scenarios.
     */
@Test
    public void testCodec98NPE_literalMutation100() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodec98NPE_literalMutation100");
            final byte[] codec98 = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.CODEC_98_NPE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),134,codec98);
            final byte[] codec98_1024 = new byte[1023];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),135,codec98_1024);
            java.lang.System.arraycopy(codec98, 0, codec98_1024, 0, codec98.length);
            final ByteArrayOutputStream data = new ByteArrayOutputStream(1024);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),136,data);
            final Base64OutputStream stream = new Base64OutputStream(data , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),137,stream);
            stream.write(codec98_1024, 0, 1024);
            stream.close();
            final byte[] decodedBytes = data.toByteArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),138,decodedBytes);
            final String decoded = org.apache.commons.codec.binary.StringUtils.newStringUtf8(decodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),139,decoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),132,org.apache.commons.codec.binary.Base64TestData.CODEC_98_NPE_DECODED);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),133,decoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation against the special NPE inducing input
     * identified in the CODEC-98 bug.
     * 
     * @throws Exception for some failure scenarios.
     */
@Test
    public void testCodec98NPE_literalMutation102() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodec98NPE_literalMutation102");
            final byte[] codec98 = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.CODEC_98_NPE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),134,codec98);
            final byte[] codec98_1024 = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),135,codec98_1024);
            java.lang.System.arraycopy(codec98, 1, codec98_1024, 0, codec98.length);
            final ByteArrayOutputStream data = new ByteArrayOutputStream(1024);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),136,data);
            final Base64OutputStream stream = new Base64OutputStream(data , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),137,stream);
            stream.write(codec98_1024, 0, 1024);
            stream.close();
            final byte[] decodedBytes = data.toByteArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),138,decodedBytes);
            final String decoded = org.apache.commons.codec.binary.StringUtils.newStringUtf8(decodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),139,decoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),132,org.apache.commons.codec.binary.Base64TestData.CODEC_98_NPE_DECODED);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),133,decoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation against the special NPE inducing input
     * identified in the CODEC-98 bug.
     * 
     * @throws Exception for some failure scenarios.
     */
@Test
    public void testCodec98NPE_literalMutation103() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodec98NPE_literalMutation103");
            final byte[] codec98 = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.CODEC_98_NPE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),134,codec98);
            final byte[] codec98_1024 = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),135,codec98_1024);
            java.lang.System.arraycopy(codec98, -1, codec98_1024, 0, codec98.length);
            final ByteArrayOutputStream data = new ByteArrayOutputStream(1024);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),136,data);
            final Base64OutputStream stream = new Base64OutputStream(data , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),137,stream);
            stream.write(codec98_1024, 0, 1024);
            stream.close();
            final byte[] decodedBytes = data.toByteArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),138,decodedBytes);
            final String decoded = org.apache.commons.codec.binary.StringUtils.newStringUtf8(decodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),139,decoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),132,org.apache.commons.codec.binary.Base64TestData.CODEC_98_NPE_DECODED);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),133,decoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation against the special NPE inducing input
     * identified in the CODEC-98 bug.
     * 
     * @throws Exception for some failure scenarios.
     */
@Test
    public void testCodec98NPE_literalMutation104() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodec98NPE_literalMutation104");
            final byte[] codec98 = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.CODEC_98_NPE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),134,codec98);
            final byte[] codec98_1024 = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),135,codec98_1024);
            java.lang.System.arraycopy(codec98, 0, codec98_1024, 0, codec98.length);
            final ByteArrayOutputStream data = new ByteArrayOutputStream(1024);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),136,data);
            final Base64OutputStream stream = new Base64OutputStream(data , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),137,stream);
            stream.write(codec98_1024, 0, 1024);
            stream.close();
            final byte[] decodedBytes = data.toByteArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),138,decodedBytes);
            final String decoded = org.apache.commons.codec.binary.StringUtils.newStringUtf8(decodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),139,decoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),132,org.apache.commons.codec.binary.Base64TestData.CODEC_98_NPE_DECODED);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),133,decoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation against the special NPE inducing input
     * identified in the CODEC-98 bug.
     * 
     * @throws Exception for some failure scenarios.
     */
@Test
    public void testCodec98NPE_literalMutation106() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodec98NPE_literalMutation106");
            final byte[] codec98 = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.CODEC_98_NPE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),134,codec98);
            final byte[] codec98_1024 = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),135,codec98_1024);
            java.lang.System.arraycopy(codec98, 0, codec98_1024, 1, codec98.length);
            final ByteArrayOutputStream data = new ByteArrayOutputStream(1024);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),136,data);
            final Base64OutputStream stream = new Base64OutputStream(data , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),137,stream);
            stream.write(codec98_1024, 0, 1024);
            stream.close();
            final byte[] decodedBytes = data.toByteArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),138,decodedBytes);
            final String decoded = org.apache.commons.codec.binary.StringUtils.newStringUtf8(decodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),139,decoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),132,org.apache.commons.codec.binary.Base64TestData.CODEC_98_NPE_DECODED);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),133,decoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation against the special NPE inducing input
     * identified in the CODEC-98 bug.
     * 
     * @throws Exception for some failure scenarios.
     */
@Test
    public void testCodec98NPE_literalMutation107() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodec98NPE_literalMutation107");
            final byte[] codec98 = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.CODEC_98_NPE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),134,codec98);
            final byte[] codec98_1024 = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),135,codec98_1024);
            java.lang.System.arraycopy(codec98, 0, codec98_1024, -1, codec98.length);
            final ByteArrayOutputStream data = new ByteArrayOutputStream(1024);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),136,data);
            final Base64OutputStream stream = new Base64OutputStream(data , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),137,stream);
            stream.write(codec98_1024, 0, 1024);
            stream.close();
            final byte[] decodedBytes = data.toByteArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),138,decodedBytes);
            final String decoded = org.apache.commons.codec.binary.StringUtils.newStringUtf8(decodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),139,decoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),132,org.apache.commons.codec.binary.Base64TestData.CODEC_98_NPE_DECODED);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),133,decoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation against the special NPE inducing input
     * identified in the CODEC-98 bug.
     * 
     * @throws Exception for some failure scenarios.
     */
@Test
    public void testCodec98NPE_literalMutation108() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodec98NPE_literalMutation108");
            final byte[] codec98 = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.CODEC_98_NPE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),134,codec98);
            final byte[] codec98_1024 = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),135,codec98_1024);
            java.lang.System.arraycopy(codec98, 0, codec98_1024, 0, codec98.length);
            final ByteArrayOutputStream data = new ByteArrayOutputStream(1024);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),136,data);
            final Base64OutputStream stream = new Base64OutputStream(data , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),137,stream);
            stream.write(codec98_1024, 0, 1024);
            stream.close();
            final byte[] decodedBytes = data.toByteArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),138,decodedBytes);
            final String decoded = org.apache.commons.codec.binary.StringUtils.newStringUtf8(decodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),139,decoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),132,org.apache.commons.codec.binary.Base64TestData.CODEC_98_NPE_DECODED);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),133,decoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation against the special NPE inducing input
     * identified in the CODEC-98 bug.
     * 
     * @throws Exception for some failure scenarios.
     */
@Test
    public void testCodec98NPE_literalMutation110() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodec98NPE_literalMutation110");
            final byte[] codec98 = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.CODEC_98_NPE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),134,codec98);
            final byte[] codec98_1024 = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),135,codec98_1024);
            java.lang.System.arraycopy(codec98, 0, codec98_1024, 0, codec98.length);
            final ByteArrayOutputStream data = new ByteArrayOutputStream(1025);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),136,data);
            final Base64OutputStream stream = new Base64OutputStream(data , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),137,stream);
            stream.write(codec98_1024, 0, 1024);
            stream.close();
            final byte[] decodedBytes = data.toByteArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),138,decodedBytes);
            final String decoded = org.apache.commons.codec.binary.StringUtils.newStringUtf8(decodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),139,decoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),132,org.apache.commons.codec.binary.Base64TestData.CODEC_98_NPE_DECODED);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),133,decoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation against the special NPE inducing input
     * identified in the CODEC-98 bug.
     * 
     * @throws Exception for some failure scenarios.
     */
@Test
    public void testCodec98NPE_literalMutation111() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodec98NPE_literalMutation111");
            final byte[] codec98 = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.CODEC_98_NPE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),134,codec98);
            final byte[] codec98_1024 = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),135,codec98_1024);
            java.lang.System.arraycopy(codec98, 0, codec98_1024, 0, codec98.length);
            final ByteArrayOutputStream data = new ByteArrayOutputStream(512);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),136,data);
            final Base64OutputStream stream = new Base64OutputStream(data , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),137,stream);
            stream.write(codec98_1024, 0, 1024);
            stream.close();
            final byte[] decodedBytes = data.toByteArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),138,decodedBytes);
            final String decoded = org.apache.commons.codec.binary.StringUtils.newStringUtf8(decodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),139,decoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),132,org.apache.commons.codec.binary.Base64TestData.CODEC_98_NPE_DECODED);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),133,decoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation against the special NPE inducing input
     * identified in the CODEC-98 bug.
     * 
     * @throws Exception for some failure scenarios.
     */
@Test
    public void testCodec98NPE_literalMutation112() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodec98NPE_literalMutation112");
            final byte[] codec98 = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.CODEC_98_NPE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),134,codec98);
            final byte[] codec98_1024 = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),135,codec98_1024);
            java.lang.System.arraycopy(codec98, 0, codec98_1024, 0, codec98.length);
            final ByteArrayOutputStream data = new ByteArrayOutputStream(2048);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),136,data);
            final Base64OutputStream stream = new Base64OutputStream(data , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),137,stream);
            stream.write(codec98_1024, 0, 1024);
            stream.close();
            final byte[] decodedBytes = data.toByteArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),138,decodedBytes);
            final String decoded = org.apache.commons.codec.binary.StringUtils.newStringUtf8(decodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),139,decoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),132,org.apache.commons.codec.binary.Base64TestData.CODEC_98_NPE_DECODED);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),133,decoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation against the special NPE inducing input
     * identified in the CODEC-98 bug.
     * 
     * @throws Exception for some failure scenarios.
     */
@Test
    public void testCodec98NPE_literalMutation113() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodec98NPE_literalMutation113");
            final byte[] codec98 = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.CODEC_98_NPE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),134,codec98);
            final byte[] codec98_1024 = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),135,codec98_1024);
            java.lang.System.arraycopy(codec98, 0, codec98_1024, 0, codec98.length);
            final ByteArrayOutputStream data = new ByteArrayOutputStream(1023);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),136,data);
            final Base64OutputStream stream = new Base64OutputStream(data , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),137,stream);
            stream.write(codec98_1024, 0, 1024);
            stream.close();
            final byte[] decodedBytes = data.toByteArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),138,decodedBytes);
            final String decoded = org.apache.commons.codec.binary.StringUtils.newStringUtf8(decodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),139,decoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),132,org.apache.commons.codec.binary.Base64TestData.CODEC_98_NPE_DECODED);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),133,decoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation against the special NPE inducing input
     * identified in the CODEC-98 bug.
     * 
     * @throws Exception for some failure scenarios.
     */
@Test
    public void testCodec98NPE_literalMutation115() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodec98NPE_literalMutation115");
            final byte[] codec98 = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.CODEC_98_NPE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),134,codec98);
            final byte[] codec98_1024 = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),135,codec98_1024);
            java.lang.System.arraycopy(codec98, 0, codec98_1024, 0, codec98.length);
            final ByteArrayOutputStream data = new ByteArrayOutputStream(1024);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),136,data);
            final Base64OutputStream stream = new Base64OutputStream(data , true);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),137,stream);
            stream.write(codec98_1024, 0, 1024);
            stream.close();
            final byte[] decodedBytes = data.toByteArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),138,decodedBytes);
            final String decoded = org.apache.commons.codec.binary.StringUtils.newStringUtf8(decodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),139,decoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),132,org.apache.commons.codec.binary.Base64TestData.CODEC_98_NPE_DECODED);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),133,decoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation against the special NPE inducing input
     * identified in the CODEC-98 bug.
     * 
     * @throws Exception for some failure scenarios.
     */
@Test
    public void testCodec98NPE_literalMutation116() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodec98NPE_literalMutation116");
            final byte[] codec98 = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.CODEC_98_NPE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),134,codec98);
            final byte[] codec98_1024 = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),135,codec98_1024);
            java.lang.System.arraycopy(codec98, 0, codec98_1024, 0, codec98.length);
            final ByteArrayOutputStream data = new ByteArrayOutputStream(1024);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),136,data);
            final Base64OutputStream stream = new Base64OutputStream(data , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),137,stream);
            stream.write(codec98_1024, 1, 1024);
            stream.close();
            final byte[] decodedBytes = data.toByteArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),138,decodedBytes);
            final String decoded = org.apache.commons.codec.binary.StringUtils.newStringUtf8(decodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),139,decoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),132,org.apache.commons.codec.binary.Base64TestData.CODEC_98_NPE_DECODED);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),133,decoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation against the special NPE inducing input
     * identified in the CODEC-98 bug.
     * 
     * @throws Exception for some failure scenarios.
     */
@Test
    public void testCodec98NPE_literalMutation117() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodec98NPE_literalMutation117");
            final byte[] codec98 = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.CODEC_98_NPE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),134,codec98);
            final byte[] codec98_1024 = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),135,codec98_1024);
            java.lang.System.arraycopy(codec98, 0, codec98_1024, 0, codec98.length);
            final ByteArrayOutputStream data = new ByteArrayOutputStream(1024);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),136,data);
            final Base64OutputStream stream = new Base64OutputStream(data , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),137,stream);
            stream.write(codec98_1024, -1, 1024);
            stream.close();
            final byte[] decodedBytes = data.toByteArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),138,decodedBytes);
            final String decoded = org.apache.commons.codec.binary.StringUtils.newStringUtf8(decodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),139,decoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),132,org.apache.commons.codec.binary.Base64TestData.CODEC_98_NPE_DECODED);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),133,decoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation against the special NPE inducing input
     * identified in the CODEC-98 bug.
     * 
     * @throws Exception for some failure scenarios.
     */
@Test
    public void testCodec98NPE_literalMutation118() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodec98NPE_literalMutation118");
            final byte[] codec98 = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.CODEC_98_NPE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),134,codec98);
            final byte[] codec98_1024 = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),135,codec98_1024);
            java.lang.System.arraycopy(codec98, 0, codec98_1024, 0, codec98.length);
            final ByteArrayOutputStream data = new ByteArrayOutputStream(1024);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),136,data);
            final Base64OutputStream stream = new Base64OutputStream(data , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),137,stream);
            stream.write(codec98_1024, 0, 1024);
            stream.close();
            final byte[] decodedBytes = data.toByteArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),138,decodedBytes);
            final String decoded = org.apache.commons.codec.binary.StringUtils.newStringUtf8(decodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),139,decoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),132,org.apache.commons.codec.binary.Base64TestData.CODEC_98_NPE_DECODED);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),133,decoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation against the special NPE inducing input
     * identified in the CODEC-98 bug.
     * 
     * @throws Exception for some failure scenarios.
     */
@Test
    public void testCodec98NPE_literalMutation120() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodec98NPE_literalMutation120");
            final byte[] codec98 = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.CODEC_98_NPE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),134,codec98);
            final byte[] codec98_1024 = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),135,codec98_1024);
            java.lang.System.arraycopy(codec98, 0, codec98_1024, 0, codec98.length);
            final ByteArrayOutputStream data = new ByteArrayOutputStream(1024);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),136,data);
            final Base64OutputStream stream = new Base64OutputStream(data , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),137,stream);
            stream.write(codec98_1024, 0, 1025);
            stream.close();
            final byte[] decodedBytes = data.toByteArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),138,decodedBytes);
            final String decoded = org.apache.commons.codec.binary.StringUtils.newStringUtf8(decodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),139,decoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),132,org.apache.commons.codec.binary.Base64TestData.CODEC_98_NPE_DECODED);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),133,decoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation against the special NPE inducing input
     * identified in the CODEC-98 bug.
     * 
     * @throws Exception for some failure scenarios.
     */
@Test
    public void testCodec98NPE_literalMutation121() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodec98NPE_literalMutation121");
            final byte[] codec98 = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.CODEC_98_NPE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),134,codec98);
            final byte[] codec98_1024 = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),135,codec98_1024);
            java.lang.System.arraycopy(codec98, 0, codec98_1024, 0, codec98.length);
            final ByteArrayOutputStream data = new ByteArrayOutputStream(1024);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),136,data);
            final Base64OutputStream stream = new Base64OutputStream(data , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),137,stream);
            stream.write(codec98_1024, 0, 512);
            stream.close();
            final byte[] decodedBytes = data.toByteArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),138,decodedBytes);
            final String decoded = org.apache.commons.codec.binary.StringUtils.newStringUtf8(decodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),139,decoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),132,org.apache.commons.codec.binary.Base64TestData.CODEC_98_NPE_DECODED);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),133,decoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation against the special NPE inducing input
     * identified in the CODEC-98 bug.
     * 
     * @throws Exception for some failure scenarios.
     */
@Test
    public void testCodec98NPE_literalMutation122() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodec98NPE_literalMutation122");
            final byte[] codec98 = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.CODEC_98_NPE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),134,codec98);
            final byte[] codec98_1024 = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),135,codec98_1024);
            java.lang.System.arraycopy(codec98, 0, codec98_1024, 0, codec98.length);
            final ByteArrayOutputStream data = new ByteArrayOutputStream(1024);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),136,data);
            final Base64OutputStream stream = new Base64OutputStream(data , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),137,stream);
            stream.write(codec98_1024, 0, 2048);
            stream.close();
            final byte[] decodedBytes = data.toByteArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),138,decodedBytes);
            final String decoded = org.apache.commons.codec.binary.StringUtils.newStringUtf8(decodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),139,decoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),132,org.apache.commons.codec.binary.Base64TestData.CODEC_98_NPE_DECODED);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),133,decoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation against the special NPE inducing input
     * identified in the CODEC-98 bug.
     * 
     * @throws Exception for some failure scenarios.
     */
@Test
    public void testCodec98NPE_literalMutation123() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodec98NPE_literalMutation123");
            final byte[] codec98 = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.CODEC_98_NPE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),134,codec98);
            final byte[] codec98_1024 = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),135,codec98_1024);
            java.lang.System.arraycopy(codec98, 0, codec98_1024, 0, codec98.length);
            final ByteArrayOutputStream data = new ByteArrayOutputStream(1024);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),136,data);
            final Base64OutputStream stream = new Base64OutputStream(data , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),137,stream);
            stream.write(codec98_1024, 0, 1023);
            stream.close();
            final byte[] decodedBytes = data.toByteArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),138,decodedBytes);
            final String decoded = org.apache.commons.codec.binary.StringUtils.newStringUtf8(decodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),139,decoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),132,org.apache.commons.codec.binary.Base64TestData.CODEC_98_NPE_DECODED);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),133,decoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation against the special NPE inducing input
     * identified in the CODEC-98 bug.
     * 
     * @throws Exception for some failure scenarios.
     */
@Test
    public void testCodec98NPE() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodec98NPE");
            final byte[] codec98 = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.CODEC_98_NPE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),134,codec98);
            final byte[] codec98_1024 = new byte[1025];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),135,codec98_1024);
            java.lang.System.arraycopy(codec98, 0, codec98_1024, 0, codec98.length);
            final ByteArrayOutputStream data = new ByteArrayOutputStream(1024);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),136,data);
            final Base64OutputStream stream = new Base64OutputStream(data , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),137,stream);
            stream.write(codec98_1024, 0, 1024);
            stream.close();
            final byte[] decodedBytes = data.toByteArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),138,decodedBytes);
            final String decoded = org.apache.commons.codec.binary.StringUtils.newStringUtf8(decodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),139,decoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),132,org.apache.commons.codec.binary.Base64TestData.CODEC_98_NPE_DECODED);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),133,decoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation against the special NPE inducing input
     * identified in the CODEC-98 bug.
     * 
     * @throws Exception for some failure scenarios.
     */
@Test
    public void testCodec98NPE_literalMutation98() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodec98NPE_literalMutation98");
            final byte[] codec98 = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.CODEC_98_NPE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),134,codec98);
            final byte[] codec98_1024 = new byte[512];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),135,codec98_1024);
            java.lang.System.arraycopy(codec98, 0, codec98_1024, 0, codec98.length);
            final ByteArrayOutputStream data = new ByteArrayOutputStream(1024);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),136,data);
            final Base64OutputStream stream = new Base64OutputStream(data , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),137,stream);
            stream.write(codec98_1024, 0, 1024);
            stream.close();
            final byte[] decodedBytes = data.toByteArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),138,decodedBytes);
            final String decoded = org.apache.commons.codec.binary.StringUtils.newStringUtf8(decodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),139,decoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),132,org.apache.commons.codec.binary.Base64TestData.CODEC_98_NPE_DECODED);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),133,decoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation against the special NPE inducing input
     * identified in the CODEC-98 bug.
     * 
     * @throws Exception for some failure scenarios.
     */
@Test
    public void testCodec98NPE_literalMutation99() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodec98NPE_literalMutation99");
            final byte[] codec98 = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.CODEC_98_NPE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),134,codec98);
            final byte[] codec98_1024 = new byte[2048];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),135,codec98_1024);
            java.lang.System.arraycopy(codec98, 0, codec98_1024, 0, codec98.length);
            final ByteArrayOutputStream data = new ByteArrayOutputStream(1024);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),136,data);
            final Base64OutputStream stream = new Base64OutputStream(data , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),137,stream);
            stream.write(codec98_1024, 0, 1024);
            stream.close();
            final byte[] decodedBytes = data.toByteArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),138,decodedBytes);
            final String decoded = org.apache.commons.codec.binary.StringUtils.newStringUtf8(decodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),139,decoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),132,org.apache.commons.codec.binary.Base64TestData.CODEC_98_NPE_DECODED);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),133,decoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation against the special NPE inducing input
     * identified in the CODEC-98 bug.
     * 
     * @throws Exception for some failure scenarios.
     */
@Test(timeout = 1000)
    public void testCodec98NPE_remove13() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodec98NPE_remove13");
            final byte[] codec98 = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.CODEC_98_NPE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),134,codec98);
            final byte[] codec98_1024 = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),135,codec98_1024);
            final ByteArrayOutputStream data = new ByteArrayOutputStream(1024);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),136,data);
            final Base64OutputStream stream = new Base64OutputStream(data , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),137,stream);
            stream.write(codec98_1024, 0, 1024);
            stream.close();
            final byte[] decodedBytes = data.toByteArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),138,decodedBytes);
            final String decoded = org.apache.commons.codec.binary.StringUtils.newStringUtf8(decodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),139,decoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),132,org.apache.commons.codec.binary.Base64TestData.CODEC_98_NPE_DECODED);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),133,decoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation against the special NPE inducing input
     * identified in the CODEC-98 bug.
     * 
     * @throws Exception for some failure scenarios.
     */
@Test(timeout = 1000)
    public void testCodec98NPE_remove14() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodec98NPE_remove14");
            final byte[] codec98 = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.CODEC_98_NPE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),134,codec98);
            final byte[] codec98_1024 = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),135,codec98_1024);
            java.lang.System.arraycopy(codec98, 0, codec98_1024, 0, codec98.length);
            final ByteArrayOutputStream data = new ByteArrayOutputStream(1024);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),136,data);
            final Base64OutputStream stream = new Base64OutputStream(data , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),137,stream);
            stream.close();
            final byte[] decodedBytes = data.toByteArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),138,decodedBytes);
            final String decoded = org.apache.commons.codec.binary.StringUtils.newStringUtf8(decodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),139,decoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),132,org.apache.commons.codec.binary.Base64TestData.CODEC_98_NPE_DECODED);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),133,decoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation against the special NPE inducing input
     * identified in the CODEC-98 bug.
     * 
     * @throws Exception for some failure scenarios.
     */
@Test(timeout = 1000)
    public void testCodec98NPE_remove15() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodec98NPE_remove15");
            final byte[] codec98 = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.CODEC_98_NPE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),134,codec98);
            final byte[] codec98_1024 = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),135,codec98_1024);
            java.lang.System.arraycopy(codec98, 0, codec98_1024, 0, codec98.length);
            final ByteArrayOutputStream data = new ByteArrayOutputStream(1024);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),136,data);
            final Base64OutputStream stream = new Base64OutputStream(data , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),137,stream);
            stream.write(codec98_1024, 0, 1024);
            final byte[] decodedBytes = data.toByteArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),138,decodedBytes);
            final String decoded = org.apache.commons.codec.binary.StringUtils.newStringUtf8(decodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),139,decoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),132,org.apache.commons.codec.binary.Base64TestData.CODEC_98_NPE_DECODED);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),133,decoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation against empty input.
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test(timeout = 1000)
    public void testBase64EmptyOutputStreamMimeChunkSize() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64EmptyOutputStreamMimeChunkSize");
            testBase64EmptyOutputStream(org.apache.commons.codec.binary.BaseNCodec.MIME_CHUNK_SIZE);
            testBase64EmptyOutputStream(org.apache.commons.codec.binary.BaseNCodec.MIME_CHUNK_SIZE);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation against empty input.
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test(timeout = 1000)
    public void testBase64EmptyOutputStreamMimeChunkSize_remove1() throws Exception {
    }

    /** 
     * Test the Base64OutputStream implementation against empty input.
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test(timeout = 1000)
    public void testBase64EmptyOutputStreamPemChunkSize() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64EmptyOutputStreamPemChunkSize");
            testBase64EmptyOutputStream(org.apache.commons.codec.binary.BaseNCodec.PEM_CHUNK_SIZE);
            testBase64EmptyOutputStream(org.apache.commons.codec.binary.BaseNCodec.PEM_CHUNK_SIZE);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation against empty input.
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test(timeout = 1000)
    public void testBase64EmptyOutputStreamPemChunkSize_remove2() throws Exception {
    }

    private void testBase64EmptyOutputStream(final int chunkSize) throws Exception {
        final byte[] emptyEncoded = new byte[0];
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),74,emptyEncoded);
        final byte[] emptyDecoded = new byte[0];
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),75,emptyDecoded);
        testByteByByte(emptyEncoded, emptyDecoded, chunkSize, CRLF);
        testByChunk(emptyEncoded, emptyDecoded, chunkSize, CRLF);
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test(timeout = 1000)
    public void testBase64OutputStreamByChunk_add5() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByChunk_add5");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),84,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),85,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.MIME_CHUNK_SIZE, CRLF);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.MIME_CHUNK_SIZE, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),76,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),77,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.MIME_CHUNK_SIZE, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),78,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),79,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.PEM_CHUNK_SIZE, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),86,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),80,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),81,decoded);
            testByChunk(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),87,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),82,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),83,decoded);
                testByChunk(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test(timeout = 1000)
    public void testBase64OutputStreamByChunk_add6() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByChunk_add6");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),84,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),85,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.MIME_CHUNK_SIZE, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),76,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),77,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.MIME_CHUNK_SIZE, CRLF);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.MIME_CHUNK_SIZE, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),78,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),79,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.PEM_CHUNK_SIZE, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),86,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),80,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),81,decoded);
            testByChunk(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),87,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),82,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),83,decoded);
                testByChunk(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test(timeout = 1000)
    public void testBase64OutputStreamByChunk_add7() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByChunk_add7");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),84,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),85,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.MIME_CHUNK_SIZE, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),76,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),77,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.MIME_CHUNK_SIZE, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),78,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),79,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.PEM_CHUNK_SIZE, LF);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.PEM_CHUNK_SIZE, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),86,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),80,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),81,decoded);
            testByChunk(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),87,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),82,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),83,decoded);
                testByChunk(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test(timeout = 1000)
    public void testBase64OutputStreamByChunk_add8() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByChunk_add8");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),84,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),85,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.MIME_CHUNK_SIZE, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),76,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),77,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.MIME_CHUNK_SIZE, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),78,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),79,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.PEM_CHUNK_SIZE, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),86,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),80,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),81,decoded);
            testByChunk(encoded, decoded, 0, LF);
            testByChunk(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),87,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),82,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),83,decoded);
                testByChunk(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test(timeout = 1000)
    public void testBase64OutputStreamByChunk_add9() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByChunk_add9");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),84,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),85,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.MIME_CHUNK_SIZE, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),76,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),77,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.MIME_CHUNK_SIZE, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),78,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),79,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.PEM_CHUNK_SIZE, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),86,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),80,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),81,decoded);
            testByChunk(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),87,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),82,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),83,decoded);
                testByChunk(encoded, decoded, 0, LF);
                testByChunk(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testBase64OutputStreamByChunk() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByChunk");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8g¯29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),84,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),85,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.MIME_CHUNK_SIZE, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),76,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),77,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.MIME_CHUNK_SIZE, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),78,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),79,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.PEM_CHUNK_SIZE, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),86,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),80,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),81,decoded);
            testByChunk(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),87,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),82,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),83,decoded);
                testByChunk(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testBase64OutputStreamByChunk_literalMutation63() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByChunk_literalMutation63");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbëG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),84,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),85,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.MIME_CHUNK_SIZE, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),76,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),77,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.MIME_CHUNK_SIZE, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),78,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),79,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.PEM_CHUNK_SIZE, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),86,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),80,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),81,decoded);
            testByChunk(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),87,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),82,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),83,decoded);
                testByChunk(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testBase64OutputStreamByChunk_literalMutation64() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByChunk_literalMutation64");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),84,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),85,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.MIME_CHUNK_SIZE, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),76,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),77,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.MIME_CHUNK_SIZE, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),78,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),79,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.PEM_CHUNK_SIZE, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),86,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),80,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),81,decoded);
            testByChunk(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),87,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),82,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),83,decoded);
                testByChunk(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testBase64OutputStreamByChunk_literalMutation65() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByChunk_literalMutation65");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),84,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),85,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.MIME_CHUNK_SIZE, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AAÎ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),76,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),77,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.MIME_CHUNK_SIZE, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),78,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),79,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.PEM_CHUNK_SIZE, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),86,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),80,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),81,decoded);
            testByChunk(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),87,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),82,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),83,decoded);
                testByChunk(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testBase64OutputStreamByChunk_literalMutation66() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByChunk_literalMutation66");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),84,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),85,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.MIME_CHUNK_SIZE, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AúA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),76,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),77,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.MIME_CHUNK_SIZE, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),78,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),79,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.PEM_CHUNK_SIZE, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),86,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),80,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),81,decoded);
            testByChunk(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),87,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),82,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),83,decoded);
                testByChunk(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testBase64OutputStreamByChunk_literalMutation67() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByChunk_literalMutation67");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),84,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),85,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.MIME_CHUNK_SIZE, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("A==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),76,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),77,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.MIME_CHUNK_SIZE, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),78,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),79,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.PEM_CHUNK_SIZE, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),86,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),80,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),81,decoded);
            testByChunk(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),87,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),82,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),83,decoded);
                testByChunk(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testBase64OutputStreamByChunk_literalMutation68() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByChunk_literalMutation68");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),84,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),85,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.MIME_CHUNK_SIZE, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),76,encoded);
            decoded = new byte[]{ ((byte)(1)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),77,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.MIME_CHUNK_SIZE, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),78,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),79,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.PEM_CHUNK_SIZE, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),86,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),80,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),81,decoded);
            testByChunk(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),87,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),82,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),83,decoded);
                testByChunk(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testBase64OutputStreamByChunk_literalMutation69() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByChunk_literalMutation69");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),84,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),85,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.MIME_CHUNK_SIZE, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),76,encoded);
            decoded = new byte[]{ ((byte)(-1)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),77,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.MIME_CHUNK_SIZE, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),78,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),79,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.PEM_CHUNK_SIZE, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),86,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),80,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),81,decoded);
            testByChunk(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),87,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),82,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),83,decoded);
                testByChunk(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testBase64OutputStreamByChunk_literalMutation70() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByChunk_literalMutation70");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),84,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),85,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.MIME_CHUNK_SIZE, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),76,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),77,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.MIME_CHUNK_SIZE, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),78,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),79,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.PEM_CHUNK_SIZE, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),86,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),80,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),81,decoded);
            testByChunk(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),87,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),82,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),83,decoded);
                testByChunk(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test(timeout = 1000)
    public void testBase64OutputStreamByChunk_remove3() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByChunk_remove3");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),84,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),85,decoded);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),76,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),77,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.MIME_CHUNK_SIZE, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),78,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),79,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.PEM_CHUNK_SIZE, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),86,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),80,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),81,decoded);
            testByChunk(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),87,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),82,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),83,decoded);
                testByChunk(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test(timeout = 1000)
    public void testBase64OutputStreamByChunk_remove4() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByChunk_remove4");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),84,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),85,decoded);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),76,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),77,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.MIME_CHUNK_SIZE, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),78,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),79,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.PEM_CHUNK_SIZE, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),86,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),80,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),81,decoded);
            testByChunk(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),87,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),82,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),83,decoded);
                testByChunk(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test(timeout = 1000)
    public void testBase64OutputStreamByChunk_remove5() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByChunk_remove5");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),84,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),85,decoded);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),76,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),77,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.MIME_CHUNK_SIZE, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),78,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),79,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.PEM_CHUNK_SIZE, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),86,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),80,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),81,decoded);
            testByChunk(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),87,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),82,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),83,decoded);
                testByChunk(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test(timeout = 1000)
    public void testBase64OutputStreamByChunk_remove6() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByChunk_remove6");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),84,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),85,decoded);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),76,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),77,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.MIME_CHUNK_SIZE, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),78,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),79,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.PEM_CHUNK_SIZE, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),86,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),80,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),81,decoded);
            testByChunk(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),87,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),82,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),83,decoded);
                testByChunk(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test(timeout = 1000)
    public void testBase64OutputStreamByChunk_remove7() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByChunk_remove7");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),84,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),85,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.MIME_CHUNK_SIZE, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),76,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),77,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.MIME_CHUNK_SIZE, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),78,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),79,decoded);
            testByChunk(encoded, decoded, org.apache.commons.codec.binary.BaseNCodec.PEM_CHUNK_SIZE, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),86,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),80,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),81,decoded);
            testByChunk(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),87,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),82,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),83,decoded);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test(timeout = 1000)
    public void testBase64OutputStreamByteByByte_add10() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByteByByte_add10");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),96,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),97,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),88,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),89,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),90,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),91,decoded);
            testByteByByte(encoded, decoded, 64, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),98,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),92,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),93,decoded);
            testByteByByte(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),99,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),94,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),95,decoded);
                testByteByByte(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test(timeout = 1000)
    public void testBase64OutputStreamByteByByte_add11() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByteByByte_add11");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),96,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),97,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),88,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),89,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),90,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),91,decoded);
            testByteByByte(encoded, decoded, 64, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),98,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),92,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),93,decoded);
            testByteByByte(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),99,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),94,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),95,decoded);
                testByteByByte(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test(timeout = 1000)
    public void testBase64OutputStreamByteByByte_add12() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByteByByte_add12");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),96,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),97,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),88,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),89,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),90,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),91,decoded);
            testByteByByte(encoded, decoded, 64, LF);
            testByteByByte(encoded, decoded, 64, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),98,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),92,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),93,decoded);
            testByteByByte(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),99,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),94,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),95,decoded);
                testByteByByte(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test(timeout = 1000)
    public void testBase64OutputStreamByteByByte_add13() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByteByByte_add13");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),96,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),97,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),88,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),89,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),90,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),91,decoded);
            testByteByByte(encoded, decoded, 64, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),98,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),92,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),93,decoded);
            testByteByByte(encoded, decoded, 0, LF);
            testByteByByte(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),99,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),94,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),95,decoded);
                testByteByByte(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test(timeout = 1000)
    public void testBase64OutputStreamByteByByte_add14() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByteByByte_add14");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),96,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),97,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),88,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),89,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),90,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),91,decoded);
            testByteByByte(encoded, decoded, 64, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),98,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),92,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),93,decoded);
            testByteByByte(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),99,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),94,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),95,decoded);
                testByteByByte(encoded, decoded, 0, LF);
                testByteByByte(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testBase64OutputStreamByteByByte() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByteByByte");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8g29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),96,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),97,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),88,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),89,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),90,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),91,decoded);
            testByteByByte(encoded, decoded, 64, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),98,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),92,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),93,decoded);
            testByteByByte(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),99,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),94,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),95,decoded);
                testByteByByte(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testBase64OutputStreamByteByByte_literalMutation73() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByteByByte_literalMutation73");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gVv29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),96,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),97,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),88,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),89,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),90,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),91,decoded);
            testByteByByte(encoded, decoded, 64, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),98,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),92,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),93,decoded);
            testByteByByte(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),99,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),94,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),95,decoded);
                testByteByByte(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testBase64OutputStreamByteByByte_literalMutation74() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByteByByte_literalMutation74");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV2ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),96,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),97,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),88,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),89,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),90,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),91,decoded);
            testByteByByte(encoded, decoded, 64, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),98,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),92,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),93,decoded);
            testByteByByte(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),99,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),94,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),95,decoded);
                testByteByByte(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testBase64OutputStreamByteByByte_literalMutation75() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByteByByte_literalMutation75");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),96,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),97,decoded);
            testByteByByte(encoded, decoded, 75, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),88,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),89,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),90,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),91,decoded);
            testByteByByte(encoded, decoded, 64, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),98,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),92,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),93,decoded);
            testByteByByte(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),99,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),94,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),95,decoded);
                testByteByByte(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testBase64OutputStreamByteByByte_literalMutation76() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByteByByte_literalMutation76");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),96,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),97,decoded);
            testByteByByte(encoded, decoded, 77, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),88,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),89,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),90,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),91,decoded);
            testByteByByte(encoded, decoded, 64, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),98,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),92,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),93,decoded);
            testByteByByte(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),99,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),94,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),95,decoded);
                testByteByByte(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testBase64OutputStreamByteByByte_literalMutation77() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByteByByte_literalMutation77");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),96,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),97,decoded);
            testByteByByte(encoded, decoded, 38, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),88,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),89,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),90,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),91,decoded);
            testByteByByte(encoded, decoded, 64, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),98,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),92,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),93,decoded);
            testByteByByte(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),99,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),94,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),95,decoded);
                testByteByByte(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testBase64OutputStreamByteByByte_literalMutation78() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByteByByte_literalMutation78");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),96,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),97,decoded);
            testByteByByte(encoded, decoded, 152, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),88,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),89,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),90,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),91,decoded);
            testByteByByte(encoded, decoded, 64, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),98,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),92,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),93,decoded);
            testByteByByte(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),99,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),94,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),95,decoded);
                testByteByByte(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testBase64OutputStreamByteByByte_literalMutation80() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByteByByte_literalMutation80");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),96,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),97,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AI==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),88,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),89,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),90,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),91,decoded);
            testByteByByte(encoded, decoded, 64, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),98,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),92,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),93,decoded);
            testByteByByte(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),99,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),94,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),95,decoded);
                testByteByByte(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testBase64OutputStreamByteByByte_literalMutation81() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByteByByte_literalMutation81");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),96,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),97,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA=Ì=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),88,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),89,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),90,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),91,decoded);
            testByteByByte(encoded, decoded, 64, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),98,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),92,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),93,decoded);
            testByteByByte(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),99,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),94,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),95,decoded);
                testByteByByte(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testBase64OutputStreamByteByByte_literalMutation82() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByteByByte_literalMutation82");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),96,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),97,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),88,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),89,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),90,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),91,decoded);
            testByteByByte(encoded, decoded, 64, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),98,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),92,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),93,decoded);
            testByteByByte(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),99,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),94,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),95,decoded);
                testByteByByte(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testBase64OutputStreamByteByByte_literalMutation83() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByteByByte_literalMutation83");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),96,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),97,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),88,encoded);
            decoded = new byte[]{ ((byte)(1)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),89,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),90,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),91,decoded);
            testByteByByte(encoded, decoded, 64, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),98,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),92,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),93,decoded);
            testByteByByte(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),99,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),94,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),95,decoded);
                testByteByByte(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testBase64OutputStreamByteByByte_literalMutation84() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByteByByte_literalMutation84");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),96,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),97,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),88,encoded);
            decoded = new byte[]{ ((byte)(-1)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),89,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),90,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),91,decoded);
            testByteByByte(encoded, decoded, 64, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),98,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),92,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),93,decoded);
            testByteByByte(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),99,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),94,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),95,decoded);
                testByteByByte(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testBase64OutputStreamByteByByte_literalMutation85() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByteByByte_literalMutation85");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),96,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),97,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),88,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),89,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),90,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),91,decoded);
            testByteByByte(encoded, decoded, 64, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),98,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),92,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),93,decoded);
            testByteByByte(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),99,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),94,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),95,decoded);
                testByteByByte(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testBase64OutputStreamByteByByte_literalMutation87() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByteByByte_literalMutation87");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),96,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),97,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),88,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),89,decoded);
            testByteByByte(encoded, decoded, 75, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),90,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),91,decoded);
            testByteByByte(encoded, decoded, 64, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),98,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),92,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),93,decoded);
            testByteByByte(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),99,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),94,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),95,decoded);
                testByteByByte(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testBase64OutputStreamByteByByte_literalMutation88() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByteByByte_literalMutation88");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),96,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),97,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),88,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),89,decoded);
            testByteByByte(encoded, decoded, 77, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),90,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),91,decoded);
            testByteByByte(encoded, decoded, 64, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),98,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),92,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),93,decoded);
            testByteByByte(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),99,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),94,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),95,decoded);
                testByteByByte(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testBase64OutputStreamByteByByte_literalMutation89() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByteByByte_literalMutation89");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),96,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),97,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),88,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),89,decoded);
            testByteByByte(encoded, decoded, 38, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),90,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),91,decoded);
            testByteByByte(encoded, decoded, 64, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),98,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),92,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),93,decoded);
            testByteByByte(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),99,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),94,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),95,decoded);
                testByteByByte(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testBase64OutputStreamByteByByte_literalMutation90() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByteByByte_literalMutation90");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),96,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),97,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),88,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),89,decoded);
            testByteByByte(encoded, decoded, 152, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),90,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),91,decoded);
            testByteByByte(encoded, decoded, 64, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),98,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),92,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),93,decoded);
            testByteByByte(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),99,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),94,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),95,decoded);
                testByteByByte(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testBase64OutputStreamByteByByte_literalMutation92() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByteByByte_literalMutation92");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),96,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),97,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),88,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),89,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),90,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),91,decoded);
            testByteByByte(encoded, decoded, 65, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),98,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),92,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),93,decoded);
            testByteByByte(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),99,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),94,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),95,decoded);
                testByteByByte(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testBase64OutputStreamByteByByte_literalMutation93() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByteByByte_literalMutation93");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),96,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),97,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),88,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),89,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),90,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),91,decoded);
            testByteByByte(encoded, decoded, 32, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),98,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),92,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),93,decoded);
            testByteByByte(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),99,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),94,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),95,decoded);
                testByteByByte(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testBase64OutputStreamByteByByte_literalMutation94() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByteByByte_literalMutation94");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),96,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),97,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),88,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),89,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),90,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),91,decoded);
            testByteByByte(encoded, decoded, 128, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),98,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),92,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),93,decoded);
            testByteByByte(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),99,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),94,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),95,decoded);
                testByteByByte(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testBase64OutputStreamByteByByte_literalMutation95() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByteByByte_literalMutation95");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),96,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),97,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),88,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),89,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),90,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),91,decoded);
            testByteByByte(encoded, decoded, 63, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),98,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),92,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),93,decoded);
            testByteByByte(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),99,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),94,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),95,decoded);
                testByteByByte(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test(timeout = 1000)
    public void testBase64OutputStreamByteByByte_remove10() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByteByByte_remove10");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),96,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),97,decoded);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),88,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),89,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),90,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),91,decoded);
            testByteByByte(encoded, decoded, 64, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),98,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),92,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),93,decoded);
            testByteByByte(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),99,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),94,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),95,decoded);
                testByteByByte(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test(timeout = 1000)
    public void testBase64OutputStreamByteByByte_remove11() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByteByByte_remove11");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),96,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),97,decoded);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),88,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),89,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),90,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),91,decoded);
            testByteByByte(encoded, decoded, 64, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),98,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),92,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),93,decoded);
            testByteByByte(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),99,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),94,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),95,decoded);
                testByteByByte(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test(timeout = 1000)
    public void testBase64OutputStreamByteByByte_remove12() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByteByByte_remove12");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),96,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),97,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),88,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),89,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),90,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),91,decoded);
            testByteByByte(encoded, decoded, 64, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),98,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),92,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),93,decoded);
            testByteByByte(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),99,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),94,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),95,decoded);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test(timeout = 1000)
    public void testBase64OutputStreamByteByByte_remove8() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByteByByte_remove8");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),96,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),97,decoded);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),88,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),89,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),90,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),91,decoded);
            testByteByByte(encoded, decoded, 64, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),98,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),92,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),93,decoded);
            testByteByByte(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),99,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),94,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),95,decoded);
                testByteByByte(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64OutputStream implementation
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test(timeout = 1000)
    public void testBase64OutputStreamByteByByte_remove9() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64OutputStreamByteByByte_remove9");
            byte[] encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("SGVsbG8gV29ybGQ=\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),96,encoded);
            byte[] decoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(STRING_FIXTURE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),97,decoded);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("AA==\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),88,encoded);
            decoded = new byte[]{ ((byte)(0)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),89,decoded);
            testByteByByte(encoded, decoded, 76, CRLF);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(Base64TestData.ENCODED_64_CHARS_PER_LINE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),90,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),91,decoded);
            testByteByByte(encoded, decoded, 64, LF);
            final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),98,singleLine);
            encoded = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(singleLine);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),92,encoded);
            decoded = Base64TestData.DECODED;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),93,decoded);
            testByteByByte(encoded, decoded, 0, LF);
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, false);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),99,randomData);
                encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),94,encoded);
                decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),95,decoded);
                testByteByByte(encoded, decoded, 0, LF);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test method does three tests on the supplied data: 1. encoded ---[DECODE]--> decoded 2. decoded ---[ENCODE]-->
     * encoded 3. decoded ---[WRAP-WRAP-WRAP-etc...] --> decoded
     * <p/>
     * By "[WRAP-WRAP-WRAP-etc...]" we mean situation where the Base64OutputStream wraps itself in encode and decode
     * mode over and over again.
     * 
     * @param encoded
     * base64 encoded data
     * @param decoded
     * the data from above, but decoded
     * @param chunkSize
     * chunk size (line-length) of the base64 encoded data.
     * @param separator
     * Line separator in the base64 encoded data.
     * @throws Exception
     * Usually signifies a bug in the Base64 commons-codec implementation.
     */
private void testByChunk(final byte[] encoded, final byte[] decoded, final int chunkSize, final byte[] separator) throws Exception {
        ByteArrayOutputStream byteOut = new ByteArrayOutputStream();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),111,byteOut);
        OutputStream out = new Base64OutputStream(byteOut , true , chunkSize , separator);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),112,out);
        out.write(decoded);
        out.close();
        byte[] output = byteOut.toByteArray();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),113,output);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),100,java.util.Arrays.equals(output, encoded));
        byteOut = new ByteArrayOutputStream();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),103,byteOut);
        out = new Base64OutputStream(byteOut , false);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),104,out);
        out.write(encoded);
        out.close();
        output = byteOut.toByteArray();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),105,output);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),101,java.util.Arrays.equals(output, decoded));
        byteOut = new ByteArrayOutputStream();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),106,byteOut);
        out = byteOut;
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),107,out);
        for (int i = 0 ; i < 10 ; i++) {
            out = new Base64OutputStream(out , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),108,out);
            out = new Base64OutputStream(out , true , chunkSize , separator);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),109,out);
        }
        out.write(decoded);
        out.close();
        output = byteOut.toByteArray();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),110,output);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),102,java.util.Arrays.equals(output, decoded));
    }

    /** 
     * Test method does three tests on the supplied data: 1. encoded ---[DECODE]--> decoded 2. decoded ---[ENCODE]-->
     * encoded 3. decoded ---[WRAP-WRAP-WRAP-etc...] --> decoded
     * <p/>
     * By "[WRAP-WRAP-WRAP-etc...]" we mean situation where the Base64OutputStream wraps itself in encode and decode
     * mode over and over again.
     * 
     * @param encoded
     * base64 encoded data
     * @param decoded
     * the data from above, but decoded
     * @param chunkSize
     * chunk size (line-length) of the base64 encoded data.
     * @param separator
     * Line separator in the base64 encoded data.
     * @throws Exception
     * Usually signifies a bug in the Base64 commons-codec implementation.
     */
private void testByteByByte(final byte[] encoded, final byte[] decoded, final int chunkSize, final byte[] separator) throws Exception {
        ByteArrayOutputStream byteOut = new ByteArrayOutputStream();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),129,byteOut);
        OutputStream out = new Base64OutputStream(byteOut , true , chunkSize , separator);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),130,out);
        for (final byte element : decoded) {
            out.write(element);
        }
        out.close();
        byte[] output = byteOut.toByteArray();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),131,output);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),114,java.util.Arrays.equals(output, encoded));
        byteOut = new ByteArrayOutputStream();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),118,byteOut);
        out = new Base64OutputStream(byteOut , false);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),119,out);
        for (final byte element : encoded) {
            out.write(element);
        }
        out.close();
        output = byteOut.toByteArray();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),120,output);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),115,java.util.Arrays.equals(output, decoded));
        byteOut = new ByteArrayOutputStream();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),121,byteOut);
        out = new Base64OutputStream(byteOut , false);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),122,out);
        for (final byte element : encoded) {
            out.write(element);
            out.flush();
        }
        out.close();
        output = byteOut.toByteArray();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),123,output);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),116,java.util.Arrays.equals(output, decoded));
        byteOut = new ByteArrayOutputStream();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,byteOut);
        out = byteOut;
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),125,out);
        for (int i = 0 ; i < 10 ; i++) {
            out = new Base64OutputStream(out , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),126,out);
            out = new Base64OutputStream(out , true , chunkSize , separator);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),127,out);
        }
        for (final byte element : decoded) {
            out.write(element);
        }
        out.close();
        output = byteOut.toByteArray();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),128,output);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),117,java.util.Arrays.equals(output, decoded));
    }

    /** 
     * Tests Base64OutputStream.write for expected IndexOutOfBoundsException conditions.
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test(timeout = 1000)
    public void testWriteOutOfBounds_add18() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriteOutOfBounds_add18");
            final byte[] buf = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),140,buf);
            final ByteArrayOutputStream bout = new ByteArrayOutputStream();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),141,bout);
            final Base64OutputStream out = new Base64OutputStream(bout);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),142,out);
            try {
                out.write(buf, 2, 1);
                out.write(buf, 2, 1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, 1, 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) + 1), 0);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) - 1), 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            out.close();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests Base64OutputStream.write for expected IndexOutOfBoundsException conditions.
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test(timeout = 1000)
    public void testWriteOutOfBounds_add19() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriteOutOfBounds_add19");
            final byte[] buf = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),140,buf);
            final ByteArrayOutputStream bout = new ByteArrayOutputStream();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),141,bout);
            final Base64OutputStream out = new Base64OutputStream(bout);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),142,out);
            try {
                out.write(buf, 2, 1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, 1, 2);
                out.write(buf, 1, 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) + 1), 0);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) - 1), 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            out.close();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests Base64OutputStream.write for expected IndexOutOfBoundsException conditions.
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test(timeout = 1000)
    public void testWriteOutOfBounds_add20() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriteOutOfBounds_add20");
            final byte[] buf = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),140,buf);
            final ByteArrayOutputStream bout = new ByteArrayOutputStream();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),141,bout);
            final Base64OutputStream out = new Base64OutputStream(bout);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),142,out);
            try {
                out.write(buf, 2, 1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, 1, 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) + 1), 0);
                out.write(buf, ((buf.length) + 1), 0);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) - 1), 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            out.close();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests Base64OutputStream.write for expected IndexOutOfBoundsException conditions.
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test(timeout = 1000)
    public void testWriteOutOfBounds_add21() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriteOutOfBounds_add21");
            final byte[] buf = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),140,buf);
            final ByteArrayOutputStream bout = new ByteArrayOutputStream();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),141,bout);
            final Base64OutputStream out = new Base64OutputStream(bout);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),142,out);
            try {
                out.write(buf, 2, 1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, 1, 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) + 1), 0);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) - 1), 2);
                out.write(buf, ((buf.length) - 1), 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            out.close();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests Base64OutputStream.write for expected IndexOutOfBoundsException conditions.
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test(timeout = 1000)
    public void testWriteOutOfBounds_add22() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriteOutOfBounds_add22");
            final byte[] buf = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),140,buf);
            final ByteArrayOutputStream bout = new ByteArrayOutputStream();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),141,bout);
            final Base64OutputStream out = new Base64OutputStream(bout);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),142,out);
            try {
                out.write(buf, 2, 1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, 1, 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) + 1), 0);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) - 1), 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            out.close();
            out.close();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests Base64OutputStream.write for expected IndexOutOfBoundsException conditions.
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testWriteOutOfBounds() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriteOutOfBounds");
            final byte[] buf = new byte[1025];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),140,buf);
            final ByteArrayOutputStream bout = new ByteArrayOutputStream();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),141,bout);
            final Base64OutputStream out = new Base64OutputStream(bout);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),142,out);
            try {
                out.write(buf, -1, 1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, 1, -1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) + 1), 0);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) - 1), 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            out.close();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests Base64OutputStream.write for expected IndexOutOfBoundsException conditions.
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testWriteOutOfBounds_literalMutation126() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriteOutOfBounds_literalMutation126");
            final byte[] buf = new byte[512];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),140,buf);
            final ByteArrayOutputStream bout = new ByteArrayOutputStream();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),141,bout);
            final Base64OutputStream out = new Base64OutputStream(bout);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),142,out);
            try {
                out.write(buf, -1, 1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, 1, -1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) + 1), 0);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) - 1), 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            out.close();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests Base64OutputStream.write for expected IndexOutOfBoundsException conditions.
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testWriteOutOfBounds_literalMutation127() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriteOutOfBounds_literalMutation127");
            final byte[] buf = new byte[2048];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),140,buf);
            final ByteArrayOutputStream bout = new ByteArrayOutputStream();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),141,bout);
            final Base64OutputStream out = new Base64OutputStream(bout);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),142,out);
            try {
                out.write(buf, -1, 1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, 1, -1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) + 1), 0);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) - 1), 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            out.close();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests Base64OutputStream.write for expected IndexOutOfBoundsException conditions.
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testWriteOutOfBounds_literalMutation128() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriteOutOfBounds_literalMutation128");
            final byte[] buf = new byte[1023];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),140,buf);
            final ByteArrayOutputStream bout = new ByteArrayOutputStream();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),141,bout);
            final Base64OutputStream out = new Base64OutputStream(bout);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),142,out);
            try {
                out.write(buf, -1, 1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, 1, -1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) + 1), 0);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) - 1), 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            out.close();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests Base64OutputStream.write for expected IndexOutOfBoundsException conditions.
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testWriteOutOfBounds_literalMutation130() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriteOutOfBounds_literalMutation130");
            final byte[] buf = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),140,buf);
            final ByteArrayOutputStream bout = new ByteArrayOutputStream();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),141,bout);
            final Base64OutputStream out = new Base64OutputStream(bout);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),142,out);
            try {
                out.write(buf, -2, 1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, 1, -1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) + 1), 0);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) - 1), 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            out.close();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests Base64OutputStream.write for expected IndexOutOfBoundsException conditions.
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testWriteOutOfBounds_literalMutation131() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriteOutOfBounds_literalMutation131");
            final byte[] buf = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),140,buf);
            final ByteArrayOutputStream bout = new ByteArrayOutputStream();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),141,bout);
            final Base64OutputStream out = new Base64OutputStream(bout);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),142,out);
            try {
                out.write(buf, 0, 1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, 1, -1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) + 1), 0);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) - 1), 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            out.close();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests Base64OutputStream.write for expected IndexOutOfBoundsException conditions.
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testWriteOutOfBounds_literalMutation132() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriteOutOfBounds_literalMutation132");
            final byte[] buf = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),140,buf);
            final ByteArrayOutputStream bout = new ByteArrayOutputStream();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),141,bout);
            final Base64OutputStream out = new Base64OutputStream(bout);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),142,out);
            try {
                out.write(buf, 0, 1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, 1, -1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) + 1), 0);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) - 1), 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            out.close();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests Base64OutputStream.write for expected IndexOutOfBoundsException conditions.
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testWriteOutOfBounds_literalMutation134() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriteOutOfBounds_literalMutation134");
            final byte[] buf = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),140,buf);
            final ByteArrayOutputStream bout = new ByteArrayOutputStream();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),141,bout);
            final Base64OutputStream out = new Base64OutputStream(bout);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),142,out);
            try {
                out.write(buf, 2, 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, 1, -1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) + 1), 0);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) - 1), 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            out.close();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests Base64OutputStream.write for expected IndexOutOfBoundsException conditions.
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testWriteOutOfBounds_literalMutation135() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriteOutOfBounds_literalMutation135");
            final byte[] buf = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),140,buf);
            final ByteArrayOutputStream bout = new ByteArrayOutputStream();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),141,bout);
            final Base64OutputStream out = new Base64OutputStream(bout);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),142,out);
            try {
                out.write(buf, 2, 0);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, 1, -1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) + 1), 0);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) - 1), 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            out.close();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests Base64OutputStream.write for expected IndexOutOfBoundsException conditions.
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testWriteOutOfBounds_literalMutation136() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriteOutOfBounds_literalMutation136");
            final byte[] buf = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),140,buf);
            final ByteArrayOutputStream bout = new ByteArrayOutputStream();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),141,bout);
            final Base64OutputStream out = new Base64OutputStream(bout);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),142,out);
            try {
                out.write(buf, 2, 0);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, 1, -1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) + 1), 0);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) - 1), 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            out.close();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests Base64OutputStream.write for expected IndexOutOfBoundsException conditions.
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testWriteOutOfBounds_literalMutation138() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriteOutOfBounds_literalMutation138");
            final byte[] buf = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),140,buf);
            final ByteArrayOutputStream bout = new ByteArrayOutputStream();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),141,bout);
            final Base64OutputStream out = new Base64OutputStream(bout);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),142,out);
            try {
                out.write(buf, 2, 1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, 2, -1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) + 1), 0);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) - 1), 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            out.close();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests Base64OutputStream.write for expected IndexOutOfBoundsException conditions.
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testWriteOutOfBounds_literalMutation139() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriteOutOfBounds_literalMutation139");
            final byte[] buf = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),140,buf);
            final ByteArrayOutputStream bout = new ByteArrayOutputStream();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),141,bout);
            final Base64OutputStream out = new Base64OutputStream(bout);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),142,out);
            try {
                out.write(buf, 2, 1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, 0, -1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) + 1), 0);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) - 1), 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            out.close();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests Base64OutputStream.write for expected IndexOutOfBoundsException conditions.
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testWriteOutOfBounds_literalMutation140() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriteOutOfBounds_literalMutation140");
            final byte[] buf = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),140,buf);
            final ByteArrayOutputStream bout = new ByteArrayOutputStream();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),141,bout);
            final Base64OutputStream out = new Base64OutputStream(bout);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),142,out);
            try {
                out.write(buf, 2, 1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, 0, -1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) + 1), 0);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) - 1), 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            out.close();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests Base64OutputStream.write for expected IndexOutOfBoundsException conditions.
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testWriteOutOfBounds_literalMutation142() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriteOutOfBounds_literalMutation142");
            final byte[] buf = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),140,buf);
            final ByteArrayOutputStream bout = new ByteArrayOutputStream();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),141,bout);
            final Base64OutputStream out = new Base64OutputStream(bout);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),142,out);
            try {
                out.write(buf, 2, 1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, 1, -2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) + 1), 0);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) - 1), 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            out.close();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests Base64OutputStream.write for expected IndexOutOfBoundsException conditions.
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testWriteOutOfBounds_literalMutation143() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriteOutOfBounds_literalMutation143");
            final byte[] buf = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),140,buf);
            final ByteArrayOutputStream bout = new ByteArrayOutputStream();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),141,bout);
            final Base64OutputStream out = new Base64OutputStream(bout);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),142,out);
            try {
                out.write(buf, 2, 1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, 1, 0);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) + 1), 0);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) - 1), 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            out.close();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests Base64OutputStream.write for expected IndexOutOfBoundsException conditions.
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testWriteOutOfBounds_literalMutation144() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriteOutOfBounds_literalMutation144");
            final byte[] buf = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),140,buf);
            final ByteArrayOutputStream bout = new ByteArrayOutputStream();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),141,bout);
            final Base64OutputStream out = new Base64OutputStream(bout);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),142,out);
            try {
                out.write(buf, 2, 1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, 1, 0);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) + 1), 0);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) - 1), 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            out.close();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests Base64OutputStream.write for expected IndexOutOfBoundsException conditions.
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testWriteOutOfBounds_literalMutation146() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriteOutOfBounds_literalMutation146");
            final byte[] buf = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),140,buf);
            final ByteArrayOutputStream bout = new ByteArrayOutputStream();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),141,bout);
            final Base64OutputStream out = new Base64OutputStream(bout);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),142,out);
            try {
                out.write(buf, 2, 1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, 1, 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) + 2), 0);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) - 1), 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            out.close();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests Base64OutputStream.write for expected IndexOutOfBoundsException conditions.
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testWriteOutOfBounds_literalMutation147() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriteOutOfBounds_literalMutation147");
            final byte[] buf = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),140,buf);
            final ByteArrayOutputStream bout = new ByteArrayOutputStream();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),141,bout);
            final Base64OutputStream out = new Base64OutputStream(bout);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),142,out);
            try {
                out.write(buf, 2, 1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, 1, 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) + 0), 0);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) - 1), 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            out.close();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests Base64OutputStream.write for expected IndexOutOfBoundsException conditions.
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testWriteOutOfBounds_literalMutation148() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriteOutOfBounds_literalMutation148");
            final byte[] buf = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),140,buf);
            final ByteArrayOutputStream bout = new ByteArrayOutputStream();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),141,bout);
            final Base64OutputStream out = new Base64OutputStream(bout);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),142,out);
            try {
                out.write(buf, 2, 1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, 1, 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) + 0), 0);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) - 1), 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            out.close();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests Base64OutputStream.write for expected IndexOutOfBoundsException conditions.
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testWriteOutOfBounds_literalMutation150() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriteOutOfBounds_literalMutation150");
            final byte[] buf = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),140,buf);
            final ByteArrayOutputStream bout = new ByteArrayOutputStream();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),141,bout);
            final Base64OutputStream out = new Base64OutputStream(bout);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),142,out);
            try {
                out.write(buf, 2, 1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, 1, 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) + 1), 1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) - 1), 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            out.close();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests Base64OutputStream.write for expected IndexOutOfBoundsException conditions.
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testWriteOutOfBounds_literalMutation151() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriteOutOfBounds_literalMutation151");
            final byte[] buf = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),140,buf);
            final ByteArrayOutputStream bout = new ByteArrayOutputStream();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),141,bout);
            final Base64OutputStream out = new Base64OutputStream(bout);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),142,out);
            try {
                out.write(buf, 2, 1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, 1, 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) + 1), -1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) - 1), 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            out.close();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests Base64OutputStream.write for expected IndexOutOfBoundsException conditions.
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testWriteOutOfBounds_literalMutation152() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriteOutOfBounds_literalMutation152");
            final byte[] buf = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),140,buf);
            final ByteArrayOutputStream bout = new ByteArrayOutputStream();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),141,bout);
            final Base64OutputStream out = new Base64OutputStream(bout);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),142,out);
            try {
                out.write(buf, 2, 1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, 1, 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) + 1), 0);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) - 1), 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            out.close();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests Base64OutputStream.write for expected IndexOutOfBoundsException conditions.
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testWriteOutOfBounds_literalMutation154() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriteOutOfBounds_literalMutation154");
            final byte[] buf = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),140,buf);
            final ByteArrayOutputStream bout = new ByteArrayOutputStream();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),141,bout);
            final Base64OutputStream out = new Base64OutputStream(bout);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),142,out);
            try {
                out.write(buf, 2, 1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, 1, 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) + 1), 0);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) - 2), 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            out.close();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests Base64OutputStream.write for expected IndexOutOfBoundsException conditions.
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testWriteOutOfBounds_literalMutation155() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriteOutOfBounds_literalMutation155");
            final byte[] buf = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),140,buf);
            final ByteArrayOutputStream bout = new ByteArrayOutputStream();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),141,bout);
            final Base64OutputStream out = new Base64OutputStream(bout);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),142,out);
            try {
                out.write(buf, 2, 1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, 1, 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) + 1), 0);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) - 0), 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            out.close();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests Base64OutputStream.write for expected IndexOutOfBoundsException conditions.
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testWriteOutOfBounds_literalMutation156() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriteOutOfBounds_literalMutation156");
            final byte[] buf = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),140,buf);
            final ByteArrayOutputStream bout = new ByteArrayOutputStream();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),141,bout);
            final Base64OutputStream out = new Base64OutputStream(bout);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),142,out);
            try {
                out.write(buf, 2, 1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, 1, 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) + 1), 0);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) - 0), 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            out.close();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests Base64OutputStream.write for expected IndexOutOfBoundsException conditions.
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testWriteOutOfBounds_literalMutation158() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriteOutOfBounds_literalMutation158");
            final byte[] buf = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),140,buf);
            final ByteArrayOutputStream bout = new ByteArrayOutputStream();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),141,bout);
            final Base64OutputStream out = new Base64OutputStream(bout);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),142,out);
            try {
                out.write(buf, 2, 1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, 1, 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) + 1), 0);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) - 1), 1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            out.close();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests Base64OutputStream.write for expected IndexOutOfBoundsException conditions.
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testWriteOutOfBounds_literalMutation159() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriteOutOfBounds_literalMutation159");
            final byte[] buf = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),140,buf);
            final ByteArrayOutputStream bout = new ByteArrayOutputStream();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),141,bout);
            final Base64OutputStream out = new Base64OutputStream(bout);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),142,out);
            try {
                out.write(buf, 2, 1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, 1, 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) + 1), 0);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) - 1), 4);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            out.close();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests Base64OutputStream.write for expected IndexOutOfBoundsException conditions.
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testWriteOutOfBounds_literalMutation160() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriteOutOfBounds_literalMutation160");
            final byte[] buf = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),140,buf);
            final ByteArrayOutputStream bout = new ByteArrayOutputStream();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),141,bout);
            final Base64OutputStream out = new Base64OutputStream(bout);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),142,out);
            try {
                out.write(buf, 2, 1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, 1, 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) + 1), 0);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) - 1), 3);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            out.close();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests Base64OutputStream.write for expected IndexOutOfBoundsException conditions.
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test(timeout = 1000)
    public void testWriteOutOfBounds_remove16() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriteOutOfBounds_remove16");
            final byte[] buf = new byte[1024];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),140,buf);
            final ByteArrayOutputStream bout = new ByteArrayOutputStream();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),141,bout);
            final Base64OutputStream out = new Base64OutputStream(bout);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),142,out);
            try {
                out.write(buf, 2, 1);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, 1, 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) + 1), 0);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
            try {
                out.write(buf, ((buf.length) - 1), 2);
            } catch (final IndexOutOfBoundsException ioobe) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests Base64OutputStream.write(null).
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test(timeout = 1000)
    public void testWriteToNullCoverage_add23() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriteToNullCoverage_add23");
            final ByteArrayOutputStream bout = new ByteArrayOutputStream();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),143,bout);
            final Base64OutputStream out = new Base64OutputStream(bout);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),144,out);
            try {
                out.write(null, 0, 0);
                out.write(null, 0, 0);
            } catch (final NullPointerException e) {
            } finally {
                out.close();
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests Base64OutputStream.write(null).
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test(timeout = 1000)
    public void testWriteToNullCoverage_add24() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriteToNullCoverage_add24");
            final ByteArrayOutputStream bout = new ByteArrayOutputStream();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),143,bout);
            final Base64OutputStream out = new Base64OutputStream(bout);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),144,out);
            try {
                out.write(null, 0, 0);
            } catch (final NullPointerException e) {
            } finally {
                out.close();
                out.close();
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests Base64OutputStream.write(null).
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testWriteToNullCoverage() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriteToNullCoverage");
            final ByteArrayOutputStream bout = new ByteArrayOutputStream();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),143,bout);
            final Base64OutputStream out = new Base64OutputStream(bout);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),144,out);
            try {
                out.write(null, 1, 0);
            } catch (final NullPointerException e) {
            } finally {
                out.close();
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests Base64OutputStream.write(null).
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testWriteToNullCoverage_literalMutation164() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriteToNullCoverage_literalMutation164");
            final ByteArrayOutputStream bout = new ByteArrayOutputStream();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),143,bout);
            final Base64OutputStream out = new Base64OutputStream(bout);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),144,out);
            try {
                out.write(null, -1, 0);
            } catch (final NullPointerException e) {
            } finally {
                out.close();
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests Base64OutputStream.write(null).
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testWriteToNullCoverage_literalMutation165() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriteToNullCoverage_literalMutation165");
            final ByteArrayOutputStream bout = new ByteArrayOutputStream();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),143,bout);
            final Base64OutputStream out = new Base64OutputStream(bout);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),144,out);
            try {
                out.write(null, 0, 0);
            } catch (final NullPointerException e) {
            } finally {
                out.close();
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests Base64OutputStream.write(null).
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testWriteToNullCoverage_literalMutation167() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriteToNullCoverage_literalMutation167");
            final ByteArrayOutputStream bout = new ByteArrayOutputStream();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),143,bout);
            final Base64OutputStream out = new Base64OutputStream(bout);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),144,out);
            try {
                out.write(null, 0, 1);
            } catch (final NullPointerException e) {
            } finally {
                out.close();
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests Base64OutputStream.write(null).
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testWriteToNullCoverage_literalMutation168() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriteToNullCoverage_literalMutation168");
            final ByteArrayOutputStream bout = new ByteArrayOutputStream();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),143,bout);
            final Base64OutputStream out = new Base64OutputStream(bout);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),144,out);
            try {
                out.write(null, 0, -1);
            } catch (final NullPointerException e) {
            } finally {
                out.close();
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests Base64OutputStream.write(null).
     * 
     * @throws Exception
     * for some failure scenarios.
     */
@Test
    public void testWriteToNullCoverage_literalMutation169() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testWriteToNullCoverage_literalMutation169");
            final ByteArrayOutputStream bout = new ByteArrayOutputStream();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),143,bout);
            final Base64OutputStream out = new Base64OutputStream(bout);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),144,out);
            try {
                out.write(null, 0, 0);
            } catch (final NullPointerException e) {
            } finally {
                out.close();
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }
}

