package org.apache.commons.codec.binary;

import java.math.BigInteger;
import org.apache.commons.codec.DecoderException;
import org.apache.commons.codec.EncoderException;
import org.junit.Ignore;
import java.util.Random;
import org.junit.Test;

/** 
 * Test cases for Base64 class.
 * 
 * @see <a href="http://www.ietf.org/rfc/rfc2045.txt">RFC 2045</a>
 * @version $Id$
 */
public class Base64Test {
    private final Random random = new Random();

    /** 
     * @return Returns the random.
     */
public Random getRandom() {
        return this.random;
    }

    /** 
     * Test the isStringBase64 method.
     */
@Test(timeout = 1000)
    public void testIsStringBase64() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsStringBase64");
            final String nullString = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),314,nullString);
            final String emptyString = "";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),315,emptyString);
            final String validString = "abc===defg\n\r123456\r789\r\rABC\n\nDEF==GHI\r\nJKL==============";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),316,validString);
            final String invalidString = validString + ((char)(0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),317,invalidString);
            try {
                Base64.isBase64(nullString);
                Base64.isBase64(nullString);
            } catch (final NullPointerException npe) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),310,npe);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),311,org.apache.commons.codec.binary.Base64.isBase64(emptyString));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),312,org.apache.commons.codec.binary.Base64.isBase64(validString));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),313,org.apache.commons.codec.binary.Base64.isBase64(invalidString));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64 implementation
     */
@Test
    public void testBase64() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64");
            final String content = "He¥lo World";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),156,content);
            String encodedContent;
            byte[] encodedBytes = Base64.encodeBase64(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(content));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),157,encodedBytes);
            encodedContent = org.apache.commons.codec.binary.StringUtils.newStringUtf8(encodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),150,encodedContent);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),146,encodedContent);
            Base64 b64 = new Base64(BaseNCodec.MIME_CHUNK_SIZE , null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),158,b64);
            encodedBytes = b64.encode(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(content));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),151,encodedBytes);
            encodedContent = org.apache.commons.codec.binary.StringUtils.newStringUtf8(encodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),152,encodedContent);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),147,encodedContent);
            b64 = new Base64(0 , null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),153,b64);
            encodedBytes = b64.encode(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(content));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),154,encodedBytes);
            encodedContent = org.apache.commons.codec.binary.StringUtils.newStringUtf8(encodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),155,encodedContent);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),148,encodedContent);
            final byte[] decode = b64.decode("SGVsbG{éééééé}8gV29ybGQ=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),159,decode);
            final String decodeString = org.apache.commons.codec.binary.StringUtils.newStringUtf8(decode);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),160,decodeString);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),149,decodeString);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64 implementation
     */
@Test
    public void testBase64_literalMutation172() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64_literalMutation172");
            final String content = "Hello Wo±rld";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),156,content);
            String encodedContent;
            byte[] encodedBytes = Base64.encodeBase64(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(content));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),157,encodedBytes);
            encodedContent = org.apache.commons.codec.binary.StringUtils.newStringUtf8(encodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),150,encodedContent);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),146,encodedContent);
            Base64 b64 = new Base64(BaseNCodec.MIME_CHUNK_SIZE , null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),158,b64);
            encodedBytes = b64.encode(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(content));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),151,encodedBytes);
            encodedContent = org.apache.commons.codec.binary.StringUtils.newStringUtf8(encodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),152,encodedContent);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),147,encodedContent);
            b64 = new Base64(0 , null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),153,b64);
            encodedBytes = b64.encode(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(content));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),154,encodedBytes);
            encodedContent = org.apache.commons.codec.binary.StringUtils.newStringUtf8(encodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),155,encodedContent);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),148,encodedContent);
            final byte[] decode = b64.decode("SGVsbG{éééééé}8gV29ybGQ=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),159,decode);
            final String decodeString = org.apache.commons.codec.binary.StringUtils.newStringUtf8(decode);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),160,decodeString);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),149,decodeString);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64 implementation
     */
@Test
    public void testBase64_literalMutation173() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64_literalMutation173");
            final String content = "Hello Wrld";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),156,content);
            String encodedContent;
            byte[] encodedBytes = Base64.encodeBase64(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(content));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),157,encodedBytes);
            encodedContent = org.apache.commons.codec.binary.StringUtils.newStringUtf8(encodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),150,encodedContent);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),146,encodedContent);
            Base64 b64 = new Base64(BaseNCodec.MIME_CHUNK_SIZE , null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),158,b64);
            encodedBytes = b64.encode(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(content));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),151,encodedBytes);
            encodedContent = org.apache.commons.codec.binary.StringUtils.newStringUtf8(encodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),152,encodedContent);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),147,encodedContent);
            b64 = new Base64(0 , null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),153,b64);
            encodedBytes = b64.encode(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(content));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),154,encodedBytes);
            encodedContent = org.apache.commons.codec.binary.StringUtils.newStringUtf8(encodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),155,encodedContent);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),148,encodedContent);
            final byte[] decode = b64.decode("SGVsbG{éééééé}8gV29ybGQ=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),159,decode);
            final String decodeString = org.apache.commons.codec.binary.StringUtils.newStringUtf8(decode);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),160,decodeString);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),149,decodeString);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64 implementation
     */
@Test
    public void testBase64_literalMutation175() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64_literalMutation175");
            final String content = "Hello World";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),156,content);
            String encodedContent;
            byte[] encodedBytes = Base64.encodeBase64(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(content));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),157,encodedBytes);
            encodedContent = org.apache.commons.codec.binary.StringUtils.newStringUtf8(encodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),150,encodedContent);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),146,encodedContent);
            Base64 b64 = new Base64(BaseNCodec.MIME_CHUNK_SIZE , null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),158,b64);
            encodedBytes = b64.encode(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(content));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),151,encodedBytes);
            encodedContent = org.apache.commons.codec.binary.StringUtils.newStringUtf8(encodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),152,encodedContent);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),147,encodedContent);
            b64 = new Base64(1 , null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),153,b64);
            encodedBytes = b64.encode(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(content));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),154,encodedBytes);
            encodedContent = org.apache.commons.codec.binary.StringUtils.newStringUtf8(encodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),155,encodedContent);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),148,encodedContent);
            final byte[] decode = b64.decode("SGVsbG{éééééé}8gV29ybGQ=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),159,decode);
            final String decodeString = org.apache.commons.codec.binary.StringUtils.newStringUtf8(decode);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),160,decodeString);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),149,decodeString);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64 implementation
     */
@Test
    public void testBase64_literalMutation176() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64_literalMutation176");
            final String content = "Hello World";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),156,content);
            String encodedContent;
            byte[] encodedBytes = Base64.encodeBase64(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(content));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),157,encodedBytes);
            encodedContent = org.apache.commons.codec.binary.StringUtils.newStringUtf8(encodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),150,encodedContent);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),146,encodedContent);
            Base64 b64 = new Base64(BaseNCodec.MIME_CHUNK_SIZE , null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),158,b64);
            encodedBytes = b64.encode(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(content));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),151,encodedBytes);
            encodedContent = org.apache.commons.codec.binary.StringUtils.newStringUtf8(encodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),152,encodedContent);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),147,encodedContent);
            b64 = new Base64(-1 , null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),153,b64);
            encodedBytes = b64.encode(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(content));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),154,encodedBytes);
            encodedContent = org.apache.commons.codec.binary.StringUtils.newStringUtf8(encodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),155,encodedContent);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),148,encodedContent);
            final byte[] decode = b64.decode("SGVsbG{éééééé}8gV29ybGQ=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),159,decode);
            final String decodeString = org.apache.commons.codec.binary.StringUtils.newStringUtf8(decode);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),160,decodeString);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),149,decodeString);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64 implementation
     */
@Test
    public void testBase64_literalMutation177() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64_literalMutation177");
            final String content = "Hello World";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),156,content);
            String encodedContent;
            byte[] encodedBytes = Base64.encodeBase64(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(content));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),157,encodedBytes);
            encodedContent = org.apache.commons.codec.binary.StringUtils.newStringUtf8(encodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),150,encodedContent);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),146,encodedContent);
            Base64 b64 = new Base64(BaseNCodec.MIME_CHUNK_SIZE , null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),158,b64);
            encodedBytes = b64.encode(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(content));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),151,encodedBytes);
            encodedContent = org.apache.commons.codec.binary.StringUtils.newStringUtf8(encodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),152,encodedContent);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),147,encodedContent);
            b64 = new Base64(0 , null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),153,b64);
            encodedBytes = b64.encode(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(content));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),154,encodedBytes);
            encodedContent = org.apache.commons.codec.binary.StringUtils.newStringUtf8(encodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),155,encodedContent);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),148,encodedContent);
            final byte[] decode = b64.decode("SGVsbG{éééééé}8gV29ybGQ=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),159,decode);
            final String decodeString = org.apache.commons.codec.binary.StringUtils.newStringUtf8(decode);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),160,decodeString);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),149,decodeString);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64 implementation
     */
@Test
    public void testBase64_literalMutation180() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64_literalMutation180");
            final String content = "Hello World";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),156,content);
            String encodedContent;
            byte[] encodedBytes = Base64.encodeBase64(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(content));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),157,encodedBytes);
            encodedContent = org.apache.commons.codec.binary.StringUtils.newStringUtf8(encodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),150,encodedContent);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),146,encodedContent);
            Base64 b64 = new Base64(BaseNCodec.MIME_CHUNK_SIZE , null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),158,b64);
            encodedBytes = b64.encode(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(content));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),151,encodedBytes);
            encodedContent = org.apache.commons.codec.binary.StringUtils.newStringUtf8(encodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),152,encodedContent);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),147,encodedContent);
            b64 = new Base64(0 , null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),153,b64);
            encodedBytes = b64.encode(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(content));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),154,encodedBytes);
            encodedContent = org.apache.commons.codec.binary.StringUtils.newStringUtf8(encodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),155,encodedContent);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),148,encodedContent);
            final byte[] decode = b64.decode("SGVsbU{éééééé}8gV29ybGQ=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),159,decode);
            final String decodeString = org.apache.commons.codec.binary.StringUtils.newStringUtf8(decode);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),160,decodeString);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),149,decodeString);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64 implementation
     */
@Test
    public void testBase64_literalMutation181() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64_literalMutation181");
            final String content = "Hello World";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),156,content);
            String encodedContent;
            byte[] encodedBytes = Base64.encodeBase64(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(content));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),157,encodedBytes);
            encodedContent = org.apache.commons.codec.binary.StringUtils.newStringUtf8(encodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),150,encodedContent);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),146,encodedContent);
            Base64 b64 = new Base64(BaseNCodec.MIME_CHUNK_SIZE , null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),158,b64);
            encodedBytes = b64.encode(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(content));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),151,encodedBytes);
            encodedContent = org.apache.commons.codec.binary.StringUtils.newStringUtf8(encodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),152,encodedContent);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),147,encodedContent);
            b64 = new Base64(0 , null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),153,b64);
            encodedBytes = b64.encode(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(content));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),154,encodedBytes);
            encodedContent = org.apache.commons.codec.binary.StringUtils.newStringUtf8(encodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),155,encodedContent);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),148,encodedContent);
            final byte[] decode = b64.decode("SGVsbG{éééééé}8gV29ÉybGQ=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),159,decode);
            final String decodeString = org.apache.commons.codec.binary.StringUtils.newStringUtf8(decode);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),160,decodeString);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),149,decodeString);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the Base64 implementation
     */
@Test
    public void testBase64_literalMutation182() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBase64_literalMutation182");
            final String content = "Hello World";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),156,content);
            String encodedContent;
            byte[] encodedBytes = Base64.encodeBase64(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(content));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),157,encodedBytes);
            encodedContent = org.apache.commons.codec.binary.StringUtils.newStringUtf8(encodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),150,encodedContent);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),146,encodedContent);
            Base64 b64 = new Base64(BaseNCodec.MIME_CHUNK_SIZE , null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),158,b64);
            encodedBytes = b64.encode(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(content));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),151,encodedBytes);
            encodedContent = org.apache.commons.codec.binary.StringUtils.newStringUtf8(encodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),152,encodedContent);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),147,encodedContent);
            b64 = new Base64(0 , null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),153,b64);
            encodedBytes = b64.encode(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(content));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),154,encodedBytes);
            encodedContent = org.apache.commons.codec.binary.StringUtils.newStringUtf8(encodedBytes);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),155,encodedContent);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),148,encodedContent);
            final byte[] decode = b64.decode("SGVsb{éééééé}8gV29ybGQ=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),159,decode);
            final String decodeString = org.apache.commons.codec.binary.StringUtils.newStringUtf8(decode);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),160,decodeString);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),149,decodeString);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test our decode with pad character in the middle.
     * (Our current implementation:  halt decode and return what we've got so far).
     * 
     * The point of this test is not to say "this is the correct way to decode base64."
     * The point is simply to keep us aware of the current logic since 1.4 so we
     * don't accidentally break it without realizing.
     * 
     * Note for historians.  The 1.3 logic would decode to:
     * "Hello World\u0000Hello World" -- null in the middle ---
     * and 1.4 unwittingly changed it to current logic.
     */
@Test
    public void testDecodeWithInnerPad() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodeWithInnerPad");
            final String content = "SGV_bG8gV29ybGQ=SGVsbG8gV29ybGQ=";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),254,content);
            final byte[] result = Base64.decodeBase64(content);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),255,result);
            final byte[] shouldBe = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("Hello World");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),256,shouldBe);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),253,java.util.Arrays.equals(result, shouldBe));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test our decode with pad character in the middle.
     * (Our current implementation:  halt decode and return what we've got so far).
     * 
     * The point of this test is not to say "this is the correct way to decode base64."
     * The point is simply to keep us aware of the current logic since 1.4 so we
     * don't accidentally break it without realizing.
     * 
     * Note for historians.  The 1.3 logic would decode to:
     * "Hello World\u0000Hello World" -- null in the middle ---
     * and 1.4 unwittingly changed it to current logic.
     */
@Test
    public void testDecodeWithInnerPad_literalMutation348() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodeWithInnerPad_literalMutation348");
            final String content = "SGVsbG8gV29ybGQ=SGVsbG8gV29ybGQ=";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),254,content);
            final byte[] result = Base64.decodeBase64(content);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),255,result);
            final byte[] shouldBe = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("Hello World");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),256,shouldBe);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),253,java.util.Arrays.equals(result, shouldBe));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test our decode with pad character in the middle.
     * (Our current implementation:  halt decode and return what we've got so far).
     * 
     * The point of this test is not to say "this is the correct way to decode base64."
     * The point is simply to keep us aware of the current logic since 1.4 so we
     * don't accidentally break it without realizing.
     * 
     * Note for historians.  The 1.3 logic would decode to:
     * "Hello World\u0000Hello World" -- null in the middle ---
     * and 1.4 unwittingly changed it to current logic.
     */
@Test
    public void testDecodeWithInnerPad_literalMutation349() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodeWithInnerPad_literalMutation349");
            final String content = "SGVsbG8gV29ybGQ=SGVsbG8gV29bGQ=";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),254,content);
            final byte[] result = Base64.decodeBase64(content);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),255,result);
            final byte[] shouldBe = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("Hello World");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),256,shouldBe);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),253,java.util.Arrays.equals(result, shouldBe));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test our decode with pad character in the middle.
     * (Our current implementation:  halt decode and return what we've got so far).
     * 
     * The point of this test is not to say "this is the correct way to decode base64."
     * The point is simply to keep us aware of the current logic since 1.4 so we
     * don't accidentally break it without realizing.
     * 
     * Note for historians.  The 1.3 logic would decode to:
     * "Hello World\u0000Hello World" -- null in the middle ---
     * and 1.4 unwittingly changed it to current logic.
     */
@Test
    public void testDecodeWithInnerPad_literalMutation350() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodeWithInnerPad_literalMutation350");
            final String content = "SGVsbG8gV29ybGQ=SGVsbG8gV29ybGQ=";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),254,content);
            final byte[] result = Base64.decodeBase64(content);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),255,result);
            final byte[] shouldBe = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("HÜllo World");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),256,shouldBe);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),253,java.util.Arrays.equals(result, shouldBe));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test our decode with pad character in the middle.
     * (Our current implementation:  halt decode and return what we've got so far).
     * 
     * The point of this test is not to say "this is the correct way to decode base64."
     * The point is simply to keep us aware of the current logic since 1.4 so we
     * don't accidentally break it without realizing.
     * 
     * Note for historians.  The 1.3 logic would decode to:
     * "Hello World\u0000Hello World" -- null in the middle ---
     * and 1.4 unwittingly changed it to current logic.
     */
@Test
    public void testDecodeWithInnerPad_literalMutation351() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodeWithInnerPad_literalMutation351");
            final String content = "SGVsbG8gV29ybGQ=SGVsbG8gV29ybGQ=";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),254,content);
            final byte[] result = Base64.decodeBase64(content);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),255,result);
            final byte[] shouldBe = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("Hecllo World");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),256,shouldBe);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),253,java.util.Arrays.equals(result, shouldBe));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test our decode with pad character in the middle.
     * (Our current implementation:  halt decode and return what we've got so far).
     * 
     * The point of this test is not to say "this is the correct way to decode base64."
     * The point is simply to keep us aware of the current logic since 1.4 so we
     * don't accidentally break it without realizing.
     * 
     * Note for historians.  The 1.3 logic would decode to:
     * "Hello World\u0000Hello World" -- null in the middle ---
     * and 1.4 unwittingly changed it to current logic.
     */
@Test
    public void testDecodeWithInnerPad_literalMutation352() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodeWithInnerPad_literalMutation352");
            final String content = "SGVsbG8gV29ybGQ=SGVsbG8gV29ybGQ=";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),254,content);
            final byte[] result = Base64.decodeBase64(content);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),255,result);
            final byte[] shouldBe = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("HelloWorld");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),256,shouldBe);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),253,java.util.Arrays.equals(result, shouldBe));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests Base64.encodeBase64().
     */
@Test
    public void testChunkedEncodeMultipleOf76() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testChunkedEncodeMultipleOf76");
            final byte[] expectedEncode = Base64.encodeBase64(Base64TestData.DECODED, true);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),176,expectedEncode);
            final String actualResult = Base64TestData.ENCODED_76_CHARS_PER_LINE.replaceAll("\n", "\r\n");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),177,actualResult);
            final byte[] actualEncode = org.apache.commons.codec.binary.StringUtils.getBytesUtf8(actualResult);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),178,actualEncode);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),175,java.util.Arrays.equals(expectedEncode, actualEncode));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * CODEC-68: isBase64 throws ArrayIndexOutOfBoundsException on some non-BASE64 bytes
     */
@Test(timeout = 1000)
    public void testCodec68_add27() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodec68_add27");
            final byte[] x = new byte[]{ 'n' , 'A' , '=' , '=' , ((byte)(156)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),205,x);
            Base64.decodeBase64(x);
            Base64.decodeBase64(x);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * CODEC-68: isBase64 throws ArrayIndexOutOfBoundsException on some non-BASE64 bytes
     */
@Test
    public void testCodec68() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodec68");
            final byte[] x = new byte[]{ 'n' , 'A' , '=' , '=' , ((byte)(157)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),205,x);
            Base64.decodeBase64(x);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * CODEC-68: isBase64 throws ArrayIndexOutOfBoundsException on some non-BASE64 bytes
     */
@Test
    public void testCodec68_literalMutation274() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodec68_literalMutation274");
            final byte[] x = new byte[]{ 'n' , 'A' , '=' , '=' , ((byte)(155)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),205,x);
            Base64.decodeBase64(x);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * CODEC-68: isBase64 throws ArrayIndexOutOfBoundsException on some non-BASE64 bytes
     */
@Test
    public void testCodec68_literalMutation275() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodec68_literalMutation275");
            final byte[] x = new byte[]{ 'n' , 'A' , '=' , '=' , ((byte)(78)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),205,x);
            Base64.decodeBase64(x);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * CODEC-68: isBase64 throws ArrayIndexOutOfBoundsException on some non-BASE64 bytes
     */
@Test
    public void testCodec68_literalMutation276() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodec68_literalMutation276");
            final byte[] x = new byte[]{ 'n' , 'A' , '=' , '=' , ((byte)(312)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),205,x);
            Base64.decodeBase64(x);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * CODEC-68: isBase64 throws ArrayIndexOutOfBoundsException on some non-BASE64 bytes
     */
@Test(timeout = 1000)
    public void testCodec68_remove18() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodec68_remove18");
            final byte[] x = new byte[]{ 'n' , 'A' , '=' , '=' , ((byte)(156)) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),205,x);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger1() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger1");
            final String encodedInt1 = "li7dhDacuo67Jg7mtqEm2TRuOMU=";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),183,encodedInt1);
            final BigInteger bigInt1 = new BigInteger(("85739377120809420210425962799" + "0318636601332086981"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),184,bigInt1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),179,encodedInt1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),180,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt1)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),181,bigInt1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),182,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt1.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger1_literalMutation200() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger1_literalMutation200");
            final String encodedInt1 = "li7dzDacuo67Jg7mtqEm2TR3uOMU=";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),183,encodedInt1);
            final BigInteger bigInt1 = new BigInteger(("85739377120809420210425962799" + "0318636601332086981"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),184,bigInt1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),179,encodedInt1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),180,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt1)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),181,bigInt1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),182,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt1.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger1_literalMutation201() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger1_literalMutation201");
            final String encodedInt1 = "li7dzDacuo67Jg7mtqEm2RuOMU=";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),183,encodedInt1);
            final BigInteger bigInt1 = new BigInteger(("85739377120809420210425962799" + "0318636601332086981"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),184,bigInt1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),179,encodedInt1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),180,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt1)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),181,bigInt1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),182,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt1.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger1_literalMutation202() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger1_literalMutation202");
            final String encodedInt1 = "li7dzDacuo67Jg7mtqEm2TRuOMU=";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),183,encodedInt1);
            final BigInteger bigInt1 = new BigInteger(("8573937712¾809420210425962799" + "0318636601332086981"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),184,bigInt1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),179,encodedInt1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),180,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt1)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),181,bigInt1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),182,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt1.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger1_literalMutation203() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger1_literalMutation203");
            final String encodedInt1 = "li7dzDacuo67Jg7mtqEm2TRuOMU=";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),183,encodedInt1);
            final BigInteger bigInt1 = new BigInteger(("8573937Î7120809420210425962799" + "0318636601332086981"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),184,bigInt1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),179,encodedInt1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),180,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt1)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),181,bigInt1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),182,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt1.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger1_literalMutation204() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger1_literalMutation204");
            final String encodedInt1 = "li7dzDacuo67Jg7mtqEm2TRuOMU=";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),183,encodedInt1);
            final BigInteger bigInt1 = new BigInteger(("8573937712080942021042596799" + "0318636601332086981"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),184,bigInt1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),179,encodedInt1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),180,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt1)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),181,bigInt1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),182,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt1.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger1_literalMutation205() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger1_literalMutation205");
            final String encodedInt1 = "li7dzDacuo67Jg7mtqEm2TRuOMU=";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),183,encodedInt1);
            final BigInteger bigInt1 = new BigInteger(("85739377120809420210425962799" + "031863660133208981"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),184,bigInt1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),179,encodedInt1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),180,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt1)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),181,bigInt1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),182,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt1.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger1_literalMutation206() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger1_literalMutation206");
            final String encodedInt1 = "li7dzDacuo67Jg7mtqEm2TRuOMU=";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),183,encodedInt1);
            final BigInteger bigInt1 = new BigInteger(("85739377120809420210425962799" + "0´318636601332086981"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),184,bigInt1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),179,encodedInt1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),180,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt1)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),181,bigInt1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),182,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt1.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger1_literalMutation207() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger1_literalMutation207");
            final String encodedInt1 = "li7dzDacuo67Jg7mtqEm2TRuOMU=";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),183,encodedInt1);
            final BigInteger bigInt1 = new BigInteger(("85739377120809420210425962799" + "031863660332086981"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),184,bigInt1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),179,encodedInt1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),180,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt1)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),181,bigInt1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),182,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt1.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger2() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger2");
            final String encodedInt2 = "9B5pLY9pMOmtxCeTDHgwdNFeGs=";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),189,encodedInt2);
            final BigInteger bigInt2 = new BigInteger(("13936727572861167254666467268" + "91466679477132949611"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),190,bigInt2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),185,encodedInt2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),186,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt2)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),187,bigInt2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),188,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt2.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger2_literalMutation209() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger2_literalMutation209");
            final String encodedInt2 = "9B5ypLY9-pMOmtxCeTDHgwdNFeGs=";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),189,encodedInt2);
            final BigInteger bigInt2 = new BigInteger(("13936727572861167254666467268" + "91466679477132949611"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),190,bigInt2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),185,encodedInt2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),186,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt2)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),187,bigInt2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),188,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt2.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger2_literalMutation210() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger2_literalMutation210");
            final String encodedInt2 = "9B5yLY9pMOmtxCeTDHgwdNFeGs=";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),189,encodedInt2);
            final BigInteger bigInt2 = new BigInteger(("13936727572861167254666467268" + "91466679477132949611"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),190,bigInt2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),185,encodedInt2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),186,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt2)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),187,bigInt2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),188,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt2.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger2_literalMutation211() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger2_literalMutation211");
            final String encodedInt2 = "9B5ypLY9pMOmtxCeTDHgwdNFeGs=";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),189,encodedInt2);
            final BigInteger bigInt2 = new BigInteger(("1393627572861167254666467268" + "91466679477132949611"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),190,bigInt2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),185,encodedInt2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),186,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt2)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),187,bigInt2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),188,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt2.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger2_literalMutation212() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger2_literalMutation212");
            final String encodedInt2 = "9B5ypLY9pMOmtxCeTDHgwdNFeGs=";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),189,encodedInt2);
            final BigInteger bigInt2 = new BigInteger(("1393672757286¹1167254666467268" + "91466679477132949611"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),190,bigInt2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),185,encodedInt2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),186,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt2)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),187,bigInt2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),188,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt2.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger2_literalMutation213() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger2_literalMutation213");
            final String encodedInt2 = "9B5ypLY9pMOmtxCeTDHgwdNFeGs=";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),189,encodedInt2);
            final BigInteger bigInt2 = new BigInteger(("1393672757286116754666467268" + "91466679477132949611"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),190,bigInt2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),185,encodedInt2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),186,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt2)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),187,bigInt2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),188,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt2.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger2_literalMutation214() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger2_literalMutation214");
            final String encodedInt2 = "9B5ypLY9pMOmtxCeTDHgwdNFeGs=";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),189,encodedInt2);
            final BigInteger bigInt2 = new BigInteger(("13936727572861167254666467268" + "9146667947713249611"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),190,bigInt2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),185,encodedInt2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),186,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt2)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),187,bigInt2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),188,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt2.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger2_literalMutation215() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger2_literalMutation215");
            final String encodedInt2 = "9B5ypLY9pMOmtxCeTDHgwdNFeGs=";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),189,encodedInt2);
            final BigInteger bigInt2 = new BigInteger(("13936727572861167254666467268" + "914666794771ß32949611"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),190,bigInt2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),185,encodedInt2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),186,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt2)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),187,bigInt2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),188,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt2.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger2_literalMutation216() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger2_literalMutation216");
            final String encodedInt2 = "9B5ypLY9pMOmtxCeTDHgwdNFeGs=";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),189,encodedInt2);
            final BigInteger bigInt2 = new BigInteger(("13936727572861167254666467268" + "9146667947132949611"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),190,bigInt2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),185,encodedInt2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),186,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt2)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),187,bigInt2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),188,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt2.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger3() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger3");
            final String encodedInt3 = "FKIhdgaG5LGKiEtF1vHy4fSy700zaD6QwDS3IrNVGzNp2" + "rY+1LFWTK6D44AyiC1n8uWz1itkYMZF0/aKDK0Yjg==";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),195,encodedInt3);
            final BigInteger bigInt3 = new BigInteger(("10806548154093873461951748545" + ("1196989136416448805819079363524309897749044958112417136240557" + "4495062430572478766856090958495998158114332651671116876320938126")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),196,bigInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),191,encodedInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),192,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt3)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),193,bigInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),194,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt3.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger3_literalMutation218() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger3_literalMutation218");
            final String encodedInt3 = "FKIhdgaG5LGKiEtF1AvHy4f3y700zaD6QwDS3IrNVGzNp2" + "rY+1LFWTK6D44AyiC1n8uWz1itkYMZF0/aKDK0Yjg==";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),195,encodedInt3);
            final BigInteger bigInt3 = new BigInteger(("10806548154093873461951748545" + ("1196989136416448805819079363524309897749044958112417136240557" + "4495062430572478766856090958495998158114332651671116876320938126")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),196,bigInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),191,encodedInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),192,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt3)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),193,bigInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),194,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt3.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger3_literalMutation219() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger3_literalMutation219");
            final String encodedInt3 = "FKIhdgaG5LGKiEF1vHy4f3y700zaD6QwDS3IrNVGzNp2" + "rY+1LFWTK6D44AyiC1n8uWz1itkYMZF0/aKDK0Yjg==";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),195,encodedInt3);
            final BigInteger bigInt3 = new BigInteger(("10806548154093873461951748545" + ("1196989136416448805819079363524309897749044958112417136240557" + "4495062430572478766856090958495998158114332651671116876320938126")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),196,bigInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),191,encodedInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),192,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt3)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),193,bigInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),194,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt3.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger3_literalMutation220() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger3_literalMutation220");
            final String encodedInt3 = "FKIhdgaG5LGKiEtF1vHy4f3y700zaD6QwDS3IrNVGzNp2" + "rY+1LFWTK6D44AyiC1n8uWz1itkYMZF0/aKD\"0Yjg==";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),195,encodedInt3);
            final BigInteger bigInt3 = new BigInteger(("10806548154093873461951748545" + ("1196989136416448805819079363524309897749044958112417136240557" + "4495062430572478766856090958495998158114332651671116876320938126")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),196,bigInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),191,encodedInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),192,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt3)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),193,bigInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),194,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt3.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger3_literalMutation221() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger3_literalMutation221");
            final String encodedInt3 = "FKIhdgaG5LGKiEtF1vHy4f3y700zaD6QwDS3IrNVGzNp2" + "rY+1LFWTK6D44AyiC1n8uWz1itkYMcZF0/aKDK0Yjg==";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),195,encodedInt3);
            final BigInteger bigInt3 = new BigInteger(("10806548154093873461951748545" + ("1196989136416448805819079363524309897749044958112417136240557" + "4495062430572478766856090958495998158114332651671116876320938126")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),196,bigInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),191,encodedInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),192,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt3)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),193,bigInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),194,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt3.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger3_literalMutation222() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger3_literalMutation222");
            final String encodedInt3 = "FKIhdgaG5LGKiEtF1vHy4f3y700zaD6QwDS3IrNVGzNp2" + "rY+1LFWTK6D44AyiC1n8uWz1itkYMZF0aKDK0Yjg==";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),195,encodedInt3);
            final BigInteger bigInt3 = new BigInteger(("10806548154093873461951748545" + ("1196989136416448805819079363524309897749044958112417136240557" + "4495062430572478766856090958495998158114332651671116876320938126")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),196,bigInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),191,encodedInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),192,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt3)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),193,bigInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),194,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt3.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger3_literalMutation223() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger3_literalMutation223");
            final String encodedInt3 = "FKIhdgaG5LGKiEtF1vHy4f3y700zaD6QwDS3IrNVGzNp2" + "rY+1LFWTK6D44AyiC1n8uWz1itkYMZF0/aKDK0Yjg==";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),195,encodedInt3);
            final BigInteger bigInt3 = new BigInteger(("1080654815409387346195174845" + ("1196989136416448805819079363524309897749044958112417136240557" + "4495062430572478766856090958495998158114332651671116876320938126")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),196,bigInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),191,encodedInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),192,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt3)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),193,bigInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),194,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt3.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger3_literalMutation224() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger3_literalMutation224");
            final String encodedInt3 = "FKIhdgaG5LGKiEtF1vHy4f3y700zaD6QwDS3IrNVGzNp2" + "rY+1LFWTK6D44AyiC1n8uWz1itkYMZF0/aKDK0Yjg==";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),195,encodedInt3);
            final BigInteger bigInt3 = new BigInteger(("10806548154093873461\b951748545" + ("1196989136416448805819079363524309897749044958112417136240557" + "4495062430572478766856090958495998158114332651671116876320938126")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),196,bigInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),191,encodedInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),192,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt3)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),193,bigInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),194,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt3.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger3_literalMutation225() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger3_literalMutation225");
            final String encodedInt3 = "FKIhdgaG5LGKiEtF1vHy4f3y700zaD6QwDS3IrNVGzNp2" + "rY+1LFWTK6D44AyiC1n8uWz1itkYMZF0/aKDK0Yjg==";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),195,encodedInt3);
            final BigInteger bigInt3 = new BigInteger(("1080654815409387346195148545" + ("1196989136416448805819079363524309897749044958112417136240557" + "4495062430572478766856090958495998158114332651671116876320938126")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),196,bigInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),191,encodedInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),192,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt3)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),193,bigInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),194,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt3.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger3_literalMutation226() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger3_literalMutation226");
            final String encodedInt3 = "FKIhdgaG5LGKiEtF1vHy4f3y700zaD6QwDS3IrNVGzNp2" + "rY+1LFWTK6D44AyiC1n8uWz1itkYMZF0/aKDK0Yjg==";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),195,encodedInt3);
            final BigInteger bigInt3 = new BigInteger(("10806548154093873461951748545" + ("119698913z416448805819079363524309897749044958112417136240557" + "4495062430572478766856090958495998158114332651671116876320938126")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),196,bigInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),191,encodedInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),192,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt3)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),193,bigInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),194,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt3.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger3_literalMutation227() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger3_literalMutation227");
            final String encodedInt3 = "FKIhdgaG5LGKiEtF1vHy4f3y700zaD6QwDS3IrNVGzNp2" + "rY+1LFWTK6D44AyiC1n8uWz1itkYMZF0/aKDK0Yjg==";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),195,encodedInt3);
            final BigInteger bigInt3 = new BigInteger(("10806548154093873461951748545" + ("1196989136ø416448805819079363524309897749044958112417136240557" + "4495062430572478766856090958495998158114332651671116876320938126")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),196,bigInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),191,encodedInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),192,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt3)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),193,bigInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),194,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt3.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger3_literalMutation228() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger3_literalMutation228");
            final String encodedInt3 = "FKIhdgaG5LGKiEtF1vHy4f3y700zaD6QwDS3IrNVGzNp2" + "rY+1LFWTK6D44AyiC1n8uWz1itkYMZF0/aKDK0Yjg==";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),195,encodedInt3);
            final BigInteger bigInt3 = new BigInteger(("10806548154093873461951748545" + ("119698913641644880581907936352409897749044958112417136240557" + "4495062430572478766856090958495998158114332651671116876320938126")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),196,bigInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),191,encodedInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),192,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt3)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),193,bigInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),194,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt3.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger3_literalMutation229() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger3_literalMutation229");
            final String encodedInt3 = "FKIhdgaG5LGKiEtF1vHy4f3y700zaD6QwDS3IrNVGzNp2" + "rY+1LFWTK6D44AyiC1n8uWz1itkYMZF0/aKDK0Yjg==";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),195,encodedInt3);
            final BigInteger bigInt3 = new BigInteger(("10806548154093873461951748545" + ("1196989136416448805819079363524309897749044958112417136240557" + "449506243057247876685609095849599815811433265167111687þ320938126")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),196,bigInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),191,encodedInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),192,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt3)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),193,bigInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),194,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt3.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger3_literalMutation230() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger3_literalMutation230");
            final String encodedInt3 = "FKIhdgaG5LGKiEtF1vHy4f3y700zaD6QwDS3IrNVGzNp2" + "rY+1LFWTK6D44AyiC1n8uWz1itkYMZF0/aKDK0Yjg==";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),195,encodedInt3);
            final BigInteger bigInt3 = new BigInteger(("10806548154093873461951748545" + ("1196989136416448805819079363524309897749044958112417136240557" + "44950624305724787668560909584U95998158114332651671116876320938126")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),196,bigInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),191,encodedInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),192,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt3)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),193,bigInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),194,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt3.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger3_literalMutation231() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger3_literalMutation231");
            final String encodedInt3 = "FKIhdgaG5LGKiEtF1vHy4f3y700zaD6QwDS3IrNVGzNp2" + "rY+1LFWTK6D44AyiC1n8uWz1itkYMZF0/aKDK0Yjg==";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),195,encodedInt3);
            final BigInteger bigInt3 = new BigInteger(("10806548154093873461951748545" + ("1196989136416448805819079363524309897749044958112417136240557" + "449506240572478766856090958495998158114332651671116876320938126")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),196,bigInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),191,encodedInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),192,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt3)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),193,bigInt3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),194,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt3.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger4() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger4");
            final String encodedInt4 = "ctA8YGxrtngg/zKVvqEOe\tnwmViFztcnPBYPlJsvh6yKI" + ("4iDm68fnp4Mi3RrJ6bZAygFrUIQLxLjV+OJtgJAEto0xAs+Mehuq1DkSFEpP3o" + ("DzCTOsrOiS1DwQe4oIb7zVk/9l7aPtJMHW0LVlMdwZNFNNJoqMcT2ZfCPrfvYv" + "Q0="));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),201,encodedInt4);
            final BigInteger bigInt4 = new BigInteger(("80624726256040348115552042320" + ("6968135001872753709424419772586693950232350200555646471175944" + ("519297087885987040810778908507262272892702303774422853675597" + ("748008534040890923814202286633163248086055216976551456088015" + ("338880713818192088877057717530169381044092839402438015097654" + "53542091716518238707344493641683483917"))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),202,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),197,encodedInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),198,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt4)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),199,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt4.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger4_literalMutation233() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger4_literalMutation233");
            final String encodedInt4 = "ctA8YGxrtngg/zKVvqEOefnwmViFztcnPBYPlJsvh6yKI" + ("4iDm68fnp4Mi3RrJ6bZAygFrUIQLxLjV+OJtgJAEto0xAs+Mehuq1DkSFEpP3o" + ("DzCTOsrOiS1DwQe4oIb7zVk/9l7aPtJMHW0LVlMdwZNFNNJoqMcT2ZfCPrfvYv" + "Q0="));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),201,encodedInt4);
            final BigInteger bigInt4 = new BigInteger(("80624726256040348115552042320" + ("6968135001872753709424419772586693950232350200555646471175944" + ("519297087885987040810778908507262272892702303774422853675597" + ("748008534040890923814202286633163248086055216976551456088015" + ("338880713818192088877057717530169381044092839402438015097654" + "53542091716518238707344493641683483917"))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),202,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),197,encodedInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),198,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt4)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),199,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt4.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger4_literalMutation234() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger4_literalMutation234");
            final String encodedInt4 = "ctA8YGxrngg/zKVvqEOefnwmViFztcnPBYPlJsvh6yKI" + ("4iDm68fnp4Mi3RrJ6bZAygFrUIQLxLjV+OJtgJAEto0xAs+Mehuq1DkSFEpP3o" + ("DzCTOsrOiS1DwQe4oIb7zVk/9l7aPtJMHW0LVlMdwZNFNNJoqMcT2ZfCPrfvYv" + "Q0="));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),201,encodedInt4);
            final BigInteger bigInt4 = new BigInteger(("80624726256040348115552042320" + ("6968135001872753709424419772586693950232350200555646471175944" + ("519297087885987040810778908507262272892702303774422853675597" + ("748008534040890923814202286633163248086055216976551456088015" + ("338880713818192088877057717530169381044092839402438015097654" + "53542091716518238707344493641683483917"))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),202,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),197,encodedInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),198,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt4)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),199,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt4.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger4_literalMutation235() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger4_literalMutation235");
            final String encodedInt4 = "ctA8YGxrtngg/zKVvqEOefnwmViFztcnPBYPlJsvh6yKI" + ("4iDm68fnp4Mi3RrJ6bZAygFrUIQLxLjV+OJtgJAEt 0xAs+Mehuq1DkSFEpP3o" + ("DzCTOsrOiS1DwQe4oIb7zVk/9l7aPtJMHW0LVlMdwZNFNNJoqMcT2ZfCPrfvYv" + "Q0="));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),201,encodedInt4);
            final BigInteger bigInt4 = new BigInteger(("80624726256040348115552042320" + ("6968135001872753709424419772586693950232350200555646471175944" + ("519297087885987040810778908507262272892702303774422853675597" + ("748008534040890923814202286633163248086055216976551456088015" + ("338880713818192088877057717530169381044092839402438015097654" + "53542091716518238707344493641683483917"))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),202,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),197,encodedInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),198,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt4)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),199,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt4.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger4_literalMutation236() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger4_literalMutation236");
            final String encodedInt4 = "ctA8YGxrtngg/zKVvqEOefnwmViFztcnPBYPlJsvh6yKI" + ("4iDm68fnp4Mi3RrJ6bZAygFrUIQLxLjV+OJtgJAEjto0xAs+Mehuq1DkSFEpP3o" + ("DzCTOsrOiS1DwQe4oIb7zVk/9l7aPtJMHW0LVlMdwZNFNNJoqMcT2ZfCPrfvYv" + "Q0="));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),201,encodedInt4);
            final BigInteger bigInt4 = new BigInteger(("80624726256040348115552042320" + ("6968135001872753709424419772586693950232350200555646471175944" + ("519297087885987040810778908507262272892702303774422853675597" + ("748008534040890923814202286633163248086055216976551456088015" + ("338880713818192088877057717530169381044092839402438015097654" + "53542091716518238707344493641683483917"))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),202,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),197,encodedInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),198,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt4)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),199,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt4.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger4_literalMutation237() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger4_literalMutation237");
            final String encodedInt4 = "ctA8YGxrtngg/zKVvqEOefnwmViFztcnPBYPlJsvh6yKI" + ("4iDm68fnp4Mi3RrJ6bZAygFrUIQLxLj+OJtgJAEto0xAs+Mehuq1DkSFEpP3o" + ("DzCTOsrOiS1DwQe4oIb7zVk/9l7aPtJMHW0LVlMdwZNFNNJoqMcT2ZfCPrfvYv" + "Q0="));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),201,encodedInt4);
            final BigInteger bigInt4 = new BigInteger(("80624726256040348115552042320" + ("6968135001872753709424419772586693950232350200555646471175944" + ("519297087885987040810778908507262272892702303774422853675597" + ("748008534040890923814202286633163248086055216976551456088015" + ("338880713818192088877057717530169381044092839402438015097654" + "53542091716518238707344493641683483917"))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),202,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),197,encodedInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),198,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt4)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),199,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt4.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger4_literalMutation238() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger4_literalMutation238");
            final String encodedInt4 = "ctA8YGxrtngg/zKVvqEOefnwmViFztcnPBYPlJsvh6yKI" + ("4iDm68fnp4Mi3RrJ6bZAygFrUIQLxLjV+OJtgJAEto0xAs+Mehuq1DkSFEpP3o" + ("DzCTOsrOiS1DwQe4oIb7zVk/9l7aPtJgHW0LVlMdwZNFNNJoqMcT2ZfCPrfvYv" + "Q0="));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),201,encodedInt4);
            final BigInteger bigInt4 = new BigInteger(("80624726256040348115552042320" + ("6968135001872753709424419772586693950232350200555646471175944" + ("519297087885987040810778908507262272892702303774422853675597" + ("748008534040890923814202286633163248086055216976551456088015" + ("338880713818192088877057717530169381044092839402438015097654" + "53542091716518238707344493641683483917"))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),202,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),197,encodedInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),198,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt4)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),199,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt4.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger4_literalMutation239() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger4_literalMutation239");
            final String encodedInt4 = "ctA8YGxrtngg/zKVvqEOefnwmViFztcnPBYPlJsvh6yKI" + ("4iDm68fnp4Mi3RrJ6bZAygFrUIQLxLjV+OJtgJAEto0xAs+Mehuq1DkSFEpP3o" + ("DzCTOsrOLiS1DwQe4oIb7zVk/9l7aPtJMHW0LVlMdwZNFNNJoqMcT2ZfCPrfvYv" + "Q0="));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),201,encodedInt4);
            final BigInteger bigInt4 = new BigInteger(("80624726256040348115552042320" + ("6968135001872753709424419772586693950232350200555646471175944" + ("519297087885987040810778908507262272892702303774422853675597" + ("748008534040890923814202286633163248086055216976551456088015" + ("338880713818192088877057717530169381044092839402438015097654" + "53542091716518238707344493641683483917"))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),202,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),197,encodedInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),198,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt4)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),199,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt4.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger4_literalMutation240() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger4_literalMutation240");
            final String encodedInt4 = "ctA8YGxrtngg/zKVvqEOefnwmViFztcnPBYPlJsvh6yKI" + ("4iDm68fnp4Mi3RrJ6bZAygFrUIQLxLjV+OJtgJAEto0xAs+Mehuq1DkSFEpP3o" + ("DzCTOsrOiS1DwQe4oIb7zVk/9l7aPtJMHW0LVlMdwZNFNNJoqMcT2ZfCPrfvv" + "Q0="));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),201,encodedInt4);
            final BigInteger bigInt4 = new BigInteger(("80624726256040348115552042320" + ("6968135001872753709424419772586693950232350200555646471175944" + ("519297087885987040810778908507262272892702303774422853675597" + ("748008534040890923814202286633163248086055216976551456088015" + ("338880713818192088877057717530169381044092839402438015097654" + "53542091716518238707344493641683483917"))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),202,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),197,encodedInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),198,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt4)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),199,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt4.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger4_literalMutation241() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger4_literalMutation241");
            final String encodedInt4 = "ctA8YGxrtngg/zKVvqEOefnwmViFztcnPBYPlJsvh6yKI" + ("4iDm68fnp4Mi3RrJ6bZAygFrUIQLxLjV+OJtgJAEto0xAs+Mehuq1DkSFEpP3o" + ("DzCTOsrOiS1DwQe4oIb7zVk/9l7aPtJMHW0LVlMdwZNFNNJoqMcT2ZfCPrfvYv" + "/0="));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),201,encodedInt4);
            final BigInteger bigInt4 = new BigInteger(("80624726256040348115552042320" + ("6968135001872753709424419772586693950232350200555646471175944" + ("519297087885987040810778908507262272892702303774422853675597" + ("748008534040890923814202286633163248086055216976551456088015" + ("338880713818192088877057717530169381044092839402438015097654" + "53542091716518238707344493641683483917"))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),202,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),197,encodedInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),198,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt4)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),199,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt4.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger4_literalMutation242() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger4_literalMutation242");
            final String encodedInt4 = "ctA8YGxrtngg/zKVvqEOefnwmViFztcnPBYPlJsvh6yKI" + ("4iDm68fnp4Mi3RrJ6bZAygFrUIQLxLjV+OJtgJAEto0xAs+Mehuq1DkSFEpP3o" + ("DzCTOsrOiS1DwQe4oIb7zVk/9l7aPtJMHW0LVlMdwZNFNNJoqMcT2ZfCPrfvYv" + "QÛ0="));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),201,encodedInt4);
            final BigInteger bigInt4 = new BigInteger(("80624726256040348115552042320" + ("6968135001872753709424419772586693950232350200555646471175944" + ("519297087885987040810778908507262272892702303774422853675597" + ("748008534040890923814202286633163248086055216976551456088015" + ("338880713818192088877057717530169381044092839402438015097654" + "53542091716518238707344493641683483917"))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),202,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),197,encodedInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),198,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt4)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),199,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt4.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger4_literalMutation243() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger4_literalMutation243");
            final String encodedInt4 = "ctA8YGxrtngg/zKVvqEOefnwmViFztcnPBYPlJsvh6yKI" + ("4iDm68fnp4Mi3RrJ6bZAygFrUIQLxLjV+OJtgJAEto0xAs+Mehuq1DkSFEpP3o" + ("DzCTOsrOiS1DwQe4oIb7zVk/9l7aPtJMHW0LVlMdwZNFNNJoqMcT2ZfCPrfvYv" + "Q="));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),201,encodedInt4);
            final BigInteger bigInt4 = new BigInteger(("80624726256040348115552042320" + ("6968135001872753709424419772586693950232350200555646471175944" + ("519297087885987040810778908507262272892702303774422853675597" + ("748008534040890923814202286633163248086055216976551456088015" + ("338880713818192088877057717530169381044092839402438015097654" + "53542091716518238707344493641683483917"))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),202,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),197,encodedInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),198,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt4)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),199,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt4.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger4_literalMutation244() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger4_literalMutation244");
            final String encodedInt4 = "ctA8YGxrtngg/zKVvqEOefnwmViFztcnPBYPlJsvh6yKI" + ("4iDm68fnp4Mi3RrJ6bZAygFrUIQLxLjV+OJtgJAEto0xAs+Mehuq1DkSFEpP3o" + ("DzCTOsrOiS1DwQe4oIb7zVk/9l7aPtJMHW0LVlMdwZNFNNJoqMcT2ZfCPrfvYv" + "Q0="));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),201,encodedInt4);
            final BigInteger bigInt4 = new BigInteger(("8062476256040348115552042320" + ("6968135001872753709424419772586693950232350200555646471175944" + ("519297087885987040810778908507262272892702303774422853675597" + ("748008534040890923814202286633163248086055216976551456088015" + ("338880713818192088877057717530169381044092839402438015097654" + "53542091716518238707344493641683483917"))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),202,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),197,encodedInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),198,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt4)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),199,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt4.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger4_literalMutation245() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger4_literalMutation245");
            final String encodedInt4 = "ctA8YGxrtngg/zKVvqEOefnwmViFztcnPBYPlJsvh6yKI" + ("4iDm68fnp4Mi3RrJ6bZAygFrUIQLxLjV+OJtgJAEto0xAs+Mehuq1DkSFEpP3o" + ("DzCTOsrOiS1DwQe4oIb7zVk/9l7aPtJMHW0LVlMdwZNFNNJoqMcT2ZfCPrfvYv" + "Q0="));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),201,encodedInt4);
            final BigInteger bigInt4 = new BigInteger(("80624726256040348115552042320" + ("6968135001872753709424419772586693950232350200555646471175944" + ("519297087885987040810778908507262272892702303774422853675597" + ("748008534040890923814202286633163248086055216976551456088015" + ("338880713818192088877057717530169381044092839402438015097654" + "53542091716518238707344493641683483917"))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),202,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),197,encodedInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),198,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt4)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),199,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt4.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger4_literalMutation246() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger4_literalMutation246");
            final String encodedInt4 = "ctA8YGxrtngg/zKVvqEOefnwmViFztcnPBYPlJsvh6yKI" + ("4iDm68fnp4Mi3RrJ6bZAygFrUIQLxLjV+OJtgJAEto0xAs+Mehuq1DkSFEpP3o" + ("DzCTOsrOiS1DwQe4oIb7zVk/9l7aPtJMHW0LVlMdwZNFNNJoqMcT2ZfCPrfvYv" + "Q0="));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),201,encodedInt4);
            final BigInteger bigInt4 = new BigInteger(("8062472625604034811552042320" + ("6968135001872753709424419772586693950232350200555646471175944" + ("519297087885987040810778908507262272892702303774422853675597" + ("748008534040890923814202286633163248086055216976551456088015" + ("338880713818192088877057717530169381044092839402438015097654" + "53542091716518238707344493641683483917"))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),202,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),197,encodedInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),198,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt4)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),199,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt4.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger4_literalMutation247() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger4_literalMutation247");
            final String encodedInt4 = "ctA8YGxrtngg/zKVvqEOefnwmViFztcnPBYPlJsvh6yKI" + ("4iDm68fnp4Mi3RrJ6bZAygFrUIQLxLjV+OJtgJAEto0xAs+Mehuq1DkSFEpP3o" + ("DzCTOsrOiS1DwQe4oIb7zVk/9l7aPtJMHW0LVlMdwZNFNNJoqMcT2ZfCPrfvYv" + "Q0="));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),201,encodedInt4);
            final BigInteger bigInt4 = new BigInteger(("80624726256040348115552042320" + ("6968135001872753709424419772586693950232§50200555646471175944" + ("519297087885987040810778908507262272892702303774422853675597" + ("748008534040890923814202286633163248086055216976551456088015" + ("338880713818192088877057717530169381044092839402438015097654" + "53542091716518238707344493641683483917"))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),202,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),197,encodedInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),198,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt4)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),199,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt4.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger4_literalMutation248() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger4_literalMutation248");
            final String encodedInt4 = "ctA8YGxrtngg/zKVvqEOefnwmViFztcnPBYPlJsvh6yKI" + ("4iDm68fnp4Mi3RrJ6bZAygFrUIQLxLjV+OJtgJAEto0xAs+Mehuq1DkSFEpP3o" + ("DzCTOsrOiS1DwQe4oIb7zVk/9l7aPtJMHW0LVlMdwZNFNNJoqMcT2ZfCPrfvYv" + "Q0="));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),201,encodedInt4);
            final BigInteger bigInt4 = new BigInteger(("80624726256040348115552042320" + ("69681350018727537094244197725866939502323502005545646471175944" + ("519297087885987040810778908507262272892702303774422853675597" + ("748008534040890923814202286633163248086055216976551456088015" + ("338880713818192088877057717530169381044092839402438015097654" + "53542091716518238707344493641683483917"))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),202,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),197,encodedInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),198,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt4)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),199,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt4.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger4_literalMutation249() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger4_literalMutation249");
            final String encodedInt4 = "ctA8YGxrtngg/zKVvqEOefnwmViFztcnPBYPlJsvh6yKI" + ("4iDm68fnp4Mi3RrJ6bZAygFrUIQLxLjV+OJtgJAEto0xAs+Mehuq1DkSFEpP3o" + ("DzCTOsrOiS1DwQe4oIb7zVk/9l7aPtJMHW0LVlMdwZNFNNJoqMcT2ZfCPrfvYv" + "Q0="));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),201,encodedInt4);
            final BigInteger bigInt4 = new BigInteger(("80624726256040348115552042320" + ("696813500187275370942449772586693950232350200555646471175944" + ("519297087885987040810778908507262272892702303774422853675597" + ("748008534040890923814202286633163248086055216976551456088015" + ("338880713818192088877057717530169381044092839402438015097654" + "53542091716518238707344493641683483917"))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),202,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),197,encodedInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),198,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt4)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),199,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt4.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger4_literalMutation250() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger4_literalMutation250");
            final String encodedInt4 = "ctA8YGxrtngg/zKVvqEOefnwmViFztcnPBYPlJsvh6yKI" + ("4iDm68fnp4Mi3RrJ6bZAygFrUIQLxLjV+OJtgJAEto0xAs+Mehuq1DkSFEpP3o" + ("DzCTOsrOiS1DwQe4oIb7zVk/9l7aPtJMHW0LVlMdwZNFNNJoqMcT2ZfCPrfvYv" + "Q0="));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),201,encodedInt4);
            final BigInteger bigInt4 = new BigInteger(("80624726256040348115552042320" + ("6968135001872753709424419772586693950232350200555646471175944" + ("519297087885987040810778908507262272892702ì03774422853675597" + ("748008534040890923814202286633163248086055216976551456088015" + ("338880713818192088877057717530169381044092839402438015097654" + "53542091716518238707344493641683483917"))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),202,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),197,encodedInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),198,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt4)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),199,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt4.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger4_literalMutation251() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger4_literalMutation251");
            final String encodedInt4 = "ctA8YGxrtngg/zKVvqEOefnwmViFztcnPBYPlJsvh6yKI" + ("4iDm68fnp4Mi3RrJ6bZAygFrUIQLxLjV+OJtgJAEto0xAs+Mehuq1DkSFEpP3o" + ("DzCTOsrOiS1DwQe4oIb7zVk/9l7aPtJMHW0LVlMdwZNFNNJoqMcT2ZfCPrfvYv" + "Q0="));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),201,encodedInt4);
            final BigInteger bigInt4 = new BigInteger(("80624726256040348115552042320" + ("6968135001872753709424419772586693950232350200555646471175944" + ("519297087885987040810778908507262272892702303774422853675597" + ("748008534040890923814202286633163248086055216976551456088015" + ("338880713818192088877057717530169381044092839402438015097654" + "53542091716518238707344493641683483917"))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),202,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),197,encodedInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),198,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt4)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),199,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt4.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger4_literalMutation252() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger4_literalMutation252");
            final String encodedInt4 = "ctA8YGxrtngg/zKVvqEOefnwmViFztcnPBYPlJsvh6yKI" + ("4iDm68fnp4Mi3RrJ6bZAygFrUIQLxLjV+OJtgJAEto0xAs+Mehuq1DkSFEpP3o" + ("DzCTOsrOiS1DwQe4oIb7zVk/9l7aPtJMHW0LVlMdwZNFNNJoqMcT2ZfCPrfvYv" + "Q0="));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),201,encodedInt4);
            final BigInteger bigInt4 = new BigInteger(("80624726256040348115552042320" + ("6968135001872753709424419772586693950232350200555646471175944" + ("51929708788598704081077890850726227289270230377422853675597" + ("748008534040890923814202286633163248086055216976551456088015" + ("338880713818192088877057717530169381044092839402438015097654" + "53542091716518238707344493641683483917"))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),202,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),197,encodedInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),198,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt4)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),199,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt4.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger4_literalMutation253() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger4_literalMutation253");
            final String encodedInt4 = "ctA8YGxrtngg/zKVvqEOefnwmViFztcnPBYPlJsvh6yKI" + ("4iDm68fnp4Mi3RrJ6bZAygFrUIQLxLjV+OJtgJAEto0xAs+Mehuq1DkSFEpP3o" + ("DzCTOsrOiS1DwQe4oIb7zVk/9l7aPtJMHW0LVlMdwZNFNNJoqMcT2ZfCPrfvYv" + "Q0="));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),201,encodedInt4);
            final BigInteger bigInt4 = new BigInteger(("80624726256040348115552042320" + ("6968135001872753709424419772586693950232350200555646471175944" + ("519297087885987040810778908507262272892702303774422853675597" + ("74800853404089092381420226633163248086055216976551456088015" + ("338880713818192088877057717530169381044092839402438015097654" + "53542091716518238707344493641683483917"))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),202,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),197,encodedInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),198,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt4)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),199,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt4.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger4_literalMutation254() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger4_literalMutation254");
            final String encodedInt4 = "ctA8YGxrtngg/zKVvqEOefnwmViFztcnPBYPlJsvh6yKI" + ("4iDm68fnp4Mi3RrJ6bZAygFrUIQLxLjV+OJtgJAEto0xAs+Mehuq1DkSFEpP3o" + ("DzCTOsrOiS1DwQe4oIb7zVk/9l7aPtJMHW0LVlMdwZNFNNJoqMcT2ZfCPrfvYv" + "Q0="));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),201,encodedInt4);
            final BigInteger bigInt4 = new BigInteger(("80624726256040348115552042320" + ("6968135001872753709424419772586693950232350200555646471175944" + ("519297087885987040810778908507262272892702303774422853675597" + ("74800853404089092381420228663316324808Å6055216976551456088015" + ("338880713818192088877057717530169381044092839402438015097654" + "53542091716518238707344493641683483917"))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),202,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),197,encodedInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),198,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt4)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),199,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt4.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger4_literalMutation255() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger4_literalMutation255");
            final String encodedInt4 = "ctA8YGxrtngg/zKVvqEOefnwmViFztcnPBYPlJsvh6yKI" + ("4iDm68fnp4Mi3RrJ6bZAygFrUIQLxLjV+OJtgJAEto0xAs+Mehuq1DkSFEpP3o" + ("DzCTOsrOiS1DwQe4oIb7zVk/9l7aPtJMHW0LVlMdwZNFNNJoqMcT2ZfCPrfvYv" + "Q0="));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),201,encodedInt4);
            final BigInteger bigInt4 = new BigInteger(("80624726256040348115552042320" + ("6968135001872753709424419772586693950232350200555646471175944" + ("519297087885987040810778908507262272892702303774422853675597" + ("74800853404089092381420228663316324808605521697655145608015" + ("338880713818192088877057717530169381044092839402438015097654" + "53542091716518238707344493641683483917"))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),202,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),197,encodedInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),198,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt4)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),199,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt4.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger4_literalMutation256() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger4_literalMutation256");
            final String encodedInt4 = "ctA8YGxrtngg/zKVvqEOefnwmViFztcnPBYPlJsvh6yKI" + ("4iDm68fnp4Mi3RrJ6bZAygFrUIQLxLjV+OJtgJAEto0xAs+Mehuq1DkSFEpP3o" + ("DzCTOsrOiS1DwQe4oIb7zVk/9l7aPtJMHW0LVlMdwZNFNNJoqMcT2ZfCPrfvYv" + "Q0="));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),201,encodedInt4);
            final BigInteger bigInt4 = new BigInteger(("80624726256040348115552042320" + ("6968135001872753709424419772586693950232350200555646471175944" + ("519297087885987040810778908507262272892702303774422853675597" + ("748008534040890923814202286633163248086055216976551456088015" + ("33888071381819208887705771753016938^044092839402438015097654" + "53542091716518238707344493641683483917"))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),202,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),197,encodedInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),198,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt4)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),199,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt4.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger4_literalMutation257() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger4_literalMutation257");
            final String encodedInt4 = "ctA8YGxrtngg/zKVvqEOefnwmViFztcnPBYPlJsvh6yKI" + ("4iDm68fnp4Mi3RrJ6bZAygFrUIQLxLjV+OJtgJAEto0xAs+Mehuq1DkSFEpP3o" + ("DzCTOsrOiS1DwQe4oIb7zVk/9l7aPtJMHW0LVlMdwZNFNNJoqMcT2ZfCPrfvYv" + "Q0="));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),201,encodedInt4);
            final BigInteger bigInt4 = new BigInteger(("80624726256040348115552042320" + ("6968135001872753709424419772586693950232350200555646471175944" + ("519297087885987040810778908507262272892702303774422853675597" + ("748008534040890923814202286633163248086055216976551456088015" + ("33888071381W8192088877057717530169381044092839402438015097654" + "53542091716518238707344493641683483917"))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),202,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),197,encodedInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),198,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt4)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),199,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt4.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger4_literalMutation258() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger4_literalMutation258");
            final String encodedInt4 = "ctA8YGxrtngg/zKVvqEOefnwmViFztcnPBYPlJsvh6yKI" + ("4iDm68fnp4Mi3RrJ6bZAygFrUIQLxLjV+OJtgJAEto0xAs+Mehuq1DkSFEpP3o" + ("DzCTOsrOiS1DwQe4oIb7zVk/9l7aPtJMHW0LVlMdwZNFNNJoqMcT2ZfCPrfvYv" + "Q0="));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),201,encodedInt4);
            final BigInteger bigInt4 = new BigInteger(("80624726256040348115552042320" + ("6968135001872753709424419772586693950232350200555646471175944" + ("519297087885987040810778908507262272892702303774422853675597" + ("748008534040890923814202286633163248086055216976551456088015" + ("33888071381819208887705771753016938104402839402438015097654" + "53542091716518238707344493641683483917"))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),202,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),197,encodedInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),198,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt4)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),199,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt4.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger4_literalMutation259() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger4_literalMutation259");
            final String encodedInt4 = "ctA8YGxrtngg/zKVvqEOefnwmViFztcnPBYPlJsvh6yKI" + ("4iDm68fnp4Mi3RrJ6bZAygFrUIQLxLjV+OJtgJAEto0xAs+Mehuq1DkSFEpP3o" + ("DzCTOsrOiS1DwQe4oIb7zVk/9l7aPtJMHW0LVlMdwZNFNNJoqMcT2ZfCPrfvYv" + "Q0="));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),201,encodedInt4);
            final BigInteger bigInt4 = new BigInteger(("80624726256040348115552042320" + ("6968135001872753709424419772586693950232350200555646471175944" + ("519297087885987040810778908507262272892702303774422853675597" + ("748008534040890923814202286633163248086055216976551456088015" + ("338880713818192088877057717530169381044092839402438015097654" + "5354209171651823870734449364683483917"))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),202,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),197,encodedInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),198,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt4)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),199,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt4.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger4_literalMutation260() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger4_literalMutation260");
            final String encodedInt4 = "ctA8YGxrtngg/zKVvqEOefnwmViFztcnPBYPlJsvh6yKI" + ("4iDm68fnp4Mi3RrJ6bZAygFrUIQLxLjV+OJtgJAEto0xAs+Mehuq1DkSFEpP3o" + ("DzCTOsrOiS1DwQe4oIb7zVk/9l7aPtJMHW0LVlMdwZNFNNJoqMcT2ZfCPrfvYv" + "Q0="));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),201,encodedInt4);
            final BigInteger bigInt4 = new BigInteger(("80624726256040348115552042320" + ("6968135001872753709424419772586693950232350200555646471175944" + ("519297087885987040810778908507262272892702303774422853675597" + ("748008534040890923814202286633163248086055216976551456088015" + ("338880713818192088877057717530169381044092839402438015097654" + "53Ç542091716518238707344493641683483917"))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),202,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),197,encodedInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),198,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt4)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),199,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt4.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeInteger4_literalMutation261() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeInteger4_literalMutation261");
            final String encodedInt4 = "ctA8YGxrtngg/zKVvqEOefnwmViFztcnPBYPlJsvh6yKI" + ("4iDm68fnp4Mi3RrJ6bZAygFrUIQLxLjV+OJtgJAEto0xAs+Mehuq1DkSFEpP3o" + ("DzCTOsrOiS1DwQe4oIb7zVk/9l7aPtJMHW0LVlMdwZNFNNJoqMcT2ZfCPrfvYv" + "Q0="));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),201,encodedInt4);
            final BigInteger bigInt4 = new BigInteger(("80624726256040348115552042320" + ("6968135001872753709424419772586693950232350200555646471175944" + ("519297087885987040810778908507262272892702303774422853675597" + ("748008534040890923814202286633163248086055216976551456088015" + ("338880713818192088877057717530169381044092839402438015097654" + "5354209171651823870734449364163483917"))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),202,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),197,encodedInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),198,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeInteger(bigInt4)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),199,bigInt4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,org.apache.commons.codec.binary.Base64.decodeInteger(encodedInt4.getBytes(org.apache.commons.codec.Charsets.UTF_8)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodeIntegerEdgeCases() {
    }

    @Test(timeout = 1000)
    public void testCodeIntegerNull() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodeIntegerNull");
            try {
                Base64.encodeInteger(null);
                Base64.encodeInteger(null);
            } catch (final NullPointerException npe) {
            } catch (final Exception e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testConstructors() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructors");
            Base64 base64;
            base64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),224,base64);
            base64 = new Base64(-2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),225,base64);
            base64 = new Base64(-1 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),226,base64);
            base64 = new Base64(64 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),227,base64);
            try {
                base64 = new Base64(-1 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),228,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),229,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ '=' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),230,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ '$' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),231,base64);
            try {
                base64 = new Base64(64 , new byte[]{ 'A' , '$' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ ' ' , '$' , '\n' , '\r' , '\t' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),233,base64);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),223,base64);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testConstructors_literalMutation295() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructors_literalMutation295");
            Base64 base64;
            base64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),224,base64);
            base64 = new Base64(0);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),225,base64);
            base64 = new Base64(-1 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),226,base64);
            base64 = new Base64(64 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),227,base64);
            try {
                base64 = new Base64(-1 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),228,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),229,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ '=' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),230,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ '$' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),231,base64);
            try {
                base64 = new Base64(64 , new byte[]{ 'A' , '$' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ ' ' , '$' , '\n' , '\r' , '\t' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),233,base64);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),223,base64);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testConstructors_literalMutation296() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructors_literalMutation296");
            Base64 base64;
            base64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),224,base64);
            base64 = new Base64(0);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),225,base64);
            base64 = new Base64(-1 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),226,base64);
            base64 = new Base64(64 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),227,base64);
            try {
                base64 = new Base64(-1 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),228,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),229,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ '=' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),230,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ '$' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),231,base64);
            try {
                base64 = new Base64(64 , new byte[]{ 'A' , '$' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ ' ' , '$' , '\n' , '\r' , '\t' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),233,base64);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),223,base64);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testConstructors_literalMutation298() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructors_literalMutation298");
            Base64 base64;
            base64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),224,base64);
            base64 = new Base64(2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),225,base64);
            base64 = new Base64(-2 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),226,base64);
            base64 = new Base64(64 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),227,base64);
            try {
                base64 = new Base64(-1 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),228,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),229,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ '=' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),230,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ '$' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),231,base64);
            try {
                base64 = new Base64(64 , new byte[]{ 'A' , '$' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ ' ' , '$' , '\n' , '\r' , '\t' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),233,base64);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),223,base64);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testConstructors_literalMutation299() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructors_literalMutation299");
            Base64 base64;
            base64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),224,base64);
            base64 = new Base64(2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),225,base64);
            base64 = new Base64(0 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),226,base64);
            base64 = new Base64(64 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),227,base64);
            try {
                base64 = new Base64(-1 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),228,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),229,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ '=' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),230,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ '$' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),231,base64);
            try {
                base64 = new Base64(64 , new byte[]{ 'A' , '$' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ ' ' , '$' , '\n' , '\r' , '\t' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),233,base64);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),223,base64);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testConstructors_literalMutation300() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructors_literalMutation300");
            Base64 base64;
            base64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),224,base64);
            base64 = new Base64(2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),225,base64);
            base64 = new Base64(0 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),226,base64);
            base64 = new Base64(64 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),227,base64);
            try {
                base64 = new Base64(-1 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),228,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),229,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ '=' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),230,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ '$' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),231,base64);
            try {
                base64 = new Base64(64 , new byte[]{ 'A' , '$' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ ' ' , '$' , '\n' , '\r' , '\t' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),233,base64);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),223,base64);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testConstructors_literalMutation302() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructors_literalMutation302");
            Base64 base64;
            base64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),224,base64);
            base64 = new Base64(2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),225,base64);
            base64 = new Base64(2 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),226,base64);
            base64 = new Base64(65 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),227,base64);
            try {
                base64 = new Base64(-1 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),228,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),229,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ '=' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),230,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ '$' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),231,base64);
            try {
                base64 = new Base64(64 , new byte[]{ 'A' , '$' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ ' ' , '$' , '\n' , '\r' , '\t' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),233,base64);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),223,base64);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testConstructors_literalMutation303() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructors_literalMutation303");
            Base64 base64;
            base64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),224,base64);
            base64 = new Base64(2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),225,base64);
            base64 = new Base64(2 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),226,base64);
            base64 = new Base64(32 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),227,base64);
            try {
                base64 = new Base64(-1 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),228,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),229,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ '=' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),230,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ '$' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),231,base64);
            try {
                base64 = new Base64(64 , new byte[]{ 'A' , '$' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ ' ' , '$' , '\n' , '\r' , '\t' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),233,base64);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),223,base64);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testConstructors_literalMutation304() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructors_literalMutation304");
            Base64 base64;
            base64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),224,base64);
            base64 = new Base64(2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),225,base64);
            base64 = new Base64(2 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),226,base64);
            base64 = new Base64(128 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),227,base64);
            try {
                base64 = new Base64(-1 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),228,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),229,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ '=' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),230,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ '$' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),231,base64);
            try {
                base64 = new Base64(64 , new byte[]{ 'A' , '$' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ ' ' , '$' , '\n' , '\r' , '\t' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),233,base64);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),223,base64);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testConstructors_literalMutation305() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructors_literalMutation305");
            Base64 base64;
            base64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),224,base64);
            base64 = new Base64(2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),225,base64);
            base64 = new Base64(2 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),226,base64);
            base64 = new Base64(63 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),227,base64);
            try {
                base64 = new Base64(-1 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),228,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),229,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ '=' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),230,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ '$' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),231,base64);
            try {
                base64 = new Base64(64 , new byte[]{ 'A' , '$' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ ' ' , '$' , '\n' , '\r' , '\t' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),233,base64);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),223,base64);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testConstructors_literalMutation307() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructors_literalMutation307");
            Base64 base64;
            base64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),224,base64);
            base64 = new Base64(2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),225,base64);
            base64 = new Base64(2 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),226,base64);
            base64 = new Base64(64 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),227,base64);
            try {
                base64 = new Base64(-2 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),228,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),229,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ '=' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),230,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ '$' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),231,base64);
            try {
                base64 = new Base64(64 , new byte[]{ 'A' , '$' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ ' ' , '$' , '\n' , '\r' , '\t' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),233,base64);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),223,base64);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testConstructors_literalMutation308() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructors_literalMutation308");
            Base64 base64;
            base64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),224,base64);
            base64 = new Base64(2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),225,base64);
            base64 = new Base64(2 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),226,base64);
            base64 = new Base64(64 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),227,base64);
            try {
                base64 = new Base64(0 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),228,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),229,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ '=' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),230,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ '$' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),231,base64);
            try {
                base64 = new Base64(64 , new byte[]{ 'A' , '$' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ ' ' , '$' , '\n' , '\r' , '\t' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),233,base64);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),223,base64);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testConstructors_literalMutation309() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructors_literalMutation309");
            Base64 base64;
            base64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),224,base64);
            base64 = new Base64(2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),225,base64);
            base64 = new Base64(2 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),226,base64);
            base64 = new Base64(64 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),227,base64);
            try {
                base64 = new Base64(0 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),228,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),229,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ '=' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),230,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ '$' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),231,base64);
            try {
                base64 = new Base64(64 , new byte[]{ 'A' , '$' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ ' ' , '$' , '\n' , '\r' , '\t' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),233,base64);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),223,base64);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testConstructors_literalMutation312() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructors_literalMutation312");
            Base64 base64;
            base64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),224,base64);
            base64 = new Base64(2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),225,base64);
            base64 = new Base64(2 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),226,base64);
            base64 = new Base64(64 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),227,base64);
            try {
                base64 = new Base64(2 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),228,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(65 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),229,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ '=' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),230,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ '$' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),231,base64);
            try {
                base64 = new Base64(64 , new byte[]{ 'A' , '$' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ ' ' , '$' , '\n' , '\r' , '\t' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),233,base64);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),223,base64);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testConstructors_literalMutation313() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructors_literalMutation313");
            Base64 base64;
            base64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),224,base64);
            base64 = new Base64(2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),225,base64);
            base64 = new Base64(2 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),226,base64);
            base64 = new Base64(64 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),227,base64);
            try {
                base64 = new Base64(2 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),228,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(32 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),229,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ '=' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),230,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ '$' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),231,base64);
            try {
                base64 = new Base64(64 , new byte[]{ 'A' , '$' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ ' ' , '$' , '\n' , '\r' , '\t' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),233,base64);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),223,base64);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testConstructors_literalMutation314() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructors_literalMutation314");
            Base64 base64;
            base64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),224,base64);
            base64 = new Base64(2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),225,base64);
            base64 = new Base64(2 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),226,base64);
            base64 = new Base64(64 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),227,base64);
            try {
                base64 = new Base64(2 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),228,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(128 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),229,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ '=' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),230,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ '$' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),231,base64);
            try {
                base64 = new Base64(64 , new byte[]{ 'A' , '$' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ ' ' , '$' , '\n' , '\r' , '\t' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),233,base64);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),223,base64);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testConstructors_literalMutation315() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructors_literalMutation315");
            Base64 base64;
            base64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),224,base64);
            base64 = new Base64(2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),225,base64);
            base64 = new Base64(2 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),226,base64);
            base64 = new Base64(64 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),227,base64);
            try {
                base64 = new Base64(2 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),228,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(63 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),229,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ '=' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),230,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ '$' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),231,base64);
            try {
                base64 = new Base64(64 , new byte[]{ 'A' , '$' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ ' ' , '$' , '\n' , '\r' , '\t' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),233,base64);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),223,base64);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testConstructors_literalMutation318() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructors_literalMutation318");
            Base64 base64;
            base64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),224,base64);
            base64 = new Base64(2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),225,base64);
            base64 = new Base64(2 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),226,base64);
            base64 = new Base64(64 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),227,base64);
            try {
                base64 = new Base64(2 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),228,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),229,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(65 , new byte[]{ '=' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),230,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ '$' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),231,base64);
            try {
                base64 = new Base64(64 , new byte[]{ 'A' , '$' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ ' ' , '$' , '\n' , '\r' , '\t' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),233,base64);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),223,base64);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testConstructors_literalMutation319() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructors_literalMutation319");
            Base64 base64;
            base64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),224,base64);
            base64 = new Base64(2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),225,base64);
            base64 = new Base64(2 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),226,base64);
            base64 = new Base64(64 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),227,base64);
            try {
                base64 = new Base64(2 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),228,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),229,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(32 , new byte[]{ '=' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),230,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ '$' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),231,base64);
            try {
                base64 = new Base64(64 , new byte[]{ 'A' , '$' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ ' ' , '$' , '\n' , '\r' , '\t' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),233,base64);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),223,base64);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testConstructors_literalMutation320() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructors_literalMutation320");
            Base64 base64;
            base64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),224,base64);
            base64 = new Base64(2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),225,base64);
            base64 = new Base64(2 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),226,base64);
            base64 = new Base64(64 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),227,base64);
            try {
                base64 = new Base64(2 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),228,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),229,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(128 , new byte[]{ '=' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),230,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ '$' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),231,base64);
            try {
                base64 = new Base64(64 , new byte[]{ 'A' , '$' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ ' ' , '$' , '\n' , '\r' , '\t' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),233,base64);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),223,base64);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testConstructors_literalMutation321() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructors_literalMutation321");
            Base64 base64;
            base64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),224,base64);
            base64 = new Base64(2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),225,base64);
            base64 = new Base64(2 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),226,base64);
            base64 = new Base64(64 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),227,base64);
            try {
                base64 = new Base64(2 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),228,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),229,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(63 , new byte[]{ '=' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),230,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ '$' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),231,base64);
            try {
                base64 = new Base64(64 , new byte[]{ 'A' , '$' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ ' ' , '$' , '\n' , '\r' , '\t' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),233,base64);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),223,base64);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testConstructors_literalMutation324() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructors_literalMutation324");
            Base64 base64;
            base64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),224,base64);
            base64 = new Base64(2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),225,base64);
            base64 = new Base64(2 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),226,base64);
            base64 = new Base64(64 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),227,base64);
            try {
                base64 = new Base64(2 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),228,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),229,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ '=' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),230,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(65 , new byte[]{ '$' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),231,base64);
            try {
                base64 = new Base64(64 , new byte[]{ 'A' , '$' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ ' ' , '$' , '\n' , '\r' , '\t' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),233,base64);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),223,base64);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testConstructors_literalMutation325() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructors_literalMutation325");
            Base64 base64;
            base64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),224,base64);
            base64 = new Base64(2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),225,base64);
            base64 = new Base64(2 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),226,base64);
            base64 = new Base64(64 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),227,base64);
            try {
                base64 = new Base64(2 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),228,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),229,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ '=' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),230,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(32 , new byte[]{ '$' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),231,base64);
            try {
                base64 = new Base64(64 , new byte[]{ 'A' , '$' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ ' ' , '$' , '\n' , '\r' , '\t' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),233,base64);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),223,base64);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testConstructors_literalMutation326() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructors_literalMutation326");
            Base64 base64;
            base64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),224,base64);
            base64 = new Base64(2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),225,base64);
            base64 = new Base64(2 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),226,base64);
            base64 = new Base64(64 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),227,base64);
            try {
                base64 = new Base64(2 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),228,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),229,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ '=' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),230,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(128 , new byte[]{ '$' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),231,base64);
            try {
                base64 = new Base64(64 , new byte[]{ 'A' , '$' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ ' ' , '$' , '\n' , '\r' , '\t' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),233,base64);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),223,base64);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testConstructors_literalMutation327() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructors_literalMutation327");
            Base64 base64;
            base64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),224,base64);
            base64 = new Base64(2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),225,base64);
            base64 = new Base64(2 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),226,base64);
            base64 = new Base64(64 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),227,base64);
            try {
                base64 = new Base64(2 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),228,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),229,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ '=' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),230,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(63 , new byte[]{ '$' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),231,base64);
            try {
                base64 = new Base64(64 , new byte[]{ 'A' , '$' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ ' ' , '$' , '\n' , '\r' , '\t' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),233,base64);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),223,base64);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testConstructors_literalMutation330() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructors_literalMutation330");
            Base64 base64;
            base64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),224,base64);
            base64 = new Base64(2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),225,base64);
            base64 = new Base64(2 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),226,base64);
            base64 = new Base64(64 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),227,base64);
            try {
                base64 = new Base64(2 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),228,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),229,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ '=' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),230,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ '$' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),231,base64);
            try {
                base64 = new Base64(65 , new byte[]{ 'A' , '$' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ ' ' , '$' , '\n' , '\r' , '\t' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),233,base64);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),223,base64);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testConstructors_literalMutation331() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructors_literalMutation331");
            Base64 base64;
            base64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),224,base64);
            base64 = new Base64(2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),225,base64);
            base64 = new Base64(2 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),226,base64);
            base64 = new Base64(64 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),227,base64);
            try {
                base64 = new Base64(2 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),228,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),229,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ '=' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),230,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ '$' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),231,base64);
            try {
                base64 = new Base64(32 , new byte[]{ 'A' , '$' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ ' ' , '$' , '\n' , '\r' , '\t' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),233,base64);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),223,base64);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testConstructors_literalMutation332() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructors_literalMutation332");
            Base64 base64;
            base64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),224,base64);
            base64 = new Base64(2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),225,base64);
            base64 = new Base64(2 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),226,base64);
            base64 = new Base64(64 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),227,base64);
            try {
                base64 = new Base64(2 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),228,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),229,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ '=' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),230,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ '$' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),231,base64);
            try {
                base64 = new Base64(128 , new byte[]{ 'A' , '$' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ ' ' , '$' , '\n' , '\r' , '\t' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),233,base64);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),223,base64);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testConstructors_literalMutation333() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructors_literalMutation333");
            Base64 base64;
            base64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),224,base64);
            base64 = new Base64(2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),225,base64);
            base64 = new Base64(2 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),226,base64);
            base64 = new Base64(64 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),227,base64);
            try {
                base64 = new Base64(2 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),228,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),229,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ '=' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),230,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ '$' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),231,base64);
            try {
                base64 = new Base64(63 , new byte[]{ 'A' , '$' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ ' ' , '$' , '\n' , '\r' , '\t' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),233,base64);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),223,base64);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testConstructors_literalMutation337() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructors_literalMutation337");
            Base64 base64;
            base64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),224,base64);
            base64 = new Base64(2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),225,base64);
            base64 = new Base64(2 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),226,base64);
            base64 = new Base64(64 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),227,base64);
            try {
                base64 = new Base64(2 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),228,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),229,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ '=' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),230,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ '$' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),231,base64);
            try {
                base64 = new Base64(64 , new byte[]{ 'A' , '$' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(65 , new byte[]{ ' ' , '$' , '\n' , '\r' , '\t' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),233,base64);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),223,base64);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testConstructors_literalMutation338() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructors_literalMutation338");
            Base64 base64;
            base64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),224,base64);
            base64 = new Base64(2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),225,base64);
            base64 = new Base64(2 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),226,base64);
            base64 = new Base64(64 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),227,base64);
            try {
                base64 = new Base64(2 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),228,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),229,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ '=' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),230,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ '$' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),231,base64);
            try {
                base64 = new Base64(64 , new byte[]{ 'A' , '$' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(32 , new byte[]{ ' ' , '$' , '\n' , '\r' , '\t' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),233,base64);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),223,base64);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testConstructors_literalMutation339() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructors_literalMutation339");
            Base64 base64;
            base64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),224,base64);
            base64 = new Base64(2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),225,base64);
            base64 = new Base64(2 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),226,base64);
            base64 = new Base64(64 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),227,base64);
            try {
                base64 = new Base64(2 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),228,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),229,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ '=' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),230,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ '$' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),231,base64);
            try {
                base64 = new Base64(64 , new byte[]{ 'A' , '$' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(128 , new byte[]{ ' ' , '$' , '\n' , '\r' , '\t' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),233,base64);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),223,base64);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testConstructors_literalMutation340() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructors_literalMutation340");
            Base64 base64;
            base64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),224,base64);
            base64 = new Base64(2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),225,base64);
            base64 = new Base64(2 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),226,base64);
            base64 = new Base64(64 , new byte[]{  });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),227,base64);
            try {
                base64 = new Base64(2 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),228,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ 'A' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),229,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            try {
                base64 = new Base64(64 , new byte[]{ '=' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),230,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(64 , new byte[]{ '$' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),231,base64);
            try {
                base64 = new Base64(64 , new byte[]{ 'A' , '$' });
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,base64);
            } catch (final IllegalArgumentException ignored) {
            }
            base64 = new Base64(63 , new byte[]{ ' ' , '$' , '\n' , '\r' , '\t' });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),233,base64);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),223,base64);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testConstructor_Int_ByteArray_Boolean() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructor_Int_ByteArray_Boolean");
            final Base64 base64 = new Base64(66 , new byte[]{ '\t' } , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),219,base64);
            final byte[] encoded = base64.encode(Base64TestData.DECODED);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),220,encoded);
            String expectedResult = Base64TestData.ENCODED_64_CHARS_PER_LINE;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),221,expectedResult);
            expectedResult = expectedResult.replace('\n', '\t');
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),218,expectedResult);
            final String result = org.apache.commons.codec.binary.StringUtils.newStringUtf8(encoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),222,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),216,expectedResult);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),217,result);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testConstructor_Int_ByteArray_Boolean_literalMutation279() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructor_Int_ByteArray_Boolean_literalMutation279");
            final Base64 base64 = new Base64(64 , new byte[]{ '\t' } , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),219,base64);
            final byte[] encoded = base64.encode(Base64TestData.DECODED);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),220,encoded);
            String expectedResult = Base64TestData.ENCODED_64_CHARS_PER_LINE;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),221,expectedResult);
            expectedResult = expectedResult.replace('\n', '\t');
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),218,expectedResult);
            final String result = org.apache.commons.codec.binary.StringUtils.newStringUtf8(encoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),222,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),216,expectedResult);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),217,result);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testConstructor_Int_ByteArray_Boolean_literalMutation280() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructor_Int_ByteArray_Boolean_literalMutation280");
            final Base64 base64 = new Base64(32 , new byte[]{ '\t' } , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),219,base64);
            final byte[] encoded = base64.encode(Base64TestData.DECODED);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),220,encoded);
            String expectedResult = Base64TestData.ENCODED_64_CHARS_PER_LINE;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),221,expectedResult);
            expectedResult = expectedResult.replace('\n', '\t');
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),218,expectedResult);
            final String result = org.apache.commons.codec.binary.StringUtils.newStringUtf8(encoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),222,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),216,expectedResult);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),217,result);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testConstructor_Int_ByteArray_Boolean_literalMutation281() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructor_Int_ByteArray_Boolean_literalMutation281");
            final Base64 base64 = new Base64(130 , new byte[]{ '\t' } , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),219,base64);
            final byte[] encoded = base64.encode(Base64TestData.DECODED);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),220,encoded);
            String expectedResult = Base64TestData.ENCODED_64_CHARS_PER_LINE;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),221,expectedResult);
            expectedResult = expectedResult.replace('\n', '\t');
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),218,expectedResult);
            final String result = org.apache.commons.codec.binary.StringUtils.newStringUtf8(encoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),222,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),216,expectedResult);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),217,result);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testConstructor_Int_ByteArray_Boolean_literalMutation284() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructor_Int_ByteArray_Boolean_literalMutation284");
            final Base64 base64 = new Base64(65 , new byte[]{ '\t' } , true);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),219,base64);
            final byte[] encoded = base64.encode(Base64TestData.DECODED);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),220,encoded);
            String expectedResult = Base64TestData.ENCODED_64_CHARS_PER_LINE;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),221,expectedResult);
            expectedResult = expectedResult.replace('\n', '\t');
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),218,expectedResult);
            final String result = org.apache.commons.codec.binary.StringUtils.newStringUtf8(encoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),222,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),216,expectedResult);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),217,result);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testConstructor_Int_ByteArray_Boolean_UrlSafe() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructor_Int_ByteArray_Boolean_UrlSafe");
            final Base64 base64 = new Base64(65 , new byte[]{ '\t' } , true);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),212,base64);
            final byte[] encoded = base64.encode(Base64TestData.DECODED);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),213,encoded);
            String expectedResult = Base64TestData.ENCODED_64_CHARS_PER_LINE;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),214,expectedResult);
            expectedResult = expectedResult.replaceAll("=", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),208,expectedResult);
            expectedResult = expectedResult.replace('\n', '\t');
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),209,expectedResult);
            expectedResult = expectedResult.replace('+', '-');
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),210,expectedResult);
            expectedResult = expectedResult.replace('/', '_');
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),211,expectedResult);
            final String result = org.apache.commons.codec.binary.StringUtils.newStringUtf8(encoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),215,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),206,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),207,expectedResult);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testConstructor_Int_ByteArray_Boolean_UrlSafe_literalMutation288() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructor_Int_ByteArray_Boolean_UrlSafe_literalMutation288");
            final Base64 base64 = new Base64(32 , new byte[]{ '\t' } , true);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),212,base64);
            final byte[] encoded = base64.encode(Base64TestData.DECODED);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),213,encoded);
            String expectedResult = Base64TestData.ENCODED_64_CHARS_PER_LINE;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),214,expectedResult);
            expectedResult = expectedResult.replaceAll("=", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),208,expectedResult);
            expectedResult = expectedResult.replace('\n', '\t');
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),209,expectedResult);
            expectedResult = expectedResult.replace('+', '-');
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),210,expectedResult);
            expectedResult = expectedResult.replace('/', '_');
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),211,expectedResult);
            final String result = org.apache.commons.codec.binary.StringUtils.newStringUtf8(encoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),215,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),206,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),207,expectedResult);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testConstructor_Int_ByteArray_Boolean_UrlSafe_literalMutation289() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructor_Int_ByteArray_Boolean_UrlSafe_literalMutation289");
            final Base64 base64 = new Base64(128 , new byte[]{ '\t' } , true);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),212,base64);
            final byte[] encoded = base64.encode(Base64TestData.DECODED);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),213,encoded);
            String expectedResult = Base64TestData.ENCODED_64_CHARS_PER_LINE;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),214,expectedResult);
            expectedResult = expectedResult.replaceAll("=", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),208,expectedResult);
            expectedResult = expectedResult.replace('\n', '\t');
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),209,expectedResult);
            expectedResult = expectedResult.replace('+', '-');
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),210,expectedResult);
            expectedResult = expectedResult.replace('/', '_');
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),211,expectedResult);
            final String result = org.apache.commons.codec.binary.StringUtils.newStringUtf8(encoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),215,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),206,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),207,expectedResult);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testConstructor_Int_ByteArray_Boolean_UrlSafe_literalMutation290() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructor_Int_ByteArray_Boolean_UrlSafe_literalMutation290");
            final Base64 base64 = new Base64(63 , new byte[]{ '\t' } , true);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),212,base64);
            final byte[] encoded = base64.encode(Base64TestData.DECODED);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),213,encoded);
            String expectedResult = Base64TestData.ENCODED_64_CHARS_PER_LINE;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),214,expectedResult);
            expectedResult = expectedResult.replaceAll("=", "");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),208,expectedResult);
            expectedResult = expectedResult.replace('\n', '\t');
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),209,expectedResult);
            expectedResult = expectedResult.replace('+', '-');
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),210,expectedResult);
            expectedResult = expectedResult.replace('/', '_');
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),211,expectedResult);
            final String result = org.apache.commons.codec.binary.StringUtils.newStringUtf8(encoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),215,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),206,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),207,expectedResult);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests conditional true branch for "marker0" test.
     */
@Test
    public void testDecodePadMarkerIndex2() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodePadMarkerIndex2");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),238,new java.lang.String(org.apache.commons.codec.binary.Base64.decodeBase64("QQ==".getBytes(org.apache.commons.codec.Charsets.UTF_8))));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests conditional branches for "marker1" test.
     */
@Test
    public void testDecodePadMarkerIndex3() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodePadMarkerIndex3");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),239,new java.lang.String(org.apache.commons.codec.binary.Base64.decodeBase64("QUE=".getBytes(org.apache.commons.codec.Charsets.UTF_8))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),240,new java.lang.String(org.apache.commons.codec.binary.Base64.decodeBase64("QUFB".getBytes(org.apache.commons.codec.Charsets.UTF_8))));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testDecodePadOnly() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodePadOnly");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),241,org.apache.commons.codec.binary.Base64.decodeBase64("====".getBytes(org.apache.commons.codec.Charsets.UTF_8)).length);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),242,new java.lang.String(org.apache.commons.codec.binary.Base64.decodeBase64("====".getBytes(org.apache.commons.codec.Charsets.UTF_8))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),243,org.apache.commons.codec.binary.Base64.decodeBase64("===".getBytes(org.apache.commons.codec.Charsets.UTF_8)).length);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),244,org.apache.commons.codec.binary.Base64.decodeBase64("==".getBytes(org.apache.commons.codec.Charsets.UTF_8)).length);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),245,org.apache.commons.codec.binary.Base64.decodeBase64("=".getBytes(org.apache.commons.codec.Charsets.UTF_8)).length);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),246,org.apache.commons.codec.binary.Base64.decodeBase64("".getBytes(org.apache.commons.codec.Charsets.UTF_8)).length);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testDecodePadOnlyChunked() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodePadOnlyChunked");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),247,org.apache.commons.codec.binary.Base64.decodeBase64("====\n".getBytes(org.apache.commons.codec.Charsets.UTF_8)).length);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),248,new java.lang.String(org.apache.commons.codec.binary.Base64.decodeBase64("====\n".getBytes(org.apache.commons.codec.Charsets.UTF_8))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),249,org.apache.commons.codec.binary.Base64.decodeBase64("===\n".getBytes(org.apache.commons.codec.Charsets.UTF_8)).length);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),250,org.apache.commons.codec.binary.Base64.decodeBase64("==\n".getBytes(org.apache.commons.codec.Charsets.UTF_8)).length);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),251,org.apache.commons.codec.binary.Base64.decodeBase64("=\n".getBytes(org.apache.commons.codec.Charsets.UTF_8)).length);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),252,org.apache.commons.codec.binary.Base64.decodeBase64("\n".getBytes(org.apache.commons.codec.Charsets.UTF_8)).length);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDecodeWithWhitespace_add28() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodeWithWhitespace_add28");
            final String orig = "I am a late night coder.";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),259,orig);
            final byte[] encodedArray = Base64.encodeBase64(orig.getBytes(org.apache.commons.codec.Charsets.UTF_8));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),260,encodedArray);
            final StringBuilder intermediate = new StringBuilder(new String(encodedArray));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),261,intermediate);
            intermediate.insert(2, ' ');
            intermediate.insert(2, ' ');
            intermediate.insert(5, '\t');
            intermediate.insert(10, '\r');
            intermediate.insert(15, '\n');
            final byte[] encodedWithWS = intermediate.toString().getBytes(org.apache.commons.codec.Charsets.UTF_8);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),262,encodedWithWS);
            final byte[] decodedWithWS = Base64.decodeBase64(encodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),263,decodedWithWS);
            final String dest = new String(decodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),264,dest);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),257,orig);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),258,dest);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDecodeWithWhitespace_add29() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodeWithWhitespace_add29");
            final String orig = "I am a late night coder.";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),259,orig);
            final byte[] encodedArray = Base64.encodeBase64(orig.getBytes(org.apache.commons.codec.Charsets.UTF_8));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),260,encodedArray);
            final StringBuilder intermediate = new StringBuilder(new String(encodedArray));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),261,intermediate);
            intermediate.insert(2, ' ');
            intermediate.insert(5, '\t');
            intermediate.insert(5, '\t');
            intermediate.insert(10, '\r');
            intermediate.insert(15, '\n');
            final byte[] encodedWithWS = intermediate.toString().getBytes(org.apache.commons.codec.Charsets.UTF_8);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),262,encodedWithWS);
            final byte[] decodedWithWS = Base64.decodeBase64(encodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),263,decodedWithWS);
            final String dest = new String(decodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),264,dest);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),257,orig);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),258,dest);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDecodeWithWhitespace_add30() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodeWithWhitespace_add30");
            final String orig = "I am a late night coder.";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),259,orig);
            final byte[] encodedArray = Base64.encodeBase64(orig.getBytes(org.apache.commons.codec.Charsets.UTF_8));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),260,encodedArray);
            final StringBuilder intermediate = new StringBuilder(new String(encodedArray));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),261,intermediate);
            intermediate.insert(2, ' ');
            intermediate.insert(5, '\t');
            intermediate.insert(10, '\r');
            intermediate.insert(10, '\r');
            intermediate.insert(15, '\n');
            final byte[] encodedWithWS = intermediate.toString().getBytes(org.apache.commons.codec.Charsets.UTF_8);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),262,encodedWithWS);
            final byte[] decodedWithWS = Base64.decodeBase64(encodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),263,decodedWithWS);
            final String dest = new String(decodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),264,dest);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),257,orig);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),258,dest);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDecodeWithWhitespace_add31() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodeWithWhitespace_add31");
            final String orig = "I am a late night coder.";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),259,orig);
            final byte[] encodedArray = Base64.encodeBase64(orig.getBytes(org.apache.commons.codec.Charsets.UTF_8));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),260,encodedArray);
            final StringBuilder intermediate = new StringBuilder(new String(encodedArray));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),261,intermediate);
            intermediate.insert(2, ' ');
            intermediate.insert(5, '\t');
            intermediate.insert(10, '\r');
            intermediate.insert(15, '\n');
            intermediate.insert(15, '\n');
            final byte[] encodedWithWS = intermediate.toString().getBytes(org.apache.commons.codec.Charsets.UTF_8);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),262,encodedWithWS);
            final byte[] decodedWithWS = Base64.decodeBase64(encodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),263,decodedWithWS);
            final String dest = new String(decodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),264,dest);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),257,orig);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),258,dest);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testDecodeWithWhitespace() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodeWithWhitespace");
            final String orig = "I am a:late night coder.";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),259,orig);
            final byte[] encodedArray = Base64.encodeBase64(orig.getBytes(org.apache.commons.codec.Charsets.UTF_8));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),260,encodedArray);
            final StringBuilder intermediate = new StringBuilder(new String(encodedArray));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),261,intermediate);
            intermediate.insert(2, ' ');
            intermediate.insert(5, '\t');
            intermediate.insert(10, '\r');
            intermediate.insert(15, '\n');
            final byte[] encodedWithWS = intermediate.toString().getBytes(org.apache.commons.codec.Charsets.UTF_8);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),262,encodedWithWS);
            final byte[] decodedWithWS = Base64.decodeBase64(encodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),263,decodedWithWS);
            final String dest = new String(decodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),264,dest);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),257,orig);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),258,dest);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testDecodeWithWhitespace_literalMutation354() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodeWithWhitespace_literalMutation354");
            final String orig = "I am a laHte night coder.";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),259,orig);
            final byte[] encodedArray = Base64.encodeBase64(orig.getBytes(org.apache.commons.codec.Charsets.UTF_8));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),260,encodedArray);
            final StringBuilder intermediate = new StringBuilder(new String(encodedArray));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),261,intermediate);
            intermediate.insert(2, ' ');
            intermediate.insert(5, '\t');
            intermediate.insert(10, '\r');
            intermediate.insert(15, '\n');
            final byte[] encodedWithWS = intermediate.toString().getBytes(org.apache.commons.codec.Charsets.UTF_8);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),262,encodedWithWS);
            final byte[] decodedWithWS = Base64.decodeBase64(encodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),263,decodedWithWS);
            final String dest = new String(decodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),264,dest);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),257,orig);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),258,dest);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testDecodeWithWhitespace_literalMutation355() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodeWithWhitespace_literalMutation355");
            final String orig = "I am  late night coder.";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),259,orig);
            final byte[] encodedArray = Base64.encodeBase64(orig.getBytes(org.apache.commons.codec.Charsets.UTF_8));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),260,encodedArray);
            final StringBuilder intermediate = new StringBuilder(new String(encodedArray));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),261,intermediate);
            intermediate.insert(2, ' ');
            intermediate.insert(5, '\t');
            intermediate.insert(10, '\r');
            intermediate.insert(15, '\n');
            final byte[] encodedWithWS = intermediate.toString().getBytes(org.apache.commons.codec.Charsets.UTF_8);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),262,encodedWithWS);
            final byte[] decodedWithWS = Base64.decodeBase64(encodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),263,decodedWithWS);
            final String dest = new String(decodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),264,dest);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),257,orig);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),258,dest);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testDecodeWithWhitespace_literalMutation356() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodeWithWhitespace_literalMutation356");
            final String orig = "I am a late night coder.";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),259,orig);
            final byte[] encodedArray = Base64.encodeBase64(orig.getBytes(org.apache.commons.codec.Charsets.UTF_8));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),260,encodedArray);
            final StringBuilder intermediate = new StringBuilder(new String(encodedArray));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),261,intermediate);
            intermediate.insert(1, ' ');
            intermediate.insert(5, '\t');
            intermediate.insert(10, '\r');
            intermediate.insert(15, '\n');
            final byte[] encodedWithWS = intermediate.toString().getBytes(org.apache.commons.codec.Charsets.UTF_8);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),262,encodedWithWS);
            final byte[] decodedWithWS = Base64.decodeBase64(encodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),263,decodedWithWS);
            final String dest = new String(decodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),264,dest);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),257,orig);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),258,dest);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testDecodeWithWhitespace_literalMutation357() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodeWithWhitespace_literalMutation357");
            final String orig = "I am a late night coder.";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),259,orig);
            final byte[] encodedArray = Base64.encodeBase64(orig.getBytes(org.apache.commons.codec.Charsets.UTF_8));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),260,encodedArray);
            final StringBuilder intermediate = new StringBuilder(new String(encodedArray));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),261,intermediate);
            intermediate.insert(4, ' ');
            intermediate.insert(5, '\t');
            intermediate.insert(10, '\r');
            intermediate.insert(15, '\n');
            final byte[] encodedWithWS = intermediate.toString().getBytes(org.apache.commons.codec.Charsets.UTF_8);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),262,encodedWithWS);
            final byte[] decodedWithWS = Base64.decodeBase64(encodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),263,decodedWithWS);
            final String dest = new String(decodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),264,dest);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),257,orig);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),258,dest);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testDecodeWithWhitespace_literalMutation358() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodeWithWhitespace_literalMutation358");
            final String orig = "I am a late night coder.";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),259,orig);
            final byte[] encodedArray = Base64.encodeBase64(orig.getBytes(org.apache.commons.codec.Charsets.UTF_8));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),260,encodedArray);
            final StringBuilder intermediate = new StringBuilder(new String(encodedArray));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),261,intermediate);
            intermediate.insert(3, ' ');
            intermediate.insert(5, '\t');
            intermediate.insert(10, '\r');
            intermediate.insert(15, '\n');
            final byte[] encodedWithWS = intermediate.toString().getBytes(org.apache.commons.codec.Charsets.UTF_8);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),262,encodedWithWS);
            final byte[] decodedWithWS = Base64.decodeBase64(encodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),263,decodedWithWS);
            final String dest = new String(decodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),264,dest);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),257,orig);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),258,dest);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testDecodeWithWhitespace_literalMutation361() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodeWithWhitespace_literalMutation361");
            final String orig = "I am a late night coder.";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),259,orig);
            final byte[] encodedArray = Base64.encodeBase64(orig.getBytes(org.apache.commons.codec.Charsets.UTF_8));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),260,encodedArray);
            final StringBuilder intermediate = new StringBuilder(new String(encodedArray));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),261,intermediate);
            intermediate.insert(2, ' ');
            intermediate.insert(4, '\t');
            intermediate.insert(10, '\r');
            intermediate.insert(15, '\n');
            final byte[] encodedWithWS = intermediate.toString().getBytes(org.apache.commons.codec.Charsets.UTF_8);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),262,encodedWithWS);
            final byte[] decodedWithWS = Base64.decodeBase64(encodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),263,decodedWithWS);
            final String dest = new String(decodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),264,dest);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),257,orig);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),258,dest);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testDecodeWithWhitespace_literalMutation362() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodeWithWhitespace_literalMutation362");
            final String orig = "I am a late night coder.";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),259,orig);
            final byte[] encodedArray = Base64.encodeBase64(orig.getBytes(org.apache.commons.codec.Charsets.UTF_8));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),260,encodedArray);
            final StringBuilder intermediate = new StringBuilder(new String(encodedArray));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),261,intermediate);
            intermediate.insert(2, ' ');
            intermediate.insert(2, '\t');
            intermediate.insert(10, '\r');
            intermediate.insert(15, '\n');
            final byte[] encodedWithWS = intermediate.toString().getBytes(org.apache.commons.codec.Charsets.UTF_8);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),262,encodedWithWS);
            final byte[] decodedWithWS = Base64.decodeBase64(encodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),263,decodedWithWS);
            final String dest = new String(decodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),264,dest);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),257,orig);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),258,dest);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testDecodeWithWhitespace_literalMutation363() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodeWithWhitespace_literalMutation363");
            final String orig = "I am a late night coder.";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),259,orig);
            final byte[] encodedArray = Base64.encodeBase64(orig.getBytes(org.apache.commons.codec.Charsets.UTF_8));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),260,encodedArray);
            final StringBuilder intermediate = new StringBuilder(new String(encodedArray));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),261,intermediate);
            intermediate.insert(2, ' ');
            intermediate.insert(10, '\t');
            intermediate.insert(10, '\r');
            intermediate.insert(15, '\n');
            final byte[] encodedWithWS = intermediate.toString().getBytes(org.apache.commons.codec.Charsets.UTF_8);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),262,encodedWithWS);
            final byte[] decodedWithWS = Base64.decodeBase64(encodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),263,decodedWithWS);
            final String dest = new String(decodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),264,dest);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),257,orig);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),258,dest);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testDecodeWithWhitespace_literalMutation364() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodeWithWhitespace_literalMutation364");
            final String orig = "I am a late night coder.";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),259,orig);
            final byte[] encodedArray = Base64.encodeBase64(orig.getBytes(org.apache.commons.codec.Charsets.UTF_8));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),260,encodedArray);
            final StringBuilder intermediate = new StringBuilder(new String(encodedArray));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),261,intermediate);
            intermediate.insert(2, ' ');
            intermediate.insert(6, '\t');
            intermediate.insert(10, '\r');
            intermediate.insert(15, '\n');
            final byte[] encodedWithWS = intermediate.toString().getBytes(org.apache.commons.codec.Charsets.UTF_8);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),262,encodedWithWS);
            final byte[] decodedWithWS = Base64.decodeBase64(encodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),263,decodedWithWS);
            final String dest = new String(decodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),264,dest);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),257,orig);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),258,dest);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testDecodeWithWhitespace_literalMutation367() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodeWithWhitespace_literalMutation367");
            final String orig = "I am a late night coder.";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),259,orig);
            final byte[] encodedArray = Base64.encodeBase64(orig.getBytes(org.apache.commons.codec.Charsets.UTF_8));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),260,encodedArray);
            final StringBuilder intermediate = new StringBuilder(new String(encodedArray));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),261,intermediate);
            intermediate.insert(2, ' ');
            intermediate.insert(5, '\t');
            intermediate.insert(9, '\r');
            intermediate.insert(15, '\n');
            final byte[] encodedWithWS = intermediate.toString().getBytes(org.apache.commons.codec.Charsets.UTF_8);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),262,encodedWithWS);
            final byte[] decodedWithWS = Base64.decodeBase64(encodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),263,decodedWithWS);
            final String dest = new String(decodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),264,dest);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),257,orig);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),258,dest);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testDecodeWithWhitespace_literalMutation368() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodeWithWhitespace_literalMutation368");
            final String orig = "I am a late night coder.";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),259,orig);
            final byte[] encodedArray = Base64.encodeBase64(orig.getBytes(org.apache.commons.codec.Charsets.UTF_8));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),260,encodedArray);
            final StringBuilder intermediate = new StringBuilder(new String(encodedArray));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),261,intermediate);
            intermediate.insert(2, ' ');
            intermediate.insert(5, '\t');
            intermediate.insert(5, '\r');
            intermediate.insert(15, '\n');
            final byte[] encodedWithWS = intermediate.toString().getBytes(org.apache.commons.codec.Charsets.UTF_8);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),262,encodedWithWS);
            final byte[] decodedWithWS = Base64.decodeBase64(encodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),263,decodedWithWS);
            final String dest = new String(decodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),264,dest);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),257,orig);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),258,dest);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testDecodeWithWhitespace_literalMutation369() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodeWithWhitespace_literalMutation369");
            final String orig = "I am a late night coder.";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),259,orig);
            final byte[] encodedArray = Base64.encodeBase64(orig.getBytes(org.apache.commons.codec.Charsets.UTF_8));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),260,encodedArray);
            final StringBuilder intermediate = new StringBuilder(new String(encodedArray));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),261,intermediate);
            intermediate.insert(2, ' ');
            intermediate.insert(5, '\t');
            intermediate.insert(20, '\r');
            intermediate.insert(15, '\n');
            final byte[] encodedWithWS = intermediate.toString().getBytes(org.apache.commons.codec.Charsets.UTF_8);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),262,encodedWithWS);
            final byte[] decodedWithWS = Base64.decodeBase64(encodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),263,decodedWithWS);
            final String dest = new String(decodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),264,dest);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),257,orig);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),258,dest);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testDecodeWithWhitespace_literalMutation370() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodeWithWhitespace_literalMutation370");
            final String orig = "I am a late night coder.";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),259,orig);
            final byte[] encodedArray = Base64.encodeBase64(orig.getBytes(org.apache.commons.codec.Charsets.UTF_8));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),260,encodedArray);
            final StringBuilder intermediate = new StringBuilder(new String(encodedArray));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),261,intermediate);
            intermediate.insert(2, ' ');
            intermediate.insert(5, '\t');
            intermediate.insert(11, '\r');
            intermediate.insert(15, '\n');
            final byte[] encodedWithWS = intermediate.toString().getBytes(org.apache.commons.codec.Charsets.UTF_8);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),262,encodedWithWS);
            final byte[] decodedWithWS = Base64.decodeBase64(encodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),263,decodedWithWS);
            final String dest = new String(decodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),264,dest);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),257,orig);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),258,dest);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testDecodeWithWhitespace_literalMutation373() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodeWithWhitespace_literalMutation373");
            final String orig = "I am a late night coder.";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),259,orig);
            final byte[] encodedArray = Base64.encodeBase64(orig.getBytes(org.apache.commons.codec.Charsets.UTF_8));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),260,encodedArray);
            final StringBuilder intermediate = new StringBuilder(new String(encodedArray));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),261,intermediate);
            intermediate.insert(2, ' ');
            intermediate.insert(5, '\t');
            intermediate.insert(10, '\r');
            intermediate.insert(16, '\n');
            final byte[] encodedWithWS = intermediate.toString().getBytes(org.apache.commons.codec.Charsets.UTF_8);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),262,encodedWithWS);
            final byte[] decodedWithWS = Base64.decodeBase64(encodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),263,decodedWithWS);
            final String dest = new String(decodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),264,dest);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),257,orig);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),258,dest);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testDecodeWithWhitespace_literalMutation374() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodeWithWhitespace_literalMutation374");
            final String orig = "I am a late night coder.";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),259,orig);
            final byte[] encodedArray = Base64.encodeBase64(orig.getBytes(org.apache.commons.codec.Charsets.UTF_8));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),260,encodedArray);
            final StringBuilder intermediate = new StringBuilder(new String(encodedArray));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),261,intermediate);
            intermediate.insert(2, ' ');
            intermediate.insert(5, '\t');
            intermediate.insert(10, '\r');
            intermediate.insert(14, '\n');
            final byte[] encodedWithWS = intermediate.toString().getBytes(org.apache.commons.codec.Charsets.UTF_8);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),262,encodedWithWS);
            final byte[] decodedWithWS = Base64.decodeBase64(encodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),263,decodedWithWS);
            final String dest = new String(decodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),264,dest);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),257,orig);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),258,dest);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testDecodeWithWhitespace_literalMutation375() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodeWithWhitespace_literalMutation375");
            final String orig = "I am a late night coder.";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),259,orig);
            final byte[] encodedArray = Base64.encodeBase64(orig.getBytes(org.apache.commons.codec.Charsets.UTF_8));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),260,encodedArray);
            final StringBuilder intermediate = new StringBuilder(new String(encodedArray));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),261,intermediate);
            intermediate.insert(2, ' ');
            intermediate.insert(5, '\t');
            intermediate.insert(10, '\r');
            intermediate.insert(7, '\n');
            final byte[] encodedWithWS = intermediate.toString().getBytes(org.apache.commons.codec.Charsets.UTF_8);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),262,encodedWithWS);
            final byte[] decodedWithWS = Base64.decodeBase64(encodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),263,decodedWithWS);
            final String dest = new String(decodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),264,dest);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),257,orig);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),258,dest);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testDecodeWithWhitespace_literalMutation376() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodeWithWhitespace_literalMutation376");
            final String orig = "I am a late night coder.";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),259,orig);
            final byte[] encodedArray = Base64.encodeBase64(orig.getBytes(org.apache.commons.codec.Charsets.UTF_8));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),260,encodedArray);
            final StringBuilder intermediate = new StringBuilder(new String(encodedArray));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),261,intermediate);
            intermediate.insert(2, ' ');
            intermediate.insert(5, '\t');
            intermediate.insert(10, '\r');
            intermediate.insert(30, '\n');
            final byte[] encodedWithWS = intermediate.toString().getBytes(org.apache.commons.codec.Charsets.UTF_8);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),262,encodedWithWS);
            final byte[] decodedWithWS = Base64.decodeBase64(encodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),263,decodedWithWS);
            final String dest = new String(decodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),264,dest);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),257,orig);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),258,dest);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDecodeWithWhitespace_remove19() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodeWithWhitespace_remove19");
            final String orig = "I am a late night coder.";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),259,orig);
            final byte[] encodedArray = Base64.encodeBase64(orig.getBytes(org.apache.commons.codec.Charsets.UTF_8));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),260,encodedArray);
            final StringBuilder intermediate = new StringBuilder(new String(encodedArray));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),261,intermediate);
            intermediate.insert(5, '\t');
            intermediate.insert(10, '\r');
            intermediate.insert(15, '\n');
            final byte[] encodedWithWS = intermediate.toString().getBytes(org.apache.commons.codec.Charsets.UTF_8);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),262,encodedWithWS);
            final byte[] decodedWithWS = Base64.decodeBase64(encodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),263,decodedWithWS);
            final String dest = new String(decodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),264,dest);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),257,orig);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),258,dest);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDecodeWithWhitespace_remove20() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodeWithWhitespace_remove20");
            final String orig = "I am a late night coder.";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),259,orig);
            final byte[] encodedArray = Base64.encodeBase64(orig.getBytes(org.apache.commons.codec.Charsets.UTF_8));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),260,encodedArray);
            final StringBuilder intermediate = new StringBuilder(new String(encodedArray));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),261,intermediate);
            intermediate.insert(5, '\t');
            intermediate.insert(10, '\r');
            intermediate.insert(15, '\n');
            final byte[] encodedWithWS = intermediate.toString().getBytes(org.apache.commons.codec.Charsets.UTF_8);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),262,encodedWithWS);
            final byte[] decodedWithWS = Base64.decodeBase64(encodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),263,decodedWithWS);
            final String dest = new String(decodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),264,dest);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),257,orig);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),258,dest);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDecodeWithWhitespace_remove21() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodeWithWhitespace_remove21");
            final String orig = "I am a late night coder.";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),259,orig);
            final byte[] encodedArray = Base64.encodeBase64(orig.getBytes(org.apache.commons.codec.Charsets.UTF_8));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),260,encodedArray);
            final StringBuilder intermediate = new StringBuilder(new String(encodedArray));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),261,intermediate);
            intermediate.insert(5, '\t');
            intermediate.insert(10, '\r');
            intermediate.insert(15, '\n');
            final byte[] encodedWithWS = intermediate.toString().getBytes(org.apache.commons.codec.Charsets.UTF_8);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),262,encodedWithWS);
            final byte[] decodedWithWS = Base64.decodeBase64(encodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),263,decodedWithWS);
            final String dest = new String(decodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),264,dest);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),257,orig);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),258,dest);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDecodeWithWhitespace_remove22() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodeWithWhitespace_remove22");
            final String orig = "I am a late night coder.";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),259,orig);
            final byte[] encodedArray = Base64.encodeBase64(orig.getBytes(org.apache.commons.codec.Charsets.UTF_8));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),260,encodedArray);
            final StringBuilder intermediate = new StringBuilder(new String(encodedArray));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),261,intermediate);
            intermediate.insert(5, '\t');
            intermediate.insert(10, '\r');
            intermediate.insert(15, '\n');
            final byte[] encodedWithWS = intermediate.toString().getBytes(org.apache.commons.codec.Charsets.UTF_8);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),262,encodedWithWS);
            final byte[] decodedWithWS = Base64.decodeBase64(encodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),263,decodedWithWS);
            final String dest = new String(decodedWithWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),264,dest);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),257,orig);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),258,dest);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test encode and decode of empty byte array.
     */
@Test
    public void testEmptyBase64() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEmptyBase64");
            byte[] empty = new byte[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),271,empty);
            byte[] result = Base64.encodeBase64(empty);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),272,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),265,result.length);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),266,org.apache.commons.codec.binary.Base64.encodeBase64(null));
            empty = new byte[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),269,empty);
            result = Base64.decodeBase64(empty);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),270,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),267,result.length);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),268,org.apache.commons.codec.binary.Base64.decodeBase64(((byte[])(null))));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test encode and decode of empty byte array.
     */
@Test
    public void testEmptyBase64_literalMutation380() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEmptyBase64_literalMutation380");
            byte[] empty = new byte[-1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),271,empty);
            byte[] result = Base64.encodeBase64(empty);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),272,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),265,result.length);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),266,org.apache.commons.codec.binary.Base64.encodeBase64(null));
            empty = new byte[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),269,empty);
            result = Base64.decodeBase64(empty);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),270,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),267,result.length);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),268,org.apache.commons.codec.binary.Base64.decodeBase64(((byte[])(null))));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test encode and decode of empty byte array.
     */
@Test
    public void testEmptyBase64_literalMutation381() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEmptyBase64_literalMutation381");
            byte[] empty = new byte[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),271,empty);
            byte[] result = Base64.encodeBase64(empty);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),272,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),265,result.length);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),266,org.apache.commons.codec.binary.Base64.encodeBase64(null));
            empty = new byte[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),269,empty);
            result = Base64.decodeBase64(empty);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),270,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),267,result.length);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),268,org.apache.commons.codec.binary.Base64.decodeBase64(((byte[])(null))));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test encode and decode of empty byte array.
     */
@Test
    public void testEmptyBase64_literalMutation383() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEmptyBase64_literalMutation383");
            byte[] empty = new byte[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),271,empty);
            byte[] result = Base64.encodeBase64(empty);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),272,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),265,result.length);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),266,org.apache.commons.codec.binary.Base64.encodeBase64(null));
            empty = new byte[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),269,empty);
            result = Base64.decodeBase64(empty);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),270,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),267,result.length);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),268,org.apache.commons.codec.binary.Base64.decodeBase64(((byte[])(null))));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test encode and decode of empty byte array.
     */
@Test
    public void testEmptyBase64_literalMutation384() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEmptyBase64_literalMutation384");
            byte[] empty = new byte[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),271,empty);
            byte[] result = Base64.encodeBase64(empty);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),272,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),265,result.length);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),266,org.apache.commons.codec.binary.Base64.encodeBase64(null));
            empty = new byte[-1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),269,empty);
            result = Base64.decodeBase64(empty);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),270,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),267,result.length);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),268,org.apache.commons.codec.binary.Base64.decodeBase64(((byte[])(null))));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test encode and decode of empty byte array.
     */
@Test
    public void testEmptyBase64_literalMutation385() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEmptyBase64_literalMutation385");
            byte[] empty = new byte[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),271,empty);
            byte[] result = Base64.encodeBase64(empty);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),272,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),265,result.length);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),266,org.apache.commons.codec.binary.Base64.encodeBase64(null));
            empty = new byte[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),269,empty);
            result = Base64.decodeBase64(empty);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),270,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),267,result.length);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),268,org.apache.commons.codec.binary.Base64.decodeBase64(((byte[])(null))));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testEncodeDecodeRandom_add32() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeDecodeRandom_add32");
            for (int i = 1 ; i < 5 ; i++) {
                final byte[] data = new byte[(getRandom().nextInt(10000)) + 1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),279,data);
                getRandom().nextBytes(data);
                getRandom().nextBytes(data);
                final byte[] enc = Base64.encodeBase64(data);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),280,enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),277,org.apache.commons.codec.binary.Base64.isBase64(enc));
                final byte[] data2 = Base64.decodeBase64(enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),281,data2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),278,java.util.Arrays.equals(data, data2));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testEncodeDecodeRandom() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeDecodeRandom");
            for (int i = 2 ; i < 5 ; i++) {
                final byte[] data = new byte[(getRandom().nextInt(10000)) + 1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),279,data);
                getRandom().nextBytes(data);
                final byte[] enc = Base64.encodeBase64(data);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),280,enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),277,org.apache.commons.codec.binary.Base64.isBase64(enc));
                final byte[] data2 = Base64.decodeBase64(enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),281,data2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),278,java.util.Arrays.equals(data, data2));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testEncodeDecodeRandom_literalMutation388() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeDecodeRandom_literalMutation388");
            for (int i = 0 ; i < 5 ; i++) {
                final byte[] data = new byte[(getRandom().nextInt(10000)) + 1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),279,data);
                getRandom().nextBytes(data);
                final byte[] enc = Base64.encodeBase64(data);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),280,enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),277,org.apache.commons.codec.binary.Base64.isBase64(enc));
                final byte[] data2 = Base64.decodeBase64(enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),281,data2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),278,java.util.Arrays.equals(data, data2));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testEncodeDecodeRandom_literalMutation389() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeDecodeRandom_literalMutation389");
            for (int i = 0 ; i < 5 ; i++) {
                final byte[] data = new byte[(getRandom().nextInt(10000)) + 1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),279,data);
                getRandom().nextBytes(data);
                final byte[] enc = Base64.encodeBase64(data);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),280,enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),277,org.apache.commons.codec.binary.Base64.isBase64(enc));
                final byte[] data2 = Base64.decodeBase64(enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),281,data2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),278,java.util.Arrays.equals(data, data2));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testEncodeDecodeRandom_literalMutation391() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeDecodeRandom_literalMutation391");
            for (int i = 1 ; i < 4 ; i++) {
                final byte[] data = new byte[(getRandom().nextInt(10000)) + 1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),279,data);
                getRandom().nextBytes(data);
                final byte[] enc = Base64.encodeBase64(data);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),280,enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),277,org.apache.commons.codec.binary.Base64.isBase64(enc));
                final byte[] data2 = Base64.decodeBase64(enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),281,data2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),278,java.util.Arrays.equals(data, data2));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testEncodeDecodeRandom_literalMutation392() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeDecodeRandom_literalMutation392");
            for (int i = 1 ; i < 2 ; i++) {
                final byte[] data = new byte[(getRandom().nextInt(10000)) + 1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),279,data);
                getRandom().nextBytes(data);
                final byte[] enc = Base64.encodeBase64(data);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),280,enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),277,org.apache.commons.codec.binary.Base64.isBase64(enc));
                final byte[] data2 = Base64.decodeBase64(enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),281,data2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),278,java.util.Arrays.equals(data, data2));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testEncodeDecodeRandom_literalMutation393() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeDecodeRandom_literalMutation393");
            for (int i = 1 ; i < 10 ; i++) {
                final byte[] data = new byte[(getRandom().nextInt(10000)) + 1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),279,data);
                getRandom().nextBytes(data);
                final byte[] enc = Base64.encodeBase64(data);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),280,enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),277,org.apache.commons.codec.binary.Base64.isBase64(enc));
                final byte[] data2 = Base64.decodeBase64(enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),281,data2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),278,java.util.Arrays.equals(data, data2));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testEncodeDecodeRandom_literalMutation394() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeDecodeRandom_literalMutation394");
            for (int i = 1 ; i < 6 ; i++) {
                final byte[] data = new byte[(getRandom().nextInt(10000)) + 1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),279,data);
                getRandom().nextBytes(data);
                final byte[] enc = Base64.encodeBase64(data);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),280,enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),277,org.apache.commons.codec.binary.Base64.isBase64(enc));
                final byte[] data2 = Base64.decodeBase64(enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),281,data2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),278,java.util.Arrays.equals(data, data2));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testEncodeDecodeRandom_literalMutation396() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeDecodeRandom_literalMutation396");
            for (int i = 1 ; i < 5 ; i++) {
                final byte[] data = new byte[(getRandom().nextInt(10001)) + 1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),279,data);
                getRandom().nextBytes(data);
                final byte[] enc = Base64.encodeBase64(data);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),280,enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),277,org.apache.commons.codec.binary.Base64.isBase64(enc));
                final byte[] data2 = Base64.decodeBase64(enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),281,data2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),278,java.util.Arrays.equals(data, data2));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testEncodeDecodeRandom_literalMutation397() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeDecodeRandom_literalMutation397");
            for (int i = 1 ; i < 5 ; i++) {
                final byte[] data = new byte[(getRandom().nextInt(9999)) + 1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),279,data);
                getRandom().nextBytes(data);
                final byte[] enc = Base64.encodeBase64(data);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),280,enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),277,org.apache.commons.codec.binary.Base64.isBase64(enc));
                final byte[] data2 = Base64.decodeBase64(enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),281,data2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),278,java.util.Arrays.equals(data, data2));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testEncodeDecodeRandom_literalMutation398() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeDecodeRandom_literalMutation398");
            for (int i = 1 ; i < 5 ; i++) {
                final byte[] data = new byte[(getRandom().nextInt(5000)) + 1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),279,data);
                getRandom().nextBytes(data);
                final byte[] enc = Base64.encodeBase64(data);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),280,enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),277,org.apache.commons.codec.binary.Base64.isBase64(enc));
                final byte[] data2 = Base64.decodeBase64(enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),281,data2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),278,java.util.Arrays.equals(data, data2));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testEncodeDecodeRandom_literalMutation399() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeDecodeRandom_literalMutation399");
            for (int i = 1 ; i < 5 ; i++) {
                final byte[] data = new byte[(getRandom().nextInt(20000)) + 1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),279,data);
                getRandom().nextBytes(data);
                final byte[] enc = Base64.encodeBase64(data);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),280,enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),277,org.apache.commons.codec.binary.Base64.isBase64(enc));
                final byte[] data2 = Base64.decodeBase64(enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),281,data2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),278,java.util.Arrays.equals(data, data2));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testEncodeDecodeRandom_literalMutation401() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeDecodeRandom_literalMutation401");
            for (int i = 1 ; i < 5 ; i++) {
                final byte[] data = new byte[(getRandom().nextInt(10000)) + 2];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),279,data);
                getRandom().nextBytes(data);
                final byte[] enc = Base64.encodeBase64(data);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),280,enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),277,org.apache.commons.codec.binary.Base64.isBase64(enc));
                final byte[] data2 = Base64.decodeBase64(enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),281,data2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),278,java.util.Arrays.equals(data, data2));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testEncodeDecodeRandom_literalMutation402() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeDecodeRandom_literalMutation402");
            for (int i = 1 ; i < 5 ; i++) {
                final byte[] data = new byte[(getRandom().nextInt(10000)) + 0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),279,data);
                getRandom().nextBytes(data);
                final byte[] enc = Base64.encodeBase64(data);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),280,enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),277,org.apache.commons.codec.binary.Base64.isBase64(enc));
                final byte[] data2 = Base64.decodeBase64(enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),281,data2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),278,java.util.Arrays.equals(data, data2));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testEncodeDecodeRandom_literalMutation403() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeDecodeRandom_literalMutation403");
            for (int i = 1 ; i < 5 ; i++) {
                final byte[] data = new byte[(getRandom().nextInt(10000)) + 0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),279,data);
                getRandom().nextBytes(data);
                final byte[] enc = Base64.encodeBase64(data);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),280,enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),277,org.apache.commons.codec.binary.Base64.isBase64(enc));
                final byte[] data2 = Base64.decodeBase64(enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),281,data2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),278,java.util.Arrays.equals(data, data2));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testEncodeDecodeRandom_remove23() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeDecodeRandom_remove23");
            for (int i = 1 ; i < 5 ; i++) {
                final byte[] data = new byte[(getRandom().nextInt(10000)) + 1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),279,data);
                final byte[] enc = Base64.encodeBase64(data);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),280,enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),277,org.apache.commons.codec.binary.Base64.isBase64(enc));
                final byte[] data2 = Base64.decodeBase64(enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),281,data2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),278,java.util.Arrays.equals(data, data2));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testEncodeDecodeSmall_add33() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeDecodeSmall_add33");
            for (int i = 0 ; i < 12 ; i++) {
                final byte[] data = new byte[i];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),286,data);
                getRandom().nextBytes(data);
                getRandom().nextBytes(data);
                final byte[] enc = Base64.encodeBase64(data);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),287,enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),282,(("\"" + (new java.lang.String(enc))) + "\" is Base64 data."));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),283,org.apache.commons.codec.binary.Base64.isBase64(enc));
                final byte[] data2 = Base64.decodeBase64(enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),288,data2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),284,(((toString(data)) + " equals ") + (toString(data2))));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),285,java.util.Arrays.equals(data, data2));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testEncodeDecodeSmall() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeDecodeSmall");
            for (int i = 1 ; i < 12 ; i++) {
                final byte[] data = new byte[i];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),286,data);
                getRandom().nextBytes(data);
                final byte[] enc = Base64.encodeBase64(data);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),287,enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),282,(("\"" + (new java.lang.String(enc))) + "\" is Base64 data."));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),283,org.apache.commons.codec.binary.Base64.isBase64(enc));
                final byte[] data2 = Base64.decodeBase64(enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),288,data2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),284,(((toString(data)) + " equals ") + (toString(data2))));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),285,java.util.Arrays.equals(data, data2));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testEncodeDecodeSmall_literalMutation406() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeDecodeSmall_literalMutation406");
            for (int i = -1 ; i < 12 ; i++) {
                final byte[] data = new byte[i];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),286,data);
                getRandom().nextBytes(data);
                final byte[] enc = Base64.encodeBase64(data);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),287,enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),282,(("\"" + (new java.lang.String(enc))) + "\" is Base64 data."));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),283,org.apache.commons.codec.binary.Base64.isBase64(enc));
                final byte[] data2 = Base64.decodeBase64(enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),288,data2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),284,(((toString(data)) + " equals ") + (toString(data2))));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),285,java.util.Arrays.equals(data, data2));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testEncodeDecodeSmall_literalMutation407() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeDecodeSmall_literalMutation407");
            for (int i = 0 ; i < 12 ; i++) {
                final byte[] data = new byte[i];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),286,data);
                getRandom().nextBytes(data);
                final byte[] enc = Base64.encodeBase64(data);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),287,enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),282,(("\"" + (new java.lang.String(enc))) + "\" is Base64 data."));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),283,org.apache.commons.codec.binary.Base64.isBase64(enc));
                final byte[] data2 = Base64.decodeBase64(enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),288,data2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),284,(((toString(data)) + " equals ") + (toString(data2))));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),285,java.util.Arrays.equals(data, data2));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testEncodeDecodeSmall_literalMutation409() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeDecodeSmall_literalMutation409");
            for (int i = 0 ; i < 11 ; i++) {
                final byte[] data = new byte[i];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),286,data);
                getRandom().nextBytes(data);
                final byte[] enc = Base64.encodeBase64(data);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),287,enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),282,(("\"" + (new java.lang.String(enc))) + "\" is Base64 data."));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),283,org.apache.commons.codec.binary.Base64.isBase64(enc));
                final byte[] data2 = Base64.decodeBase64(enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),288,data2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),284,(((toString(data)) + " equals ") + (toString(data2))));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),285,java.util.Arrays.equals(data, data2));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testEncodeDecodeSmall_literalMutation410() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeDecodeSmall_literalMutation410");
            for (int i = 0 ; i < 6 ; i++) {
                final byte[] data = new byte[i];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),286,data);
                getRandom().nextBytes(data);
                final byte[] enc = Base64.encodeBase64(data);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),287,enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),282,(("\"" + (new java.lang.String(enc))) + "\" is Base64 data."));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),283,org.apache.commons.codec.binary.Base64.isBase64(enc));
                final byte[] data2 = Base64.decodeBase64(enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),288,data2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),284,(((toString(data)) + " equals ") + (toString(data2))));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),285,java.util.Arrays.equals(data, data2));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testEncodeDecodeSmall_literalMutation411() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeDecodeSmall_literalMutation411");
            for (int i = 0 ; i < 24 ; i++) {
                final byte[] data = new byte[i];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),286,data);
                getRandom().nextBytes(data);
                final byte[] enc = Base64.encodeBase64(data);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),287,enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),282,(("\"" + (new java.lang.String(enc))) + "\" is Base64 data."));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),283,org.apache.commons.codec.binary.Base64.isBase64(enc));
                final byte[] data2 = Base64.decodeBase64(enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),288,data2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),284,(((toString(data)) + " equals ") + (toString(data2))));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),285,java.util.Arrays.equals(data, data2));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testEncodeDecodeSmall_literalMutation412() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeDecodeSmall_literalMutation412");
            for (int i = 0 ; i < 13 ; i++) {
                final byte[] data = new byte[i];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),286,data);
                getRandom().nextBytes(data);
                final byte[] enc = Base64.encodeBase64(data);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),287,enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),282,(("\"" + (new java.lang.String(enc))) + "\" is Base64 data."));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),283,org.apache.commons.codec.binary.Base64.isBase64(enc));
                final byte[] data2 = Base64.decodeBase64(enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),288,data2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),284,(((toString(data)) + " equals ") + (toString(data2))));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),285,java.util.Arrays.equals(data, data2));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testEncodeDecodeSmall_remove24() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeDecodeSmall_remove24");
            for (int i = 0 ; i < 12 ; i++) {
                final byte[] data = new byte[i];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),286,data);
                final byte[] enc = Base64.encodeBase64(data);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),287,enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),282,(("\"" + (new java.lang.String(enc))) + "\" is Base64 data."));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),283,org.apache.commons.codec.binary.Base64.isBase64(enc));
                final byte[] data2 = Base64.decodeBase64(enc);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),288,data2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),284,(((toString(data)) + " equals ") + (toString(data2))));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),285,java.util.Arrays.equals(data, data2));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testEncodeOverMaxSize_add34() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeOverMaxSize_add34");
            testEncodeOverMaxSize(2);
            testEncodeOverMaxSize(2);
            testEncodeOverMaxSize(0);
            testEncodeOverMaxSize(1);
            testEncodeOverMaxSize(2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testEncodeOverMaxSize_add35() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeOverMaxSize_add35");
            testEncodeOverMaxSize(2);
            testEncodeOverMaxSize(0);
            testEncodeOverMaxSize(0);
            testEncodeOverMaxSize(1);
            testEncodeOverMaxSize(2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testEncodeOverMaxSize_add36() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeOverMaxSize_add36");
            testEncodeOverMaxSize(2);
            testEncodeOverMaxSize(0);
            testEncodeOverMaxSize(1);
            testEncodeOverMaxSize(1);
            testEncodeOverMaxSize(2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testEncodeOverMaxSize_add37() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeOverMaxSize_add37");
            testEncodeOverMaxSize(2);
            testEncodeOverMaxSize(0);
            testEncodeOverMaxSize(1);
            testEncodeOverMaxSize(2);
            testEncodeOverMaxSize(2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testEncodeOverMaxSize() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeOverMaxSize");
            testEncodeOverMaxSize(-2);
            testEncodeOverMaxSize(0);
            testEncodeOverMaxSize(1);
            testEncodeOverMaxSize(2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testEncodeOverMaxSize_literalMutation415() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeOverMaxSize_literalMutation415");
            testEncodeOverMaxSize(0);
            testEncodeOverMaxSize(0);
            testEncodeOverMaxSize(1);
            testEncodeOverMaxSize(2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testEncodeOverMaxSize_literalMutation416() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeOverMaxSize_literalMutation416");
            testEncodeOverMaxSize(0);
            testEncodeOverMaxSize(0);
            testEncodeOverMaxSize(1);
            testEncodeOverMaxSize(2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testEncodeOverMaxSize_literalMutation418() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeOverMaxSize_literalMutation418");
            testEncodeOverMaxSize(2);
            testEncodeOverMaxSize(1);
            testEncodeOverMaxSize(1);
            testEncodeOverMaxSize(2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testEncodeOverMaxSize_literalMutation419() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeOverMaxSize_literalMutation419");
            testEncodeOverMaxSize(2);
            testEncodeOverMaxSize(-1);
            testEncodeOverMaxSize(1);
            testEncodeOverMaxSize(2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testEncodeOverMaxSize_literalMutation420() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeOverMaxSize_literalMutation420");
            testEncodeOverMaxSize(2);
            testEncodeOverMaxSize(0);
            testEncodeOverMaxSize(1);
            testEncodeOverMaxSize(2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testEncodeOverMaxSize_literalMutation422() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeOverMaxSize_literalMutation422");
            testEncodeOverMaxSize(2);
            testEncodeOverMaxSize(0);
            testEncodeOverMaxSize(2);
            testEncodeOverMaxSize(2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testEncodeOverMaxSize_literalMutation423() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeOverMaxSize_literalMutation423");
            testEncodeOverMaxSize(2);
            testEncodeOverMaxSize(0);
            testEncodeOverMaxSize(0);
            testEncodeOverMaxSize(2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testEncodeOverMaxSize_literalMutation424() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeOverMaxSize_literalMutation424");
            testEncodeOverMaxSize(2);
            testEncodeOverMaxSize(0);
            testEncodeOverMaxSize(0);
            testEncodeOverMaxSize(2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testEncodeOverMaxSize_literalMutation426() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeOverMaxSize_literalMutation426");
            testEncodeOverMaxSize(2);
            testEncodeOverMaxSize(0);
            testEncodeOverMaxSize(1);
            testEncodeOverMaxSize(1);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testEncodeOverMaxSize_literalMutation427() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeOverMaxSize_literalMutation427");
            testEncodeOverMaxSize(2);
            testEncodeOverMaxSize(0);
            testEncodeOverMaxSize(1);
            testEncodeOverMaxSize(4);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testEncodeOverMaxSize_literalMutation428() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeOverMaxSize_literalMutation428");
            testEncodeOverMaxSize(2);
            testEncodeOverMaxSize(0);
            testEncodeOverMaxSize(1);
            testEncodeOverMaxSize(3);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testEncodeOverMaxSize_remove25() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeOverMaxSize_remove25");
            testEncodeOverMaxSize(0);
            testEncodeOverMaxSize(1);
            testEncodeOverMaxSize(2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testEncodeOverMaxSize_remove26() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeOverMaxSize_remove26");
            testEncodeOverMaxSize(0);
            testEncodeOverMaxSize(1);
            testEncodeOverMaxSize(2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testEncodeOverMaxSize_remove27() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeOverMaxSize_remove27");
            testEncodeOverMaxSize(0);
            testEncodeOverMaxSize(1);
            testEncodeOverMaxSize(2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testEncodeOverMaxSize_remove28() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeOverMaxSize_remove28");
            testEncodeOverMaxSize(0);
            testEncodeOverMaxSize(1);
            testEncodeOverMaxSize(2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCodec112_add26() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodec112_add26");
            final byte[] in = new byte[]{ 0 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),203,in);
            final byte[] out = Base64.encodeBase64(in);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),204,out);
            Base64.encodeBase64(in, false, false, out.length);
            Base64.encodeBase64(in, false, false, out.length);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodec112() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodec112");
            final byte[] in = new byte[]{ 1 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),203,in);
            final byte[] out = Base64.encodeBase64(in);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),204,out);
            Base64.encodeBase64(in, false, false, out.length);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodec112_literalMutation264() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodec112_literalMutation264");
            final byte[] in = new byte[]{ -1 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),203,in);
            final byte[] out = Base64.encodeBase64(in);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),204,out);
            Base64.encodeBase64(in, false, false, out.length);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodec112_literalMutation265() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodec112_literalMutation265");
            final byte[] in = new byte[]{ 0 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),203,in);
            final byte[] out = Base64.encodeBase64(in);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),204,out);
            Base64.encodeBase64(in, false, false, out.length);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodec112_literalMutation267() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodec112_literalMutation267");
            final byte[] in = new byte[]{ 0 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),203,in);
            final byte[] out = Base64.encodeBase64(in);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),204,out);
            Base64.encodeBase64(in, true, false, out.length);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testCodec112_literalMutation268() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodec112_literalMutation268");
            final byte[] in = new byte[]{ 0 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),203,in);
            final byte[] out = Base64.encodeBase64(in);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),204,out);
            Base64.encodeBase64(in, false, true, out.length);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCodec112_remove17() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCodec112_remove17");
            final byte[] in = new byte[]{ 0 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),203,in);
            final byte[] out = Base64.encodeBase64(in);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),204,out);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    private void testEncodeOverMaxSize(final int maxSize) throws Exception {
        try {
            Base64.encodeBase64(Base64TestData.DECODED, true, false, maxSize);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),289,("Expected " + (java.lang.IllegalArgumentException.class.getName())));
        } catch (final IllegalArgumentException e) {
        }
    }

    @Test
    public void testIgnoringNonBase64InDecode() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIgnoringNonBase64InDecode");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),298,new java.lang.String(org.apache.commons.codec.binary.Base64.decodeBase64("VGhlIH@$#$@%F1aWN@#@#@@rIGJyb3duIGZve\n\r\t%#%#%#%CBqd##$#$W1wZWQgb3ZlciB0aGUgbGF6eSBkb2dzLg==".getBytes(org.apache.commons.codec.Charsets.UTF_8))));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testIsArrayByteBase64() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsArrayByteBase64");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),299,org.apache.commons.codec.binary.Base64.isBase64(new byte[]{ java.lang.Byte.MIN_VALUE }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),300,org.apache.commons.codec.binary.Base64.isBase64(new byte[]{ -125 }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),301,org.apache.commons.codec.binary.Base64.isBase64(new byte[]{ -10 }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),302,org.apache.commons.codec.binary.Base64.isBase64(new byte[]{ 0 }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),303,org.apache.commons.codec.binary.Base64.isBase64(new byte[]{ 64 , java.lang.Byte.MAX_VALUE }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),304,org.apache.commons.codec.binary.Base64.isBase64(new byte[]{ java.lang.Byte.MAX_VALUE }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),305,org.apache.commons.codec.binary.Base64.isBase64(new byte[]{ 'A' }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),306,org.apache.commons.codec.binary.Base64.isBase64(new byte[]{ 'A' , java.lang.Byte.MIN_VALUE }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),307,org.apache.commons.codec.binary.Base64.isBase64(new byte[]{ 'A' , 'Z' , 'a' }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),308,org.apache.commons.codec.binary.Base64.isBase64(new byte[]{ '/' , '=' , '+' }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),309,org.apache.commons.codec.binary.Base64.isBase64(new byte[]{ '$' }));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests isUrlSafe.
     */
@Test
    public void testIsUrlSafe() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsUrlSafe");
            final Base64 base64Standard = new Base64(true);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),321,base64Standard);
            final Base64 base64URLSafe = new Base64(true);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),322,base64URLSafe);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),318,base64Standard.isUrlSafe());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),319,base64URLSafe.isUrlSafe());
            final byte[] whiteSpace = new byte[]{ ' ' , '\n' , '\r' , '\t' };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),323,whiteSpace);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),320,org.apache.commons.codec.binary.Base64.isBase64(whiteSpace));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testKnownDecodings() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testKnownDecodings");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),324,new java.lang.String(org.apache.commons.codec.binary.Base64.decodeBase64("VGhlIHF1aWNrIGJyb3duIGZveCBqdW1wZWQgb3ZlciB0aGUgbGF6eSBkb2dzLg==".getBytes(org.apache.commons.codec.Charsets.UTF_8))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),325,new java.lang.String(org.apache.commons.codec.binary.Base64.decodeBase64("SXQgd2FzIHRoZSBiZXN0IG9mIHRpbWVzLCBpdCB3YXMgdGhlIHdvcnN0IG9mIHRpbWVzLg==".getBytes(org.apache.commons.codec.Charsets.UTF_8))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),326,new java.lang.String(org.apache.commons.codec.binary.Base64.decodeBase64("aHR0cDovL2pha2FydGEuYXBhY2hlLm9yZy9jb21tbW9ucw==".getBytes(org.apache.commons.codec.Charsets.UTF_8))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),327,new java.lang.String(org.apache.commons.codec.binary.Base64.decodeBase64("QWFCYkNjRGRFZUZmR2dIaElpSmpLa0xsTW1Obk9vUHBRcVJyU3NUdFV1VnZXd1h4WXlaeg==".getBytes(org.apache.commons.codec.Charsets.UTF_8))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),328,new java.lang.String(org.apache.commons.codec.binary.Base64.decodeBase64("eyAwLCAxLCAyLCAzLCA0LCA1LCA2LCA3LCA4LCA5IH0=".getBytes(org.apache.commons.codec.Charsets.UTF_8))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),329,new java.lang.String(org.apache.commons.codec.binary.Base64.decodeBase64("eHl6enkh".getBytes(org.apache.commons.codec.Charsets.UTF_8))));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testKnownEncodings() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testKnownEncodings");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),330,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64("The quick brown fox jumped over the lazy dogs.".getBytes(org.apache.commons.codec.Charsets.UTF_8))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked("blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah".getBytes(org.apache.commons.codec.Charsets.UTF_8))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),332,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64("It was the best of times, it was the worst of times.".getBytes(org.apache.commons.codec.Charsets.UTF_8))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),333,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64("http://jakarta.apache.org/commmons".getBytes(org.apache.commons.codec.Charsets.UTF_8))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),334,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64("AaBbCcDdEeFfGgHhIiJjKkLlMmNnOoPpQqRrSsTtUuVvWwXxYyZz".getBytes(org.apache.commons.codec.Charsets.UTF_8))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),335,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64("{ 0, 1, 2, 3, 4, 5, 6, 7, 8, 9 }".getBytes(org.apache.commons.codec.Charsets.UTF_8))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),336,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64("xyzzy!".getBytes(org.apache.commons.codec.Charsets.UTF_8))));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testNonBase64Test() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNonBase64Test");
            final byte[] bArray = new byte[]{ '%' };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),342,bArray);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),337,("Invalid Base64 array was incorrectly validated as " + "an array of Base64 encoded data"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),338,org.apache.commons.codec.binary.Base64.isBase64(bArray));
            try {
                final Base64 b64 = new Base64();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),343,b64);
                final byte[] result = b64.decode(bArray);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),344,result);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),339,("The result should be empty as the test encoded content did " + "not contain any valid base 64 characters"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),340,result.length);
            } catch (final Exception e) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),341,("Exception was thrown when trying to decode " + ("invalid base64 encoded data - RFC 2045 requires that all " + ("non base64 character be discarded, an exception should not" + " have been thrown"))));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testObjectDecodeWithInvalidParameter_add39() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testObjectDecodeWithInvalidParameter_add39");
            final Base64 b64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),345,b64);
            try {
                b64.decode(java.lang.Integer.valueOf(5));
                b64.decode(java.lang.Integer.valueOf(5));
            } catch (final DecoderException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testObjectDecodeWithInvalidParameter() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testObjectDecodeWithInvalidParameter");
            final Base64 b64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),345,b64);
            try {
                b64.decode(java.lang.Integer.valueOf(4));
            } catch (final DecoderException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testObjectDecodeWithInvalidParameter_literalMutation462() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testObjectDecodeWithInvalidParameter_literalMutation462");
            final Base64 b64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),345,b64);
            try {
                b64.decode(java.lang.Integer.valueOf(2));
            } catch (final DecoderException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testObjectDecodeWithInvalidParameter_literalMutation463() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testObjectDecodeWithInvalidParameter_literalMutation463");
            final Base64 b64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),345,b64);
            try {
                b64.decode(java.lang.Integer.valueOf(10));
            } catch (final DecoderException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testObjectDecodeWithInvalidParameter_literalMutation464() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testObjectDecodeWithInvalidParameter_literalMutation464");
            final Base64 b64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),345,b64);
            try {
                b64.decode(java.lang.Integer.valueOf(6));
            } catch (final DecoderException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testObjectDecodeWithValidParameter() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testObjectDecodeWithValidParameter");
            final String original = "Hello !orld!";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),348,original);
            final Object o = Base64.encodeBase64(original.getBytes(org.apache.commons.codec.Charsets.UTF_8));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),349,o);
            final Base64 b64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),350,b64);
            final Object oDecoded = b64.decode(o);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),351,oDecoded);
            final byte[] baDecoded = ((byte[])(oDecoded));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),352,baDecoded);
            final String dest = new String(baDecoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),353,dest);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),346,original);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),347,dest);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testObjectDecodeWithValidParameter_literalMutation467() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testObjectDecodeWithValidParameter_literalMutation467");
            final String original = "Helloø World!";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),348,original);
            final Object o = Base64.encodeBase64(original.getBytes(org.apache.commons.codec.Charsets.UTF_8));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),349,o);
            final Base64 b64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),350,b64);
            final Object oDecoded = b64.decode(o);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),351,oDecoded);
            final byte[] baDecoded = ((byte[])(oDecoded));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),352,baDecoded);
            final String dest = new String(baDecoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),353,dest);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),346,original);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),347,dest);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testObjectDecodeWithValidParameter_literalMutation468() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testObjectDecodeWithValidParameter_literalMutation468");
            final String original = "Hello Word!";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),348,original);
            final Object o = Base64.encodeBase64(original.getBytes(org.apache.commons.codec.Charsets.UTF_8));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),349,o);
            final Base64 b64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),350,b64);
            final Object oDecoded = b64.decode(o);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),351,oDecoded);
            final byte[] baDecoded = ((byte[])(oDecoded));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),352,baDecoded);
            final String dest = new String(baDecoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),353,dest);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),346,original);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),347,dest);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testObjectEncodeWithInvalidParameter_add40() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testObjectEncodeWithInvalidParameter_add40");
            final Base64 b64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),354,b64);
            try {
                b64.encode("Yadayadayada");
                b64.encode("Yadayadayada");
            } catch (final EncoderException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testObjectEncode() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testObjectEncode");
            final Base64 b64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),354,b64);
            try {
                b64.encode("Yadayaayada");
            } catch (final EncoderException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testObjectEncodeWithInvalidParameter() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testObjectEncodeWithInvalidParameter");
            final Base64 b64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),354,b64);
            try {
                b64.encode("Yada$yadayada");
            } catch (final EncoderException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testObjectEncodeWithInvalidParameter_literalMutation471() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testObjectEncodeWithInvalidParameter_literalMutation471");
            final Base64 b64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),354,b64);
            try {
                b64.encode("Yaayadayada");
            } catch (final EncoderException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testObjectEncodeWithValidParameter() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testObjectEncodeWithValidParameter");
            final String original = "HellÇ World!";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),357,original);
            final Object origObj = original.getBytes(org.apache.commons.codec.Charsets.UTF_8);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),358,origObj);
            final Base64 b64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),359,b64);
            final Object oEncoded = b64.encode(origObj);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),360,oEncoded);
            final byte[] bArray = Base64.decodeBase64(((byte[])(oEncoded)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),361,bArray);
            final String dest = new String(bArray);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),362,dest);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),355,original);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),356,dest);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testObjectEncodeWithValidParameter_literalMutation473() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testObjectEncodeWithValidParameter_literalMutation473");
            final String original = "Hell­o World!";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),357,original);
            final Object origObj = original.getBytes(org.apache.commons.codec.Charsets.UTF_8);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),358,origObj);
            final Base64 b64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),359,b64);
            final Object oEncoded = b64.encode(origObj);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),360,oEncoded);
            final byte[] bArray = Base64.decodeBase64(((byte[])(oEncoded)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),361,bArray);
            final String dest = new String(bArray);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),362,dest);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),355,original);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),356,dest);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testObjectEncodeWithValidParameter_literalMutation474() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testObjectEncodeWithValidParameter_literalMutation474");
            final String original = "Helo World!";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),357,original);
            final Object origObj = original.getBytes(org.apache.commons.codec.Charsets.UTF_8);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),358,origObj);
            final Base64 b64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),359,b64);
            final Object oEncoded = b64.encode(origObj);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),360,oEncoded);
            final byte[] bArray = Base64.decodeBase64(((byte[])(oEncoded)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),361,bArray);
            final String dest = new String(bArray);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),362,dest);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),355,original);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),356,dest);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testPairs() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPairs");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),363,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ 0 , 0 })));
            for (int i = -129 ; i <= 127 ; i++) {
                final byte[] test = new byte[]{ ((byte)(i)) , ((byte)(i)) };
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),365,test);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),364,java.util.Arrays.equals(test, org.apache.commons.codec.binary.Base64.decodeBase64(org.apache.commons.codec.binary.Base64.encodeBase64(test))));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testPairs_literalMutation476() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPairs_literalMutation476");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),363,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ 0 , 0 })));
            for (int i = 64 ; i <= 127 ; i++) {
                final byte[] test = new byte[]{ ((byte)(i)) , ((byte)(i)) };
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),365,test);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),364,java.util.Arrays.equals(test, org.apache.commons.codec.binary.Base64.decodeBase64(org.apache.commons.codec.binary.Base64.encodeBase64(test))));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testPairs_literalMutation477() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPairs_literalMutation477");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),363,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ 0 , 0 })));
            for (int i = 256 ; i <= 127 ; i++) {
                final byte[] test = new byte[]{ ((byte)(i)) , ((byte)(i)) };
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),365,test);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),364,java.util.Arrays.equals(test, org.apache.commons.codec.binary.Base64.decodeBase64(org.apache.commons.codec.binary.Base64.encodeBase64(test))));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testPairs_literalMutation478() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPairs_literalMutation478");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),363,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ 0 , 0 })));
            for (int i = 127 ; i <= 127 ; i++) {
                final byte[] test = new byte[]{ ((byte)(i)) , ((byte)(i)) };
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),365,test);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),364,java.util.Arrays.equals(test, org.apache.commons.codec.binary.Base64.decodeBase64(org.apache.commons.codec.binary.Base64.encodeBase64(test))));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testPairs_literalMutation480() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPairs_literalMutation480");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),363,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ 0 , 0 })));
            for (int i = 129 ; i <= 128 ; i++) {
                final byte[] test = new byte[]{ ((byte)(i)) , ((byte)(i)) };
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),365,test);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),364,java.util.Arrays.equals(test, org.apache.commons.codec.binary.Base64.decodeBase64(org.apache.commons.codec.binary.Base64.encodeBase64(test))));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testPairs_literalMutation481() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPairs_literalMutation481");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),363,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ 0 , 0 })));
            for (int i = 129 ; i <= 126 ; i++) {
                final byte[] test = new byte[]{ ((byte)(i)) , ((byte)(i)) };
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),365,test);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),364,java.util.Arrays.equals(test, org.apache.commons.codec.binary.Base64.decodeBase64(org.apache.commons.codec.binary.Base64.encodeBase64(test))));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testPairs_literalMutation482() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPairs_literalMutation482");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),363,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ 0 , 0 })));
            for (int i = 129 ; i <= 63 ; i++) {
                final byte[] test = new byte[]{ ((byte)(i)) , ((byte)(i)) };
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),365,test);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),364,java.util.Arrays.equals(test, org.apache.commons.codec.binary.Base64.decodeBase64(org.apache.commons.codec.binary.Base64.encodeBase64(test))));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testPairs_literalMutation483() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPairs_literalMutation483");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),363,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ 0 , 0 })));
            for (int i = 129 ; i <= 254 ; i++) {
                final byte[] test = new byte[]{ ((byte)(i)) , ((byte)(i)) };
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),365,test);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),364,java.util.Arrays.equals(test, org.apache.commons.codec.binary.Base64.decodeBase64(org.apache.commons.codec.binary.Base64.encodeBase64(test))));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests RFC 2045 section 2.1 CRLF definition.
     */
@Test
    public void testRfc2045Section2Dot1CrLfDefinition() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRfc2045Section2Dot1CrLfDefinition");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),367,java.util.Arrays.equals(new byte[]{ 13 , 10 }, org.apache.commons.codec.binary.Base64.CHUNK_SEPARATOR));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests RFC 2045 section 6.8 chuck size definition.
     */
@Test
    public void testRfc2045Section6Dot8ChunkSizeDefinition() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRfc2045Section6Dot8ChunkSizeDefinition");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),368,org.apache.commons.codec.binary.BaseNCodec.MIME_CHUNK_SIZE);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests RFC 1421 section 4.3.2.4 chuck size definition.
     */
@Test
    public void testRfc1421Section6Dot8ChunkSizeDefinition() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRfc1421Section6Dot8ChunkSizeDefinition");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),366,org.apache.commons.codec.binary.BaseNCodec.PEM_CHUNK_SIZE);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests RFC 4648 section 10 test vectors.
     * <ul>
     * <li>BASE64("") = ""</li>
     * <li>BASE64("f") = "Zg=="</li>
     * <li>BASE64("fo") = "Zm8="</li>
     * <li>BASE64("foo") = "Zm9v"</li>
     * <li>BASE64("foob") = "Zm9vYg=="</li>
     * <li>BASE64("fooba") = "Zm9vYmE="</li>
     * <li>BASE64("foobar") = "Zm9vYmFy"</li>
     * </ul>
     * 
     * @see <a href="http://tools.ietf.org/html/rfc4648">http://tools.ietf.org/html/rfc4648</a>
     */
@Test
    public void testRfc4648Section10DecodeWithCrLf() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRfc4648Section10DecodeWithCrLf");
            final String CRLF = org.apache.commons.codec.binary.StringUtils.newStringUsAscii(Base64.CHUNK_SEPARATOR);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),376,CRLF);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),369,org.apache.commons.codec.binary.StringUtils.newStringUsAscii(org.apache.commons.codec.binary.Base64.decodeBase64(("" + CRLF))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),370,org.apache.commons.codec.binary.StringUtils.newStringUsAscii(org.apache.commons.codec.binary.Base64.decodeBase64(("Zg==" + CRLF))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),371,org.apache.commons.codec.binary.StringUtils.newStringUsAscii(org.apache.commons.codec.binary.Base64.decodeBase64(("Zm8=" + CRLF))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),372,org.apache.commons.codec.binary.StringUtils.newStringUsAscii(org.apache.commons.codec.binary.Base64.decodeBase64(("Zm9v" + CRLF))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),373,org.apache.commons.codec.binary.StringUtils.newStringUsAscii(org.apache.commons.codec.binary.Base64.decodeBase64(("Zm9vYg==" + CRLF))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),374,org.apache.commons.codec.binary.StringUtils.newStringUsAscii(org.apache.commons.codec.binary.Base64.decodeBase64(("Zm9vYmE=" + CRLF))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),375,org.apache.commons.codec.binary.StringUtils.newStringUsAscii(org.apache.commons.codec.binary.Base64.decodeBase64(("Zm9vYmFy" + CRLF))));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests RFC 4648 section 10 test vectors.
     * <ul>
     * <li>BASE64("") = ""</li>
     * <li>BASE64("f") = "Zg=="</li>
     * <li>BASE64("fo") = "Zm8="</li>
     * <li>BASE64("foo") = "Zm9v"</li>
     * <li>BASE64("foob") = "Zm9vYg=="</li>
     * <li>BASE64("fooba") = "Zm9vYmE="</li>
     * <li>BASE64("foobar") = "Zm9vYmFy"</li>
     * </ul>
     * 
     * @see <a href="http://tools.ietf.org/html/rfc4648">http://tools.ietf.org/html/rfc4648</a>
     */
@Test
    public void testRfc4648Section10DecodeEncode() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRfc4648Section10DecodeEncode");
            testDecodeEncode("");
            testDecodeEncode("Zg==");
            testDecodeEncode("Zm8=");
            testDecodeEncode("Zm9v");
            testDecodeEncode("Zm9vYg==");
            testDecodeEncode("Zm9vYmE=");
            testDecodeEncode("Zm9vYmFy");
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests RFC 4648 section 10 test vectors.
     * <ul>
     * <li>BASE64("") = ""</li>
     * <li>BASE64("f") = "Zg=="</li>
     * <li>BASE64("fo") = "Zm8="</li>
     * <li>BASE64("foo") = "Zm9v"</li>
     * <li>BASE64("foob") = "Zm9vYg=="</li>
     * <li>BASE64("fooba") = "Zm9vYmE="</li>
     * <li>BASE64("foobar") = "Zm9vYmFy"</li>
     * </ul>
     * 
     * @see <a href="http://tools.ietf.org/html/rfc4648">http://tools.ietf.org/html/rfc4648</a>
     */
@Test(timeout = 1000)
    public void testRfc4648Section10Decode() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRfc4648Section10Decode");
            testDecodeEncode("");
            testDecodeEncode("");
            testDecodeEncode("Zg==");
            testDecodeEncode("Zm8=");
            testDecodeEncode("Zm9v");
            testDecodeEncode("Zm9vYg==");
            testDecodeEncode("Zm9vYmE=");
            testDecodeEncode("Zm9vYmFy");
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests RFC 4648 section 10 test vectors.
     * <ul>
     * <li>BASE64("") = ""</li>
     * <li>BASE64("f") = "Zg=="</li>
     * <li>BASE64("fo") = "Zm8="</li>
     * <li>BASE64("foo") = "Zm9v"</li>
     * <li>BASE64("foob") = "Zm9vYg=="</li>
     * <li>BASE64("fooba") = "Zm9vYmE="</li>
     * <li>BASE64("foobar") = "Zm9vYmFy"</li>
     * </ul>
     * 
     * @see <a href="http://tools.ietf.org/html/rfc4648">http://tools.ietf.org/html/rfc4648</a>
     */
@Test(timeout = 1000)
    public void testRfc4648Section10DecodeEncode_add42() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRfc4648Section10DecodeEncode_add42");
            testDecodeEncode("");
            testDecodeEncode("Zg==");
            testDecodeEncode("Zg==");
            testDecodeEncode("Zm8=");
            testDecodeEncode("Zm9v");
            testDecodeEncode("Zm9vYg==");
            testDecodeEncode("Zm9vYmE=");
            testDecodeEncode("Zm9vYmFy");
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests RFC 4648 section 10 test vectors.
     * <ul>
     * <li>BASE64("") = ""</li>
     * <li>BASE64("f") = "Zg=="</li>
     * <li>BASE64("fo") = "Zm8="</li>
     * <li>BASE64("foo") = "Zm9v"</li>
     * <li>BASE64("foob") = "Zm9vYg=="</li>
     * <li>BASE64("fooba") = "Zm9vYmE="</li>
     * <li>BASE64("foobar") = "Zm9vYmFy"</li>
     * </ul>
     * 
     * @see <a href="http://tools.ietf.org/html/rfc4648">http://tools.ietf.org/html/rfc4648</a>
     */
@Test(timeout = 1000)
    public void testRfc4648Section10DecodeEncode_add43() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRfc4648Section10DecodeEncode_add43");
            testDecodeEncode("");
            testDecodeEncode("Zg==");
            testDecodeEncode("Zm8=");
            testDecodeEncode("Zm8=");
            testDecodeEncode("Zm9v");
            testDecodeEncode("Zm9vYg==");
            testDecodeEncode("Zm9vYmE=");
            testDecodeEncode("Zm9vYmFy");
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests RFC 4648 section 10 test vectors.
     * <ul>
     * <li>BASE64("") = ""</li>
     * <li>BASE64("f") = "Zg=="</li>
     * <li>BASE64("fo") = "Zm8="</li>
     * <li>BASE64("foo") = "Zm9v"</li>
     * <li>BASE64("foob") = "Zm9vYg=="</li>
     * <li>BASE64("fooba") = "Zm9vYmE="</li>
     * <li>BASE64("foobar") = "Zm9vYmFy"</li>
     * </ul>
     * 
     * @see <a href="http://tools.ietf.org/html/rfc4648">http://tools.ietf.org/html/rfc4648</a>
     */
@Test(timeout = 1000)
    public void testRfc4648Section10DecodeEncode_add44() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRfc4648Section10DecodeEncode_add44");
            testDecodeEncode("");
            testDecodeEncode("Zg==");
            testDecodeEncode("Zm8=");
            testDecodeEncode("Zm9v");
            testDecodeEncode("Zm9v");
            testDecodeEncode("Zm9vYg==");
            testDecodeEncode("Zm9vYmE=");
            testDecodeEncode("Zm9vYmFy");
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests RFC 4648 section 10 test vectors.
     * <ul>
     * <li>BASE64("") = ""</li>
     * <li>BASE64("f") = "Zg=="</li>
     * <li>BASE64("fo") = "Zm8="</li>
     * <li>BASE64("foo") = "Zm9v"</li>
     * <li>BASE64("foob") = "Zm9vYg=="</li>
     * <li>BASE64("fooba") = "Zm9vYmE="</li>
     * <li>BASE64("foobar") = "Zm9vYmFy"</li>
     * </ul>
     * 
     * @see <a href="http://tools.ietf.org/html/rfc4648">http://tools.ietf.org/html/rfc4648</a>
     */
@Test(timeout = 1000)
    public void testRfc4648Section10DecodeEncode_add45() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRfc4648Section10DecodeEncode_add45");
            testDecodeEncode("");
            testDecodeEncode("Zg==");
            testDecodeEncode("Zm8=");
            testDecodeEncode("Zm9v");
            testDecodeEncode("Zm9vYg==");
            testDecodeEncode("Zm9vYg==");
            testDecodeEncode("Zm9vYmE=");
            testDecodeEncode("Zm9vYmFy");
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests RFC 4648 section 10 test vectors.
     * <ul>
     * <li>BASE64("") = ""</li>
     * <li>BASE64("f") = "Zg=="</li>
     * <li>BASE64("fo") = "Zm8="</li>
     * <li>BASE64("foo") = "Zm9v"</li>
     * <li>BASE64("foob") = "Zm9vYg=="</li>
     * <li>BASE64("fooba") = "Zm9vYmE="</li>
     * <li>BASE64("foobar") = "Zm9vYmFy"</li>
     * </ul>
     * 
     * @see <a href="http://tools.ietf.org/html/rfc4648">http://tools.ietf.org/html/rfc4648</a>
     */
@Test(timeout = 1000)
    public void testRfc4648Section10DecodeEncode_add46() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRfc4648Section10DecodeEncode_add46");
            testDecodeEncode("");
            testDecodeEncode("Zg==");
            testDecodeEncode("Zm8=");
            testDecodeEncode("Zm9v");
            testDecodeEncode("Zm9vYg==");
            testDecodeEncode("Zm9vYmE=");
            testDecodeEncode("Zm9vYmE=");
            testDecodeEncode("Zm9vYmFy");
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests RFC 4648 section 10 test vectors.
     * <ul>
     * <li>BASE64("") = ""</li>
     * <li>BASE64("f") = "Zg=="</li>
     * <li>BASE64("fo") = "Zm8="</li>
     * <li>BASE64("foo") = "Zm9v"</li>
     * <li>BASE64("foob") = "Zm9vYg=="</li>
     * <li>BASE64("fooba") = "Zm9vYmE="</li>
     * <li>BASE64("foobar") = "Zm9vYmFy"</li>
     * </ul>
     * 
     * @see <a href="http://tools.ietf.org/html/rfc4648">http://tools.ietf.org/html/rfc4648</a>
     */
@Test(timeout = 1000)
    public void testRfc4648Section10DecodeEncode_add47() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRfc4648Section10DecodeEncode_add47");
            testDecodeEncode("");
            testDecodeEncode("Zg==");
            testDecodeEncode("Zm8=");
            testDecodeEncode("Zm9v");
            testDecodeEncode("Zm9vYg==");
            testDecodeEncode("Zm9vYmE=");
            testDecodeEncode("Zm9vYmFy");
            testDecodeEncode("Zm9vYmFy");
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests RFC 4648 section 10 test vectors.
     * <ul>
     * <li>BASE64("") = ""</li>
     * <li>BASE64("f") = "Zg=="</li>
     * <li>BASE64("fo") = "Zm8="</li>
     * <li>BASE64("foo") = "Zm9v"</li>
     * <li>BASE64("foob") = "Zm9vYg=="</li>
     * <li>BASE64("fooba") = "Zm9vYmE="</li>
     * <li>BASE64("foobar") = "Zm9vYmFy"</li>
     * </ul>
     * 
     * @see <a href="http://tools.ietf.org/html/rfc4648">http://tools.ietf.org/html/rfc4648</a>
     */
@Test(timeout = 1000)
    public void testRfc4648Section10DecodeEncode_remove29() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRfc4648Section10DecodeEncode_remove29");
            testDecodeEncode("Zg==");
            testDecodeEncode("Zm8=");
            testDecodeEncode("Zm9v");
            testDecodeEncode("Zm9vYg==");
            testDecodeEncode("Zm9vYmE=");
            testDecodeEncode("Zm9vYmFy");
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests RFC 4648 section 10 test vectors.
     * <ul>
     * <li>BASE64("") = ""</li>
     * <li>BASE64("f") = "Zg=="</li>
     * <li>BASE64("fo") = "Zm8="</li>
     * <li>BASE64("foo") = "Zm9v"</li>
     * <li>BASE64("foob") = "Zm9vYg=="</li>
     * <li>BASE64("fooba") = "Zm9vYmE="</li>
     * <li>BASE64("foobar") = "Zm9vYmFy"</li>
     * </ul>
     * 
     * @see <a href="http://tools.ietf.org/html/rfc4648">http://tools.ietf.org/html/rfc4648</a>
     */
@Test(timeout = 1000)
    public void testRfc4648Section10DecodeEncode_remove30() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRfc4648Section10DecodeEncode_remove30");
            testDecodeEncode("Zg==");
            testDecodeEncode("Zm8=");
            testDecodeEncode("Zm9v");
            testDecodeEncode("Zm9vYg==");
            testDecodeEncode("Zm9vYmE=");
            testDecodeEncode("Zm9vYmFy");
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests RFC 4648 section 10 test vectors.
     * <ul>
     * <li>BASE64("") = ""</li>
     * <li>BASE64("f") = "Zg=="</li>
     * <li>BASE64("fo") = "Zm8="</li>
     * <li>BASE64("foo") = "Zm9v"</li>
     * <li>BASE64("foob") = "Zm9vYg=="</li>
     * <li>BASE64("fooba") = "Zm9vYmE="</li>
     * <li>BASE64("foobar") = "Zm9vYmFy"</li>
     * </ul>
     * 
     * @see <a href="http://tools.ietf.org/html/rfc4648">http://tools.ietf.org/html/rfc4648</a>
     */
@Test(timeout = 1000)
    public void testRfc4648Section10DecodeEncode_remove31() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRfc4648Section10DecodeEncode_remove31");
            testDecodeEncode("Zg==");
            testDecodeEncode("Zm8=");
            testDecodeEncode("Zm9v");
            testDecodeEncode("Zm9vYg==");
            testDecodeEncode("Zm9vYmE=");
            testDecodeEncode("Zm9vYmFy");
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests RFC 4648 section 10 test vectors.
     * <ul>
     * <li>BASE64("") = ""</li>
     * <li>BASE64("f") = "Zg=="</li>
     * <li>BASE64("fo") = "Zm8="</li>
     * <li>BASE64("foo") = "Zm9v"</li>
     * <li>BASE64("foob") = "Zm9vYg=="</li>
     * <li>BASE64("fooba") = "Zm9vYmE="</li>
     * <li>BASE64("foobar") = "Zm9vYmFy"</li>
     * </ul>
     * 
     * @see <a href="http://tools.ietf.org/html/rfc4648">http://tools.ietf.org/html/rfc4648</a>
     */
@Test(timeout = 1000)
    public void testRfc4648Section10DecodeEncode_remove32() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRfc4648Section10DecodeEncode_remove32");
            testDecodeEncode("Zg==");
            testDecodeEncode("Zm8=");
            testDecodeEncode("Zm9v");
            testDecodeEncode("Zm9vYg==");
            testDecodeEncode("Zm9vYmE=");
            testDecodeEncode("Zm9vYmFy");
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests RFC 4648 section 10 test vectors.
     * <ul>
     * <li>BASE64("") = ""</li>
     * <li>BASE64("f") = "Zg=="</li>
     * <li>BASE64("fo") = "Zm8="</li>
     * <li>BASE64("foo") = "Zm9v"</li>
     * <li>BASE64("foob") = "Zm9vYg=="</li>
     * <li>BASE64("fooba") = "Zm9vYmE="</li>
     * <li>BASE64("foobar") = "Zm9vYmFy"</li>
     * </ul>
     * 
     * @see <a href="http://tools.ietf.org/html/rfc4648">http://tools.ietf.org/html/rfc4648</a>
     */
@Test(timeout = 1000)
    public void testRfc4648Section10DecodeEncode_remove33() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRfc4648Section10DecodeEncode_remove33");
            testDecodeEncode("Zg==");
            testDecodeEncode("Zm8=");
            testDecodeEncode("Zm9v");
            testDecodeEncode("Zm9vYg==");
            testDecodeEncode("Zm9vYmE=");
            testDecodeEncode("Zm9vYmFy");
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests RFC 4648 section 10 test vectors.
     * <ul>
     * <li>BASE64("") = ""</li>
     * <li>BASE64("f") = "Zg=="</li>
     * <li>BASE64("fo") = "Zm8="</li>
     * <li>BASE64("foo") = "Zm9v"</li>
     * <li>BASE64("foob") = "Zm9vYg=="</li>
     * <li>BASE64("fooba") = "Zm9vYmE="</li>
     * <li>BASE64("foobar") = "Zm9vYmFy"</li>
     * </ul>
     * 
     * @see <a href="http://tools.ietf.org/html/rfc4648">http://tools.ietf.org/html/rfc4648</a>
     */
@Test(timeout = 1000)
    public void testRfc4648Section10DecodeEncode_remove34() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRfc4648Section10DecodeEncode_remove34");
            testDecodeEncode("Zg==");
            testDecodeEncode("Zm8=");
            testDecodeEncode("Zm9v");
            testDecodeEncode("Zm9vYg==");
            testDecodeEncode("Zm9vYmE=");
            testDecodeEncode("Zm9vYmFy");
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests RFC 4648 section 10 test vectors.
     * <ul>
     * <li>BASE64("") = ""</li>
     * <li>BASE64("f") = "Zg=="</li>
     * <li>BASE64("fo") = "Zm8="</li>
     * <li>BASE64("foo") = "Zm9v"</li>
     * <li>BASE64("foob") = "Zm9vYg=="</li>
     * <li>BASE64("fooba") = "Zm9vYmE="</li>
     * <li>BASE64("foobar") = "Zm9vYmFy"</li>
     * </ul>
     * 
     * @see <a href="http://tools.ietf.org/html/rfc4648">http://tools.ietf.org/html/rfc4648</a>
     */
@Test(timeout = 1000)
    public void testRfc4648Section10DecodeEncode_remove35() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRfc4648Section10DecodeEncode_remove35");
            testDecodeEncode("Zg==");
            testDecodeEncode("Zm8=");
            testDecodeEncode("Zm9v");
            testDecodeEncode("Zm9vYg==");
            testDecodeEncode("Zm9vYmE=");
            testDecodeEncode("Zm9vYmFy");
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    private void testDecodeEncode(final String encodedText) {
        final String decodedText = org.apache.commons.codec.binary.StringUtils.newStringUsAscii(Base64.decodeBase64(encodedText));
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),236,decodedText);
        final String encodedText2 = Base64.encodeBase64String(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(decodedText));
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),237,encodedText2);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),234,encodedText);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),235,encodedText2);
    }

    /** 
     * Tests RFC 4648 section 10 test vectors.
     * <ul>
     * <li>BASE64("") = ""</li>
     * <li>BASE64("f") = "Zg=="</li>
     * <li>BASE64("fo") = "Zm8="</li>
     * <li>BASE64("foo") = "Zm9v"</li>
     * <li>BASE64("foob") = "Zm9vYg=="</li>
     * <li>BASE64("fooba") = "Zm9vYmE="</li>
     * <li>BASE64("foobar") = "Zm9vYmFy"</li>
     * </ul>
     * 
     * @see <a href="http://tools.ietf.org/html/rfc4648">http://tools.ietf.org/html/rfc4648</a>
     */
@Test(timeout = 1000)
    public void testRfc4648Section10Encode() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRfc4648Section10Encode");
            testEncodeDecode("");
            testEncodeDecode("");
            testEncodeDecode("f");
            testEncodeDecode("fo");
            testEncodeDecode("foo");
            testEncodeDecode("foob");
            testEncodeDecode("fooba");
            testEncodeDecode("foobar");
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests RFC 4648 section 10 test vectors.
     * <ul>
     * <li>BASE64("") = ""</li>
     * <li>BASE64("f") = "Zg=="</li>
     * <li>BASE64("fo") = "Zm8="</li>
     * <li>BASE64("foo") = "Zm9v"</li>
     * <li>BASE64("foob") = "Zm9vYg=="</li>
     * <li>BASE64("fooba") = "Zm9vYmE="</li>
     * <li>BASE64("foobar") = "Zm9vYmFy"</li>
     * </ul>
     * 
     * @see <a href="http://tools.ietf.org/html/rfc4648">http://tools.ietf.org/html/rfc4648</a>
     */
@Test(timeout = 1000)
    public void testRfc4648Section10EncodeDecode() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRfc4648Section10EncodeDecode");
            testEncodeDecode("");
            testEncodeDecode("f");
            testEncodeDecode("f");
            testEncodeDecode("fo");
            testEncodeDecode("foo");
            testEncodeDecode("foob");
            testEncodeDecode("fooba");
            testEncodeDecode("foobar");
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests RFC 4648 section 10 test vectors.
     * <ul>
     * <li>BASE64("") = ""</li>
     * <li>BASE64("f") = "Zg=="</li>
     * <li>BASE64("fo") = "Zm8="</li>
     * <li>BASE64("foo") = "Zm9v"</li>
     * <li>BASE64("foob") = "Zm9vYg=="</li>
     * <li>BASE64("fooba") = "Zm9vYmE="</li>
     * <li>BASE64("foobar") = "Zm9vYmFy"</li>
     * </ul>
     * 
     * @see <a href="http://tools.ietf.org/html/rfc4648">http://tools.ietf.org/html/rfc4648</a>
     */
@Test(timeout = 1000)
    public void testRfc4648Section10EncodeDecode_add50() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRfc4648Section10EncodeDecode_add50");
            testEncodeDecode("");
            testEncodeDecode("f");
            testEncodeDecode("fo");
            testEncodeDecode("fo");
            testEncodeDecode("foo");
            testEncodeDecode("foob");
            testEncodeDecode("fooba");
            testEncodeDecode("foobar");
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests RFC 4648 section 10 test vectors.
     * <ul>
     * <li>BASE64("") = ""</li>
     * <li>BASE64("f") = "Zg=="</li>
     * <li>BASE64("fo") = "Zm8="</li>
     * <li>BASE64("foo") = "Zm9v"</li>
     * <li>BASE64("foob") = "Zm9vYg=="</li>
     * <li>BASE64("fooba") = "Zm9vYmE="</li>
     * <li>BASE64("foobar") = "Zm9vYmFy"</li>
     * </ul>
     * 
     * @see <a href="http://tools.ietf.org/html/rfc4648">http://tools.ietf.org/html/rfc4648</a>
     */
@Test(timeout = 1000)
    public void testRfc4648Section10EncodeDecode_add51() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRfc4648Section10EncodeDecode_add51");
            testEncodeDecode("");
            testEncodeDecode("f");
            testEncodeDecode("fo");
            testEncodeDecode("foo");
            testEncodeDecode("foo");
            testEncodeDecode("foob");
            testEncodeDecode("fooba");
            testEncodeDecode("foobar");
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests RFC 4648 section 10 test vectors.
     * <ul>
     * <li>BASE64("") = ""</li>
     * <li>BASE64("f") = "Zg=="</li>
     * <li>BASE64("fo") = "Zm8="</li>
     * <li>BASE64("foo") = "Zm9v"</li>
     * <li>BASE64("foob") = "Zm9vYg=="</li>
     * <li>BASE64("fooba") = "Zm9vYmE="</li>
     * <li>BASE64("foobar") = "Zm9vYmFy"</li>
     * </ul>
     * 
     * @see <a href="http://tools.ietf.org/html/rfc4648">http://tools.ietf.org/html/rfc4648</a>
     */
@Test(timeout = 1000)
    public void testRfc4648Section10EncodeDecode_add52() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRfc4648Section10EncodeDecode_add52");
            testEncodeDecode("");
            testEncodeDecode("f");
            testEncodeDecode("fo");
            testEncodeDecode("foo");
            testEncodeDecode("foob");
            testEncodeDecode("foob");
            testEncodeDecode("fooba");
            testEncodeDecode("foobar");
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests RFC 4648 section 10 test vectors.
     * <ul>
     * <li>BASE64("") = ""</li>
     * <li>BASE64("f") = "Zg=="</li>
     * <li>BASE64("fo") = "Zm8="</li>
     * <li>BASE64("foo") = "Zm9v"</li>
     * <li>BASE64("foob") = "Zm9vYg=="</li>
     * <li>BASE64("fooba") = "Zm9vYmE="</li>
     * <li>BASE64("foobar") = "Zm9vYmFy"</li>
     * </ul>
     * 
     * @see <a href="http://tools.ietf.org/html/rfc4648">http://tools.ietf.org/html/rfc4648</a>
     */
@Test(timeout = 1000)
    public void testRfc4648Section10EncodeDecode_add53() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRfc4648Section10EncodeDecode_add53");
            testEncodeDecode("");
            testEncodeDecode("f");
            testEncodeDecode("fo");
            testEncodeDecode("foo");
            testEncodeDecode("foob");
            testEncodeDecode("fooba");
            testEncodeDecode("fooba");
            testEncodeDecode("foobar");
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests RFC 4648 section 10 test vectors.
     * <ul>
     * <li>BASE64("") = ""</li>
     * <li>BASE64("f") = "Zg=="</li>
     * <li>BASE64("fo") = "Zm8="</li>
     * <li>BASE64("foo") = "Zm9v"</li>
     * <li>BASE64("foob") = "Zm9vYg=="</li>
     * <li>BASE64("fooba") = "Zm9vYmE="</li>
     * <li>BASE64("foobar") = "Zm9vYmFy"</li>
     * </ul>
     * 
     * @see <a href="http://tools.ietf.org/html/rfc4648">http://tools.ietf.org/html/rfc4648</a>
     */
@Test(timeout = 1000)
    public void testRfc4648Section10EncodeDecode_add54() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRfc4648Section10EncodeDecode_add54");
            testEncodeDecode("");
            testEncodeDecode("f");
            testEncodeDecode("fo");
            testEncodeDecode("foo");
            testEncodeDecode("foob");
            testEncodeDecode("fooba");
            testEncodeDecode("foobar");
            testEncodeDecode("foobar");
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests RFC 4648 section 10 test vectors.
     * <ul>
     * <li>BASE64("") = ""</li>
     * <li>BASE64("f") = "Zg=="</li>
     * <li>BASE64("fo") = "Zm8="</li>
     * <li>BASE64("foo") = "Zm9v"</li>
     * <li>BASE64("foob") = "Zm9vYg=="</li>
     * <li>BASE64("fooba") = "Zm9vYmE="</li>
     * <li>BASE64("foobar") = "Zm9vYmFy"</li>
     * </ul>
     * 
     * @see <a href="http://tools.ietf.org/html/rfc4648">http://tools.ietf.org/html/rfc4648</a>
     */
@Test(timeout = 1000)
    public void testRfc4648Section10EncodeDecode_remove36() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRfc4648Section10EncodeDecode_remove36");
            testEncodeDecode("f");
            testEncodeDecode("fo");
            testEncodeDecode("foo");
            testEncodeDecode("foob");
            testEncodeDecode("fooba");
            testEncodeDecode("foobar");
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests RFC 4648 section 10 test vectors.
     * <ul>
     * <li>BASE64("") = ""</li>
     * <li>BASE64("f") = "Zg=="</li>
     * <li>BASE64("fo") = "Zm8="</li>
     * <li>BASE64("foo") = "Zm9v"</li>
     * <li>BASE64("foob") = "Zm9vYg=="</li>
     * <li>BASE64("fooba") = "Zm9vYmE="</li>
     * <li>BASE64("foobar") = "Zm9vYmFy"</li>
     * </ul>
     * 
     * @see <a href="http://tools.ietf.org/html/rfc4648">http://tools.ietf.org/html/rfc4648</a>
     */
@Test(timeout = 1000)
    public void testRfc4648Section10EncodeDecode_remove37() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRfc4648Section10EncodeDecode_remove37");
            testEncodeDecode("f");
            testEncodeDecode("fo");
            testEncodeDecode("foo");
            testEncodeDecode("foob");
            testEncodeDecode("fooba");
            testEncodeDecode("foobar");
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests RFC 4648 section 10 test vectors.
     * <ul>
     * <li>BASE64("") = ""</li>
     * <li>BASE64("f") = "Zg=="</li>
     * <li>BASE64("fo") = "Zm8="</li>
     * <li>BASE64("foo") = "Zm9v"</li>
     * <li>BASE64("foob") = "Zm9vYg=="</li>
     * <li>BASE64("fooba") = "Zm9vYmE="</li>
     * <li>BASE64("foobar") = "Zm9vYmFy"</li>
     * </ul>
     * 
     * @see <a href="http://tools.ietf.org/html/rfc4648">http://tools.ietf.org/html/rfc4648</a>
     */
@Test(timeout = 1000)
    public void testRfc4648Section10EncodeDecode_remove38() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRfc4648Section10EncodeDecode_remove38");
            testEncodeDecode("f");
            testEncodeDecode("fo");
            testEncodeDecode("foo");
            testEncodeDecode("foob");
            testEncodeDecode("fooba");
            testEncodeDecode("foobar");
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests RFC 4648 section 10 test vectors.
     * <ul>
     * <li>BASE64("") = ""</li>
     * <li>BASE64("f") = "Zg=="</li>
     * <li>BASE64("fo") = "Zm8="</li>
     * <li>BASE64("foo") = "Zm9v"</li>
     * <li>BASE64("foob") = "Zm9vYg=="</li>
     * <li>BASE64("fooba") = "Zm9vYmE="</li>
     * <li>BASE64("foobar") = "Zm9vYmFy"</li>
     * </ul>
     * 
     * @see <a href="http://tools.ietf.org/html/rfc4648">http://tools.ietf.org/html/rfc4648</a>
     */
@Test(timeout = 1000)
    public void testRfc4648Section10EncodeDecode_remove39() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRfc4648Section10EncodeDecode_remove39");
            testEncodeDecode("f");
            testEncodeDecode("fo");
            testEncodeDecode("foo");
            testEncodeDecode("foob");
            testEncodeDecode("fooba");
            testEncodeDecode("foobar");
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests RFC 4648 section 10 test vectors.
     * <ul>
     * <li>BASE64("") = ""</li>
     * <li>BASE64("f") = "Zg=="</li>
     * <li>BASE64("fo") = "Zm8="</li>
     * <li>BASE64("foo") = "Zm9v"</li>
     * <li>BASE64("foob") = "Zm9vYg=="</li>
     * <li>BASE64("fooba") = "Zm9vYmE="</li>
     * <li>BASE64("foobar") = "Zm9vYmFy"</li>
     * </ul>
     * 
     * @see <a href="http://tools.ietf.org/html/rfc4648">http://tools.ietf.org/html/rfc4648</a>
     */
@Test(timeout = 1000)
    public void testRfc4648Section10EncodeDecode_remove40() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRfc4648Section10EncodeDecode_remove40");
            testEncodeDecode("f");
            testEncodeDecode("fo");
            testEncodeDecode("foo");
            testEncodeDecode("foob");
            testEncodeDecode("fooba");
            testEncodeDecode("foobar");
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests RFC 4648 section 10 test vectors.
     * <ul>
     * <li>BASE64("") = ""</li>
     * <li>BASE64("f") = "Zg=="</li>
     * <li>BASE64("fo") = "Zm8="</li>
     * <li>BASE64("foo") = "Zm9v"</li>
     * <li>BASE64("foob") = "Zm9vYg=="</li>
     * <li>BASE64("fooba") = "Zm9vYmE="</li>
     * <li>BASE64("foobar") = "Zm9vYmFy"</li>
     * </ul>
     * 
     * @see <a href="http://tools.ietf.org/html/rfc4648">http://tools.ietf.org/html/rfc4648</a>
     */
@Test(timeout = 1000)
    public void testRfc4648Section10EncodeDecode_remove41() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRfc4648Section10EncodeDecode_remove41");
            testEncodeDecode("f");
            testEncodeDecode("fo");
            testEncodeDecode("foo");
            testEncodeDecode("foob");
            testEncodeDecode("fooba");
            testEncodeDecode("foobar");
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests RFC 4648 section 10 test vectors.
     * <ul>
     * <li>BASE64("") = ""</li>
     * <li>BASE64("f") = "Zg=="</li>
     * <li>BASE64("fo") = "Zm8="</li>
     * <li>BASE64("foo") = "Zm9v"</li>
     * <li>BASE64("foob") = "Zm9vYg=="</li>
     * <li>BASE64("fooba") = "Zm9vYmE="</li>
     * <li>BASE64("foobar") = "Zm9vYmFy"</li>
     * </ul>
     * 
     * @see <a href="http://tools.ietf.org/html/rfc4648">http://tools.ietf.org/html/rfc4648</a>
     */
@Test(timeout = 1000)
    public void testRfc4648Section10EncodeDecode_remove42() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRfc4648Section10EncodeDecode_remove42");
            testEncodeDecode("f");
            testEncodeDecode("fo");
            testEncodeDecode("foo");
            testEncodeDecode("foob");
            testEncodeDecode("fooba");
            testEncodeDecode("foobar");
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    private void testEncodeDecode(final String plainText) {
        final String encodedText = Base64.encodeBase64String(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(plainText));
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),275,encodedText);
        final String decodedText = org.apache.commons.codec.binary.StringUtils.newStringUsAscii(Base64.decodeBase64(encodedText));
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),276,decodedText);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),273,plainText);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),274,decodedText);
    }

    @Test
    public void testSingletons() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSingletons");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),482,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),483,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(1)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(2)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(3)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(4)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(5)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(6)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(7)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(8)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(9)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(10)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(11)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(12)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(13)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(14)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(15)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(16)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(17)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(18)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(19)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(20)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(21)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(22)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(23)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(24)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(25)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(26)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(27)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(28)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),511,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(29)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),512,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(30)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),513,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(31)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),514,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(32)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),515,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(33)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),516,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(34)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),517,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(35)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),518,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(36)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),519,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(37)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),520,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(38)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),521,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(39)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),522,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(40)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),523,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(41)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),524,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(42)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),525,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(43)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),526,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(44)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),527,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(45)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),528,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(46)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),529,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(47)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),530,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(48)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),531,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(49)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),532,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(50)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),533,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(51)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),534,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(52)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),535,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(53)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),536,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(54)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),537,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(55)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),538,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(56)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),539,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(57)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),540,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(58)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),541,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(59)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),542,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(60)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),543,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(61)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),544,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(62)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),545,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(63)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),546,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(64)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),547,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(65)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),548,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(66)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),549,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(67)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),550,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(68)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),551,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(69)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),552,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(70)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),553,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(71)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),554,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(72)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),555,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(73)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),556,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(74)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),557,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(75)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),558,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(76)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),559,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(77)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),560,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(78)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),561,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(79)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),562,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(80)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),563,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(81)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),564,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(82)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),565,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(83)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),566,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(84)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),567,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(85)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),568,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(86)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),569,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(87)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),570,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(88)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),571,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(89)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),572,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(90)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),573,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(91)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),574,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(92)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),575,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(93)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),576,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(94)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),577,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(95)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),578,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(96)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),579,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(97)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),580,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(98)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),581,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(99)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),582,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(100)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),583,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(101)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),584,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(102)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),585,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(103)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),586,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(104)) })));
            for (int i = -129 ; i <= 127 ; i++) {
                final byte[] test = new byte[]{ ((byte)(i)) };
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),588,test);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),587,java.util.Arrays.equals(test, org.apache.commons.codec.binary.Base64.decodeBase64(org.apache.commons.codec.binary.Base64.encodeBase64(test))));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testSingletons_literalMutation486() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSingletons_literalMutation486");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),482,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),483,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(1)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(2)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(3)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(4)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(5)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(6)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(7)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(8)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(9)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(10)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(11)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(12)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(13)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(14)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(15)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(16)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(17)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(18)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(19)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(20)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(21)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(22)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(23)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(24)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(25)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(26)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(27)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(28)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),511,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(29)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),512,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(30)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),513,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(31)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),514,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(32)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),515,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(33)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),516,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(34)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),517,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(35)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),518,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(36)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),519,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(37)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),520,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(38)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),521,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(39)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),522,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(40)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),523,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(41)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),524,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(42)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),525,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(43)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),526,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(44)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),527,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(45)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),528,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(46)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),529,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(47)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),530,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(48)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),531,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(49)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),532,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(50)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),533,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(51)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),534,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(52)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),535,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(53)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),536,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(54)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),537,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(55)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),538,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(56)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),539,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(57)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),540,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(58)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),541,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(59)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),542,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(60)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),543,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(61)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),544,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(62)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),545,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(63)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),546,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(64)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),547,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(65)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),548,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(66)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),549,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(67)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),550,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(68)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),551,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(69)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),552,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(70)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),553,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(71)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),554,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(72)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),555,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(73)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),556,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(74)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),557,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(75)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),558,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(76)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),559,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(77)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),560,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(78)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),561,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(79)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),562,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(80)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),563,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(81)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),564,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(82)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),565,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(83)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),566,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(84)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),567,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(85)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),568,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(86)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),569,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(87)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),570,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(88)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),571,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(89)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),572,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(90)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),573,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(91)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),574,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(92)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),575,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(93)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),576,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(94)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),577,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(95)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),578,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(96)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),579,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(97)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),580,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(98)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),581,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(99)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),582,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(100)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),583,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(101)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),584,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(102)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),585,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(103)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),586,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(104)) })));
            for (int i = 64 ; i <= 127 ; i++) {
                final byte[] test = new byte[]{ ((byte)(i)) };
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),588,test);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),587,java.util.Arrays.equals(test, org.apache.commons.codec.binary.Base64.decodeBase64(org.apache.commons.codec.binary.Base64.encodeBase64(test))));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testSingletons_literalMutation487() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSingletons_literalMutation487");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),482,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),483,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(1)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(2)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(3)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(4)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(5)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(6)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(7)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(8)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(9)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(10)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(11)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(12)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(13)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(14)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(15)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(16)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(17)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(18)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(19)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(20)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(21)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(22)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(23)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(24)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(25)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(26)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(27)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(28)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),511,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(29)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),512,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(30)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),513,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(31)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),514,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(32)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),515,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(33)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),516,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(34)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),517,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(35)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),518,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(36)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),519,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(37)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),520,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(38)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),521,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(39)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),522,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(40)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),523,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(41)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),524,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(42)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),525,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(43)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),526,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(44)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),527,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(45)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),528,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(46)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),529,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(47)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),530,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(48)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),531,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(49)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),532,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(50)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),533,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(51)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),534,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(52)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),535,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(53)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),536,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(54)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),537,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(55)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),538,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(56)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),539,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(57)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),540,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(58)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),541,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(59)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),542,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(60)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),543,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(61)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),544,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(62)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),545,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(63)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),546,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(64)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),547,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(65)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),548,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(66)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),549,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(67)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),550,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(68)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),551,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(69)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),552,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(70)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),553,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(71)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),554,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(72)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),555,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(73)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),556,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(74)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),557,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(75)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),558,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(76)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),559,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(77)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),560,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(78)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),561,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(79)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),562,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(80)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),563,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(81)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),564,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(82)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),565,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(83)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),566,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(84)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),567,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(85)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),568,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(86)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),569,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(87)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),570,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(88)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),571,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(89)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),572,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(90)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),573,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(91)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),574,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(92)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),575,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(93)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),576,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(94)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),577,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(95)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),578,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(96)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),579,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(97)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),580,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(98)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),581,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(99)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),582,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(100)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),583,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(101)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),584,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(102)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),585,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(103)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),586,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(104)) })));
            for (int i = 256 ; i <= 127 ; i++) {
                final byte[] test = new byte[]{ ((byte)(i)) };
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),588,test);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),587,java.util.Arrays.equals(test, org.apache.commons.codec.binary.Base64.decodeBase64(org.apache.commons.codec.binary.Base64.encodeBase64(test))));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testSingletons_literalMutation488() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSingletons_literalMutation488");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),482,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),483,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(1)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(2)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(3)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(4)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(5)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(6)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(7)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(8)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(9)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(10)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(11)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(12)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(13)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(14)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(15)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(16)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(17)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(18)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(19)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(20)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(21)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(22)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(23)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(24)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(25)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(26)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(27)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(28)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),511,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(29)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),512,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(30)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),513,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(31)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),514,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(32)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),515,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(33)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),516,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(34)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),517,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(35)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),518,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(36)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),519,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(37)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),520,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(38)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),521,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(39)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),522,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(40)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),523,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(41)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),524,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(42)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),525,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(43)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),526,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(44)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),527,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(45)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),528,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(46)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),529,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(47)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),530,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(48)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),531,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(49)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),532,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(50)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),533,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(51)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),534,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(52)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),535,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(53)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),536,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(54)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),537,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(55)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),538,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(56)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),539,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(57)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),540,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(58)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),541,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(59)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),542,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(60)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),543,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(61)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),544,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(62)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),545,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(63)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),546,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(64)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),547,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(65)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),548,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(66)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),549,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(67)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),550,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(68)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),551,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(69)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),552,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(70)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),553,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(71)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),554,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(72)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),555,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(73)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),556,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(74)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),557,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(75)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),558,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(76)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),559,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(77)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),560,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(78)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),561,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(79)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),562,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(80)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),563,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(81)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),564,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(82)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),565,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(83)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),566,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(84)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),567,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(85)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),568,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(86)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),569,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(87)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),570,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(88)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),571,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(89)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),572,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(90)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),573,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(91)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),574,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(92)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),575,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(93)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),576,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(94)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),577,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(95)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),578,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(96)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),579,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(97)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),580,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(98)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),581,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(99)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),582,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(100)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),583,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(101)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),584,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(102)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),585,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(103)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),586,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(104)) })));
            for (int i = 127 ; i <= 127 ; i++) {
                final byte[] test = new byte[]{ ((byte)(i)) };
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),588,test);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),587,java.util.Arrays.equals(test, org.apache.commons.codec.binary.Base64.decodeBase64(org.apache.commons.codec.binary.Base64.encodeBase64(test))));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testSingletons_literalMutation490() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSingletons_literalMutation490");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),482,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),483,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(1)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(2)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(3)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(4)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(5)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(6)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(7)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(8)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(9)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(10)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(11)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(12)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(13)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(14)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(15)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(16)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(17)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(18)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(19)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(20)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(21)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(22)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(23)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(24)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(25)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(26)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(27)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(28)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),511,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(29)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),512,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(30)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),513,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(31)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),514,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(32)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),515,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(33)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),516,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(34)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),517,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(35)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),518,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(36)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),519,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(37)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),520,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(38)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),521,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(39)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),522,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(40)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),523,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(41)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),524,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(42)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),525,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(43)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),526,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(44)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),527,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(45)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),528,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(46)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),529,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(47)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),530,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(48)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),531,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(49)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),532,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(50)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),533,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(51)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),534,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(52)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),535,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(53)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),536,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(54)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),537,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(55)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),538,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(56)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),539,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(57)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),540,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(58)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),541,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(59)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),542,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(60)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),543,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(61)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),544,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(62)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),545,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(63)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),546,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(64)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),547,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(65)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),548,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(66)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),549,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(67)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),550,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(68)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),551,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(69)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),552,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(70)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),553,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(71)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),554,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(72)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),555,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(73)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),556,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(74)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),557,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(75)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),558,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(76)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),559,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(77)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),560,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(78)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),561,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(79)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),562,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(80)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),563,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(81)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),564,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(82)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),565,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(83)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),566,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(84)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),567,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(85)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),568,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(86)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),569,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(87)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),570,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(88)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),571,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(89)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),572,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(90)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),573,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(91)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),574,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(92)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),575,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(93)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),576,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(94)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),577,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(95)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),578,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(96)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),579,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(97)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),580,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(98)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),581,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(99)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),582,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(100)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),583,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(101)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),584,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(102)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),585,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(103)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),586,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(104)) })));
            for (int i = 129 ; i <= 128 ; i++) {
                final byte[] test = new byte[]{ ((byte)(i)) };
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),588,test);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),587,java.util.Arrays.equals(test, org.apache.commons.codec.binary.Base64.decodeBase64(org.apache.commons.codec.binary.Base64.encodeBase64(test))));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testSingletons_literalMutation491() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSingletons_literalMutation491");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),482,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),483,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(1)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(2)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(3)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(4)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(5)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(6)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(7)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(8)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(9)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(10)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(11)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(12)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(13)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(14)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(15)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(16)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(17)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(18)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(19)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(20)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(21)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(22)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(23)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(24)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(25)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(26)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(27)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(28)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),511,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(29)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),512,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(30)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),513,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(31)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),514,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(32)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),515,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(33)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),516,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(34)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),517,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(35)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),518,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(36)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),519,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(37)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),520,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(38)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),521,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(39)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),522,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(40)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),523,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(41)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),524,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(42)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),525,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(43)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),526,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(44)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),527,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(45)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),528,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(46)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),529,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(47)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),530,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(48)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),531,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(49)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),532,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(50)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),533,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(51)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),534,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(52)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),535,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(53)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),536,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(54)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),537,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(55)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),538,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(56)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),539,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(57)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),540,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(58)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),541,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(59)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),542,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(60)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),543,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(61)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),544,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(62)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),545,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(63)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),546,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(64)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),547,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(65)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),548,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(66)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),549,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(67)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),550,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(68)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),551,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(69)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),552,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(70)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),553,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(71)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),554,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(72)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),555,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(73)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),556,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(74)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),557,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(75)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),558,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(76)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),559,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(77)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),560,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(78)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),561,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(79)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),562,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(80)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),563,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(81)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),564,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(82)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),565,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(83)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),566,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(84)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),567,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(85)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),568,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(86)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),569,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(87)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),570,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(88)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),571,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(89)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),572,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(90)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),573,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(91)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),574,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(92)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),575,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(93)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),576,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(94)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),577,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(95)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),578,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(96)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),579,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(97)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),580,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(98)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),581,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(99)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),582,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(100)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),583,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(101)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),584,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(102)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),585,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(103)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),586,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(104)) })));
            for (int i = 129 ; i <= 126 ; i++) {
                final byte[] test = new byte[]{ ((byte)(i)) };
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),588,test);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),587,java.util.Arrays.equals(test, org.apache.commons.codec.binary.Base64.decodeBase64(org.apache.commons.codec.binary.Base64.encodeBase64(test))));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testSingletons_literalMutation492() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSingletons_literalMutation492");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),482,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),483,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(1)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(2)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(3)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(4)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(5)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(6)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(7)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(8)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(9)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(10)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(11)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(12)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(13)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(14)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(15)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(16)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(17)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(18)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(19)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(20)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(21)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(22)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(23)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(24)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(25)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(26)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(27)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(28)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),511,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(29)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),512,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(30)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),513,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(31)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),514,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(32)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),515,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(33)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),516,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(34)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),517,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(35)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),518,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(36)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),519,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(37)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),520,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(38)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),521,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(39)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),522,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(40)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),523,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(41)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),524,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(42)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),525,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(43)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),526,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(44)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),527,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(45)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),528,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(46)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),529,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(47)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),530,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(48)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),531,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(49)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),532,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(50)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),533,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(51)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),534,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(52)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),535,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(53)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),536,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(54)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),537,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(55)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),538,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(56)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),539,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(57)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),540,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(58)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),541,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(59)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),542,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(60)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),543,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(61)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),544,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(62)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),545,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(63)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),546,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(64)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),547,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(65)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),548,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(66)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),549,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(67)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),550,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(68)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),551,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(69)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),552,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(70)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),553,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(71)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),554,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(72)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),555,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(73)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),556,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(74)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),557,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(75)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),558,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(76)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),559,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(77)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),560,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(78)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),561,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(79)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),562,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(80)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),563,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(81)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),564,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(82)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),565,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(83)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),566,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(84)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),567,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(85)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),568,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(86)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),569,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(87)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),570,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(88)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),571,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(89)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),572,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(90)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),573,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(91)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),574,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(92)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),575,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(93)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),576,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(94)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),577,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(95)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),578,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(96)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),579,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(97)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),580,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(98)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),581,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(99)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),582,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(100)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),583,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(101)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),584,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(102)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),585,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(103)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),586,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(104)) })));
            for (int i = 129 ; i <= 63 ; i++) {
                final byte[] test = new byte[]{ ((byte)(i)) };
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),588,test);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),587,java.util.Arrays.equals(test, org.apache.commons.codec.binary.Base64.decodeBase64(org.apache.commons.codec.binary.Base64.encodeBase64(test))));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testSingletons_literalMutation493() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSingletons_literalMutation493");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),482,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),483,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(1)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(2)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(3)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(4)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(5)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(6)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(7)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(8)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(9)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(10)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(11)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(12)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(13)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(14)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(15)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(16)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(17)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(18)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(19)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(20)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(21)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(22)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(23)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(24)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(25)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(26)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(27)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(28)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),511,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(29)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),512,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(30)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),513,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(31)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),514,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(32)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),515,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(33)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),516,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(34)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),517,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(35)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),518,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(36)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),519,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(37)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),520,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(38)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),521,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(39)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),522,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(40)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),523,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(41)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),524,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(42)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),525,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(43)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),526,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(44)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),527,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(45)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),528,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(46)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),529,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(47)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),530,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(48)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),531,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(49)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),532,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(50)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),533,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(51)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),534,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(52)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),535,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(53)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),536,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(54)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),537,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(55)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),538,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(56)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),539,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(57)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),540,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(58)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),541,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(59)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),542,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(60)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),543,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(61)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),544,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(62)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),545,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(63)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),546,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(64)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),547,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(65)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),548,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(66)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),549,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(67)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),550,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(68)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),551,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(69)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),552,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(70)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),553,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(71)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),554,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(72)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),555,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(73)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),556,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(74)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),557,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(75)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),558,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(76)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),559,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(77)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),560,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(78)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),561,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(79)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),562,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(80)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),563,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(81)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),564,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(82)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),565,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(83)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),566,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(84)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),567,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(85)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),568,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(86)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),569,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(87)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),570,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(88)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),571,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(89)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),572,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(90)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),573,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(91)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),574,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(92)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),575,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(93)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),576,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(94)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),577,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(95)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),578,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(96)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),579,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(97)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),580,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(98)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),581,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(99)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),582,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(100)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),583,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(101)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),584,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(102)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),585,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(103)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),586,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(104)) })));
            for (int i = 129 ; i <= 254 ; i++) {
                final byte[] test = new byte[]{ ((byte)(i)) };
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),588,test);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),587,java.util.Arrays.equals(test, org.apache.commons.codec.binary.Base64.decodeBase64(org.apache.commons.codec.binary.Base64.encodeBase64(test))));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testSingletonsChunked() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSingletonsChunked");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),377,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),378,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(1)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),379,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(2)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),380,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(3)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),381,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(4)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),382,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(5)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),383,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(6)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),384,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(7)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),385,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(8)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),386,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(9)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),387,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(10)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),388,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(11)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),389,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(12)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),390,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(13)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),391,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(14)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),392,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(15)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),393,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(16)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),394,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(17)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),395,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(18)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),396,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(19)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),397,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(20)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),398,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(21)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),399,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(22)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(23)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),401,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(24)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(25)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(26)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(27)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),405,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(28)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),406,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(29)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),407,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(30)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),408,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(31)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),409,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(32)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),410,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(33)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),411,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(34)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),412,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(35)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),413,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(36)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),414,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(37)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),415,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(38)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),416,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(39)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),417,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(40)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),418,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(41)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),419,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(42)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),420,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(43)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),421,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(44)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),422,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(45)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),423,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(46)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),424,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(47)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),425,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(48)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),426,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(49)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),427,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(50)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(51)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),429,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(52)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),430,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(53)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),431,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(54)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),432,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(55)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),433,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(56)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),434,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(57)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),435,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(58)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),436,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(59)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),437,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(60)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),438,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(61)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),439,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(62)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),440,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(63)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),441,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(64)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),442,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(65)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),443,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(66)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),444,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(67)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),445,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(68)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),446,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(69)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),447,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(70)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),448,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(71)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),449,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(72)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),450,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(73)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),451,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(74)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),452,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(75)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),453,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(76)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),454,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(77)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),455,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(78)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),456,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(79)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),457,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(80)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),458,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(81)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),459,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(82)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),460,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(83)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),461,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(84)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),462,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(85)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),463,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(86)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),464,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(87)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),465,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(88)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),466,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(89)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),467,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(90)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),468,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(91)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),469,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(92)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),470,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(93)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),471,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(94)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),472,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(95)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),473,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(96)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),474,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(97)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),475,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(98)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),476,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(99)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),477,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(100)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),478,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(101)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),479,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(102)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),480,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(103)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),481,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(104)) })));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testTriplets() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTriplets");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),606,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(0)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),607,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(1)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),608,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(2)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),609,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(3)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),610,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(4)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),611,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(5)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),612,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(6)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),613,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(7)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),614,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(8)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),615,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(9)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),616,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(10)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),617,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(11)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),618,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(12)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),619,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(13)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),620,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(14)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),621,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(15)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),622,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(16)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),623,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(17)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),624,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(18)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),625,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(19)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),626,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(20)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),627,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(21)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),628,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(22)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),629,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(23)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),630,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(24)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),631,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(25)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),632,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(26)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),633,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(27)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),634,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(28)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),635,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(29)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),636,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(30)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),637,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(31)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),638,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(32)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),639,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(33)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),640,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(34)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),641,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(35)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),642,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(36)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),643,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(37)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),644,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(38)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),645,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(39)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),646,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(40)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),647,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(41)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),648,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(42)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),649,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(43)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),650,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(44)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),651,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(45)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),652,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(46)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),653,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(47)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),654,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(48)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),655,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(49)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),656,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(50)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),657,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(51)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),658,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(52)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),659,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(53)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),660,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(54)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),661,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(55)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),662,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(56)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),663,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(57)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),664,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(58)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),665,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(59)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),666,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(60)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),667,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(61)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),668,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(62)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),669,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(63)) })));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testTripletsChunked() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTripletsChunked");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),670,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(0)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),671,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(1)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),672,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(2)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),673,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(3)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),674,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(4)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),675,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(5)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),676,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(6)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),677,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(7)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),678,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(8)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),679,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(9)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),680,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(10)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),681,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(11)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),682,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(12)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),683,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(13)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),684,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(14)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),685,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(15)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),686,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(16)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),687,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(17)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),688,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(18)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),689,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(19)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),690,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(20)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),691,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(21)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),692,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(22)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),693,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(23)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),694,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(24)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),695,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(25)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),696,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(26)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),697,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(27)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),698,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(28)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),699,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(29)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),700,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(30)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),701,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(31)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),702,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(32)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),703,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(33)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),704,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(34)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),705,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(35)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),706,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(36)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),707,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(37)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),708,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(38)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),709,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(39)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),710,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(40)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),711,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(41)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),712,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(42)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),713,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(43)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),714,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(44)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),715,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(45)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),716,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(46)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),717,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(47)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),718,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(48)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),719,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(49)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),720,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(50)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),721,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(51)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),722,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(52)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),723,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(53)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),724,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(54)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),725,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(55)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),726,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(56)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),727,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(57)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),728,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(58)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),729,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(59)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),730,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(60)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),731,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(61)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),732,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(62)) })));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),733,new java.lang.String(org.apache.commons.codec.binary.Base64.encodeBase64Chunked(new byte[]{ ((byte)(0)) , ((byte)(0)) , ((byte)(63)) })));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests url-safe Base64 against random data, sizes 0 to 150.
     */
@Test
    public void testUrlSafe() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUrlSafe");
            for (int i = 1 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, true);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,randomData);
                final byte[] encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,encoded);
                final byte[] decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,decoded);
                final byte[] result = Base64.decodeBase64(encoded);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,result);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),826,("url-safe i=" + i));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),827,java.util.Arrays.equals(decoded, result));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),828,(("url-safe i=" + i) + " no \'=\'"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),829,org.apache.commons.codec.binary.Base64TestData.bytesContain(encoded, ((byte)('='))));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),830,(("url-safe i=" + i) + " no \'\\\'"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),831,org.apache.commons.codec.binary.Base64TestData.bytesContain(encoded, ((byte)('\\'))));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,(("url-safe i=" + i) + " no \'+\'"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,org.apache.commons.codec.binary.Base64TestData.bytesContain(encoded, ((byte)('+'))));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests url-safe Base64 against random data, sizes 0 to 150.
     */
@Test
    public void testUrlSafe_literalMutation682() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUrlSafe_literalMutation682");
            for (int i = -1 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, true);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,randomData);
                final byte[] encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,encoded);
                final byte[] decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,decoded);
                final byte[] result = Base64.decodeBase64(encoded);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,result);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),826,("url-safe i=" + i));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),827,java.util.Arrays.equals(decoded, result));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),828,(("url-safe i=" + i) + " no \'=\'"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),829,org.apache.commons.codec.binary.Base64TestData.bytesContain(encoded, ((byte)('='))));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),830,(("url-safe i=" + i) + " no \'\\\'"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),831,org.apache.commons.codec.binary.Base64TestData.bytesContain(encoded, ((byte)('\\'))));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,(("url-safe i=" + i) + " no \'+\'"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,org.apache.commons.codec.binary.Base64TestData.bytesContain(encoded, ((byte)('+'))));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests url-safe Base64 against random data, sizes 0 to 150.
     */
@Test
    public void testUrlSafe_literalMutation683() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUrlSafe_literalMutation683");
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, true);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,randomData);
                final byte[] encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,encoded);
                final byte[] decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,decoded);
                final byte[] result = Base64.decodeBase64(encoded);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,result);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),826,("url-safe i=" + i));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),827,java.util.Arrays.equals(decoded, result));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),828,(("url-safe i=" + i) + " no \'=\'"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),829,org.apache.commons.codec.binary.Base64TestData.bytesContain(encoded, ((byte)('='))));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),830,(("url-safe i=" + i) + " no \'\\\'"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),831,org.apache.commons.codec.binary.Base64TestData.bytesContain(encoded, ((byte)('\\'))));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,(("url-safe i=" + i) + " no \'+\'"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,org.apache.commons.codec.binary.Base64TestData.bytesContain(encoded, ((byte)('+'))));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests url-safe Base64 against random data, sizes 0 to 150.
     */
@Test
    public void testUrlSafe_literalMutation685() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUrlSafe_literalMutation685");
            for (int i = 0 ; i <= 151 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, true);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,randomData);
                final byte[] encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,encoded);
                final byte[] decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,decoded);
                final byte[] result = Base64.decodeBase64(encoded);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,result);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),826,("url-safe i=" + i));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),827,java.util.Arrays.equals(decoded, result));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),828,(("url-safe i=" + i) + " no \'=\'"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),829,org.apache.commons.codec.binary.Base64TestData.bytesContain(encoded, ((byte)('='))));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),830,(("url-safe i=" + i) + " no \'\\\'"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),831,org.apache.commons.codec.binary.Base64TestData.bytesContain(encoded, ((byte)('\\'))));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,(("url-safe i=" + i) + " no \'+\'"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,org.apache.commons.codec.binary.Base64TestData.bytesContain(encoded, ((byte)('+'))));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests url-safe Base64 against random data, sizes 0 to 150.
     */
@Test
    public void testUrlSafe_literalMutation686() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUrlSafe_literalMutation686");
            for (int i = 0 ; i <= 149 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, true);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,randomData);
                final byte[] encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,encoded);
                final byte[] decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,decoded);
                final byte[] result = Base64.decodeBase64(encoded);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,result);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),826,("url-safe i=" + i));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),827,java.util.Arrays.equals(decoded, result));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),828,(("url-safe i=" + i) + " no \'=\'"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),829,org.apache.commons.codec.binary.Base64TestData.bytesContain(encoded, ((byte)('='))));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),830,(("url-safe i=" + i) + " no \'\\\'"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),831,org.apache.commons.codec.binary.Base64TestData.bytesContain(encoded, ((byte)('\\'))));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,(("url-safe i=" + i) + " no \'+\'"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,org.apache.commons.codec.binary.Base64TestData.bytesContain(encoded, ((byte)('+'))));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests url-safe Base64 against random data, sizes 0 to 150.
     */
@Test
    public void testUrlSafe_literalMutation687() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUrlSafe_literalMutation687");
            for (int i = 0 ; i <= 75 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, true);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,randomData);
                final byte[] encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,encoded);
                final byte[] decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,decoded);
                final byte[] result = Base64.decodeBase64(encoded);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,result);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),826,("url-safe i=" + i));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),827,java.util.Arrays.equals(decoded, result));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),828,(("url-safe i=" + i) + " no \'=\'"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),829,org.apache.commons.codec.binary.Base64TestData.bytesContain(encoded, ((byte)('='))));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),830,(("url-safe i=" + i) + " no \'\\\'"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),831,org.apache.commons.codec.binary.Base64TestData.bytesContain(encoded, ((byte)('\\'))));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,(("url-safe i=" + i) + " no \'+\'"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,org.apache.commons.codec.binary.Base64TestData.bytesContain(encoded, ((byte)('+'))));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests url-safe Base64 against random data, sizes 0 to 150.
     */
@Test
    public void testUrlSafe_literalMutation688() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUrlSafe_literalMutation688");
            for (int i = 0 ; i <= 300 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, true);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,randomData);
                final byte[] encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,encoded);
                final byte[] decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,decoded);
                final byte[] result = Base64.decodeBase64(encoded);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,result);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),826,("url-safe i=" + i));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),827,java.util.Arrays.equals(decoded, result));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),828,(("url-safe i=" + i) + " no \'=\'"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),829,org.apache.commons.codec.binary.Base64TestData.bytesContain(encoded, ((byte)('='))));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),830,(("url-safe i=" + i) + " no \'\\\'"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),831,org.apache.commons.codec.binary.Base64TestData.bytesContain(encoded, ((byte)('\\'))));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,(("url-safe i=" + i) + " no \'+\'"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,org.apache.commons.codec.binary.Base64TestData.bytesContain(encoded, ((byte)('+'))));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests url-safe Base64 against random data, sizes 0 to 150.
     */
@Test
    public void testUrlSafe_literalMutation691() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUrlSafe_literalMutation691");
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, true);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,randomData);
                final byte[] encoded = randomData[2];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,encoded);
                final byte[] decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,decoded);
                final byte[] result = Base64.decodeBase64(encoded);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,result);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),826,("url-safe i=" + i));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),827,java.util.Arrays.equals(decoded, result));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),828,(("url-safe i=" + i) + " no \'=\'"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),829,org.apache.commons.codec.binary.Base64TestData.bytesContain(encoded, ((byte)('='))));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),830,(("url-safe i=" + i) + " no \'\\\'"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),831,org.apache.commons.codec.binary.Base64TestData.bytesContain(encoded, ((byte)('\\'))));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,(("url-safe i=" + i) + " no \'+\'"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,org.apache.commons.codec.binary.Base64TestData.bytesContain(encoded, ((byte)('+'))));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests url-safe Base64 against random data, sizes 0 to 150.
     */
@Test
    public void testUrlSafe_literalMutation692() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUrlSafe_literalMutation692");
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, true);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,randomData);
                final byte[] encoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,encoded);
                final byte[] decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,decoded);
                final byte[] result = Base64.decodeBase64(encoded);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,result);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),826,("url-safe i=" + i));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),827,java.util.Arrays.equals(decoded, result));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),828,(("url-safe i=" + i) + " no \'=\'"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),829,org.apache.commons.codec.binary.Base64TestData.bytesContain(encoded, ((byte)('='))));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),830,(("url-safe i=" + i) + " no \'\\\'"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),831,org.apache.commons.codec.binary.Base64TestData.bytesContain(encoded, ((byte)('\\'))));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,(("url-safe i=" + i) + " no \'+\'"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,org.apache.commons.codec.binary.Base64TestData.bytesContain(encoded, ((byte)('+'))));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests url-safe Base64 against random data, sizes 0 to 150.
     */
@Test
    public void testUrlSafe_literalMutation693() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUrlSafe_literalMutation693");
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, true);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,randomData);
                final byte[] encoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,encoded);
                final byte[] decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,decoded);
                final byte[] result = Base64.decodeBase64(encoded);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,result);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),826,("url-safe i=" + i));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),827,java.util.Arrays.equals(decoded, result));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),828,(("url-safe i=" + i) + " no \'=\'"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),829,org.apache.commons.codec.binary.Base64TestData.bytesContain(encoded, ((byte)('='))));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),830,(("url-safe i=" + i) + " no \'\\\'"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),831,org.apache.commons.codec.binary.Base64TestData.bytesContain(encoded, ((byte)('\\'))));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,(("url-safe i=" + i) + " no \'+\'"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,org.apache.commons.codec.binary.Base64TestData.bytesContain(encoded, ((byte)('+'))));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests url-safe Base64 against random data, sizes 0 to 150.
     */
@Test
    public void testUrlSafe_literalMutation695() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUrlSafe_literalMutation695");
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, true);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,randomData);
                final byte[] encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,encoded);
                final byte[] decoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,decoded);
                final byte[] result = Base64.decodeBase64(encoded);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,result);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),826,("url-safe i=" + i));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),827,java.util.Arrays.equals(decoded, result));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),828,(("url-safe i=" + i) + " no \'=\'"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),829,org.apache.commons.codec.binary.Base64TestData.bytesContain(encoded, ((byte)('='))));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),830,(("url-safe i=" + i) + " no \'\\\'"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),831,org.apache.commons.codec.binary.Base64TestData.bytesContain(encoded, ((byte)('\\'))));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,(("url-safe i=" + i) + " no \'+\'"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,org.apache.commons.codec.binary.Base64TestData.bytesContain(encoded, ((byte)('+'))));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests url-safe Base64 against random data, sizes 0 to 150.
     */
@Test
    public void testUrlSafe_literalMutation696() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUrlSafe_literalMutation696");
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, true);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,randomData);
                final byte[] encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,encoded);
                final byte[] decoded = randomData[-1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,decoded);
                final byte[] result = Base64.decodeBase64(encoded);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,result);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),826,("url-safe i=" + i));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),827,java.util.Arrays.equals(decoded, result));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),828,(("url-safe i=" + i) + " no \'=\'"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),829,org.apache.commons.codec.binary.Base64TestData.bytesContain(encoded, ((byte)('='))));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),830,(("url-safe i=" + i) + " no \'\\\'"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),831,org.apache.commons.codec.binary.Base64TestData.bytesContain(encoded, ((byte)('\\'))));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,(("url-safe i=" + i) + " no \'+\'"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,org.apache.commons.codec.binary.Base64TestData.bytesContain(encoded, ((byte)('+'))));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests url-safe Base64 against random data, sizes 0 to 150.
     */
@Test
    public void testUrlSafe_literalMutation697() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUrlSafe_literalMutation697");
            for (int i = 0 ; i <= 150 ; i++) {
                final byte[][] randomData = Base64TestData.randomData(i, true);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,randomData);
                final byte[] encoded = randomData[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,encoded);
                final byte[] decoded = randomData[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,decoded);
                final byte[] result = Base64.decodeBase64(encoded);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,result);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),826,("url-safe i=" + i));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),827,java.util.Arrays.equals(decoded, result));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),828,(("url-safe i=" + i) + " no \'=\'"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),829,org.apache.commons.codec.binary.Base64TestData.bytesContain(encoded, ((byte)('='))));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),830,(("url-safe i=" + i) + " no \'\\\'"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),831,org.apache.commons.codec.binary.Base64TestData.bytesContain(encoded, ((byte)('\\'))));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,(("url-safe i=" + i) + " no \'+\'"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,org.apache.commons.codec.binary.Base64TestData.bytesContain(encoded, ((byte)('+'))));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test(timeout = 1000)
    public void testUUID_add55() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_add55");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test(timeout = 1000)
    public void testUUID_add56() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_add56");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test(timeout = 1000)
    public void testUUID_add57() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_add57");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test(timeout = 1000)
    public void testUUID_add58() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_add58");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test(timeout = 1000)
    public void testUUID_add59() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_add59");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID");
            final byte[][] ids = new byte[2][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation499() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation499");
            final byte[][] ids = new byte[8][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation500() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation500");
            final byte[][] ids = new byte[5][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation501() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation501");
            final byte[][] ids = new byte[3][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation503() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation503");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),771,ids[1]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation504() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation504");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[-1] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),772,ids[-1]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation505() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation505");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation507() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation507");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67.04d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation508() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation508");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e449À3399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation509() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation509");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation510() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation510");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),773,ids[2]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation511() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation511");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),774,ids[0]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation512() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation512");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),774,ids[0]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation514() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation514");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701Ye4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation515() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation515");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe43z97b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation516() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation516");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49beed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation517() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation517");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),775,ids[1]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation518() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation518");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[4] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),776,ids[4]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation519() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation519");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),777,ids[3]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation521() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation521");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7®31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation522() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation522");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation523() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation523");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa4025d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation524() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation524");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[4] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),778,ids[4]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation525() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation525");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),779,ids[2]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation526() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation526");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),780,ids[1]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation527() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation527");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[6] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),781,ids[6]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation529() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation529");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306×83fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation530() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation530");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8bË5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation531() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation531");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a930613fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation532() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation532");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[2][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation533() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation533");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[8][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation534() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation534");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[5][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation535() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation535");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[3][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation537() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation537");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),782,standard[1]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation538() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation538");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[-1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),783,standard[-1]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation539() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation539");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation541() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation541");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2¼AxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation542() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation542");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATT{cA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation543() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation543");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation544() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation544");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),784,standard[2]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation545() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation545");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),785,standard[0]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation546() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation546");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),785,standard[0]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation548() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation548");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7GWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation549() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation549");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7#tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation550() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation550");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation551() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation551");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),786,standard[1]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation552() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation552");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[4] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),787,standard[4]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation553() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation553");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),788,standard[3]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation555() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation555");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgøojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation556() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation556");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZAL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation557() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation557");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation558() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation558");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[4] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),789,standard[4]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation559() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation559");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),790,standard[2]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation560() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation560");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),791,standard[1]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation561() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation561");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[6] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),792,standard[6]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation563() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation563");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation564() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation564");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A+==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation565() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation565");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBh/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation566() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation566");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[2][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation567() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation567");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[8][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation568() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation568");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[5][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation569() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation569");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[3][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation571() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation571");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),793,urlSafe1[1]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation572() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation572");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[-1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),794,urlSafe1[-1]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation573() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation573");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation575() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation575");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZ¨g-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation576() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation576");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSÚTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation577() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation577");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation578() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation578");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),795,urlSafe1[2]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation579() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation579");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),796,urlSafe1[0]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation580() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation580");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),796,urlSafe1[0]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation582() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation582");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q\\e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation583() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation583");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWséxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation584() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation584");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0r7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation585() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation585");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),797,urlSafe1[1]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation586() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation586");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[4] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),798,urlSafe1[4]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation587() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation587");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),799,urlSafe1[3]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation589() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation589");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZLVS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation590() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation590");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGAgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation591() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation591");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("Z4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation592() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation592");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[4] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),800,urlSafe1[4]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation593() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation593");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),801,urlSafe1[2]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation594() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation594");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),802,urlSafe1[1]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation595() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation595");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[6] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),803,urlSafe1[6]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation597() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation597");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-Pw&zbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation598() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation598");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_ä6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation599() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation599");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation600() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation600");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[2][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation601() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation601");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[8][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation602() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation602");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[5][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation603() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation603");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[3][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation605() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation605");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),804,urlSafe2[1]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation606() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation606");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[-1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),805,urlSafe2[-1]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation607() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation607");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation609() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation609");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkjTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation610() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation610");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATíTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation611() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation611");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation612() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation612");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),806,urlSafe2[2]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation613() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation613");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),807,urlSafe2[0]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation614() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation614");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),807,urlSafe2[0]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation616() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation616");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-µ5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation617() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation617");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwÃH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation618() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation618");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWswkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation619() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation619");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),808,urlSafe2[1]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation620() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation620");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[4] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),809,urlSafe2[4]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation621() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation621");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),810,urlSafe2[3]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation623() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation623");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation624() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation624");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VSM2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation625() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation625");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation626() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation626");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[4] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),811,urlSafe2[4]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation627() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation627");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),812,urlSafe2[2]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation628() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation628");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),813,urlSafe2[1]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation629() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation629");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[6] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),814,urlSafe2[6]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation631() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation631");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhù_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation632() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation632");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBÓzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation633() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation633");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation634() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation634");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[2][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation635() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation635");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[8][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation636() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation636");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[5][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation637() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation637");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[3][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation639() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation639");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),815,urlSafe3[1]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation640() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation640");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[-1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),816,urlSafe3[-1]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation641() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation641");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation643() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation643");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lë2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation644() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation644");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation645() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation645");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation646() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation646");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),817,urlSafe3[2]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation647() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation647");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),818,urlSafe3[0]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation648() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation648");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),818,urlSafe3[0]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation650() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation650");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwHSQ5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation651() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation651");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7txWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation652() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation652");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWswkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation653() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation653");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),819,urlSafe3[1]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation654() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation654");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[4] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),820,urlSafe3[4]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation655() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation655");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),821,urlSafe3[3]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation657() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation657");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojn>xyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation658() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation658");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEoj1nwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation659() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation659");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("Z4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation660() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation660");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[4] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),822,urlSafe3[4]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation661() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation661");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),823,urlSafe3[2]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation662() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation662");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),824,urlSafe3[1]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation663() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation663");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[6] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),825,urlSafe3[6]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation665() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation665");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qThg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation666() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation666");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qT¸Bhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation667() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation667");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation668() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation668");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 1 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation669() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation669");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = -1 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation670() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation670");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation672() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation672");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 2 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation673() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation673");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 8 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation674() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation674");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 5 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation675() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation675");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 3 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation677() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation677");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (true) {
                    System.out.println((("reference: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation678() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation678");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reØerence: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation679() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation679");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("refere\fnce: [" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test
    public void testUUID_literalMutation680() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_literalMutation680");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((("reference:[" + (org.apache.commons.codec.binary.Hex.encodeHexString(ids[i]))) + "]"));
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test(timeout = 1000)
    public void testUUID_remove43() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_remove43");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test(timeout = 1000)
    public void testUUID_remove44() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_remove44");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test(timeout = 1000)
    public void testUUID_remove45() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_remove45");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test(timeout = 1000)
    public void testUUID_remove46() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_remove46");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Base64 encoding of UUID's is a common use-case, especially in URL-SAFE mode. This test case ends up being the
     * "URL-SAFE" JUnit's.
     * 
     * @throws DecoderException
     * if Hex.decode() fails - a serious problem since Hex comes from our own commons-codec!
     */
@Test(timeout = 1000)
    public void testUUID_remove47() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUUID_remove47");
            final byte[][] ids = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),760,ids);
            ids[0] = org.apache.commons.codec.binary.Hex.decodeHex("94ed8d0319e4493399560fb67404d370".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,ids[0]);
            ids[1] = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,ids[1]);
            ids[2] = org.apache.commons.codec.binary.Hex.decodeHex("64be154b6ffa40258d1a01288e7c31ca".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,ids[2]);
            ids[3] = org.apache.commons.codec.binary.Hex.decodeHex("ff7f8fc01cdb471a8c8b5a9306183fe8".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,ids[3]);
            final byte[][] standard = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),761,standard);
            standard[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg+2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,standard[0]);
            standard[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K/fMJwH+Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,standard[1]);
            standard[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2/6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,standard[2]);
            standard[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("/3+PwBzbRxqMi1qTBhg/6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,standard[3]);
            final byte[][] urlSafe1 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,urlSafe1);
            urlSafe1[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,urlSafe1[0]);
            urlSafe1[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,urlSafe1[1]);
            urlSafe1[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,urlSafe1[2]);
            urlSafe1[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A==");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,urlSafe1[3]);
            final byte[][] urlSafe2 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),763,urlSafe2);
            urlSafe2[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,urlSafe2[0]);
            urlSafe2[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,urlSafe2[1]);
            urlSafe2[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,urlSafe2[2]);
            urlSafe2[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A=");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,urlSafe2[3]);
            final byte[][] urlSafe3 = new byte[4][];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,urlSafe3);
            urlSafe3[0] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("lO2NAxnkSTOZVg-2dATTcA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),756,urlSafe3[0]);
            urlSafe3[1] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("K_fMJwH-Q5e0nr7tWsxwkA");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),757,urlSafe3[1]);
            urlSafe3[2] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("ZL4VS2_6QCWNGgEojnwxyg");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),758,urlSafe3[2]);
            urlSafe3[3] = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("_3-PwBzbRxqMi1qTBhg_6A");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),759,urlSafe3[3]);
            for (int i = 0 ; i < 4 ; i++) {
                final byte[] encodedStandard = Base64.encodeBase64(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,encodedStandard);
                final byte[] encodedUrlSafe = Base64.encodeBase64URLSafe(ids[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,encodedUrlSafe);
                final byte[] decodedStandard = Base64.decodeBase64(standard[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,decodedStandard);
                final byte[] decodedUrlSafe1 = Base64.decodeBase64(urlSafe1[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,decodedUrlSafe1);
                final byte[] decodedUrlSafe2 = Base64.decodeBase64(urlSafe2[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,decodedUrlSafe2);
                final byte[] decodedUrlSafe3 = Base64.decodeBase64(urlSafe3[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,decodedUrlSafe3);
                if (false) {
                    System.out.println((((("standard:  [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedStandard))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(standard[i]))) + "]"));
                    System.out.println((((("safe1:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe1))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe1[i]))) + "]"));
                    System.out.println((((("safe2:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe2))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe2[i]))) + "]"));
                    System.out.println((((("safe3:     [" + (org.apache.commons.codec.binary.Hex.encodeHexString(decodedUrlSafe3))) + "] From: [") + (org.apache.commons.codec.binary.StringUtils.newStringUtf8(urlSafe3[i]))) + "]"));
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,java.util.Arrays.equals(encodedStandard, standard[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,java.util.Arrays.equals(encodedUrlSafe, urlSafe3[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,java.util.Arrays.equals(decodedStandard, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,java.util.Arrays.equals(decodedUrlSafe1, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,java.util.Arrays.equals(decodedUrlSafe2, ids[i]));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,java.util.Arrays.equals(decodedUrlSafe3, ids[i]));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testByteToStringVariations() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testByteToStringVariations");
            final Base64 base64 = new Base64(1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),170,base64);
            final byte[] b1 = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("Hello World");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),171,b1);
            final byte[] b2 = new byte[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),172,b2);
            final byte[] b3 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),173,b3);
            final byte[] b4 = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),174,b4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),161,base64.encodeToString(b1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,org.apache.commons.codec.binary.Base64.encodeBase64String(b1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),163,base64.encodeToString(b2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),164,org.apache.commons.codec.binary.Base64.encodeBase64String(b2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),165,base64.encodeToString(b3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),166,org.apache.commons.codec.binary.Base64.encodeBase64String(b3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),167,base64.encodeToString(b4));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),168,org.apache.commons.codec.binary.Base64.encodeBase64String(b4));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),169,org.apache.commons.codec.binary.Base64.encodeBase64URLSafeString(b4));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testByteToStringVariations_literalMutation184() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testByteToStringVariations_literalMutation184");
            final Base64 base64 = new Base64(-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),170,base64);
            final byte[] b1 = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("Hello World");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),171,b1);
            final byte[] b2 = new byte[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),172,b2);
            final byte[] b3 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),173,b3);
            final byte[] b4 = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),174,b4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),161,base64.encodeToString(b1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,org.apache.commons.codec.binary.Base64.encodeBase64String(b1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),163,base64.encodeToString(b2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),164,org.apache.commons.codec.binary.Base64.encodeBase64String(b2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),165,base64.encodeToString(b3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),166,org.apache.commons.codec.binary.Base64.encodeBase64String(b3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),167,base64.encodeToString(b4));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),168,org.apache.commons.codec.binary.Base64.encodeBase64String(b4));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),169,org.apache.commons.codec.binary.Base64.encodeBase64URLSafeString(b4));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testByteToStringVariations_literalMutation185() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testByteToStringVariations_literalMutation185");
            final Base64 base64 = new Base64(0);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),170,base64);
            final byte[] b1 = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("Hello World");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),171,b1);
            final byte[] b2 = new byte[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),172,b2);
            final byte[] b3 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),173,b3);
            final byte[] b4 = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),174,b4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),161,base64.encodeToString(b1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,org.apache.commons.codec.binary.Base64.encodeBase64String(b1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),163,base64.encodeToString(b2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),164,org.apache.commons.codec.binary.Base64.encodeBase64String(b2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),165,base64.encodeToString(b3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),166,org.apache.commons.codec.binary.Base64.encodeBase64String(b3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),167,base64.encodeToString(b4));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),168,org.apache.commons.codec.binary.Base64.encodeBase64String(b4));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),169,org.apache.commons.codec.binary.Base64.encodeBase64URLSafeString(b4));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testByteToStringVariations_literalMutation187() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testByteToStringVariations_literalMutation187");
            final Base64 base64 = new Base64(0);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),170,base64);
            final byte[] b1 = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("Hello 8orld");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),171,b1);
            final byte[] b2 = new byte[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),172,b2);
            final byte[] b3 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),173,b3);
            final byte[] b4 = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),174,b4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),161,base64.encodeToString(b1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,org.apache.commons.codec.binary.Base64.encodeBase64String(b1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),163,base64.encodeToString(b2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),164,org.apache.commons.codec.binary.Base64.encodeBase64String(b2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),165,base64.encodeToString(b3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),166,org.apache.commons.codec.binary.Base64.encodeBase64String(b3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),167,base64.encodeToString(b4));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),168,org.apache.commons.codec.binary.Base64.encodeBase64String(b4));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),169,org.apache.commons.codec.binary.Base64.encodeBase64URLSafeString(b4));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testByteToStringVariations_literalMutation188() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testByteToStringVariations_literalMutation188");
            final Base64 base64 = new Base64(0);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),170,base64);
            final byte[] b1 = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("Hello WorÀld");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),171,b1);
            final byte[] b2 = new byte[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),172,b2);
            final byte[] b3 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),173,b3);
            final byte[] b4 = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),174,b4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),161,base64.encodeToString(b1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,org.apache.commons.codec.binary.Base64.encodeBase64String(b1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),163,base64.encodeToString(b2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),164,org.apache.commons.codec.binary.Base64.encodeBase64String(b2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),165,base64.encodeToString(b3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),166,org.apache.commons.codec.binary.Base64.encodeBase64String(b3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),167,base64.encodeToString(b4));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),168,org.apache.commons.codec.binary.Base64.encodeBase64String(b4));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),169,org.apache.commons.codec.binary.Base64.encodeBase64URLSafeString(b4));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testByteToStringVariations_literalMutation189() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testByteToStringVariations_literalMutation189");
            final Base64 base64 = new Base64(0);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),170,base64);
            final byte[] b1 = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("Hllo World");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),171,b1);
            final byte[] b2 = new byte[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),172,b2);
            final byte[] b3 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),173,b3);
            final byte[] b4 = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),174,b4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),161,base64.encodeToString(b1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,org.apache.commons.codec.binary.Base64.encodeBase64String(b1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),163,base64.encodeToString(b2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),164,org.apache.commons.codec.binary.Base64.encodeBase64String(b2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),165,base64.encodeToString(b3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),166,org.apache.commons.codec.binary.Base64.encodeBase64String(b3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),167,base64.encodeToString(b4));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),168,org.apache.commons.codec.binary.Base64.encodeBase64String(b4));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),169,org.apache.commons.codec.binary.Base64.encodeBase64URLSafeString(b4));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testByteToStringVariations_literalMutation190() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testByteToStringVariations_literalMutation190");
            final Base64 base64 = new Base64(0);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),170,base64);
            final byte[] b1 = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("Hello World");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),171,b1);
            final byte[] b2 = new byte[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),172,b2);
            final byte[] b3 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),173,b3);
            final byte[] b4 = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),174,b4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),161,base64.encodeToString(b1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,org.apache.commons.codec.binary.Base64.encodeBase64String(b1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),163,base64.encodeToString(b2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),164,org.apache.commons.codec.binary.Base64.encodeBase64String(b2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),165,base64.encodeToString(b3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),166,org.apache.commons.codec.binary.Base64.encodeBase64String(b3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),167,base64.encodeToString(b4));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),168,org.apache.commons.codec.binary.Base64.encodeBase64String(b4));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),169,org.apache.commons.codec.binary.Base64.encodeBase64URLSafeString(b4));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testByteToStringVariations_literalMutation191() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testByteToStringVariations_literalMutation191");
            final Base64 base64 = new Base64(0);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),170,base64);
            final byte[] b1 = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("Hello World");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),171,b1);
            final byte[] b2 = new byte[-1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),172,b2);
            final byte[] b3 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),173,b3);
            final byte[] b4 = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),174,b4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),161,base64.encodeToString(b1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,org.apache.commons.codec.binary.Base64.encodeBase64String(b1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),163,base64.encodeToString(b2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),164,org.apache.commons.codec.binary.Base64.encodeBase64String(b2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),165,base64.encodeToString(b3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),166,org.apache.commons.codec.binary.Base64.encodeBase64String(b3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),167,base64.encodeToString(b4));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),168,org.apache.commons.codec.binary.Base64.encodeBase64String(b4));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),169,org.apache.commons.codec.binary.Base64.encodeBase64URLSafeString(b4));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testByteToStringVariations_literalMutation192() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testByteToStringVariations_literalMutation192");
            final Base64 base64 = new Base64(0);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),170,base64);
            final byte[] b1 = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("Hello World");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),171,b1);
            final byte[] b2 = new byte[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),172,b2);
            final byte[] b3 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),173,b3);
            final byte[] b4 = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),174,b4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),161,base64.encodeToString(b1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,org.apache.commons.codec.binary.Base64.encodeBase64String(b1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),163,base64.encodeToString(b2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),164,org.apache.commons.codec.binary.Base64.encodeBase64String(b2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),165,base64.encodeToString(b3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),166,org.apache.commons.codec.binary.Base64.encodeBase64String(b3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),167,base64.encodeToString(b4));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),168,org.apache.commons.codec.binary.Base64.encodeBase64String(b4));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),169,org.apache.commons.codec.binary.Base64.encodeBase64URLSafeString(b4));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testByteToStringVariations_literalMutation195() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testByteToStringVariations_literalMutation195");
            final Base64 base64 = new Base64(0);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),170,base64);
            final byte[] b1 = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("Hello World");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),171,b1);
            final byte[] b2 = new byte[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),172,b2);
            final byte[] b3 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),173,b3);
            final byte[] b4 = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b4ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),174,b4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),161,base64.encodeToString(b1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,org.apache.commons.codec.binary.Base64.encodeBase64String(b1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),163,base64.encodeToString(b2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),164,org.apache.commons.codec.binary.Base64.encodeBase64String(b2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),165,base64.encodeToString(b3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),166,org.apache.commons.codec.binary.Base64.encodeBase64String(b3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),167,base64.encodeToString(b4));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),168,org.apache.commons.codec.binary.Base64.encodeBase64String(b4));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),169,org.apache.commons.codec.binary.Base64.encodeBase64URLSafeString(b4));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testByteToStringVariations_literalMutation196() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testByteToStringVariations_literalMutation196");
            final Base64 base64 = new Base64(0);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),170,base64);
            final byte[] b1 = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("Hello World");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),171,b1);
            final byte[] b2 = new byte[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),172,b2);
            final byte[] b3 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),173,b3);
            final byte[] b4 = org.apache.commons.codec.binary.Hex.decodeHex("2¿bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),174,b4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),161,base64.encodeToString(b1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,org.apache.commons.codec.binary.Base64.encodeBase64String(b1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),163,base64.encodeToString(b2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),164,org.apache.commons.codec.binary.Base64.encodeBase64String(b2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),165,base64.encodeToString(b3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),166,org.apache.commons.codec.binary.Base64.encodeBase64String(b3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),167,base64.encodeToString(b4));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),168,org.apache.commons.codec.binary.Base64.encodeBase64String(b4));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),169,org.apache.commons.codec.binary.Base64.encodeBase64URLSafeString(b4));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testByteToStringVariations_literalMutation197() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testByteToStringVariations_literalMutation197");
            final Base64 base64 = new Base64(0);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),170,base64);
            final byte[] b1 = org.apache.commons.codec.binary.StringUtils.getBytesUtf8("Hello World");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),171,b1);
            final byte[] b2 = new byte[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),172,b2);
            final byte[] b3 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),173,b3);
            final byte[] b4 = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),174,b4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),161,base64.encodeToString(b1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,org.apache.commons.codec.binary.Base64.encodeBase64String(b1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),163,base64.encodeToString(b2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),164,org.apache.commons.codec.binary.Base64.encodeBase64String(b2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),165,base64.encodeToString(b3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),166,org.apache.commons.codec.binary.Base64.encodeBase64String(b3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),167,base64.encodeToString(b4));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),168,org.apache.commons.codec.binary.Base64.encodeBase64String(b4));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),169,org.apache.commons.codec.binary.Base64.encodeBase64URLSafeString(b4));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testStringToByteVariations() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringToByteVariations");
            final Base64 base64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),599,base64);
            final String s1 = "SGVsbG8gV~9ybGQ=\r\n";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),600,s1);
            final String s2 = "";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),601,s2);
            final String s3 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),602,s3);
            final String s4a = "K/fMJwH+Q5e0nr7tWsxwkA==\r\n";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),603,s4a);
            final String s4b = "K_fMJwH-Q5e0nr7tWsxwkA";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),604,s4b);
            final byte[] b4 = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),605,b4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),589,org.apache.commons.codec.binary.StringUtils.newStringUtf8(base64.decode(s1)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),590,org.apache.commons.codec.binary.StringUtils.newStringUtf8(((byte[])(base64.decode(((java.lang.Object)(s1)))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),591,org.apache.commons.codec.binary.StringUtils.newStringUtf8(org.apache.commons.codec.binary.Base64.decodeBase64(s1)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),592,org.apache.commons.codec.binary.StringUtils.newStringUtf8(base64.decode(s2)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),593,org.apache.commons.codec.binary.StringUtils.newStringUtf8(org.apache.commons.codec.binary.Base64.decodeBase64(s2)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),594,org.apache.commons.codec.binary.StringUtils.newStringUtf8(base64.decode(s3)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),595,org.apache.commons.codec.binary.StringUtils.newStringUtf8(org.apache.commons.codec.binary.Base64.decodeBase64(s3)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),596,java.util.Arrays.equals(b4, base64.decode(s4b)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),597,java.util.Arrays.equals(b4, org.apache.commons.codec.binary.Base64.decodeBase64(s4a)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),598,java.util.Arrays.equals(b4, org.apache.commons.codec.binary.Base64.decodeBase64(s4b)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testStringToByteVariations_literalMutation496() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringToByteVariations_literalMutation496");
            final Base64 base64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),599,base64);
            final String s1 = "SGVsibG8gV29ybGQ=\r\n";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),600,s1);
            final String s2 = "";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),601,s2);
            final String s3 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),602,s3);
            final String s4a = "K/fMJwH+Q5e0nr7tWsxwkA==\r\n";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),603,s4a);
            final String s4b = "K_fMJwH-Q5e0nr7tWsxwkA";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),604,s4b);
            final byte[] b4 = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),605,b4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),589,org.apache.commons.codec.binary.StringUtils.newStringUtf8(base64.decode(s1)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),590,org.apache.commons.codec.binary.StringUtils.newStringUtf8(((byte[])(base64.decode(((java.lang.Object)(s1)))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),591,org.apache.commons.codec.binary.StringUtils.newStringUtf8(org.apache.commons.codec.binary.Base64.decodeBase64(s1)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),592,org.apache.commons.codec.binary.StringUtils.newStringUtf8(base64.decode(s2)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),593,org.apache.commons.codec.binary.StringUtils.newStringUtf8(org.apache.commons.codec.binary.Base64.decodeBase64(s2)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),594,org.apache.commons.codec.binary.StringUtils.newStringUtf8(base64.decode(s3)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),595,org.apache.commons.codec.binary.StringUtils.newStringUtf8(org.apache.commons.codec.binary.Base64.decodeBase64(s3)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),596,java.util.Arrays.equals(b4, base64.decode(s4b)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),597,java.util.Arrays.equals(b4, org.apache.commons.codec.binary.Base64.decodeBase64(s4a)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),598,java.util.Arrays.equals(b4, org.apache.commons.codec.binary.Base64.decodeBase64(s4b)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testStringToByteVariations_literalMutation497() throws DecoderException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringToByteVariations_literalMutation497");
            final Base64 base64 = new Base64();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),599,base64);
            final String s1 = "SGVsbG8gV29ybG=\r\n";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),600,s1);
            final String s2 = "";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),601,s2);
            final String s3 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),602,s3);
            final String s4a = "K/fMJwH+Q5e0nr7tWsxwkA==\r\n";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),603,s4a);
            final String s4b = "K_fMJwH-Q5e0nr7tWsxwkA";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),604,s4b);
            final byte[] b4 = org.apache.commons.codec.binary.Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090".toCharArray());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),605,b4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),589,org.apache.commons.codec.binary.StringUtils.newStringUtf8(base64.decode(s1)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),590,org.apache.commons.codec.binary.StringUtils.newStringUtf8(((byte[])(base64.decode(((java.lang.Object)(s1)))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),591,org.apache.commons.codec.binary.StringUtils.newStringUtf8(org.apache.commons.codec.binary.Base64.decodeBase64(s1)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),592,org.apache.commons.codec.binary.StringUtils.newStringUtf8(base64.decode(s2)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),593,org.apache.commons.codec.binary.StringUtils.newStringUtf8(org.apache.commons.codec.binary.Base64.decodeBase64(s2)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),594,org.apache.commons.codec.binary.StringUtils.newStringUtf8(base64.decode(s3)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),595,org.apache.commons.codec.binary.StringUtils.newStringUtf8(org.apache.commons.codec.binary.Base64.decodeBase64(s3)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),596,java.util.Arrays.equals(b4, base64.decode(s4b)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),597,java.util.Arrays.equals(b4, org.apache.commons.codec.binary.Base64.decodeBase64(s4a)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),598,java.util.Arrays.equals(b4, org.apache.commons.codec.binary.Base64.decodeBase64(s4b)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    private String toString(final byte[] data) {
        final StringBuilder buf = new StringBuilder();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),145,buf);
        for (int i = 0 ; i < (data.length) ; i++) {
            buf.append(data[i]);
            if (i != ((data.length) - 1)) {
                buf.append(",");
            } 
        }
        return buf.toString();
    }

    /** 
     * Tests a lineSeparator much bigger than DEFAULT_BUFFER_SIZE.
     * 
     * @see "<a href='http://mail-archives.apache.org/mod_mbox/commons-dev/201202.mbox/%3C4F3C85D7.5060706@snafu.de%3E'>dev@commons.apache.org</a>"
     */
@Test
    @Ignore
    public void testHugeLineSeparator() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testHugeLineSeparator");
            final int BaseNCodec_DEFAULT_BUFFER_SIZE = 8193;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),292,BaseNCodec_DEFAULT_BUFFER_SIZE);
            final int Base64_BYTES_PER_ENCODED_BLOCK = 4;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),293,Base64_BYTES_PER_ENCODED_BLOCK);
            final byte[] baLineSeparator = new byte[(BaseNCodec_DEFAULT_BUFFER_SIZE * 4) - 3];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),294,baLineSeparator);
            final Base64 b64 = new Base64(Base64_BYTES_PER_ENCODED_BLOCK , baLineSeparator);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),295,b64);
            final String strOriginal = "Hello World";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),296,strOriginal);
            final String strDecoded = new String(b64.decode(b64.encode(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(strOriginal))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),297,strDecoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),290,strOriginal);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),291,strDecoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests a lineSeparator much bigger than DEFAULT_BUFFER_SIZE.
     * 
     * @see "<a href='http://mail-archives.apache.org/mod_mbox/commons-dev/201202.mbox/%3C4F3C85D7.5060706@snafu.de%3E'>dev@commons.apache.org</a>"
     */
@Test
    @Ignore
    public void testHugeLineSeparator_literalMutation431() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testHugeLineSeparator_literalMutation431");
            final int BaseNCodec_DEFAULT_BUFFER_SIZE = 4096;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),292,BaseNCodec_DEFAULT_BUFFER_SIZE);
            final int Base64_BYTES_PER_ENCODED_BLOCK = 4;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),293,Base64_BYTES_PER_ENCODED_BLOCK);
            final byte[] baLineSeparator = new byte[(BaseNCodec_DEFAULT_BUFFER_SIZE * 4) - 3];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),294,baLineSeparator);
            final Base64 b64 = new Base64(Base64_BYTES_PER_ENCODED_BLOCK , baLineSeparator);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),295,b64);
            final String strOriginal = "Hello World";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),296,strOriginal);
            final String strDecoded = new String(b64.decode(b64.encode(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(strOriginal))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),297,strDecoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),290,strOriginal);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),291,strDecoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests a lineSeparator much bigger than DEFAULT_BUFFER_SIZE.
     * 
     * @see "<a href='http://mail-archives.apache.org/mod_mbox/commons-dev/201202.mbox/%3C4F3C85D7.5060706@snafu.de%3E'>dev@commons.apache.org</a>"
     */
@Test
    @Ignore
    public void testHugeLineSeparator_literalMutation432() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testHugeLineSeparator_literalMutation432");
            final int BaseNCodec_DEFAULT_BUFFER_SIZE = 16384;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),292,BaseNCodec_DEFAULT_BUFFER_SIZE);
            final int Base64_BYTES_PER_ENCODED_BLOCK = 4;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),293,Base64_BYTES_PER_ENCODED_BLOCK);
            final byte[] baLineSeparator = new byte[(BaseNCodec_DEFAULT_BUFFER_SIZE * 4) - 3];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),294,baLineSeparator);
            final Base64 b64 = new Base64(Base64_BYTES_PER_ENCODED_BLOCK , baLineSeparator);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),295,b64);
            final String strOriginal = "Hello World";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),296,strOriginal);
            final String strDecoded = new String(b64.decode(b64.encode(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(strOriginal))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),297,strDecoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),290,strOriginal);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),291,strDecoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests a lineSeparator much bigger than DEFAULT_BUFFER_SIZE.
     * 
     * @see "<a href='http://mail-archives.apache.org/mod_mbox/commons-dev/201202.mbox/%3C4F3C85D7.5060706@snafu.de%3E'>dev@commons.apache.org</a>"
     */
@Test
    @Ignore
    public void testHugeLineSeparator_literalMutation433() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testHugeLineSeparator_literalMutation433");
            final int BaseNCodec_DEFAULT_BUFFER_SIZE = 8191;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),292,BaseNCodec_DEFAULT_BUFFER_SIZE);
            final int Base64_BYTES_PER_ENCODED_BLOCK = 4;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),293,Base64_BYTES_PER_ENCODED_BLOCK);
            final byte[] baLineSeparator = new byte[(BaseNCodec_DEFAULT_BUFFER_SIZE * 4) - 3];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),294,baLineSeparator);
            final Base64 b64 = new Base64(Base64_BYTES_PER_ENCODED_BLOCK , baLineSeparator);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),295,b64);
            final String strOriginal = "Hello World";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),296,strOriginal);
            final String strDecoded = new String(b64.decode(b64.encode(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(strOriginal))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),297,strDecoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),290,strOriginal);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),291,strDecoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests a lineSeparator much bigger than DEFAULT_BUFFER_SIZE.
     * 
     * @see "<a href='http://mail-archives.apache.org/mod_mbox/commons-dev/201202.mbox/%3C4F3C85D7.5060706@snafu.de%3E'>dev@commons.apache.org</a>"
     */
@Test
    @Ignore
    public void testHugeLineSeparator_literalMutation435() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testHugeLineSeparator_literalMutation435");
            final int BaseNCodec_DEFAULT_BUFFER_SIZE = 8192;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),292,BaseNCodec_DEFAULT_BUFFER_SIZE);
            final int Base64_BYTES_PER_ENCODED_BLOCK = 2;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),293,Base64_BYTES_PER_ENCODED_BLOCK);
            final byte[] baLineSeparator = new byte[(BaseNCodec_DEFAULT_BUFFER_SIZE * 4) - 3];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),294,baLineSeparator);
            final Base64 b64 = new Base64(Base64_BYTES_PER_ENCODED_BLOCK , baLineSeparator);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),295,b64);
            final String strOriginal = "Hello World";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),296,strOriginal);
            final String strDecoded = new String(b64.decode(b64.encode(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(strOriginal))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),297,strDecoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),290,strOriginal);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),291,strDecoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests a lineSeparator much bigger than DEFAULT_BUFFER_SIZE.
     * 
     * @see "<a href='http://mail-archives.apache.org/mod_mbox/commons-dev/201202.mbox/%3C4F3C85D7.5060706@snafu.de%3E'>dev@commons.apache.org</a>"
     */
@Test
    @Ignore
    public void testHugeLineSeparator_literalMutation436() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testHugeLineSeparator_literalMutation436");
            final int BaseNCodec_DEFAULT_BUFFER_SIZE = 8192;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),292,BaseNCodec_DEFAULT_BUFFER_SIZE);
            final int Base64_BYTES_PER_ENCODED_BLOCK = 8;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),293,Base64_BYTES_PER_ENCODED_BLOCK);
            final byte[] baLineSeparator = new byte[(BaseNCodec_DEFAULT_BUFFER_SIZE * 4) - 3];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),294,baLineSeparator);
            final Base64 b64 = new Base64(Base64_BYTES_PER_ENCODED_BLOCK , baLineSeparator);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),295,b64);
            final String strOriginal = "Hello World";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),296,strOriginal);
            final String strDecoded = new String(b64.decode(b64.encode(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(strOriginal))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),297,strDecoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),290,strOriginal);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),291,strDecoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests a lineSeparator much bigger than DEFAULT_BUFFER_SIZE.
     * 
     * @see "<a href='http://mail-archives.apache.org/mod_mbox/commons-dev/201202.mbox/%3C4F3C85D7.5060706@snafu.de%3E'>dev@commons.apache.org</a>"
     */
@Test
    @Ignore
    public void testHugeLineSeparator_literalMutation437() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testHugeLineSeparator_literalMutation437");
            final int BaseNCodec_DEFAULT_BUFFER_SIZE = 8192;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),292,BaseNCodec_DEFAULT_BUFFER_SIZE);
            final int Base64_BYTES_PER_ENCODED_BLOCK = 5;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),293,Base64_BYTES_PER_ENCODED_BLOCK);
            final byte[] baLineSeparator = new byte[(BaseNCodec_DEFAULT_BUFFER_SIZE * 4) - 3];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),294,baLineSeparator);
            final Base64 b64 = new Base64(Base64_BYTES_PER_ENCODED_BLOCK , baLineSeparator);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),295,b64);
            final String strOriginal = "Hello World";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),296,strOriginal);
            final String strDecoded = new String(b64.decode(b64.encode(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(strOriginal))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),297,strDecoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),290,strOriginal);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),291,strDecoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests a lineSeparator much bigger than DEFAULT_BUFFER_SIZE.
     * 
     * @see "<a href='http://mail-archives.apache.org/mod_mbox/commons-dev/201202.mbox/%3C4F3C85D7.5060706@snafu.de%3E'>dev@commons.apache.org</a>"
     */
@Test
    @Ignore
    public void testHugeLineSeparator_literalMutation438() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testHugeLineSeparator_literalMutation438");
            final int BaseNCodec_DEFAULT_BUFFER_SIZE = 8192;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),292,BaseNCodec_DEFAULT_BUFFER_SIZE);
            final int Base64_BYTES_PER_ENCODED_BLOCK = 3;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),293,Base64_BYTES_PER_ENCODED_BLOCK);
            final byte[] baLineSeparator = new byte[(BaseNCodec_DEFAULT_BUFFER_SIZE * 4) - 3];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),294,baLineSeparator);
            final Base64 b64 = new Base64(Base64_BYTES_PER_ENCODED_BLOCK , baLineSeparator);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),295,b64);
            final String strOriginal = "Hello World";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),296,strOriginal);
            final String strDecoded = new String(b64.decode(b64.encode(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(strOriginal))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),297,strDecoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),290,strOriginal);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),291,strDecoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests a lineSeparator much bigger than DEFAULT_BUFFER_SIZE.
     * 
     * @see "<a href='http://mail-archives.apache.org/mod_mbox/commons-dev/201202.mbox/%3C4F3C85D7.5060706@snafu.de%3E'>dev@commons.apache.org</a>"
     */
@Test
    @Ignore
    public void testHugeLineSeparator_literalMutation440() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testHugeLineSeparator_literalMutation440");
            final int BaseNCodec_DEFAULT_BUFFER_SIZE = 8192;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),292,BaseNCodec_DEFAULT_BUFFER_SIZE);
            final int Base64_BYTES_PER_ENCODED_BLOCK = 4;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),293,Base64_BYTES_PER_ENCODED_BLOCK);
            final byte[] baLineSeparator = new byte[(BaseNCodec_DEFAULT_BUFFER_SIZE * 2) - 3];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),294,baLineSeparator);
            final Base64 b64 = new Base64(Base64_BYTES_PER_ENCODED_BLOCK , baLineSeparator);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),295,b64);
            final String strOriginal = "Hello World";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),296,strOriginal);
            final String strDecoded = new String(b64.decode(b64.encode(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(strOriginal))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),297,strDecoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),290,strOriginal);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),291,strDecoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests a lineSeparator much bigger than DEFAULT_BUFFER_SIZE.
     * 
     * @see "<a href='http://mail-archives.apache.org/mod_mbox/commons-dev/201202.mbox/%3C4F3C85D7.5060706@snafu.de%3E'>dev@commons.apache.org</a>"
     */
@Test
    @Ignore
    public void testHugeLineSeparator_literalMutation441() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testHugeLineSeparator_literalMutation441");
            final int BaseNCodec_DEFAULT_BUFFER_SIZE = 8192;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),292,BaseNCodec_DEFAULT_BUFFER_SIZE);
            final int Base64_BYTES_PER_ENCODED_BLOCK = 4;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),293,Base64_BYTES_PER_ENCODED_BLOCK);
            final byte[] baLineSeparator = new byte[(BaseNCodec_DEFAULT_BUFFER_SIZE * 8) - 3];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),294,baLineSeparator);
            final Base64 b64 = new Base64(Base64_BYTES_PER_ENCODED_BLOCK , baLineSeparator);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),295,b64);
            final String strOriginal = "Hello World";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),296,strOriginal);
            final String strDecoded = new String(b64.decode(b64.encode(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(strOriginal))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),297,strDecoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),290,strOriginal);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),291,strDecoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests a lineSeparator much bigger than DEFAULT_BUFFER_SIZE.
     * 
     * @see "<a href='http://mail-archives.apache.org/mod_mbox/commons-dev/201202.mbox/%3C4F3C85D7.5060706@snafu.de%3E'>dev@commons.apache.org</a>"
     */
@Test
    @Ignore
    public void testHugeLineSeparator_literalMutation442() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testHugeLineSeparator_literalMutation442");
            final int BaseNCodec_DEFAULT_BUFFER_SIZE = 8192;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),292,BaseNCodec_DEFAULT_BUFFER_SIZE);
            final int Base64_BYTES_PER_ENCODED_BLOCK = 4;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),293,Base64_BYTES_PER_ENCODED_BLOCK);
            final byte[] baLineSeparator = new byte[(BaseNCodec_DEFAULT_BUFFER_SIZE * 5) - 3];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),294,baLineSeparator);
            final Base64 b64 = new Base64(Base64_BYTES_PER_ENCODED_BLOCK , baLineSeparator);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),295,b64);
            final String strOriginal = "Hello World";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),296,strOriginal);
            final String strDecoded = new String(b64.decode(b64.encode(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(strOriginal))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),297,strDecoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),290,strOriginal);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),291,strDecoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests a lineSeparator much bigger than DEFAULT_BUFFER_SIZE.
     * 
     * @see "<a href='http://mail-archives.apache.org/mod_mbox/commons-dev/201202.mbox/%3C4F3C85D7.5060706@snafu.de%3E'>dev@commons.apache.org</a>"
     */
@Test
    @Ignore
    public void testHugeLineSeparator_literalMutation443() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testHugeLineSeparator_literalMutation443");
            final int BaseNCodec_DEFAULT_BUFFER_SIZE = 8192;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),292,BaseNCodec_DEFAULT_BUFFER_SIZE);
            final int Base64_BYTES_PER_ENCODED_BLOCK = 4;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),293,Base64_BYTES_PER_ENCODED_BLOCK);
            final byte[] baLineSeparator = new byte[(BaseNCodec_DEFAULT_BUFFER_SIZE * 3) - 3];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),294,baLineSeparator);
            final Base64 b64 = new Base64(Base64_BYTES_PER_ENCODED_BLOCK , baLineSeparator);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),295,b64);
            final String strOriginal = "Hello World";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),296,strOriginal);
            final String strDecoded = new String(b64.decode(b64.encode(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(strOriginal))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),297,strDecoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),290,strOriginal);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),291,strDecoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests a lineSeparator much bigger than DEFAULT_BUFFER_SIZE.
     * 
     * @see "<a href='http://mail-archives.apache.org/mod_mbox/commons-dev/201202.mbox/%3C4F3C85D7.5060706@snafu.de%3E'>dev@commons.apache.org</a>"
     */
@Test
    @Ignore
    public void testHugeLineSeparator_literalMutation445() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testHugeLineSeparator_literalMutation445");
            final int BaseNCodec_DEFAULT_BUFFER_SIZE = 8192;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),292,BaseNCodec_DEFAULT_BUFFER_SIZE);
            final int Base64_BYTES_PER_ENCODED_BLOCK = 4;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),293,Base64_BYTES_PER_ENCODED_BLOCK);
            final byte[] baLineSeparator = new byte[(BaseNCodec_DEFAULT_BUFFER_SIZE * 4) - 4];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),294,baLineSeparator);
            final Base64 b64 = new Base64(Base64_BYTES_PER_ENCODED_BLOCK , baLineSeparator);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),295,b64);
            final String strOriginal = "Hello World";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),296,strOriginal);
            final String strDecoded = new String(b64.decode(b64.encode(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(strOriginal))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),297,strDecoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),290,strOriginal);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),291,strDecoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests a lineSeparator much bigger than DEFAULT_BUFFER_SIZE.
     * 
     * @see "<a href='http://mail-archives.apache.org/mod_mbox/commons-dev/201202.mbox/%3C4F3C85D7.5060706@snafu.de%3E'>dev@commons.apache.org</a>"
     */
@Test
    @Ignore
    public void testHugeLineSeparator_literalMutation446() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testHugeLineSeparator_literalMutation446");
            final int BaseNCodec_DEFAULT_BUFFER_SIZE = 8192;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),292,BaseNCodec_DEFAULT_BUFFER_SIZE);
            final int Base64_BYTES_PER_ENCODED_BLOCK = 4;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),293,Base64_BYTES_PER_ENCODED_BLOCK);
            final byte[] baLineSeparator = new byte[(BaseNCodec_DEFAULT_BUFFER_SIZE * 4) - 2];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),294,baLineSeparator);
            final Base64 b64 = new Base64(Base64_BYTES_PER_ENCODED_BLOCK , baLineSeparator);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),295,b64);
            final String strOriginal = "Hello World";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),296,strOriginal);
            final String strDecoded = new String(b64.decode(b64.encode(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(strOriginal))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),297,strDecoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),290,strOriginal);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),291,strDecoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests a lineSeparator much bigger than DEFAULT_BUFFER_SIZE.
     * 
     * @see "<a href='http://mail-archives.apache.org/mod_mbox/commons-dev/201202.mbox/%3C4F3C85D7.5060706@snafu.de%3E'>dev@commons.apache.org</a>"
     */
@Test
    @Ignore
    public void testHugeLineSeparator_literalMutation447() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testHugeLineSeparator_literalMutation447");
            final int BaseNCodec_DEFAULT_BUFFER_SIZE = 8192;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),292,BaseNCodec_DEFAULT_BUFFER_SIZE);
            final int Base64_BYTES_PER_ENCODED_BLOCK = 4;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),293,Base64_BYTES_PER_ENCODED_BLOCK);
            final byte[] baLineSeparator = new byte[(BaseNCodec_DEFAULT_BUFFER_SIZE * 4) - 1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),294,baLineSeparator);
            final Base64 b64 = new Base64(Base64_BYTES_PER_ENCODED_BLOCK , baLineSeparator);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),295,b64);
            final String strOriginal = "Hello World";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),296,strOriginal);
            final String strDecoded = new String(b64.decode(b64.encode(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(strOriginal))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),297,strDecoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),290,strOriginal);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),291,strDecoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests a lineSeparator much bigger than DEFAULT_BUFFER_SIZE.
     * 
     * @see "<a href='http://mail-archives.apache.org/mod_mbox/commons-dev/201202.mbox/%3C4F3C85D7.5060706@snafu.de%3E'>dev@commons.apache.org</a>"
     */
@Test
    @Ignore
    public void testHugeLineSeparator_literalMutation448() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testHugeLineSeparator_literalMutation448");
            final int BaseNCodec_DEFAULT_BUFFER_SIZE = 8192;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),292,BaseNCodec_DEFAULT_BUFFER_SIZE);
            final int Base64_BYTES_PER_ENCODED_BLOCK = 4;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),293,Base64_BYTES_PER_ENCODED_BLOCK);
            final byte[] baLineSeparator = new byte[(BaseNCodec_DEFAULT_BUFFER_SIZE * 4) - 6];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),294,baLineSeparator);
            final Base64 b64 = new Base64(Base64_BYTES_PER_ENCODED_BLOCK , baLineSeparator);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),295,b64);
            final String strOriginal = "Hello World";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),296,strOriginal);
            final String strDecoded = new String(b64.decode(b64.encode(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(strOriginal))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),297,strDecoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),290,strOriginal);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),291,strDecoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests a lineSeparator much bigger than DEFAULT_BUFFER_SIZE.
     * 
     * @see "<a href='http://mail-archives.apache.org/mod_mbox/commons-dev/201202.mbox/%3C4F3C85D7.5060706@snafu.de%3E'>dev@commons.apache.org</a>"
     */
@Test
    @Ignore
    public void testHugeLineSeparator_literalMutation450() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testHugeLineSeparator_literalMutation450");
            final int BaseNCodec_DEFAULT_BUFFER_SIZE = 8192;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),292,BaseNCodec_DEFAULT_BUFFER_SIZE);
            final int Base64_BYTES_PER_ENCODED_BLOCK = 4;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),293,Base64_BYTES_PER_ENCODED_BLOCK);
            final byte[] baLineSeparator = new byte[(BaseNCodec_DEFAULT_BUFFER_SIZE * 4) - 3];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),294,baLineSeparator);
            final Base64 b64 = new Base64(Base64_BYTES_PER_ENCODED_BLOCK , baLineSeparator);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),295,b64);
            final String strOriginal = "Hello Wo%ld";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),296,strOriginal);
            final String strDecoded = new String(b64.decode(b64.encode(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(strOriginal))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),297,strDecoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),290,strOriginal);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),291,strDecoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests a lineSeparator much bigger than DEFAULT_BUFFER_SIZE.
     * 
     * @see "<a href='http://mail-archives.apache.org/mod_mbox/commons-dev/201202.mbox/%3C4F3C85D7.5060706@snafu.de%3E'>dev@commons.apache.org</a>"
     */
@Test
    @Ignore
    public void testHugeLineSeparator_literalMutation451() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testHugeLineSeparator_literalMutation451");
            final int BaseNCodec_DEFAULT_BUFFER_SIZE = 8192;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),292,BaseNCodec_DEFAULT_BUFFER_SIZE);
            final int Base64_BYTES_PER_ENCODED_BLOCK = 4;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),293,Base64_BYTES_PER_ENCODED_BLOCK);
            final byte[] baLineSeparator = new byte[(BaseNCodec_DEFAULT_BUFFER_SIZE * 4) - 3];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),294,baLineSeparator);
            final Base64 b64 = new Base64(Base64_BYTES_PER_ENCODED_BLOCK , baLineSeparator);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),295,b64);
            final String strOriginal = "Hello ÓWorld";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),296,strOriginal);
            final String strDecoded = new String(b64.decode(b64.encode(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(strOriginal))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),297,strDecoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),290,strOriginal);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),291,strDecoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests a lineSeparator much bigger than DEFAULT_BUFFER_SIZE.
     * 
     * @see "<a href='http://mail-archives.apache.org/mod_mbox/commons-dev/201202.mbox/%3C4F3C85D7.5060706@snafu.de%3E'>dev@commons.apache.org</a>"
     */
@Test
    @Ignore
    public void testHugeLineSeparator_literalMutation452() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testHugeLineSeparator_literalMutation452");
            final int BaseNCodec_DEFAULT_BUFFER_SIZE = 8192;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),292,BaseNCodec_DEFAULT_BUFFER_SIZE);
            final int Base64_BYTES_PER_ENCODED_BLOCK = 4;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),293,Base64_BYTES_PER_ENCODED_BLOCK);
            final byte[] baLineSeparator = new byte[(BaseNCodec_DEFAULT_BUFFER_SIZE * 4) - 3];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),294,baLineSeparator);
            final Base64 b64 = new Base64(Base64_BYTES_PER_ENCODED_BLOCK , baLineSeparator);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),295,b64);
            final String strOriginal = "Hell World";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),296,strOriginal);
            final String strDecoded = new String(b64.decode(b64.encode(org.apache.commons.codec.binary.StringUtils.getBytesUtf8(strOriginal))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),297,strDecoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),290,strOriginal);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),291,strDecoded);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }
}

