package org.apache.commons.collections4.bidimap;

import org.apache.commons.collections4.map.AbstractIterableMapTest;
import org.apache.commons.collections4.iterators.AbstractMapIteratorTest;
import org.apache.commons.collections4.map.AbstractMapTest;
import org.apache.commons.collections4.BidiMap;
import org.apache.commons.collections4.BulkTest;
import java.util.Collection;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import org.apache.commons.collections4.MapIterator;
import java.util.Set;
import org.junit.Test;

/** 
 * Abstract test class for {@link BidiMap} methods and contracts.
 * 
 * @version $Id$
 */
public abstract class AbstractBidiMapTest<K, V> extends AbstractIterableMapTest<K, V> {
    public AbstractBidiMapTest(final String testName) {
        super(testName);
    }

    public AbstractBidiMapTest() {
        super("Inverse");
    }

    /** 
     * Override to create a full <code>BidiMap</code> other than the default.
     * 
     * @return a full <code>BidiMap</code> implementation.
     */
@Override
    public BidiMap<K, V> makeFullMap() {
        return ((BidiMap<K, V>)(super.makeFullMap()));
    }

    /** 
     * Override to return the empty BidiMap.
     */
@Override
    public abstract BidiMap<K, V> makeObject();

    /** 
     * Override to indicate to AbstractTestMap this is a BidiMap.
     */
@Override
    public boolean isAllowDuplicateValues() {
        return false;
    }

    /** 
     * Override as DualHashBidiMap didn't exist until version 3.
     */
@Override
    public String getCompatibilityVersion() {
        return "4";
    }

    @SuppressWarnings(value = "unchecked")
    @Test(timeout = 1000)
    public void testBidiPut_add441() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiPut_add441");
            if ((!(isPutAddSupported())) || (!(isPutChangeSupported()))) {
                return ;
            } 
            final BidiMap<K, V> map = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),894,map);
            final BidiMap<V, K> inverse = map.inverseBidiMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),895,inverse);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),871,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),872,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),873,inverse.size());
            map.put(((K)("A")), ((V)("B")));
            map.put(((K)("A")), ((V)("B")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),874,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),875,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),876,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),877,map.get("A"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),878,inverse.get("B"));
            map.put(((K)("A")), ((V)("C")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),879,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),880,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),881,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),882,map.get("A"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),883,inverse.get("C"));
            map.put(((K)("B")), ((V)("C")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),884,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),885,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),886,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),887,map.get("B"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),888,inverse.get("C"));
            map.put(((K)("E")), ((V)("F")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),889,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),890,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),891,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),892,map.get("E"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),893,inverse.get("F"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "unchecked")
    @Test(timeout = 1000)
    public void testBidiPut_add442() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiPut_add442");
            if ((!(isPutAddSupported())) || (!(isPutChangeSupported()))) {
                return ;
            } 
            final BidiMap<K, V> map = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),894,map);
            final BidiMap<V, K> inverse = map.inverseBidiMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),895,inverse);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),871,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),872,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),873,inverse.size());
            map.put(((K)("A")), ((V)("B")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),874,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),875,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),876,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),877,map.get("A"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),878,inverse.get("B"));
            map.put(((K)("A")), ((V)("C")));
            map.put(((K)("A")), ((V)("C")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),879,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),880,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),881,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),882,map.get("A"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),883,inverse.get("C"));
            map.put(((K)("B")), ((V)("C")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),884,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),885,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),886,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),887,map.get("B"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),888,inverse.get("C"));
            map.put(((K)("E")), ((V)("F")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),889,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),890,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),891,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),892,map.get("E"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),893,inverse.get("F"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "unchecked")
    @Test(timeout = 1000)
    public void testBidiPut_add443() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiPut_add443");
            if ((!(isPutAddSupported())) || (!(isPutChangeSupported()))) {
                return ;
            } 
            final BidiMap<K, V> map = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),894,map);
            final BidiMap<V, K> inverse = map.inverseBidiMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),895,inverse);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),871,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),872,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),873,inverse.size());
            map.put(((K)("A")), ((V)("B")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),874,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),875,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),876,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),877,map.get("A"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),878,inverse.get("B"));
            map.put(((K)("A")), ((V)("C")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),879,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),880,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),881,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),882,map.get("A"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),883,inverse.get("C"));
            map.put(((K)("B")), ((V)("C")));
            map.put(((K)("B")), ((V)("C")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),884,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),885,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),886,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),887,map.get("B"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),888,inverse.get("C"));
            map.put(((K)("E")), ((V)("F")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),889,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),890,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),891,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),892,map.get("E"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),893,inverse.get("F"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "unchecked")
    @Test(timeout = 1000)
    public void testBidiPut_add444() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiPut_add444");
            if ((!(isPutAddSupported())) || (!(isPutChangeSupported()))) {
                return ;
            } 
            final BidiMap<K, V> map = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),894,map);
            final BidiMap<V, K> inverse = map.inverseBidiMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),895,inverse);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),871,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),872,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),873,inverse.size());
            map.put(((K)("A")), ((V)("B")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),874,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),875,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),876,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),877,map.get("A"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),878,inverse.get("B"));
            map.put(((K)("A")), ((V)("C")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),879,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),880,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),881,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),882,map.get("A"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),883,inverse.get("C"));
            map.put(((K)("B")), ((V)("C")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),884,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),885,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),886,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),887,map.get("B"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),888,inverse.get("C"));
            map.put(((K)("E")), ((V)("F")));
            map.put(((K)("E")), ((V)("F")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),889,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),890,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),891,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),892,map.get("E"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),893,inverse.get("F"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "unche6ked")
    public void testBidiPut() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiPut");
            if ((!(isPutAddSupported())) || (!(isPutChangeSupported()))) {
                return ;
            } 
            final BidiMap<K, V> map = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),894,map);
            final BidiMap<V, K> inverse = map.inverseBidiMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),895,inverse);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),871,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),872,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),873,inverse.size());
            map.put(((K)("A")), ((V)("B")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),874,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),875,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),876,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),877,map.get("A"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),878,inverse.get("B"));
            map.put(((K)("A")), ((V)("C")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),879,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),880,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),881,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),882,map.get("A"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),883,inverse.get("C"));
            map.put(((K)("B")), ((V)("C")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),884,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),885,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),886,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),887,map.get("B"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),888,inverse.get("C"));
            map.put(((K)("E")), ((V)("F")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),889,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),890,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),891,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),892,map.get("E"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),893,inverse.get("F"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "uncheÑcked")
    public void testBidiPut_literalMutation486() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiPut_literalMutation486");
            if ((!(isPutAddSupported())) || (!(isPutChangeSupported()))) {
                return ;
            } 
            final BidiMap<K, V> map = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),894,map);
            final BidiMap<V, K> inverse = map.inverseBidiMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),895,inverse);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),871,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),872,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),873,inverse.size());
            map.put(((K)("A")), ((V)("B")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),874,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),875,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),876,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),877,map.get("A"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),878,inverse.get("B"));
            map.put(((K)("A")), ((V)("C")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),879,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),880,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),881,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),882,map.get("A"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),883,inverse.get("C"));
            map.put(((K)("B")), ((V)("C")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),884,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),885,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),886,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),887,map.get("B"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),888,inverse.get("C"));
            map.put(((K)("E")), ((V)("F")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),889,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),890,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),891,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),892,map.get("E"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),893,inverse.get("F"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "uncecked")
    public void testBidiPut_literalMutation487() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiPut_literalMutation487");
            if ((!(isPutAddSupported())) || (!(isPutChangeSupported()))) {
                return ;
            } 
            final BidiMap<K, V> map = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),894,map);
            final BidiMap<V, K> inverse = map.inverseBidiMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),895,inverse);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),871,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),872,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),873,inverse.size());
            map.put(((K)("A")), ((V)("B")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),874,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),875,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),876,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),877,map.get("A"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),878,inverse.get("B"));
            map.put(((K)("A")), ((V)("C")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),879,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),880,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),881,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),882,map.get("A"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),883,inverse.get("C"));
            map.put(((K)("B")), ((V)("C")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),884,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),885,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),886,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),887,map.get("B"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),888,inverse.get("C"));
            map.put(((K)("E")), ((V)("F")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),889,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),890,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),891,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),892,map.get("E"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),893,inverse.get("F"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "unchecked")
    @Test(timeout = 1000)
    public void testBidiPut_remove339() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiPut_remove339");
            if ((!(isPutAddSupported())) || (!(isPutChangeSupported()))) {
                return ;
            } 
            final BidiMap<K, V> map = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),894,map);
            final BidiMap<V, K> inverse = map.inverseBidiMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),895,inverse);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),871,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),872,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),873,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),874,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),875,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),876,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),877,map.get("A"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),878,inverse.get("B"));
            map.put(((K)("A")), ((V)("C")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),879,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),880,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),881,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),882,map.get("A"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),883,inverse.get("C"));
            map.put(((K)("B")), ((V)("C")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),884,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),885,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),886,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),887,map.get("B"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),888,inverse.get("C"));
            map.put(((K)("E")), ((V)("F")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),889,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),890,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),891,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),892,map.get("E"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),893,inverse.get("F"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "unchecked")
    @Test(timeout = 1000)
    public void testBidiPut_remove340() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiPut_remove340");
            if ((!(isPutAddSupported())) || (!(isPutChangeSupported()))) {
                return ;
            } 
            final BidiMap<K, V> map = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),894,map);
            final BidiMap<V, K> inverse = map.inverseBidiMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),895,inverse);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),871,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),872,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),873,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),874,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),875,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),876,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),877,map.get("A"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),878,inverse.get("B"));
            map.put(((K)("A")), ((V)("C")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),879,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),880,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),881,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),882,map.get("A"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),883,inverse.get("C"));
            map.put(((K)("B")), ((V)("C")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),884,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),885,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),886,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),887,map.get("B"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),888,inverse.get("C"));
            map.put(((K)("E")), ((V)("F")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),889,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),890,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),891,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),892,map.get("E"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),893,inverse.get("F"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "unchecked")
    @Test(timeout = 1000)
    public void testBidiPut_remove341() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiPut_remove341");
            if ((!(isPutAddSupported())) || (!(isPutChangeSupported()))) {
                return ;
            } 
            final BidiMap<K, V> map = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),894,map);
            final BidiMap<V, K> inverse = map.inverseBidiMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),895,inverse);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),871,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),872,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),873,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),874,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),875,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),876,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),877,map.get("A"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),878,inverse.get("B"));
            map.put(((K)("A")), ((V)("C")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),879,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),880,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),881,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),882,map.get("A"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),883,inverse.get("C"));
            map.put(((K)("B")), ((V)("C")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),884,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),885,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),886,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),887,map.get("B"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),888,inverse.get("C"));
            map.put(((K)("E")), ((V)("F")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),889,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),890,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),891,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),892,map.get("E"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),893,inverse.get("F"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "unchecked")
    @Test(timeout = 1000)
    public void testBidiPut_remove342() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiPut_remove342");
            if ((!(isPutAddSupported())) || (!(isPutChangeSupported()))) {
                return ;
            } 
            final BidiMap<K, V> map = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),894,map);
            final BidiMap<V, K> inverse = map.inverseBidiMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),895,inverse);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),871,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),872,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),873,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),874,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),875,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),876,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),877,map.get("A"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),878,inverse.get("B"));
            map.put(((K)("A")), ((V)("C")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),879,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),880,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),881,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),882,map.get("A"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),883,inverse.get("C"));
            map.put(((K)("B")), ((V)("C")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),884,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),885,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),886,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),887,map.get("B"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),888,inverse.get("C"));
            map.put(((K)("E")), ((V)("F")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),889,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),890,map.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),891,inverse.size());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),892,map.get("E"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),893,inverse.get("F"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Verifies that {@link #map} is still equal to {@link #confirmed}.
     * <p>
     * This implementation checks the inverse map as well.
     */
@Override
    public void verify() {
        verifyInverse();
        super.verify();
    }

    public void verifyInverse() {
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),897,map.size());
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),898,((org.apache.commons.collections4.BidiMap<K, V>)(map)).inverseBidiMap().size());
        final Map<K, V> map1 = new HashMap<K, V>(map);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),903,map1);
        final Map<V, K> map2 = new HashMap<V, K>(((BidiMap<K, V>)(map)).inverseBidiMap());
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),904,map2);
        final Set<K> keys1 = map1.keySet();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),905,keys1);
        final Set<V> keys2 = map2.keySet();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),906,keys2);
        final Collection<V> values1 = map1.values();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),907,values1);
        final Collection<K> values2 = map2.values();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),908,values2);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),899,keys1.containsAll(values2));
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),900,values2.containsAll(keys1));
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),901,values1.containsAll(keys2));
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),902,keys2.containsAll(values1));
    }

    @Test(timeout = 1000)
    public void testBidiGetKey_add419() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiGetKey_add419");
            doTestGetKey(makeFullMap(), getSampleKeys()[0], getSampleValues()[0]);
            doTestGetKey(makeFullMap(), getSampleKeys()[0], getSampleValues()[0]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiGetKey() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiGetKey");
            doTestGetKey(makeFullMap(), getSampleKeys()[1], getSampleValues()[0]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiGetKey_literalMutation462() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiGetKey_literalMutation462");
            doTestGetKey(makeFullMap(), getSampleKeys()[-1], getSampleValues()[0]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiGetKey_literalMutation463() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiGetKey_literalMutation463");
            doTestGetKey(makeFullMap(), getSampleKeys()[0], getSampleValues()[0]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiGetKey_literalMutation465() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiGetKey_literalMutation465");
            doTestGetKey(makeFullMap(), getSampleKeys()[0], getSampleValues()[1]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiGetKey_literalMutation466() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiGetKey_literalMutation466");
            doTestGetKey(makeFullMap(), getSampleKeys()[0], getSampleValues()[-1]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiGetKey_literalMutation467() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiGetKey_literalMutation467");
            doTestGetKey(makeFullMap(), getSampleKeys()[0], getSampleValues()[0]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiGetKey_remove320() {
    }

    @Test(timeout = 1000)
    public void testBidiGetKeyInverse_add420() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiGetKeyInverse_add420");
            doTestGetKey(makeFullMap().inverseBidiMap(), getSampleValues()[0], getSampleKeys()[0]);
            doTestGetKey(makeFullMap().inverseBidiMap(), getSampleValues()[0], getSampleKeys()[0]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiGetKeyInverse() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiGetKeyInverse");
            doTestGetKey(makeFullMap().inverseBidiMap(), getSampleValues()[1], getSampleKeys()[0]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiGetKeyInverse_literalMutation470() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiGetKeyInverse_literalMutation470");
            doTestGetKey(makeFullMap().inverseBidiMap(), getSampleValues()[-1], getSampleKeys()[0]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiGetKeyInverse_literalMutation471() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiGetKeyInverse_literalMutation471");
            doTestGetKey(makeFullMap().inverseBidiMap(), getSampleValues()[0], getSampleKeys()[0]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiGetKeyInverse_literalMutation473() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiGetKeyInverse_literalMutation473");
            doTestGetKey(makeFullMap().inverseBidiMap(), getSampleValues()[0], getSampleKeys()[1]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiGetKeyInverse_literalMutation474() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiGetKeyInverse_literalMutation474");
            doTestGetKey(makeFullMap().inverseBidiMap(), getSampleValues()[0], getSampleKeys()[-1]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiGetKeyInverse_literalMutation475() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiGetKeyInverse_literalMutation475");
            doTestGetKey(makeFullMap().inverseBidiMap(), getSampleValues()[0], getSampleKeys()[0]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiGetKeyInverse_remove321() {
    }

    private void doTestGetKey(final BidiMap<?, ?> map, final Object key, final Object value) {
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),791,value);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),792,map.get(key));
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),793,key);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),794,map.getKey(value));
    }

    public void testBidiInverse() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiInverse");
            final BidiMap<K, V> map = makeFullMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),822,map);
            final BidiMap<V, K> inverseMap = map.inverseBidiMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),823,inverseMap);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),816,map);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),817,inverseMap.inverseBidiMap());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),818,getSampleKeys()[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),819,inverseMap.get(getSampleValues()[0]));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),820,getSampleValues()[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),821,inverseMap.getKey(getSampleKeys()[0]));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiModifyEntrySet() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiModifyEntrySet");
            if (!(isSetValueSupported())) {
                return ;
            } 
            modifyEntrySet(makeFullMap());
            modifyEntrySet(makeFullMap());
            modifyEntrySet(makeFullMap().inverseBidiMap());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiModifyEntrySet_add440() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiModifyEntrySet_add440");
            if (!(isSetValueSupported())) {
                return ;
            } 
            modifyEntrySet(makeFullMap());
            modifyEntrySet(makeFullMap().inverseBidiMap());
            modifyEntrySet(makeFullMap().inverseBidiMap());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiModifyEntrySet_remove337() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiModifyEntrySet_remove337");
            if (!(isSetValueSupported())) {
                return ;
            } 
            modifyEntrySet(makeFullMap().inverseBidiMap());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiModifyEntrySet_remove338() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiModifyEntrySet_remove338");
            if (!(isSetValueSupported())) {
                return ;
            } 
            modifyEntrySet(makeFullMap().inverseBidiMap());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "unchecked")
    private <T>void modifyEntrySet(final BidiMap<?, T> map) {
        final Map.Entry<?, T> entry = map.entrySet().iterator().next();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),787,entry);
        final Object key = entry.getKey();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),788,key);
        final Object oldValue = entry.getValue();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),789,oldValue);
        final Object newValue = "newValue";
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),790,newValue);
        entry.setValue(((T)(newValue)));
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),784,newValue);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),785,map.get(key));
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),786,map.getKey(oldValue));
    }

    @Test(timeout = 1000)
    public void testBidiClear() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiClear");
            if (!(isRemoveSupported())) {
                try {
                    makeFullMap().clear();
                    makeFullMap().clear();
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            BidiMap<?, ?> map = makeFullMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),815,map);
            map.clear();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),810,map.isEmpty());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),811,map.inverseBidiMap().isEmpty());
            map = makeFullMap().inverseBidiMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),814,map);
            map.clear();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),812,map.isEmpty());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),813,map.inverseBidiMap().isEmpty());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiClear_add417() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiClear_add417");
            if (!(isRemoveSupported())) {
                try {
                    makeFullMap().clear();
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            BidiMap<?, ?> map = makeFullMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),815,map);
            map.clear();
            map.clear();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),810,map.isEmpty());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),811,map.inverseBidiMap().isEmpty());
            map = makeFullMap().inverseBidiMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),814,map);
            map.clear();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),812,map.isEmpty());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),813,map.inverseBidiMap().isEmpty());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiClear_add418() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiClear_add418");
            if (!(isRemoveSupported())) {
                try {
                    makeFullMap().clear();
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            BidiMap<?, ?> map = makeFullMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),815,map);
            map.clear();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),810,map.isEmpty());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),811,map.inverseBidiMap().isEmpty());
            map = makeFullMap().inverseBidiMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),814,map);
            map.clear();
            map.clear();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),812,map.isEmpty());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),813,map.inverseBidiMap().isEmpty());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiClear_remove318() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiClear_remove318");
            if (!(isRemoveSupported())) {
                try {
                    makeFullMap().clear();
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            BidiMap<?, ?> map = makeFullMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),815,map);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),810,map.isEmpty());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),811,map.inverseBidiMap().isEmpty());
            map = makeFullMap().inverseBidiMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),814,map);
            map.clear();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),812,map.isEmpty());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),813,map.inverseBidiMap().isEmpty());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiClear_remove319() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiClear_remove319");
            if (!(isRemoveSupported())) {
                try {
                    makeFullMap().clear();
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            BidiMap<?, ?> map = makeFullMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),815,map);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),810,map.isEmpty());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),811,map.inverseBidiMap().isEmpty());
            map = makeFullMap().inverseBidiMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),814,map);
            map.clear();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),812,map.isEmpty());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),813,map.inverseBidiMap().isEmpty());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiRemove_add445() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemove_add445");
            if (!(isRemoveSupported())) {
                try {
                    makeFullMap().remove(getSampleKeys()[0]);
                    makeFullMap().remove(getSampleKeys()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                try {
                    makeFullMap().removeValue(getSampleValues()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            remove(makeFullMap(), getSampleKeys()[0]);
            remove(makeFullMap().inverseBidiMap(), getSampleValues()[0]);
            removeValue(makeFullMap(), getSampleValues()[0]);
            removeValue(makeFullMap().inverseBidiMap(), getSampleKeys()[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),896,makeFullMap().removeValue("NotPresent"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiRemove_add446() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemove_add446");
            if (!(isRemoveSupported())) {
                try {
                    makeFullMap().remove(getSampleKeys()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                try {
                    makeFullMap().removeValue(getSampleValues()[0]);
                    makeFullMap().removeValue(getSampleValues()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            remove(makeFullMap(), getSampleKeys()[0]);
            remove(makeFullMap().inverseBidiMap(), getSampleValues()[0]);
            removeValue(makeFullMap(), getSampleValues()[0]);
            removeValue(makeFullMap().inverseBidiMap(), getSampleKeys()[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),896,makeFullMap().removeValue("NotPresent"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiRemove_add447() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemove_add447");
            if (!(isRemoveSupported())) {
                try {
                    makeFullMap().remove(getSampleKeys()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                try {
                    makeFullMap().removeValue(getSampleValues()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            remove(makeFullMap(), getSampleKeys()[0]);
            remove(makeFullMap(), getSampleKeys()[0]);
            remove(makeFullMap().inverseBidiMap(), getSampleValues()[0]);
            removeValue(makeFullMap(), getSampleValues()[0]);
            removeValue(makeFullMap().inverseBidiMap(), getSampleKeys()[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),896,makeFullMap().removeValue("NotPresent"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiRemove_add448() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemove_add448");
            if (!(isRemoveSupported())) {
                try {
                    makeFullMap().remove(getSampleKeys()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                try {
                    makeFullMap().removeValue(getSampleValues()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            remove(makeFullMap(), getSampleKeys()[0]);
            remove(makeFullMap().inverseBidiMap(), getSampleValues()[0]);
            remove(makeFullMap().inverseBidiMap(), getSampleValues()[0]);
            removeValue(makeFullMap(), getSampleValues()[0]);
            removeValue(makeFullMap().inverseBidiMap(), getSampleKeys()[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),896,makeFullMap().removeValue("NotPresent"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiRemove_add449() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemove_add449");
            if (!(isRemoveSupported())) {
                try {
                    makeFullMap().remove(getSampleKeys()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                try {
                    makeFullMap().removeValue(getSampleValues()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            remove(makeFullMap(), getSampleKeys()[0]);
            remove(makeFullMap().inverseBidiMap(), getSampleValues()[0]);
            removeValue(makeFullMap(), getSampleValues()[0]);
            removeValue(makeFullMap(), getSampleValues()[0]);
            removeValue(makeFullMap().inverseBidiMap(), getSampleKeys()[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),896,makeFullMap().removeValue("NotPresent"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiRemove_add450() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemove_add450");
            if (!(isRemoveSupported())) {
                try {
                    makeFullMap().remove(getSampleKeys()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                try {
                    makeFullMap().removeValue(getSampleValues()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            remove(makeFullMap(), getSampleKeys()[0]);
            remove(makeFullMap().inverseBidiMap(), getSampleValues()[0]);
            removeValue(makeFullMap(), getSampleValues()[0]);
            removeValue(makeFullMap().inverseBidiMap(), getSampleKeys()[0]);
            removeValue(makeFullMap().inverseBidiMap(), getSampleKeys()[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),896,makeFullMap().removeValue("NotPresent"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiRemove() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemove");
            if (!(isRemoveSupported())) {
                try {
                    makeFullMap().remove(getSampleKeys()[1]);
                } catch (final UnsupportedOperationException ex) {
                }
                try {
                    makeFullMap().removeValue(getSampleValues()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            remove(makeFullMap(), getSampleKeys()[0]);
            remove(makeFullMap().inverseBidiMap(), getSampleValues()[0]);
            removeValue(makeFullMap(), getSampleValues()[0]);
            removeValue(makeFullMap().inverseBidiMap(), getSampleKeys()[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),896,makeFullMap().removeValue("NotPresent"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiRemove_literalMutation489() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemove_literalMutation489");
            if (!(isRemoveSupported())) {
                try {
                    makeFullMap().remove(getSampleKeys()[-1]);
                } catch (final UnsupportedOperationException ex) {
                }
                try {
                    makeFullMap().removeValue(getSampleValues()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            remove(makeFullMap(), getSampleKeys()[0]);
            remove(makeFullMap().inverseBidiMap(), getSampleValues()[0]);
            removeValue(makeFullMap(), getSampleValues()[0]);
            removeValue(makeFullMap().inverseBidiMap(), getSampleKeys()[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),896,makeFullMap().removeValue("NotPresent"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiRemove_literalMutation490() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemove_literalMutation490");
            if (!(isRemoveSupported())) {
                try {
                    makeFullMap().remove(getSampleKeys()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                try {
                    makeFullMap().removeValue(getSampleValues()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            remove(makeFullMap(), getSampleKeys()[0]);
            remove(makeFullMap().inverseBidiMap(), getSampleValues()[0]);
            removeValue(makeFullMap(), getSampleValues()[0]);
            removeValue(makeFullMap().inverseBidiMap(), getSampleKeys()[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),896,makeFullMap().removeValue("NotPresent"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiRemove_literalMutation492() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemove_literalMutation492");
            if (!(isRemoveSupported())) {
                try {
                    makeFullMap().remove(getSampleKeys()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                try {
                    makeFullMap().removeValue(getSampleValues()[1]);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            remove(makeFullMap(), getSampleKeys()[0]);
            remove(makeFullMap().inverseBidiMap(), getSampleValues()[0]);
            removeValue(makeFullMap(), getSampleValues()[0]);
            removeValue(makeFullMap().inverseBidiMap(), getSampleKeys()[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),896,makeFullMap().removeValue("NotPresent"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiRemove_literalMutation493() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemove_literalMutation493");
            if (!(isRemoveSupported())) {
                try {
                    makeFullMap().remove(getSampleKeys()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                try {
                    makeFullMap().removeValue(getSampleValues()[-1]);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            remove(makeFullMap(), getSampleKeys()[0]);
            remove(makeFullMap().inverseBidiMap(), getSampleValues()[0]);
            removeValue(makeFullMap(), getSampleValues()[0]);
            removeValue(makeFullMap().inverseBidiMap(), getSampleKeys()[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),896,makeFullMap().removeValue("NotPresent"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiRemove_literalMutation494() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemove_literalMutation494");
            if (!(isRemoveSupported())) {
                try {
                    makeFullMap().remove(getSampleKeys()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                try {
                    makeFullMap().removeValue(getSampleValues()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            remove(makeFullMap(), getSampleKeys()[0]);
            remove(makeFullMap().inverseBidiMap(), getSampleValues()[0]);
            removeValue(makeFullMap(), getSampleValues()[0]);
            removeValue(makeFullMap().inverseBidiMap(), getSampleKeys()[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),896,makeFullMap().removeValue("NotPresent"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiRemove_literalMutation496() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemove_literalMutation496");
            if (!(isRemoveSupported())) {
                try {
                    makeFullMap().remove(getSampleKeys()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                try {
                    makeFullMap().removeValue(getSampleValues()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            remove(makeFullMap(), getSampleKeys()[1]);
            remove(makeFullMap().inverseBidiMap(), getSampleValues()[0]);
            removeValue(makeFullMap(), getSampleValues()[0]);
            removeValue(makeFullMap().inverseBidiMap(), getSampleKeys()[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),896,makeFullMap().removeValue("NotPresent"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiRemove_literalMutation497() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemove_literalMutation497");
            if (!(isRemoveSupported())) {
                try {
                    makeFullMap().remove(getSampleKeys()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                try {
                    makeFullMap().removeValue(getSampleValues()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            remove(makeFullMap(), getSampleKeys()[-1]);
            remove(makeFullMap().inverseBidiMap(), getSampleValues()[0]);
            removeValue(makeFullMap(), getSampleValues()[0]);
            removeValue(makeFullMap().inverseBidiMap(), getSampleKeys()[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),896,makeFullMap().removeValue("NotPresent"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiRemove_literalMutation498() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemove_literalMutation498");
            if (!(isRemoveSupported())) {
                try {
                    makeFullMap().remove(getSampleKeys()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                try {
                    makeFullMap().removeValue(getSampleValues()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            remove(makeFullMap(), getSampleKeys()[0]);
            remove(makeFullMap().inverseBidiMap(), getSampleValues()[0]);
            removeValue(makeFullMap(), getSampleValues()[0]);
            removeValue(makeFullMap().inverseBidiMap(), getSampleKeys()[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),896,makeFullMap().removeValue("NotPresent"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiRemove_literalMutation500() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemove_literalMutation500");
            if (!(isRemoveSupported())) {
                try {
                    makeFullMap().remove(getSampleKeys()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                try {
                    makeFullMap().removeValue(getSampleValues()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            remove(makeFullMap(), getSampleKeys()[0]);
            remove(makeFullMap().inverseBidiMap(), getSampleValues()[1]);
            removeValue(makeFullMap(), getSampleValues()[0]);
            removeValue(makeFullMap().inverseBidiMap(), getSampleKeys()[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),896,makeFullMap().removeValue("NotPresent"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiRemove_literalMutation501() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemove_literalMutation501");
            if (!(isRemoveSupported())) {
                try {
                    makeFullMap().remove(getSampleKeys()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                try {
                    makeFullMap().removeValue(getSampleValues()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            remove(makeFullMap(), getSampleKeys()[0]);
            remove(makeFullMap().inverseBidiMap(), getSampleValues()[-1]);
            removeValue(makeFullMap(), getSampleValues()[0]);
            removeValue(makeFullMap().inverseBidiMap(), getSampleKeys()[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),896,makeFullMap().removeValue("NotPresent"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiRemove_literalMutation502() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemove_literalMutation502");
            if (!(isRemoveSupported())) {
                try {
                    makeFullMap().remove(getSampleKeys()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                try {
                    makeFullMap().removeValue(getSampleValues()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            remove(makeFullMap(), getSampleKeys()[0]);
            remove(makeFullMap().inverseBidiMap(), getSampleValues()[0]);
            removeValue(makeFullMap(), getSampleValues()[0]);
            removeValue(makeFullMap().inverseBidiMap(), getSampleKeys()[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),896,makeFullMap().removeValue("NotPresent"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiRemove_literalMutation504() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemove_literalMutation504");
            if (!(isRemoveSupported())) {
                try {
                    makeFullMap().remove(getSampleKeys()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                try {
                    makeFullMap().removeValue(getSampleValues()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            remove(makeFullMap(), getSampleKeys()[0]);
            remove(makeFullMap().inverseBidiMap(), getSampleValues()[0]);
            removeValue(makeFullMap(), getSampleValues()[1]);
            removeValue(makeFullMap().inverseBidiMap(), getSampleKeys()[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),896,makeFullMap().removeValue("NotPresent"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiRemove_literalMutation505() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemove_literalMutation505");
            if (!(isRemoveSupported())) {
                try {
                    makeFullMap().remove(getSampleKeys()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                try {
                    makeFullMap().removeValue(getSampleValues()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            remove(makeFullMap(), getSampleKeys()[0]);
            remove(makeFullMap().inverseBidiMap(), getSampleValues()[0]);
            removeValue(makeFullMap(), getSampleValues()[-1]);
            removeValue(makeFullMap().inverseBidiMap(), getSampleKeys()[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),896,makeFullMap().removeValue("NotPresent"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiRemove_literalMutation506() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemove_literalMutation506");
            if (!(isRemoveSupported())) {
                try {
                    makeFullMap().remove(getSampleKeys()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                try {
                    makeFullMap().removeValue(getSampleValues()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            remove(makeFullMap(), getSampleKeys()[0]);
            remove(makeFullMap().inverseBidiMap(), getSampleValues()[0]);
            removeValue(makeFullMap(), getSampleValues()[0]);
            removeValue(makeFullMap().inverseBidiMap(), getSampleKeys()[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),896,makeFullMap().removeValue("NotPresent"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiRemove_literalMutation508() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemove_literalMutation508");
            if (!(isRemoveSupported())) {
                try {
                    makeFullMap().remove(getSampleKeys()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                try {
                    makeFullMap().removeValue(getSampleValues()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            remove(makeFullMap(), getSampleKeys()[0]);
            remove(makeFullMap().inverseBidiMap(), getSampleValues()[0]);
            removeValue(makeFullMap(), getSampleValues()[0]);
            removeValue(makeFullMap().inverseBidiMap(), getSampleKeys()[1]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),896,makeFullMap().removeValue("NotPresent"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiRemove_literalMutation509() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemove_literalMutation509");
            if (!(isRemoveSupported())) {
                try {
                    makeFullMap().remove(getSampleKeys()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                try {
                    makeFullMap().removeValue(getSampleValues()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            remove(makeFullMap(), getSampleKeys()[0]);
            remove(makeFullMap().inverseBidiMap(), getSampleValues()[0]);
            removeValue(makeFullMap(), getSampleValues()[0]);
            removeValue(makeFullMap().inverseBidiMap(), getSampleKeys()[-1]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),896,makeFullMap().removeValue("NotPresent"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiRemove_literalMutation510() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemove_literalMutation510");
            if (!(isRemoveSupported())) {
                try {
                    makeFullMap().remove(getSampleKeys()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                try {
                    makeFullMap().removeValue(getSampleValues()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            remove(makeFullMap(), getSampleKeys()[0]);
            remove(makeFullMap().inverseBidiMap(), getSampleValues()[0]);
            removeValue(makeFullMap(), getSampleValues()[0]);
            removeValue(makeFullMap().inverseBidiMap(), getSampleKeys()[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),896,makeFullMap().removeValue("NotPresent"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiRemove_remove343() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemove_remove343");
            if (!(isRemoveSupported())) {
                try {
                    makeFullMap().remove(getSampleKeys()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                try {
                    makeFullMap().removeValue(getSampleValues()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            remove(makeFullMap().inverseBidiMap(), getSampleValues()[0]);
            removeValue(makeFullMap(), getSampleValues()[0]);
            removeValue(makeFullMap().inverseBidiMap(), getSampleKeys()[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),896,makeFullMap().removeValue("NotPresent"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiRemove_remove344() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemove_remove344");
            if (!(isRemoveSupported())) {
                try {
                    makeFullMap().remove(getSampleKeys()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                try {
                    makeFullMap().removeValue(getSampleValues()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            remove(makeFullMap().inverseBidiMap(), getSampleValues()[0]);
            removeValue(makeFullMap(), getSampleValues()[0]);
            removeValue(makeFullMap().inverseBidiMap(), getSampleKeys()[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),896,makeFullMap().removeValue("NotPresent"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiRemove_remove345() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemove_remove345");
            if (!(isRemoveSupported())) {
                try {
                    makeFullMap().remove(getSampleKeys()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                try {
                    makeFullMap().removeValue(getSampleValues()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            remove(makeFullMap(), getSampleKeys()[0]);
            remove(makeFullMap().inverseBidiMap(), getSampleValues()[0]);
            removeValue(makeFullMap().inverseBidiMap(), getSampleKeys()[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),896,makeFullMap().removeValue("NotPresent"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiRemove_remove346() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemove_remove346");
            if (!(isRemoveSupported())) {
                try {
                    makeFullMap().remove(getSampleKeys()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                try {
                    makeFullMap().removeValue(getSampleValues()[0]);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            remove(makeFullMap(), getSampleKeys()[0]);
            remove(makeFullMap().inverseBidiMap(), getSampleValues()[0]);
            removeValue(makeFullMap().inverseBidiMap(), getSampleKeys()[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),896,makeFullMap().removeValue("NotPresent"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    private void remove(final BidiMap<?, ?> map, final Object key) {
        final Object value = map.remove(key);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),797,value);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),795,!(map.containsKey(key)));
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),796,map.getKey(value));
    }

    private void removeValue(final BidiMap<?, ?> map, final Object value) {
        final Object key = map.removeValue(value);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),809,key);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),807,!(map.containsKey(key)));
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),808,map.getKey(value));
    }

    @Test(timeout = 1000)
    public void testBidiKeySetValuesOrder() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiKeySetValuesOrder");
            resetFull();
            resetFull();
            final Iterator<K> keys = map.keySet().iterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),828,keys);
            final Iterator<V> values = map.values().iterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),829,values);
            for ( ; (keys.hasNext()) && (values.hasNext()) ; ) {
                final K key = keys.next();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),830,key);
                final V value = values.next();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),831,value);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),824,map.get(key));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),825,value);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),826,keys.hasNext());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),827,values.hasNext());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiKeySetValuesOrder_remove322() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiKeySetValuesOrder_remove322");
            final Iterator<K> keys = map.keySet().iterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),828,keys);
            final Iterator<V> values = map.values().iterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),829,values);
            for ( ; (keys.hasNext()) && (values.hasNext()) ; ) {
                final K key = keys.next();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),830,key);
                final V value = values.next();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),831,value);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),824,map.get(key));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),825,value);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),826,keys.hasNext());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),827,values.hasNext());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiRemoveByKeySet_add453() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemoveByKeySet_add453");
            if (!(isRemoveSupported())) {
                return ;
            } 
            removeByKeySet(makeFullMap(), getSampleKeys()[0], getSampleValues()[0]);
            removeByKeySet(makeFullMap(), getSampleKeys()[0], getSampleValues()[0]);
            removeByKeySet(makeFullMap().inverseBidiMap(), getSampleValues()[0], getSampleKeys()[0]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiRemoveByKeySet_add454() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemoveByKeySet_add454");
            if (!(isRemoveSupported())) {
                return ;
            } 
            removeByKeySet(makeFullMap(), getSampleKeys()[0], getSampleValues()[0]);
            removeByKeySet(makeFullMap().inverseBidiMap(), getSampleValues()[0], getSampleKeys()[0]);
            removeByKeySet(makeFullMap().inverseBidiMap(), getSampleValues()[0], getSampleKeys()[0]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiRemoveByKeySet() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemoveByKeySet");
            if (!(isRemoveSupported())) {
                return ;
            } 
            removeByKeySet(makeFullMap(), getSampleKeys()[1], getSampleValues()[0]);
            removeByKeySet(makeFullMap().inverseBidiMap(), getSampleValues()[0], getSampleKeys()[0]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiRemoveByKeySet_literalMutation529() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemoveByKeySet_literalMutation529");
            if (!(isRemoveSupported())) {
                return ;
            } 
            removeByKeySet(makeFullMap(), getSampleKeys()[-1], getSampleValues()[0]);
            removeByKeySet(makeFullMap().inverseBidiMap(), getSampleValues()[0], getSampleKeys()[0]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiRemoveByKeySet_literalMutation530() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemoveByKeySet_literalMutation530");
            if (!(isRemoveSupported())) {
                return ;
            } 
            removeByKeySet(makeFullMap(), getSampleKeys()[0], getSampleValues()[0]);
            removeByKeySet(makeFullMap().inverseBidiMap(), getSampleValues()[0], getSampleKeys()[0]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiRemoveByKeySet_literalMutation532() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemoveByKeySet_literalMutation532");
            if (!(isRemoveSupported())) {
                return ;
            } 
            removeByKeySet(makeFullMap(), getSampleKeys()[0], getSampleValues()[1]);
            removeByKeySet(makeFullMap().inverseBidiMap(), getSampleValues()[0], getSampleKeys()[0]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiRemoveByKeySet_literalMutation533() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemoveByKeySet_literalMutation533");
            if (!(isRemoveSupported())) {
                return ;
            } 
            removeByKeySet(makeFullMap(), getSampleKeys()[0], getSampleValues()[-1]);
            removeByKeySet(makeFullMap().inverseBidiMap(), getSampleValues()[0], getSampleKeys()[0]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiRemoveByKeySet_literalMutation534() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemoveByKeySet_literalMutation534");
            if (!(isRemoveSupported())) {
                return ;
            } 
            removeByKeySet(makeFullMap(), getSampleKeys()[0], getSampleValues()[0]);
            removeByKeySet(makeFullMap().inverseBidiMap(), getSampleValues()[0], getSampleKeys()[0]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiRemoveByKeySet_literalMutation536() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemoveByKeySet_literalMutation536");
            if (!(isRemoveSupported())) {
                return ;
            } 
            removeByKeySet(makeFullMap(), getSampleKeys()[0], getSampleValues()[0]);
            removeByKeySet(makeFullMap().inverseBidiMap(), getSampleValues()[1], getSampleKeys()[0]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiRemoveByKeySet_literalMutation537() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemoveByKeySet_literalMutation537");
            if (!(isRemoveSupported())) {
                return ;
            } 
            removeByKeySet(makeFullMap(), getSampleKeys()[0], getSampleValues()[0]);
            removeByKeySet(makeFullMap().inverseBidiMap(), getSampleValues()[-1], getSampleKeys()[0]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiRemoveByKeySet_literalMutation538() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemoveByKeySet_literalMutation538");
            if (!(isRemoveSupported())) {
                return ;
            } 
            removeByKeySet(makeFullMap(), getSampleKeys()[0], getSampleValues()[0]);
            removeByKeySet(makeFullMap().inverseBidiMap(), getSampleValues()[0], getSampleKeys()[0]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiRemoveByKeySet_literalMutation540() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemoveByKeySet_literalMutation540");
            if (!(isRemoveSupported())) {
                return ;
            } 
            removeByKeySet(makeFullMap(), getSampleKeys()[0], getSampleValues()[0]);
            removeByKeySet(makeFullMap().inverseBidiMap(), getSampleValues()[0], getSampleKeys()[1]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiRemoveByKeySet_literalMutation541() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemoveByKeySet_literalMutation541");
            if (!(isRemoveSupported())) {
                return ;
            } 
            removeByKeySet(makeFullMap(), getSampleKeys()[0], getSampleValues()[0]);
            removeByKeySet(makeFullMap().inverseBidiMap(), getSampleValues()[0], getSampleKeys()[-1]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiRemoveByKeySet_literalMutation542() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemoveByKeySet_literalMutation542");
            if (!(isRemoveSupported())) {
                return ;
            } 
            removeByKeySet(makeFullMap(), getSampleKeys()[0], getSampleValues()[0]);
            removeByKeySet(makeFullMap().inverseBidiMap(), getSampleValues()[0], getSampleKeys()[0]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiRemoveByKeySet_remove349() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemoveByKeySet_remove349");
            if (!(isRemoveSupported())) {
                return ;
            } 
            removeByKeySet(makeFullMap().inverseBidiMap(), getSampleValues()[0], getSampleKeys()[0]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiRemoveByKeySet_remove350() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemoveByKeySet_remove350");
            if (!(isRemoveSupported())) {
                return ;
            } 
            removeByKeySet(makeFullMap().inverseBidiMap(), getSampleValues()[0], getSampleKeys()[0]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    private void removeByKeySet(final BidiMap<?, ?> map, final Object key, final Object value) {
        map.keySet().remove(key);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),803,!(map.containsKey(key)));
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),804,!(map.containsValue(value)));
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),805,!(map.inverseBidiMap().containsValue(key)));
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),806,!(map.inverseBidiMap().containsKey(value)));
    }

    @Test(timeout = 1000)
    public void testBidiRemoveByEntrySet_add451() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemoveByEntrySet_add451");
            if (!(isRemoveSupported())) {
                return ;
            } 
            removeByEntrySet(makeFullMap(), getSampleKeys()[0], getSampleValues()[0]);
            removeByEntrySet(makeFullMap(), getSampleKeys()[0], getSampleValues()[0]);
            removeByEntrySet(makeFullMap().inverseBidiMap(), getSampleValues()[0], getSampleKeys()[0]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiRemoveByEntrySet_add452() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemoveByEntrySet_add452");
            if (!(isRemoveSupported())) {
                return ;
            } 
            removeByEntrySet(makeFullMap(), getSampleKeys()[0], getSampleValues()[0]);
            removeByEntrySet(makeFullMap().inverseBidiMap(), getSampleValues()[0], getSampleKeys()[0]);
            removeByEntrySet(makeFullMap().inverseBidiMap(), getSampleValues()[0], getSampleKeys()[0]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiRemoveByEntrySet() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemoveByEntrySet");
            if (!(isRemoveSupported())) {
                return ;
            } 
            removeByEntrySet(makeFullMap(), getSampleKeys()[1], getSampleValues()[0]);
            removeByEntrySet(makeFullMap().inverseBidiMap(), getSampleValues()[0], getSampleKeys()[0]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiRemoveByEntrySet_literalMutation513() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemoveByEntrySet_literalMutation513");
            if (!(isRemoveSupported())) {
                return ;
            } 
            removeByEntrySet(makeFullMap(), getSampleKeys()[-1], getSampleValues()[0]);
            removeByEntrySet(makeFullMap().inverseBidiMap(), getSampleValues()[0], getSampleKeys()[0]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiRemoveByEntrySet_literalMutation514() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemoveByEntrySet_literalMutation514");
            if (!(isRemoveSupported())) {
                return ;
            } 
            removeByEntrySet(makeFullMap(), getSampleKeys()[0], getSampleValues()[0]);
            removeByEntrySet(makeFullMap().inverseBidiMap(), getSampleValues()[0], getSampleKeys()[0]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiRemoveByEntrySet_literalMutation516() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemoveByEntrySet_literalMutation516");
            if (!(isRemoveSupported())) {
                return ;
            } 
            removeByEntrySet(makeFullMap(), getSampleKeys()[0], getSampleValues()[1]);
            removeByEntrySet(makeFullMap().inverseBidiMap(), getSampleValues()[0], getSampleKeys()[0]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiRemoveByEntrySet_literalMutation517() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemoveByEntrySet_literalMutation517");
            if (!(isRemoveSupported())) {
                return ;
            } 
            removeByEntrySet(makeFullMap(), getSampleKeys()[0], getSampleValues()[-1]);
            removeByEntrySet(makeFullMap().inverseBidiMap(), getSampleValues()[0], getSampleKeys()[0]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiRemoveByEntrySet_literalMutation518() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemoveByEntrySet_literalMutation518");
            if (!(isRemoveSupported())) {
                return ;
            } 
            removeByEntrySet(makeFullMap(), getSampleKeys()[0], getSampleValues()[0]);
            removeByEntrySet(makeFullMap().inverseBidiMap(), getSampleValues()[0], getSampleKeys()[0]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiRemoveByEntrySet_literalMutation520() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemoveByEntrySet_literalMutation520");
            if (!(isRemoveSupported())) {
                return ;
            } 
            removeByEntrySet(makeFullMap(), getSampleKeys()[0], getSampleValues()[0]);
            removeByEntrySet(makeFullMap().inverseBidiMap(), getSampleValues()[1], getSampleKeys()[0]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiRemoveByEntrySet_literalMutation521() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemoveByEntrySet_literalMutation521");
            if (!(isRemoveSupported())) {
                return ;
            } 
            removeByEntrySet(makeFullMap(), getSampleKeys()[0], getSampleValues()[0]);
            removeByEntrySet(makeFullMap().inverseBidiMap(), getSampleValues()[-1], getSampleKeys()[0]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiRemoveByEntrySet_literalMutation522() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemoveByEntrySet_literalMutation522");
            if (!(isRemoveSupported())) {
                return ;
            } 
            removeByEntrySet(makeFullMap(), getSampleKeys()[0], getSampleValues()[0]);
            removeByEntrySet(makeFullMap().inverseBidiMap(), getSampleValues()[0], getSampleKeys()[0]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiRemoveByEntrySet_literalMutation524() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemoveByEntrySet_literalMutation524");
            if (!(isRemoveSupported())) {
                return ;
            } 
            removeByEntrySet(makeFullMap(), getSampleKeys()[0], getSampleValues()[0]);
            removeByEntrySet(makeFullMap().inverseBidiMap(), getSampleValues()[0], getSampleKeys()[1]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiRemoveByEntrySet_literalMutation525() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemoveByEntrySet_literalMutation525");
            if (!(isRemoveSupported())) {
                return ;
            } 
            removeByEntrySet(makeFullMap(), getSampleKeys()[0], getSampleValues()[0]);
            removeByEntrySet(makeFullMap().inverseBidiMap(), getSampleValues()[0], getSampleKeys()[-1]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiRemoveByEntrySet_literalMutation526() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemoveByEntrySet_literalMutation526");
            if (!(isRemoveSupported())) {
                return ;
            } 
            removeByEntrySet(makeFullMap(), getSampleKeys()[0], getSampleValues()[0]);
            removeByEntrySet(makeFullMap().inverseBidiMap(), getSampleValues()[0], getSampleKeys()[0]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiRemoveByEntrySet_remove347() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemoveByEntrySet_remove347");
            if (!(isRemoveSupported())) {
                return ;
            } 
            removeByEntrySet(makeFullMap().inverseBidiMap(), getSampleValues()[0], getSampleKeys()[0]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiRemoveByEntrySet_remove348() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiRemoveByEntrySet_remove348");
            if (!(isRemoveSupported())) {
                return ;
            } 
            removeByEntrySet(makeFullMap().inverseBidiMap(), getSampleValues()[0], getSampleKeys()[0]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    private void removeByEntrySet(final BidiMap<?, ?> map, final Object key, final Object value) {
        final Map<java.lang.Object, java.lang.Object> temp = new HashMap<java.lang.Object, java.lang.Object>();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),802,temp);
        temp.put(key, value);
        map.entrySet().remove(temp.entrySet().iterator().next());
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),798,!(map.containsKey(key)));
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),799,!(map.containsValue(value)));
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),800,!(map.inverseBidiMap().containsValue(key)));
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),801,!(map.inverseBidiMap().containsKey(value)));
    }

    /** 
     * {@inheritDoc}
     */
@Override
    public BidiMap<K, V> getMap() {
        return ((BidiMap<K, V>)(super.getMap()));
    }

    @Override
    public BulkTest bulkTestMapEntrySet() {
        return new TestBidiMapEntrySet();
    }

    public class TestBidiMapEntrySet extends AbstractMapTest<K, V>.TestMapEntrySet {
        public TestBidiMapEntrySet() {
            super();
        }

        @Test(timeout = 1000)
        public void testMapEntrySetIteratorEntrySetValueCrossCheck_add403() {
            try {
                fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapEntrySetIteratorEntrySetValueCrossCheck_add403");
                final K key1 = getSampleKeys()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),774,key1);
                final K key2 = getSampleKeys()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),775,key2);
                final V newValue1 = getNewSampleValues()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),776,newValue1);
                final V newValue2 = getNewSampleValues()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),777,newValue2);
                resetFull();
                resetFull();
                Iterator<java.util.Map.Entry<K, V>> it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),778,it);
                final Map.Entry<K, V> entry1 = getEntry(it, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),779,entry1);
                it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),772,it);
                final Map.Entry<K, V> entry2 = getEntry(it, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),780,entry2);
                Iterator<java.util.Map.Entry<K, V>> itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),781,itConfirmed);
                final Map.Entry<K, V> entryConfirmed1 = getEntry(itConfirmed, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),782,entryConfirmed1);
                itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),773,itConfirmed);
                final Map.Entry<K, V> entryConfirmed2 = getEntry(itConfirmed, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),783,entryConfirmed2);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                if (!(isSetValueSupported())) {
                    try {
                        entry1.setValue(newValue1);
                    } catch (final UnsupportedOperationException ex) {
                    }
                    return ;
                } 
                entry1.setValue(newValue1);
                entryConfirmed1.setValue(newValue1);
                entry2.setValue(newValue2);
                entryConfirmed2.setValue(newValue2);
                try {
                    entry2.setValue(newValue1);
                } catch (final IllegalArgumentException ex) {
                    return ;
                }
                entryConfirmed2.setValue(newValue1);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,entry2.getValue());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().get(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(key1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),771,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue2));
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                it.next();
                if (isRemoveSupported()) {
                    it.remove();
                } 
            } finally {
                fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
            }
        }

        @Test(timeout = 1000)
        public void testMapEntrySetIteratorEntrySetValueCrossCheck_add404() {
            try {
                fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapEntrySetIteratorEntrySetValueCrossCheck_add404");
                final K key1 = getSampleKeys()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),774,key1);
                final K key2 = getSampleKeys()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),775,key2);
                final V newValue1 = getNewSampleValues()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),776,newValue1);
                final V newValue2 = getNewSampleValues()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),777,newValue2);
                resetFull();
                Iterator<java.util.Map.Entry<K, V>> it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),778,it);
                final Map.Entry<K, V> entry1 = getEntry(it, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),779,entry1);
                it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),772,it);
                final Map.Entry<K, V> entry2 = getEntry(it, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),780,entry2);
                Iterator<java.util.Map.Entry<K, V>> itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),781,itConfirmed);
                final Map.Entry<K, V> entryConfirmed1 = getEntry(itConfirmed, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),782,entryConfirmed1);
                itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),773,itConfirmed);
                final Map.Entry<K, V> entryConfirmed2 = getEntry(itConfirmed, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),783,entryConfirmed2);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                if (!(isSetValueSupported())) {
                    try {
                        entry1.setValue(newValue1);
                    } catch (final UnsupportedOperationException ex) {
                    }
                    return ;
                } 
                entry1.setValue(newValue1);
                entryConfirmed1.setValue(newValue1);
                entry2.setValue(newValue2);
                entryConfirmed2.setValue(newValue2);
                try {
                    entry2.setValue(newValue1);
                } catch (final IllegalArgumentException ex) {
                    return ;
                }
                entryConfirmed2.setValue(newValue1);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,entry2.getValue());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().get(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(key1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),771,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue2));
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                it.next();
                if (isRemoveSupported()) {
                    it.remove();
                } 
            } finally {
                fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
            }
        }

        @Test(timeout = 1000)
        public void testMapEntrySetIteratorEntrySetValueCrossCheck_add405() {
            try {
                fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapEntrySetIteratorEntrySetValueCrossCheck_add405");
                final K key1 = getSampleKeys()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),774,key1);
                final K key2 = getSampleKeys()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),775,key2);
                final V newValue1 = getNewSampleValues()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),776,newValue1);
                final V newValue2 = getNewSampleValues()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),777,newValue2);
                resetFull();
                Iterator<java.util.Map.Entry<K, V>> it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),778,it);
                final Map.Entry<K, V> entry1 = getEntry(it, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),779,entry1);
                it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),772,it);
                final Map.Entry<K, V> entry2 = getEntry(it, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),780,entry2);
                Iterator<java.util.Map.Entry<K, V>> itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),781,itConfirmed);
                final Map.Entry<K, V> entryConfirmed1 = getEntry(itConfirmed, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),782,entryConfirmed1);
                itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),773,itConfirmed);
                final Map.Entry<K, V> entryConfirmed2 = getEntry(itConfirmed, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),783,entryConfirmed2);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                if (!(isSetValueSupported())) {
                    try {
                        entry1.setValue(newValue1);
                        entry1.setValue(newValue1);
                    } catch (final UnsupportedOperationException ex) {
                    }
                    return ;
                } 
                entry1.setValue(newValue1);
                entryConfirmed1.setValue(newValue1);
                entry2.setValue(newValue2);
                entryConfirmed2.setValue(newValue2);
                try {
                    entry2.setValue(newValue1);
                } catch (final IllegalArgumentException ex) {
                    return ;
                }
                entryConfirmed2.setValue(newValue1);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,entry2.getValue());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().get(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(key1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),771,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue2));
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                it.next();
                if (isRemoveSupported()) {
                    it.remove();
                } 
            } finally {
                fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
            }
        }

        @Test(timeout = 1000)
        public void testMapEntrySetIteratorEntrySetValueCrossCheck_add406() {
            try {
                fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapEntrySetIteratorEntrySetValueCrossCheck_add406");
                final K key1 = getSampleKeys()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),774,key1);
                final K key2 = getSampleKeys()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),775,key2);
                final V newValue1 = getNewSampleValues()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),776,newValue1);
                final V newValue2 = getNewSampleValues()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),777,newValue2);
                resetFull();
                Iterator<java.util.Map.Entry<K, V>> it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),778,it);
                final Map.Entry<K, V> entry1 = getEntry(it, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),779,entry1);
                it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),772,it);
                final Map.Entry<K, V> entry2 = getEntry(it, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),780,entry2);
                Iterator<java.util.Map.Entry<K, V>> itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),781,itConfirmed);
                final Map.Entry<K, V> entryConfirmed1 = getEntry(itConfirmed, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),782,entryConfirmed1);
                itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),773,itConfirmed);
                final Map.Entry<K, V> entryConfirmed2 = getEntry(itConfirmed, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),783,entryConfirmed2);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                if (!(isSetValueSupported())) {
                    try {
                        entry1.setValue(newValue1);
                    } catch (final UnsupportedOperationException ex) {
                    }
                    return ;
                } 
                entry1.setValue(newValue1);
                entry1.setValue(newValue1);
                entryConfirmed1.setValue(newValue1);
                entry2.setValue(newValue2);
                entryConfirmed2.setValue(newValue2);
                try {
                    entry2.setValue(newValue1);
                } catch (final IllegalArgumentException ex) {
                    return ;
                }
                entryConfirmed2.setValue(newValue1);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,entry2.getValue());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().get(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(key1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),771,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue2));
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                it.next();
                if (isRemoveSupported()) {
                    it.remove();
                } 
            } finally {
                fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
            }
        }

        @Test(timeout = 1000)
        public void testMapEntrySetIteratorEntrySetValueCrossCheck_add407() {
            try {
                fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapEntrySetIteratorEntrySetValueCrossCheck_add407");
                final K key1 = getSampleKeys()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),774,key1);
                final K key2 = getSampleKeys()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),775,key2);
                final V newValue1 = getNewSampleValues()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),776,newValue1);
                final V newValue2 = getNewSampleValues()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),777,newValue2);
                resetFull();
                Iterator<java.util.Map.Entry<K, V>> it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),778,it);
                final Map.Entry<K, V> entry1 = getEntry(it, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),779,entry1);
                it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),772,it);
                final Map.Entry<K, V> entry2 = getEntry(it, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),780,entry2);
                Iterator<java.util.Map.Entry<K, V>> itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),781,itConfirmed);
                final Map.Entry<K, V> entryConfirmed1 = getEntry(itConfirmed, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),782,entryConfirmed1);
                itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),773,itConfirmed);
                final Map.Entry<K, V> entryConfirmed2 = getEntry(itConfirmed, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),783,entryConfirmed2);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                if (!(isSetValueSupported())) {
                    try {
                        entry1.setValue(newValue1);
                    } catch (final UnsupportedOperationException ex) {
                    }
                    return ;
                } 
                entry1.setValue(newValue1);
                entryConfirmed1.setValue(newValue1);
                entryConfirmed1.setValue(newValue1);
                entry2.setValue(newValue2);
                entryConfirmed2.setValue(newValue2);
                try {
                    entry2.setValue(newValue1);
                } catch (final IllegalArgumentException ex) {
                    return ;
                }
                entryConfirmed2.setValue(newValue1);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,entry2.getValue());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().get(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(key1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),771,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue2));
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                it.next();
                if (isRemoveSupported()) {
                    it.remove();
                } 
            } finally {
                fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
            }
        }

        @Test(timeout = 1000)
        public void testMapEntrySetIteratorEntrySetValueCrossCheck_add408() {
            try {
                fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapEntrySetIteratorEntrySetValueCrossCheck_add408");
                final K key1 = getSampleKeys()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),774,key1);
                final K key2 = getSampleKeys()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),775,key2);
                final V newValue1 = getNewSampleValues()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),776,newValue1);
                final V newValue2 = getNewSampleValues()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),777,newValue2);
                resetFull();
                Iterator<java.util.Map.Entry<K, V>> it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),778,it);
                final Map.Entry<K, V> entry1 = getEntry(it, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),779,entry1);
                it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),772,it);
                final Map.Entry<K, V> entry2 = getEntry(it, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),780,entry2);
                Iterator<java.util.Map.Entry<K, V>> itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),781,itConfirmed);
                final Map.Entry<K, V> entryConfirmed1 = getEntry(itConfirmed, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),782,entryConfirmed1);
                itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),773,itConfirmed);
                final Map.Entry<K, V> entryConfirmed2 = getEntry(itConfirmed, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),783,entryConfirmed2);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                if (!(isSetValueSupported())) {
                    try {
                        entry1.setValue(newValue1);
                    } catch (final UnsupportedOperationException ex) {
                    }
                    return ;
                } 
                entry1.setValue(newValue1);
                entryConfirmed1.setValue(newValue1);
                entry2.setValue(newValue2);
                entry2.setValue(newValue2);
                entryConfirmed2.setValue(newValue2);
                try {
                    entry2.setValue(newValue1);
                } catch (final IllegalArgumentException ex) {
                    return ;
                }
                entryConfirmed2.setValue(newValue1);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,entry2.getValue());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().get(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(key1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),771,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue2));
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                it.next();
                if (isRemoveSupported()) {
                    it.remove();
                } 
            } finally {
                fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
            }
        }

        @Test(timeout = 1000)
        public void testMapEntrySetIteratorEntrySetValueCrossCheck_add409() {
            try {
                fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapEntrySetIteratorEntrySetValueCrossCheck_add409");
                final K key1 = getSampleKeys()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),774,key1);
                final K key2 = getSampleKeys()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),775,key2);
                final V newValue1 = getNewSampleValues()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),776,newValue1);
                final V newValue2 = getNewSampleValues()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),777,newValue2);
                resetFull();
                Iterator<java.util.Map.Entry<K, V>> it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),778,it);
                final Map.Entry<K, V> entry1 = getEntry(it, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),779,entry1);
                it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),772,it);
                final Map.Entry<K, V> entry2 = getEntry(it, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),780,entry2);
                Iterator<java.util.Map.Entry<K, V>> itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),781,itConfirmed);
                final Map.Entry<K, V> entryConfirmed1 = getEntry(itConfirmed, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),782,entryConfirmed1);
                itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),773,itConfirmed);
                final Map.Entry<K, V> entryConfirmed2 = getEntry(itConfirmed, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),783,entryConfirmed2);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                if (!(isSetValueSupported())) {
                    try {
                        entry1.setValue(newValue1);
                    } catch (final UnsupportedOperationException ex) {
                    }
                    return ;
                } 
                entry1.setValue(newValue1);
                entryConfirmed1.setValue(newValue1);
                entry2.setValue(newValue2);
                entryConfirmed2.setValue(newValue2);
                entryConfirmed2.setValue(newValue2);
                try {
                    entry2.setValue(newValue1);
                } catch (final IllegalArgumentException ex) {
                    return ;
                }
                entryConfirmed2.setValue(newValue1);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,entry2.getValue());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().get(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(key1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),771,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue2));
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                it.next();
                if (isRemoveSupported()) {
                    it.remove();
                } 
            } finally {
                fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
            }
        }

        @Test(timeout = 1000)
        public void testMapEntrySetIteratorEntrySetValueCrossCheck_add410() {
            try {
                fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapEntrySetIteratorEntrySetValueCrossCheck_add410");
                final K key1 = getSampleKeys()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),774,key1);
                final K key2 = getSampleKeys()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),775,key2);
                final V newValue1 = getNewSampleValues()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),776,newValue1);
                final V newValue2 = getNewSampleValues()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),777,newValue2);
                resetFull();
                Iterator<java.util.Map.Entry<K, V>> it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),778,it);
                final Map.Entry<K, V> entry1 = getEntry(it, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),779,entry1);
                it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),772,it);
                final Map.Entry<K, V> entry2 = getEntry(it, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),780,entry2);
                Iterator<java.util.Map.Entry<K, V>> itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),781,itConfirmed);
                final Map.Entry<K, V> entryConfirmed1 = getEntry(itConfirmed, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),782,entryConfirmed1);
                itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),773,itConfirmed);
                final Map.Entry<K, V> entryConfirmed2 = getEntry(itConfirmed, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),783,entryConfirmed2);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                if (!(isSetValueSupported())) {
                    try {
                        entry1.setValue(newValue1);
                    } catch (final UnsupportedOperationException ex) {
                    }
                    return ;
                } 
                entry1.setValue(newValue1);
                entryConfirmed1.setValue(newValue1);
                entry2.setValue(newValue2);
                entryConfirmed2.setValue(newValue2);
                try {
                    entry2.setValue(newValue1);
                    entry2.setValue(newValue1);
                } catch (final IllegalArgumentException ex) {
                    return ;
                }
                entryConfirmed2.setValue(newValue1);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,entry2.getValue());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().get(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(key1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),771,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue2));
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                it.next();
                if (isRemoveSupported()) {
                    it.remove();
                } 
            } finally {
                fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
            }
        }

        @Test(timeout = 1000)
        public void testMapEntrySetIteratorEntrySetValueCrossCheck_add411() {
            try {
                fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapEntrySetIteratorEntrySetValueCrossCheck_add411");
                final K key1 = getSampleKeys()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),774,key1);
                final K key2 = getSampleKeys()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),775,key2);
                final V newValue1 = getNewSampleValues()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),776,newValue1);
                final V newValue2 = getNewSampleValues()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),777,newValue2);
                resetFull();
                Iterator<java.util.Map.Entry<K, V>> it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),778,it);
                final Map.Entry<K, V> entry1 = getEntry(it, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),779,entry1);
                it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),772,it);
                final Map.Entry<K, V> entry2 = getEntry(it, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),780,entry2);
                Iterator<java.util.Map.Entry<K, V>> itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),781,itConfirmed);
                final Map.Entry<K, V> entryConfirmed1 = getEntry(itConfirmed, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),782,entryConfirmed1);
                itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),773,itConfirmed);
                final Map.Entry<K, V> entryConfirmed2 = getEntry(itConfirmed, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),783,entryConfirmed2);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                if (!(isSetValueSupported())) {
                    try {
                        entry1.setValue(newValue1);
                    } catch (final UnsupportedOperationException ex) {
                    }
                    return ;
                } 
                entry1.setValue(newValue1);
                entryConfirmed1.setValue(newValue1);
                entry2.setValue(newValue2);
                entryConfirmed2.setValue(newValue2);
                try {
                    entry2.setValue(newValue1);
                } catch (final IllegalArgumentException ex) {
                    return ;
                }
                entryConfirmed2.setValue(newValue1);
                entryConfirmed2.setValue(newValue1);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,entry2.getValue());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().get(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(key1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),771,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue2));
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                it.next();
                if (isRemoveSupported()) {
                    it.remove();
                } 
            } finally {
                fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
            }
        }

        @Test(timeout = 1000)
        public void testMapEntrySetIteratorEntrySetValueCrossCheck_add412() {
            try {
                fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapEntrySetIteratorEntrySetValueCrossCheck_add412");
                final K key1 = getSampleKeys()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),774,key1);
                final K key2 = getSampleKeys()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),775,key2);
                final V newValue1 = getNewSampleValues()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),776,newValue1);
                final V newValue2 = getNewSampleValues()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),777,newValue2);
                resetFull();
                Iterator<java.util.Map.Entry<K, V>> it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),778,it);
                final Map.Entry<K, V> entry1 = getEntry(it, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),779,entry1);
                it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),772,it);
                final Map.Entry<K, V> entry2 = getEntry(it, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),780,entry2);
                Iterator<java.util.Map.Entry<K, V>> itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),781,itConfirmed);
                final Map.Entry<K, V> entryConfirmed1 = getEntry(itConfirmed, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),782,entryConfirmed1);
                itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),773,itConfirmed);
                final Map.Entry<K, V> entryConfirmed2 = getEntry(itConfirmed, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),783,entryConfirmed2);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                if (!(isSetValueSupported())) {
                    try {
                        entry1.setValue(newValue1);
                    } catch (final UnsupportedOperationException ex) {
                    }
                    return ;
                } 
                entry1.setValue(newValue1);
                entryConfirmed1.setValue(newValue1);
                entry2.setValue(newValue2);
                entryConfirmed2.setValue(newValue2);
                try {
                    entry2.setValue(newValue1);
                } catch (final IllegalArgumentException ex) {
                    return ;
                }
                entryConfirmed2.setValue(newValue1);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,entry2.getValue());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().get(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(key1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),771,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue2));
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                it.next();
                if (isRemoveSupported()) {
                    it.remove();
                } 
            } finally {
                fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
            }
        }

        @Test(timeout = 1000)
        public void testMapEntrySetIteratorEntrySetValueCrossCheck_add413() {
            try {
                fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapEntrySetIteratorEntrySetValueCrossCheck_add413");
                final K key1 = getSampleKeys()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),774,key1);
                final K key2 = getSampleKeys()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),775,key2);
                final V newValue1 = getNewSampleValues()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),776,newValue1);
                final V newValue2 = getNewSampleValues()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),777,newValue2);
                resetFull();
                Iterator<java.util.Map.Entry<K, V>> it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),778,it);
                final Map.Entry<K, V> entry1 = getEntry(it, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),779,entry1);
                it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),772,it);
                final Map.Entry<K, V> entry2 = getEntry(it, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),780,entry2);
                Iterator<java.util.Map.Entry<K, V>> itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),781,itConfirmed);
                final Map.Entry<K, V> entryConfirmed1 = getEntry(itConfirmed, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),782,entryConfirmed1);
                itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),773,itConfirmed);
                final Map.Entry<K, V> entryConfirmed2 = getEntry(itConfirmed, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),783,entryConfirmed2);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                if (!(isSetValueSupported())) {
                    try {
                        entry1.setValue(newValue1);
                    } catch (final UnsupportedOperationException ex) {
                    }
                    return ;
                } 
                entry1.setValue(newValue1);
                entryConfirmed1.setValue(newValue1);
                entry2.setValue(newValue2);
                entryConfirmed2.setValue(newValue2);
                try {
                    entry2.setValue(newValue1);
                } catch (final IllegalArgumentException ex) {
                    return ;
                }
                entryConfirmed2.setValue(newValue1);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,entry2.getValue());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().get(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(key1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),771,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue2));
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                it.next();
                if (isRemoveSupported()) {
                    it.remove();
                } 
            } finally {
                fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
            }
        }

        @Test(timeout = 1000)
        public void testMapEntrySetIteratorEntrySetValueCrossCheck_add414() {
            try {
                fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapEntrySetIteratorEntrySetValueCrossCheck_add414");
                final K key1 = getSampleKeys()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),774,key1);
                final K key2 = getSampleKeys()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),775,key2);
                final V newValue1 = getNewSampleValues()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),776,newValue1);
                final V newValue2 = getNewSampleValues()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),777,newValue2);
                resetFull();
                Iterator<java.util.Map.Entry<K, V>> it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),778,it);
                final Map.Entry<K, V> entry1 = getEntry(it, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),779,entry1);
                it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),772,it);
                final Map.Entry<K, V> entry2 = getEntry(it, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),780,entry2);
                Iterator<java.util.Map.Entry<K, V>> itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),781,itConfirmed);
                final Map.Entry<K, V> entryConfirmed1 = getEntry(itConfirmed, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),782,entryConfirmed1);
                itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),773,itConfirmed);
                final Map.Entry<K, V> entryConfirmed2 = getEntry(itConfirmed, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),783,entryConfirmed2);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                if (!(isSetValueSupported())) {
                    try {
                        entry1.setValue(newValue1);
                    } catch (final UnsupportedOperationException ex) {
                    }
                    return ;
                } 
                entry1.setValue(newValue1);
                entryConfirmed1.setValue(newValue1);
                entry2.setValue(newValue2);
                entryConfirmed2.setValue(newValue2);
                try {
                    entry2.setValue(newValue1);
                } catch (final IllegalArgumentException ex) {
                    return ;
                }
                entryConfirmed2.setValue(newValue1);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,entry2.getValue());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().get(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(key1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),771,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue2));
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                it.next();
                it.next();
                if (isRemoveSupported()) {
                    it.remove();
                } 
            } finally {
                fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
            }
        }

        @Test(timeout = 1000)
        public void testMapEntrySetIteratorEntrySetValueCrossCheck_add415() {
            try {
                fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapEntrySetIteratorEntrySetValueCrossCheck_add415");
                final K key1 = getSampleKeys()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),774,key1);
                final K key2 = getSampleKeys()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),775,key2);
                final V newValue1 = getNewSampleValues()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),776,newValue1);
                final V newValue2 = getNewSampleValues()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),777,newValue2);
                resetFull();
                Iterator<java.util.Map.Entry<K, V>> it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),778,it);
                final Map.Entry<K, V> entry1 = getEntry(it, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),779,entry1);
                it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),772,it);
                final Map.Entry<K, V> entry2 = getEntry(it, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),780,entry2);
                Iterator<java.util.Map.Entry<K, V>> itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),781,itConfirmed);
                final Map.Entry<K, V> entryConfirmed1 = getEntry(itConfirmed, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),782,entryConfirmed1);
                itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),773,itConfirmed);
                final Map.Entry<K, V> entryConfirmed2 = getEntry(itConfirmed, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),783,entryConfirmed2);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                if (!(isSetValueSupported())) {
                    try {
                        entry1.setValue(newValue1);
                    } catch (final UnsupportedOperationException ex) {
                    }
                    return ;
                } 
                entry1.setValue(newValue1);
                entryConfirmed1.setValue(newValue1);
                entry2.setValue(newValue2);
                entryConfirmed2.setValue(newValue2);
                try {
                    entry2.setValue(newValue1);
                } catch (final IllegalArgumentException ex) {
                    return ;
                }
                entryConfirmed2.setValue(newValue1);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,entry2.getValue());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().get(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(key1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),771,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue2));
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                it.next();
                if (isRemoveSupported()) {
                    it.remove();
                    it.remove();
                } 
            } finally {
                fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
            }
        }

        public void testMapEntrySetIteratorEntrySetValueCrossCheck() {
            try {
                fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapEntrySetIteratorEntrySetValueCrossCheck");
                final K key1 = getSampleKeys()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),774,key1);
                final K key2 = getSampleKeys()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),775,key2);
                final V newValue1 = getNewSampleValues()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),776,newValue1);
                final V newValue2 = getNewSampleValues()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),777,newValue2);
                resetFull();
                Iterator<java.util.Map.Entry<K, V>> it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),778,it);
                final Map.Entry<K, V> entry1 = getEntry(it, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),779,entry1);
                it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),772,it);
                final Map.Entry<K, V> entry2 = getEntry(it, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),780,entry2);
                Iterator<java.util.Map.Entry<K, V>> itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),781,itConfirmed);
                final Map.Entry<K, V> entryConfirmed1 = getEntry(itConfirmed, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),782,entryConfirmed1);
                itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),773,itConfirmed);
                final Map.Entry<K, V> entryConfirmed2 = getEntry(itConfirmed, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),783,entryConfirmed2);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                if (!(isSetValueSupported())) {
                    try {
                        entry1.setValue(newValue1);
                    } catch (final UnsupportedOperationException ex) {
                    }
                    return ;
                } 
                entry1.setValue(newValue1);
                entryConfirmed1.setValue(newValue1);
                entry2.setValue(newValue2);
                entryConfirmed2.setValue(newValue2);
                try {
                    entry2.setValue(newValue1);
                } catch (final IllegalArgumentException ex) {
                    return ;
                }
                entryConfirmed2.setValue(newValue1);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,entry2.getValue());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().get(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(key1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),771,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue2));
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                it.next();
                if (isRemoveSupported()) {
                    it.remove();
                } 
            } finally {
                fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
            }
        }

        public void testMapEntrySetIteratorEntrySetValueCrossCheck_literalMutation446() {
            try {
                fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapEntrySetIteratorEntrySetValueCrossCheck_literalMutation446");
                final K key1 = getSampleKeys()[-1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),774,key1);
                final K key2 = getSampleKeys()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),775,key2);
                final V newValue1 = getNewSampleValues()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),776,newValue1);
                final V newValue2 = getNewSampleValues()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),777,newValue2);
                resetFull();
                Iterator<java.util.Map.Entry<K, V>> it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),778,it);
                final Map.Entry<K, V> entry1 = getEntry(it, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),779,entry1);
                it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),772,it);
                final Map.Entry<K, V> entry2 = getEntry(it, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),780,entry2);
                Iterator<java.util.Map.Entry<K, V>> itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),781,itConfirmed);
                final Map.Entry<K, V> entryConfirmed1 = getEntry(itConfirmed, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),782,entryConfirmed1);
                itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),773,itConfirmed);
                final Map.Entry<K, V> entryConfirmed2 = getEntry(itConfirmed, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),783,entryConfirmed2);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                if (!(isSetValueSupported())) {
                    try {
                        entry1.setValue(newValue1);
                    } catch (final UnsupportedOperationException ex) {
                    }
                    return ;
                } 
                entry1.setValue(newValue1);
                entryConfirmed1.setValue(newValue1);
                entry2.setValue(newValue2);
                entryConfirmed2.setValue(newValue2);
                try {
                    entry2.setValue(newValue1);
                } catch (final IllegalArgumentException ex) {
                    return ;
                }
                entryConfirmed2.setValue(newValue1);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,entry2.getValue());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().get(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(key1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),771,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue2));
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                it.next();
                if (isRemoveSupported()) {
                    it.remove();
                } 
            } finally {
                fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
            }
        }

        public void testMapEntrySetIteratorEntrySetValueCrossCheck_literalMutation447() {
            try {
                fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapEntrySetIteratorEntrySetValueCrossCheck_literalMutation447");
                final K key1 = getSampleKeys()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),774,key1);
                final K key2 = getSampleKeys()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),775,key2);
                final V newValue1 = getNewSampleValues()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),776,newValue1);
                final V newValue2 = getNewSampleValues()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),777,newValue2);
                resetFull();
                Iterator<java.util.Map.Entry<K, V>> it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),778,it);
                final Map.Entry<K, V> entry1 = getEntry(it, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),779,entry1);
                it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),772,it);
                final Map.Entry<K, V> entry2 = getEntry(it, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),780,entry2);
                Iterator<java.util.Map.Entry<K, V>> itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),781,itConfirmed);
                final Map.Entry<K, V> entryConfirmed1 = getEntry(itConfirmed, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),782,entryConfirmed1);
                itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),773,itConfirmed);
                final Map.Entry<K, V> entryConfirmed2 = getEntry(itConfirmed, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),783,entryConfirmed2);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                if (!(isSetValueSupported())) {
                    try {
                        entry1.setValue(newValue1);
                    } catch (final UnsupportedOperationException ex) {
                    }
                    return ;
                } 
                entry1.setValue(newValue1);
                entryConfirmed1.setValue(newValue1);
                entry2.setValue(newValue2);
                entryConfirmed2.setValue(newValue2);
                try {
                    entry2.setValue(newValue1);
                } catch (final IllegalArgumentException ex) {
                    return ;
                }
                entryConfirmed2.setValue(newValue1);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,entry2.getValue());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().get(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(key1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),771,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue2));
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                it.next();
                if (isRemoveSupported()) {
                    it.remove();
                } 
            } finally {
                fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
            }
        }

        public void testMapEntrySetIteratorEntrySetValueCrossCheck_literalMutation449() {
            try {
                fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapEntrySetIteratorEntrySetValueCrossCheck_literalMutation449");
                final K key1 = getSampleKeys()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),774,key1);
                final K key2 = getSampleKeys()[2];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),775,key2);
                final V newValue1 = getNewSampleValues()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),776,newValue1);
                final V newValue2 = getNewSampleValues()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),777,newValue2);
                resetFull();
                Iterator<java.util.Map.Entry<K, V>> it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),778,it);
                final Map.Entry<K, V> entry1 = getEntry(it, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),779,entry1);
                it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),772,it);
                final Map.Entry<K, V> entry2 = getEntry(it, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),780,entry2);
                Iterator<java.util.Map.Entry<K, V>> itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),781,itConfirmed);
                final Map.Entry<K, V> entryConfirmed1 = getEntry(itConfirmed, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),782,entryConfirmed1);
                itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),773,itConfirmed);
                final Map.Entry<K, V> entryConfirmed2 = getEntry(itConfirmed, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),783,entryConfirmed2);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                if (!(isSetValueSupported())) {
                    try {
                        entry1.setValue(newValue1);
                    } catch (final UnsupportedOperationException ex) {
                    }
                    return ;
                } 
                entry1.setValue(newValue1);
                entryConfirmed1.setValue(newValue1);
                entry2.setValue(newValue2);
                entryConfirmed2.setValue(newValue2);
                try {
                    entry2.setValue(newValue1);
                } catch (final IllegalArgumentException ex) {
                    return ;
                }
                entryConfirmed2.setValue(newValue1);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,entry2.getValue());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().get(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(key1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),771,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue2));
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                it.next();
                if (isRemoveSupported()) {
                    it.remove();
                } 
            } finally {
                fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
            }
        }

        public void testMapEntrySetIteratorEntrySetValueCrossCheck_literalMutation450() {
            try {
                fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapEntrySetIteratorEntrySetValueCrossCheck_literalMutation450");
                final K key1 = getSampleKeys()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),774,key1);
                final K key2 = getSampleKeys()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),775,key2);
                final V newValue1 = getNewSampleValues()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),776,newValue1);
                final V newValue2 = getNewSampleValues()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),777,newValue2);
                resetFull();
                Iterator<java.util.Map.Entry<K, V>> it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),778,it);
                final Map.Entry<K, V> entry1 = getEntry(it, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),779,entry1);
                it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),772,it);
                final Map.Entry<K, V> entry2 = getEntry(it, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),780,entry2);
                Iterator<java.util.Map.Entry<K, V>> itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),781,itConfirmed);
                final Map.Entry<K, V> entryConfirmed1 = getEntry(itConfirmed, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),782,entryConfirmed1);
                itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),773,itConfirmed);
                final Map.Entry<K, V> entryConfirmed2 = getEntry(itConfirmed, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),783,entryConfirmed2);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                if (!(isSetValueSupported())) {
                    try {
                        entry1.setValue(newValue1);
                    } catch (final UnsupportedOperationException ex) {
                    }
                    return ;
                } 
                entry1.setValue(newValue1);
                entryConfirmed1.setValue(newValue1);
                entry2.setValue(newValue2);
                entryConfirmed2.setValue(newValue2);
                try {
                    entry2.setValue(newValue1);
                } catch (final IllegalArgumentException ex) {
                    return ;
                }
                entryConfirmed2.setValue(newValue1);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,entry2.getValue());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().get(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(key1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),771,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue2));
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                it.next();
                if (isRemoveSupported()) {
                    it.remove();
                } 
            } finally {
                fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
            }
        }

        public void testMapEntrySetIteratorEntrySetValueCrossCheck_literalMutation451() {
            try {
                fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapEntrySetIteratorEntrySetValueCrossCheck_literalMutation451");
                final K key1 = getSampleKeys()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),774,key1);
                final K key2 = getSampleKeys()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),775,key2);
                final V newValue1 = getNewSampleValues()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),776,newValue1);
                final V newValue2 = getNewSampleValues()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),777,newValue2);
                resetFull();
                Iterator<java.util.Map.Entry<K, V>> it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),778,it);
                final Map.Entry<K, V> entry1 = getEntry(it, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),779,entry1);
                it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),772,it);
                final Map.Entry<K, V> entry2 = getEntry(it, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),780,entry2);
                Iterator<java.util.Map.Entry<K, V>> itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),781,itConfirmed);
                final Map.Entry<K, V> entryConfirmed1 = getEntry(itConfirmed, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),782,entryConfirmed1);
                itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),773,itConfirmed);
                final Map.Entry<K, V> entryConfirmed2 = getEntry(itConfirmed, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),783,entryConfirmed2);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                if (!(isSetValueSupported())) {
                    try {
                        entry1.setValue(newValue1);
                    } catch (final UnsupportedOperationException ex) {
                    }
                    return ;
                } 
                entry1.setValue(newValue1);
                entryConfirmed1.setValue(newValue1);
                entry2.setValue(newValue2);
                entryConfirmed2.setValue(newValue2);
                try {
                    entry2.setValue(newValue1);
                } catch (final IllegalArgumentException ex) {
                    return ;
                }
                entryConfirmed2.setValue(newValue1);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,entry2.getValue());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().get(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(key1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),771,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue2));
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                it.next();
                if (isRemoveSupported()) {
                    it.remove();
                } 
            } finally {
                fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
            }
        }

        public void testMapEntrySetIteratorEntrySetValueCrossCheck_literalMutation453() {
            try {
                fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapEntrySetIteratorEntrySetValueCrossCheck_literalMutation453");
                final K key1 = getSampleKeys()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),774,key1);
                final K key2 = getSampleKeys()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),775,key2);
                final V newValue1 = getNewSampleValues()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),776,newValue1);
                final V newValue2 = getNewSampleValues()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),777,newValue2);
                resetFull();
                Iterator<java.util.Map.Entry<K, V>> it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),778,it);
                final Map.Entry<K, V> entry1 = getEntry(it, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),779,entry1);
                it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),772,it);
                final Map.Entry<K, V> entry2 = getEntry(it, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),780,entry2);
                Iterator<java.util.Map.Entry<K, V>> itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),781,itConfirmed);
                final Map.Entry<K, V> entryConfirmed1 = getEntry(itConfirmed, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),782,entryConfirmed1);
                itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),773,itConfirmed);
                final Map.Entry<K, V> entryConfirmed2 = getEntry(itConfirmed, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),783,entryConfirmed2);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                if (!(isSetValueSupported())) {
                    try {
                        entry1.setValue(newValue1);
                    } catch (final UnsupportedOperationException ex) {
                    }
                    return ;
                } 
                entry1.setValue(newValue1);
                entryConfirmed1.setValue(newValue1);
                entry2.setValue(newValue2);
                entryConfirmed2.setValue(newValue2);
                try {
                    entry2.setValue(newValue1);
                } catch (final IllegalArgumentException ex) {
                    return ;
                }
                entryConfirmed2.setValue(newValue1);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,entry2.getValue());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().get(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(key1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),771,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue2));
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                it.next();
                if (isRemoveSupported()) {
                    it.remove();
                } 
            } finally {
                fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
            }
        }

        public void testMapEntrySetIteratorEntrySetValueCrossCheck_literalMutation454() {
            try {
                fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapEntrySetIteratorEntrySetValueCrossCheck_literalMutation454");
                final K key1 = getSampleKeys()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),774,key1);
                final K key2 = getSampleKeys()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),775,key2);
                final V newValue1 = getNewSampleValues()[-1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),776,newValue1);
                final V newValue2 = getNewSampleValues()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),777,newValue2);
                resetFull();
                Iterator<java.util.Map.Entry<K, V>> it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),778,it);
                final Map.Entry<K, V> entry1 = getEntry(it, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),779,entry1);
                it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),772,it);
                final Map.Entry<K, V> entry2 = getEntry(it, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),780,entry2);
                Iterator<java.util.Map.Entry<K, V>> itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),781,itConfirmed);
                final Map.Entry<K, V> entryConfirmed1 = getEntry(itConfirmed, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),782,entryConfirmed1);
                itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),773,itConfirmed);
                final Map.Entry<K, V> entryConfirmed2 = getEntry(itConfirmed, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),783,entryConfirmed2);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                if (!(isSetValueSupported())) {
                    try {
                        entry1.setValue(newValue1);
                    } catch (final UnsupportedOperationException ex) {
                    }
                    return ;
                } 
                entry1.setValue(newValue1);
                entryConfirmed1.setValue(newValue1);
                entry2.setValue(newValue2);
                entryConfirmed2.setValue(newValue2);
                try {
                    entry2.setValue(newValue1);
                } catch (final IllegalArgumentException ex) {
                    return ;
                }
                entryConfirmed2.setValue(newValue1);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,entry2.getValue());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().get(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(key1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),771,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue2));
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                it.next();
                if (isRemoveSupported()) {
                    it.remove();
                } 
            } finally {
                fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
            }
        }

        public void testMapEntrySetIteratorEntrySetValueCrossCheck_literalMutation455() {
            try {
                fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapEntrySetIteratorEntrySetValueCrossCheck_literalMutation455");
                final K key1 = getSampleKeys()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),774,key1);
                final K key2 = getSampleKeys()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),775,key2);
                final V newValue1 = getNewSampleValues()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),776,newValue1);
                final V newValue2 = getNewSampleValues()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),777,newValue2);
                resetFull();
                Iterator<java.util.Map.Entry<K, V>> it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),778,it);
                final Map.Entry<K, V> entry1 = getEntry(it, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),779,entry1);
                it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),772,it);
                final Map.Entry<K, V> entry2 = getEntry(it, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),780,entry2);
                Iterator<java.util.Map.Entry<K, V>> itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),781,itConfirmed);
                final Map.Entry<K, V> entryConfirmed1 = getEntry(itConfirmed, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),782,entryConfirmed1);
                itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),773,itConfirmed);
                final Map.Entry<K, V> entryConfirmed2 = getEntry(itConfirmed, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),783,entryConfirmed2);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                if (!(isSetValueSupported())) {
                    try {
                        entry1.setValue(newValue1);
                    } catch (final UnsupportedOperationException ex) {
                    }
                    return ;
                } 
                entry1.setValue(newValue1);
                entryConfirmed1.setValue(newValue1);
                entry2.setValue(newValue2);
                entryConfirmed2.setValue(newValue2);
                try {
                    entry2.setValue(newValue1);
                } catch (final IllegalArgumentException ex) {
                    return ;
                }
                entryConfirmed2.setValue(newValue1);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,entry2.getValue());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().get(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(key1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),771,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue2));
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                it.next();
                if (isRemoveSupported()) {
                    it.remove();
                } 
            } finally {
                fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
            }
        }

        public void testMapEntrySetIteratorEntrySetValueCrossCheck_literalMutation457() {
            try {
                fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapEntrySetIteratorEntrySetValueCrossCheck_literalMutation457");
                final K key1 = getSampleKeys()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),774,key1);
                final K key2 = getSampleKeys()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),775,key2);
                final V newValue1 = getNewSampleValues()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),776,newValue1);
                final V newValue2 = getNewSampleValues()[2];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),777,newValue2);
                resetFull();
                Iterator<java.util.Map.Entry<K, V>> it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),778,it);
                final Map.Entry<K, V> entry1 = getEntry(it, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),779,entry1);
                it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),772,it);
                final Map.Entry<K, V> entry2 = getEntry(it, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),780,entry2);
                Iterator<java.util.Map.Entry<K, V>> itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),781,itConfirmed);
                final Map.Entry<K, V> entryConfirmed1 = getEntry(itConfirmed, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),782,entryConfirmed1);
                itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),773,itConfirmed);
                final Map.Entry<K, V> entryConfirmed2 = getEntry(itConfirmed, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),783,entryConfirmed2);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                if (!(isSetValueSupported())) {
                    try {
                        entry1.setValue(newValue1);
                    } catch (final UnsupportedOperationException ex) {
                    }
                    return ;
                } 
                entry1.setValue(newValue1);
                entryConfirmed1.setValue(newValue1);
                entry2.setValue(newValue2);
                entryConfirmed2.setValue(newValue2);
                try {
                    entry2.setValue(newValue1);
                } catch (final IllegalArgumentException ex) {
                    return ;
                }
                entryConfirmed2.setValue(newValue1);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,entry2.getValue());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().get(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(key1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),771,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue2));
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                it.next();
                if (isRemoveSupported()) {
                    it.remove();
                } 
            } finally {
                fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
            }
        }

        public void testMapEntrySetIteratorEntrySetValueCrossCheck_literalMutation458() {
            try {
                fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapEntrySetIteratorEntrySetValueCrossCheck_literalMutation458");
                final K key1 = getSampleKeys()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),774,key1);
                final K key2 = getSampleKeys()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),775,key2);
                final V newValue1 = getNewSampleValues()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),776,newValue1);
                final V newValue2 = getNewSampleValues()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),777,newValue2);
                resetFull();
                Iterator<java.util.Map.Entry<K, V>> it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),778,it);
                final Map.Entry<K, V> entry1 = getEntry(it, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),779,entry1);
                it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),772,it);
                final Map.Entry<K, V> entry2 = getEntry(it, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),780,entry2);
                Iterator<java.util.Map.Entry<K, V>> itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),781,itConfirmed);
                final Map.Entry<K, V> entryConfirmed1 = getEntry(itConfirmed, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),782,entryConfirmed1);
                itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),773,itConfirmed);
                final Map.Entry<K, V> entryConfirmed2 = getEntry(itConfirmed, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),783,entryConfirmed2);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                if (!(isSetValueSupported())) {
                    try {
                        entry1.setValue(newValue1);
                    } catch (final UnsupportedOperationException ex) {
                    }
                    return ;
                } 
                entry1.setValue(newValue1);
                entryConfirmed1.setValue(newValue1);
                entry2.setValue(newValue2);
                entryConfirmed2.setValue(newValue2);
                try {
                    entry2.setValue(newValue1);
                } catch (final IllegalArgumentException ex) {
                    return ;
                }
                entryConfirmed2.setValue(newValue1);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,entry2.getValue());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().get(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(key1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),771,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue2));
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                it.next();
                if (isRemoveSupported()) {
                    it.remove();
                } 
            } finally {
                fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
            }
        }

        public void testMapEntrySetIteratorEntrySetValueCrossCheck_literalMutation459() {
            try {
                fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapEntrySetIteratorEntrySetValueCrossCheck_literalMutation459");
                final K key1 = getSampleKeys()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),774,key1);
                final K key2 = getSampleKeys()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),775,key2);
                final V newValue1 = getNewSampleValues()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),776,newValue1);
                final V newValue2 = getNewSampleValues()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),777,newValue2);
                resetFull();
                Iterator<java.util.Map.Entry<K, V>> it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),778,it);
                final Map.Entry<K, V> entry1 = getEntry(it, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),779,entry1);
                it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),772,it);
                final Map.Entry<K, V> entry2 = getEntry(it, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),780,entry2);
                Iterator<java.util.Map.Entry<K, V>> itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),781,itConfirmed);
                final Map.Entry<K, V> entryConfirmed1 = getEntry(itConfirmed, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),782,entryConfirmed1);
                itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),773,itConfirmed);
                final Map.Entry<K, V> entryConfirmed2 = getEntry(itConfirmed, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),783,entryConfirmed2);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                if (!(isSetValueSupported())) {
                    try {
                        entry1.setValue(newValue1);
                    } catch (final UnsupportedOperationException ex) {
                    }
                    return ;
                } 
                entry1.setValue(newValue1);
                entryConfirmed1.setValue(newValue1);
                entry2.setValue(newValue2);
                entryConfirmed2.setValue(newValue2);
                try {
                    entry2.setValue(newValue1);
                } catch (final IllegalArgumentException ex) {
                    return ;
                }
                entryConfirmed2.setValue(newValue1);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,entry2.getValue());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().get(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(key1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),771,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue2));
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                it.next();
                if (isRemoveSupported()) {
                    it.remove();
                } 
            } finally {
                fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
            }
        }

        @Test(timeout = 1000)
        public void testMapEntrySetIteratorEntrySetValueCrossCheck_remove308() {
            try {
                fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapEntrySetIteratorEntrySetValueCrossCheck_remove308");
                final K key1 = getSampleKeys()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),774,key1);
                final K key2 = getSampleKeys()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),775,key2);
                final V newValue1 = getNewSampleValues()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),776,newValue1);
                final V newValue2 = getNewSampleValues()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),777,newValue2);
                Iterator<java.util.Map.Entry<K, V>> it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),778,it);
                final Map.Entry<K, V> entry1 = getEntry(it, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),779,entry1);
                it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),772,it);
                final Map.Entry<K, V> entry2 = getEntry(it, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),780,entry2);
                Iterator<java.util.Map.Entry<K, V>> itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),781,itConfirmed);
                final Map.Entry<K, V> entryConfirmed1 = getEntry(itConfirmed, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),782,entryConfirmed1);
                itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),773,itConfirmed);
                final Map.Entry<K, V> entryConfirmed2 = getEntry(itConfirmed, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),783,entryConfirmed2);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                if (!(isSetValueSupported())) {
                    try {
                        entry1.setValue(newValue1);
                    } catch (final UnsupportedOperationException ex) {
                    }
                    return ;
                } 
                entry1.setValue(newValue1);
                entryConfirmed1.setValue(newValue1);
                entry2.setValue(newValue2);
                entryConfirmed2.setValue(newValue2);
                try {
                    entry2.setValue(newValue1);
                } catch (final IllegalArgumentException ex) {
                    return ;
                }
                entryConfirmed2.setValue(newValue1);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,entry2.getValue());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().get(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(key1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),771,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue2));
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                it.next();
                if (isRemoveSupported()) {
                    it.remove();
                } 
            } finally {
                fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
            }
        }

        @Test(timeout = 1000)
        public void testMapEntrySetIteratorEntrySetValueCrossCheck_remove309() {
            try {
                fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapEntrySetIteratorEntrySetValueCrossCheck_remove309");
                final K key1 = getSampleKeys()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),774,key1);
                final K key2 = getSampleKeys()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),775,key2);
                final V newValue1 = getNewSampleValues()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),776,newValue1);
                final V newValue2 = getNewSampleValues()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),777,newValue2);
                resetFull();
                Iterator<java.util.Map.Entry<K, V>> it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),778,it);
                final Map.Entry<K, V> entry1 = getEntry(it, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),779,entry1);
                it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),772,it);
                final Map.Entry<K, V> entry2 = getEntry(it, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),780,entry2);
                Iterator<java.util.Map.Entry<K, V>> itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),781,itConfirmed);
                final Map.Entry<K, V> entryConfirmed1 = getEntry(itConfirmed, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),782,entryConfirmed1);
                itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),773,itConfirmed);
                final Map.Entry<K, V> entryConfirmed2 = getEntry(itConfirmed, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),783,entryConfirmed2);
                if (!(isSetValueSupported())) {
                    try {
                        entry1.setValue(newValue1);
                    } catch (final UnsupportedOperationException ex) {
                    }
                    return ;
                } 
                entry1.setValue(newValue1);
                entryConfirmed1.setValue(newValue1);
                entry2.setValue(newValue2);
                entryConfirmed2.setValue(newValue2);
                try {
                    entry2.setValue(newValue1);
                } catch (final IllegalArgumentException ex) {
                    return ;
                }
                entryConfirmed2.setValue(newValue1);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,entry2.getValue());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().get(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(key1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),771,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue2));
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                it.next();
                if (isRemoveSupported()) {
                    it.remove();
                } 
            } finally {
                fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
            }
        }

        @Test(timeout = 1000)
        public void testMapEntrySetIteratorEntrySetValueCrossCheck_remove310() {
            try {
                fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapEntrySetIteratorEntrySetValueCrossCheck_remove310");
                final K key1 = getSampleKeys()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),774,key1);
                final K key2 = getSampleKeys()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),775,key2);
                final V newValue1 = getNewSampleValues()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),776,newValue1);
                final V newValue2 = getNewSampleValues()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),777,newValue2);
                resetFull();
                Iterator<java.util.Map.Entry<K, V>> it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),778,it);
                final Map.Entry<K, V> entry1 = getEntry(it, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),779,entry1);
                it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),772,it);
                final Map.Entry<K, V> entry2 = getEntry(it, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),780,entry2);
                Iterator<java.util.Map.Entry<K, V>> itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),781,itConfirmed);
                final Map.Entry<K, V> entryConfirmed1 = getEntry(itConfirmed, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),782,entryConfirmed1);
                itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),773,itConfirmed);
                final Map.Entry<K, V> entryConfirmed2 = getEntry(itConfirmed, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),783,entryConfirmed2);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                if (!(isSetValueSupported())) {
                    try {
                        entry1.setValue(newValue1);
                    } catch (final UnsupportedOperationException ex) {
                    }
                    return ;
                } 
                entryConfirmed1.setValue(newValue1);
                entry2.setValue(newValue2);
                entryConfirmed2.setValue(newValue2);
                try {
                    entry2.setValue(newValue1);
                } catch (final IllegalArgumentException ex) {
                    return ;
                }
                entryConfirmed2.setValue(newValue1);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,entry2.getValue());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().get(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(key1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),771,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue2));
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                it.next();
                if (isRemoveSupported()) {
                    it.remove();
                } 
            } finally {
                fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
            }
        }

        @Test(timeout = 1000)
        public void testMapEntrySetIteratorEntrySetValueCrossCheck_remove311() {
            try {
                fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapEntrySetIteratorEntrySetValueCrossCheck_remove311");
                final K key1 = getSampleKeys()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),774,key1);
                final K key2 = getSampleKeys()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),775,key2);
                final V newValue1 = getNewSampleValues()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),776,newValue1);
                final V newValue2 = getNewSampleValues()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),777,newValue2);
                resetFull();
                Iterator<java.util.Map.Entry<K, V>> it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),778,it);
                final Map.Entry<K, V> entry1 = getEntry(it, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),779,entry1);
                it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),772,it);
                final Map.Entry<K, V> entry2 = getEntry(it, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),780,entry2);
                Iterator<java.util.Map.Entry<K, V>> itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),781,itConfirmed);
                final Map.Entry<K, V> entryConfirmed1 = getEntry(itConfirmed, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),782,entryConfirmed1);
                itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),773,itConfirmed);
                final Map.Entry<K, V> entryConfirmed2 = getEntry(itConfirmed, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),783,entryConfirmed2);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                if (!(isSetValueSupported())) {
                    try {
                        entry1.setValue(newValue1);
                    } catch (final UnsupportedOperationException ex) {
                    }
                    return ;
                } 
                entryConfirmed1.setValue(newValue1);
                entry2.setValue(newValue2);
                entryConfirmed2.setValue(newValue2);
                try {
                    entry2.setValue(newValue1);
                } catch (final IllegalArgumentException ex) {
                    return ;
                }
                entryConfirmed2.setValue(newValue1);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,entry2.getValue());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().get(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(key1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),771,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue2));
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                it.next();
                if (isRemoveSupported()) {
                    it.remove();
                } 
            } finally {
                fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
            }
        }

        @Test(timeout = 1000)
        public void testMapEntrySetIteratorEntrySetValueCrossCheck_remove312() {
            try {
                fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapEntrySetIteratorEntrySetValueCrossCheck_remove312");
                final K key1 = getSampleKeys()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),774,key1);
                final K key2 = getSampleKeys()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),775,key2);
                final V newValue1 = getNewSampleValues()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),776,newValue1);
                final V newValue2 = getNewSampleValues()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),777,newValue2);
                resetFull();
                Iterator<java.util.Map.Entry<K, V>> it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),778,it);
                final Map.Entry<K, V> entry1 = getEntry(it, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),779,entry1);
                it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),772,it);
                final Map.Entry<K, V> entry2 = getEntry(it, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),780,entry2);
                Iterator<java.util.Map.Entry<K, V>> itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),781,itConfirmed);
                final Map.Entry<K, V> entryConfirmed1 = getEntry(itConfirmed, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),782,entryConfirmed1);
                itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),773,itConfirmed);
                final Map.Entry<K, V> entryConfirmed2 = getEntry(itConfirmed, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),783,entryConfirmed2);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                if (!(isSetValueSupported())) {
                    try {
                        entry1.setValue(newValue1);
                    } catch (final UnsupportedOperationException ex) {
                    }
                    return ;
                } 
                entryConfirmed1.setValue(newValue1);
                entry2.setValue(newValue2);
                entryConfirmed2.setValue(newValue2);
                try {
                    entry2.setValue(newValue1);
                } catch (final IllegalArgumentException ex) {
                    return ;
                }
                entryConfirmed2.setValue(newValue1);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,entry2.getValue());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().get(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(key1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),771,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue2));
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                it.next();
                if (isRemoveSupported()) {
                    it.remove();
                } 
            } finally {
                fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
            }
        }

        @Test(timeout = 1000)
        public void testMapEntrySetIteratorEntrySetValueCrossCheck_remove313() {
            try {
                fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapEntrySetIteratorEntrySetValueCrossCheck_remove313");
                final K key1 = getSampleKeys()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),774,key1);
                final K key2 = getSampleKeys()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),775,key2);
                final V newValue1 = getNewSampleValues()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),776,newValue1);
                final V newValue2 = getNewSampleValues()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),777,newValue2);
                resetFull();
                Iterator<java.util.Map.Entry<K, V>> it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),778,it);
                final Map.Entry<K, V> entry1 = getEntry(it, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),779,entry1);
                it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),772,it);
                final Map.Entry<K, V> entry2 = getEntry(it, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),780,entry2);
                Iterator<java.util.Map.Entry<K, V>> itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),781,itConfirmed);
                final Map.Entry<K, V> entryConfirmed1 = getEntry(itConfirmed, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),782,entryConfirmed1);
                itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),773,itConfirmed);
                final Map.Entry<K, V> entryConfirmed2 = getEntry(itConfirmed, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),783,entryConfirmed2);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                if (!(isSetValueSupported())) {
                    try {
                        entry1.setValue(newValue1);
                    } catch (final UnsupportedOperationException ex) {
                    }
                    return ;
                } 
                entryConfirmed1.setValue(newValue1);
                entry2.setValue(newValue2);
                entryConfirmed2.setValue(newValue2);
                try {
                    entry2.setValue(newValue1);
                } catch (final IllegalArgumentException ex) {
                    return ;
                }
                entryConfirmed2.setValue(newValue1);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,entry2.getValue());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().get(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(key1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),771,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue2));
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                it.next();
                if (isRemoveSupported()) {
                    it.remove();
                } 
            } finally {
                fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
            }
        }

        @Test(timeout = 1000)
        public void testMapEntrySetIteratorEntrySetValueCrossCheck_remove314() {
            try {
                fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapEntrySetIteratorEntrySetValueCrossCheck_remove314");
                final K key1 = getSampleKeys()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),774,key1);
                final K key2 = getSampleKeys()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),775,key2);
                final V newValue1 = getNewSampleValues()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),776,newValue1);
                final V newValue2 = getNewSampleValues()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),777,newValue2);
                resetFull();
                Iterator<java.util.Map.Entry<K, V>> it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),778,it);
                final Map.Entry<K, V> entry1 = getEntry(it, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),779,entry1);
                it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),772,it);
                final Map.Entry<K, V> entry2 = getEntry(it, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),780,entry2);
                Iterator<java.util.Map.Entry<K, V>> itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),781,itConfirmed);
                final Map.Entry<K, V> entryConfirmed1 = getEntry(itConfirmed, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),782,entryConfirmed1);
                itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),773,itConfirmed);
                final Map.Entry<K, V> entryConfirmed2 = getEntry(itConfirmed, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),783,entryConfirmed2);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                if (!(isSetValueSupported())) {
                    try {
                        entry1.setValue(newValue1);
                    } catch (final UnsupportedOperationException ex) {
                    }
                    return ;
                } 
                entryConfirmed1.setValue(newValue1);
                entry2.setValue(newValue2);
                entryConfirmed2.setValue(newValue2);
                try {
                    entry2.setValue(newValue1);
                } catch (final IllegalArgumentException ex) {
                    return ;
                }
                entryConfirmed2.setValue(newValue1);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,entry2.getValue());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().get(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(key1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),771,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue2));
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                it.next();
                if (isRemoveSupported()) {
                    it.remove();
                } 
            } finally {
                fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
            }
        }

        @Test(timeout = 1000)
        public void testMapEntrySetIteratorEntrySetValueCrossCheck_remove315() {
            try {
                fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapEntrySetIteratorEntrySetValueCrossCheck_remove315");
                final K key1 = getSampleKeys()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),774,key1);
                final K key2 = getSampleKeys()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),775,key2);
                final V newValue1 = getNewSampleValues()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),776,newValue1);
                final V newValue2 = getNewSampleValues()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),777,newValue2);
                resetFull();
                Iterator<java.util.Map.Entry<K, V>> it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),778,it);
                final Map.Entry<K, V> entry1 = getEntry(it, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),779,entry1);
                it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),772,it);
                final Map.Entry<K, V> entry2 = getEntry(it, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),780,entry2);
                Iterator<java.util.Map.Entry<K, V>> itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),781,itConfirmed);
                final Map.Entry<K, V> entryConfirmed1 = getEntry(itConfirmed, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),782,entryConfirmed1);
                itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),773,itConfirmed);
                final Map.Entry<K, V> entryConfirmed2 = getEntry(itConfirmed, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),783,entryConfirmed2);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                if (!(isSetValueSupported())) {
                    try {
                        entry1.setValue(newValue1);
                    } catch (final UnsupportedOperationException ex) {
                    }
                    return ;
                } 
                entry1.setValue(newValue1);
                entryConfirmed1.setValue(newValue1);
                entry2.setValue(newValue2);
                entryConfirmed2.setValue(newValue2);
                try {
                    entry2.setValue(newValue1);
                } catch (final IllegalArgumentException ex) {
                    return ;
                }
                entryConfirmed2.setValue(newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,entry2.getValue());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().get(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(key1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),771,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue2));
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                it.next();
                if (isRemoveSupported()) {
                    it.remove();
                } 
            } finally {
                fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
            }
        }

        @Test(timeout = 1000)
        public void testMapEntrySetIteratorEntrySetValueCrossCheck_remove316() {
            try {
                fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapEntrySetIteratorEntrySetValueCrossCheck_remove316");
                final K key1 = getSampleKeys()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),774,key1);
                final K key2 = getSampleKeys()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),775,key2);
                final V newValue1 = getNewSampleValues()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),776,newValue1);
                final V newValue2 = getNewSampleValues()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),777,newValue2);
                resetFull();
                Iterator<java.util.Map.Entry<K, V>> it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),778,it);
                final Map.Entry<K, V> entry1 = getEntry(it, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),779,entry1);
                it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),772,it);
                final Map.Entry<K, V> entry2 = getEntry(it, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),780,entry2);
                Iterator<java.util.Map.Entry<K, V>> itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),781,itConfirmed);
                final Map.Entry<K, V> entryConfirmed1 = getEntry(itConfirmed, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),782,entryConfirmed1);
                itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),773,itConfirmed);
                final Map.Entry<K, V> entryConfirmed2 = getEntry(itConfirmed, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),783,entryConfirmed2);
                if (!(isSetValueSupported())) {
                    try {
                        entry1.setValue(newValue1);
                    } catch (final UnsupportedOperationException ex) {
                    }
                    return ;
                } 
                entry1.setValue(newValue1);
                entryConfirmed1.setValue(newValue1);
                entry2.setValue(newValue2);
                entryConfirmed2.setValue(newValue2);
                try {
                    entry2.setValue(newValue1);
                } catch (final IllegalArgumentException ex) {
                    return ;
                }
                entryConfirmed2.setValue(newValue1);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,entry2.getValue());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().get(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(key1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),771,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue2));
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                it.next();
                if (isRemoveSupported()) {
                    it.remove();
                } 
            } finally {
                fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
            }
        }

        @Test(timeout = 1000)
        public void testMapEntrySetIteratorEntrySetValueCrossCheck_remove317() {
            try {
                fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapEntrySetIteratorEntrySetValueCrossCheck_remove317");
                final K key1 = getSampleKeys()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),774,key1);
                final K key2 = getSampleKeys()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),775,key2);
                final V newValue1 = getNewSampleValues()[0];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),776,newValue1);
                final V newValue2 = getNewSampleValues()[1];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),777,newValue2);
                resetFull();
                Iterator<java.util.Map.Entry<K, V>> it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),778,it);
                final Map.Entry<K, V> entry1 = getEntry(it, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),779,entry1);
                it = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getCollection().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),772,it);
                final Map.Entry<K, V> entry2 = getEntry(it, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),780,entry2);
                Iterator<java.util.Map.Entry<K, V>> itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),781,itConfirmed);
                final Map.Entry<K, V> entryConfirmed1 = getEntry(itConfirmed, key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),782,entryConfirmed1);
                itConfirmed = org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.getConfirmed().iterator();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),773,itConfirmed);
                final Map.Entry<K, V> entryConfirmed2 = getEntry(itConfirmed, key2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),783,entryConfirmed2);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                if (!(isSetValueSupported())) {
                    try {
                        entry1.setValue(newValue1);
                    } catch (final UnsupportedOperationException ex) {
                    }
                    return ;
                } 
                entry1.setValue(newValue1);
                entryConfirmed1.setValue(newValue1);
                entry2.setValue(newValue2);
                entryConfirmed2.setValue(newValue2);
                try {
                    entry2.setValue(newValue1);
                } catch (final IllegalArgumentException ex) {
                    return ;
                }
                entryConfirmed2.setValue(newValue1);
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),764,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),765,entry2.getValue());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),766,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),767,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),768,newValue1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),769,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().get(entry2.getKey()));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),770,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsKey(key1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),771,org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().containsValue(newValue2));
                org.apache.commons.collections4.bidimap.AbstractBidiMapTest.TestBidiMapEntrySet.this.verify();
                it.next();
                if (isRemoveSupported()) {
                } 
            } finally {
                fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
            }
        }
    }

    public BulkTest bulkTestInverseMap() {
        return new TestInverseBidiMap(this);
    }

    public class TestInverseBidiMap extends AbstractBidiMapTest<V, K> {
        final AbstractBidiMapTest<K, V> main;

        public TestInverseBidiMap(final AbstractBidiMapTest<K, V> main) {
            super();
            this.main = main;
        }

        @Override
        public BidiMap<V, K> makeObject() {
            return main.makeObject().inverseBidiMap();
        }

        @Override
        public BidiMap<V, K> makeFullMap() {
            return main.makeFullMap().inverseBidiMap();
        }

        @Override
        public V[] getSampleKeys() {
            return main.getSampleValues();
        }

        @Override
        public K[] getSampleValues() {
            return main.getSampleKeys();
        }

        @Override
        public String getCompatibilityVersion() {
            return main.getCompatibilityVersion();
        }

        @Override
        public boolean isAllowNullKey() {
            return main.isAllowNullKey();
        }

        @Override
        public boolean isAllowNullValue() {
            return main.isAllowNullValue();
        }

        @Override
        public boolean isPutAddSupported() {
            return main.isPutAddSupported();
        }

        @Override
        public boolean isPutChangeSupported() {
            return main.isPutChangeSupported();
        }

        @Override
        public boolean isSetValueSupported() {
            return main.isSetValueSupported();
        }

        @Override
        public boolean isRemoveSupported() {
            return main.isRemoveSupported();
        }
    }

    public BulkTest bulkTestBidiMapIterator() {
        return new TestBidiMapIterator();
    }

    public class TestBidiMapIterator extends AbstractMapIteratorTest<K, V> {
        public TestBidiMapIterator() {
            super("TestBidiMapIterator");
        }

        @Override
        public V[] addSetValues() {
            return org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getNewSampleValues();
        }

        @Override
        public boolean supportsRemove() {
            return org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.isRemoveSupported();
        }

        @Override
        public boolean supportsSetValue() {
            return org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.isSetValueSupported();
        }

        @Override
        public MapIterator<K, V> makeEmptyIterator() {
            resetEmpty();
            return org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().mapIterator();
        }

        @Override
        public MapIterator<K, V> makeObject() {
            resetFull();
            return org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap().mapIterator();
        }

        @Override
        public BidiMap<K, V> getMap() {
            return org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getMap();
        }

        @Override
        public Map<K, V> getConfirmedMap() {
            return org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed();
        }

        @Override
        public void verify() {
            super.verify();
            org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.verify();
        }
    }

    @Test(timeout = 1000)
    public void testBidiMapIteratorSet_add422() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiMapIteratorSet_add422");
            final V newValue1 = getOtherValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,newValue1);
            final V newValue2 = getOtherValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),866,newValue2);
            resetFull();
            resetFull();
            final BidiMap<K, V> bidi = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,bidi);
            final MapIterator<K, V> it = bidi.mapIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,it.hasNext());
            final K key1 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,key1);
            if (!(isSetValueSupported())) {
                try {
                    it.setValue(newValue1);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),838,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,bidi.get(key1));
            verify();
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,bidi.get(key1));
            verify();
            final K key2 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,key2);
            it.setValue(newValue2);
            confirmed.put(key2, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,key2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),852,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),853,bidi.containsKey(key2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),854,bidi.containsValue(newValue2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),855,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),856,bidi.get(key2));
            verify();
            try {
                it.setValue(newValue1);
            } catch (final IllegalArgumentException ex) {
                return ;
            }
            confirmed.put(key2, newValue1);
            org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),857,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),858,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),859,bidi.containsKey(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),860,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),861,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),862,bidi.get(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),863,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),864,bidi.containsValue(newValue2));
            verify();
            it.next();
            if (isRemoveSupported()) {
                it.remove();
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiMapIteratorSet_add423() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiMapIteratorSet_add423");
            final V newValue1 = getOtherValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,newValue1);
            final V newValue2 = getOtherValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),866,newValue2);
            resetFull();
            final BidiMap<K, V> bidi = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,bidi);
            final MapIterator<K, V> it = bidi.mapIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,it.hasNext());
            final K key1 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,key1);
            if (!(isSetValueSupported())) {
                try {
                    it.setValue(newValue1);
                    it.setValue(newValue1);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),838,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,bidi.get(key1));
            verify();
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,bidi.get(key1));
            verify();
            final K key2 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,key2);
            it.setValue(newValue2);
            confirmed.put(key2, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,key2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),852,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),853,bidi.containsKey(key2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),854,bidi.containsValue(newValue2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),855,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),856,bidi.get(key2));
            verify();
            try {
                it.setValue(newValue1);
            } catch (final IllegalArgumentException ex) {
                return ;
            }
            confirmed.put(key2, newValue1);
            org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),857,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),858,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),859,bidi.containsKey(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),860,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),861,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),862,bidi.get(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),863,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),864,bidi.containsValue(newValue2));
            verify();
            it.next();
            if (isRemoveSupported()) {
                it.remove();
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiMapIteratorSet_add424() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiMapIteratorSet_add424");
            final V newValue1 = getOtherValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,newValue1);
            final V newValue2 = getOtherValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),866,newValue2);
            resetFull();
            final BidiMap<K, V> bidi = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,bidi);
            final MapIterator<K, V> it = bidi.mapIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,it.hasNext());
            final K key1 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,key1);
            if (!(isSetValueSupported())) {
                try {
                    it.setValue(newValue1);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.setValue(newValue1);
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),838,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,bidi.get(key1));
            verify();
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,bidi.get(key1));
            verify();
            final K key2 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,key2);
            it.setValue(newValue2);
            confirmed.put(key2, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,key2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),852,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),853,bidi.containsKey(key2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),854,bidi.containsValue(newValue2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),855,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),856,bidi.get(key2));
            verify();
            try {
                it.setValue(newValue1);
            } catch (final IllegalArgumentException ex) {
                return ;
            }
            confirmed.put(key2, newValue1);
            org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),857,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),858,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),859,bidi.containsKey(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),860,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),861,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),862,bidi.get(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),863,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),864,bidi.containsValue(newValue2));
            verify();
            it.next();
            if (isRemoveSupported()) {
                it.remove();
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiMapIteratorSet_add425() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiMapIteratorSet_add425");
            final V newValue1 = getOtherValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,newValue1);
            final V newValue2 = getOtherValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),866,newValue2);
            resetFull();
            final BidiMap<K, V> bidi = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,bidi);
            final MapIterator<K, V> it = bidi.mapIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,it.hasNext());
            final K key1 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,key1);
            if (!(isSetValueSupported())) {
                try {
                    it.setValue(newValue1);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),838,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,bidi.get(key1));
            verify();
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,bidi.get(key1));
            verify();
            final K key2 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,key2);
            it.setValue(newValue2);
            confirmed.put(key2, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,key2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),852,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),853,bidi.containsKey(key2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),854,bidi.containsValue(newValue2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),855,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),856,bidi.get(key2));
            verify();
            try {
                it.setValue(newValue1);
            } catch (final IllegalArgumentException ex) {
                return ;
            }
            confirmed.put(key2, newValue1);
            org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),857,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),858,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),859,bidi.containsKey(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),860,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),861,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),862,bidi.get(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),863,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),864,bidi.containsValue(newValue2));
            verify();
            it.next();
            if (isRemoveSupported()) {
                it.remove();
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiMapIteratorSet_add426() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiMapIteratorSet_add426");
            final V newValue1 = getOtherValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,newValue1);
            final V newValue2 = getOtherValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),866,newValue2);
            resetFull();
            final BidiMap<K, V> bidi = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,bidi);
            final MapIterator<K, V> it = bidi.mapIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,it.hasNext());
            final K key1 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,key1);
            if (!(isSetValueSupported())) {
                try {
                    it.setValue(newValue1);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),838,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,bidi.get(key1));
            verify();
            verify();
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,bidi.get(key1));
            verify();
            final K key2 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,key2);
            it.setValue(newValue2);
            confirmed.put(key2, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,key2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),852,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),853,bidi.containsKey(key2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),854,bidi.containsValue(newValue2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),855,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),856,bidi.get(key2));
            verify();
            try {
                it.setValue(newValue1);
            } catch (final IllegalArgumentException ex) {
                return ;
            }
            confirmed.put(key2, newValue1);
            org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),857,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),858,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),859,bidi.containsKey(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),860,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),861,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),862,bidi.get(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),863,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),864,bidi.containsValue(newValue2));
            verify();
            it.next();
            if (isRemoveSupported()) {
                it.remove();
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiMapIteratorSet_add427() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiMapIteratorSet_add427");
            final V newValue1 = getOtherValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,newValue1);
            final V newValue2 = getOtherValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),866,newValue2);
            resetFull();
            final BidiMap<K, V> bidi = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,bidi);
            final MapIterator<K, V> it = bidi.mapIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,it.hasNext());
            final K key1 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,key1);
            if (!(isSetValueSupported())) {
                try {
                    it.setValue(newValue1);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),838,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,bidi.get(key1));
            verify();
            it.setValue(newValue1);
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,bidi.get(key1));
            verify();
            final K key2 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,key2);
            it.setValue(newValue2);
            confirmed.put(key2, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,key2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),852,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),853,bidi.containsKey(key2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),854,bidi.containsValue(newValue2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),855,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),856,bidi.get(key2));
            verify();
            try {
                it.setValue(newValue1);
            } catch (final IllegalArgumentException ex) {
                return ;
            }
            confirmed.put(key2, newValue1);
            org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),857,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),858,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),859,bidi.containsKey(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),860,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),861,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),862,bidi.get(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),863,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),864,bidi.containsValue(newValue2));
            verify();
            it.next();
            if (isRemoveSupported()) {
                it.remove();
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiMapIteratorSet_add428() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiMapIteratorSet_add428");
            final V newValue1 = getOtherValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,newValue1);
            final V newValue2 = getOtherValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),866,newValue2);
            resetFull();
            final BidiMap<K, V> bidi = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,bidi);
            final MapIterator<K, V> it = bidi.mapIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,it.hasNext());
            final K key1 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,key1);
            if (!(isSetValueSupported())) {
                try {
                    it.setValue(newValue1);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),838,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,bidi.get(key1));
            verify();
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,bidi.get(key1));
            verify();
            final K key2 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,key2);
            it.setValue(newValue2);
            confirmed.put(key2, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,key2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),852,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),853,bidi.containsKey(key2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),854,bidi.containsValue(newValue2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),855,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),856,bidi.get(key2));
            verify();
            try {
                it.setValue(newValue1);
            } catch (final IllegalArgumentException ex) {
                return ;
            }
            confirmed.put(key2, newValue1);
            org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),857,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),858,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),859,bidi.containsKey(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),860,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),861,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),862,bidi.get(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),863,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),864,bidi.containsValue(newValue2));
            verify();
            it.next();
            if (isRemoveSupported()) {
                it.remove();
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiMapIteratorSet_add429() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiMapIteratorSet_add429");
            final V newValue1 = getOtherValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,newValue1);
            final V newValue2 = getOtherValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),866,newValue2);
            resetFull();
            final BidiMap<K, V> bidi = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,bidi);
            final MapIterator<K, V> it = bidi.mapIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,it.hasNext());
            final K key1 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,key1);
            if (!(isSetValueSupported())) {
                try {
                    it.setValue(newValue1);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),838,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,bidi.get(key1));
            verify();
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,bidi.get(key1));
            verify();
            verify();
            final K key2 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,key2);
            it.setValue(newValue2);
            confirmed.put(key2, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,key2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),852,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),853,bidi.containsKey(key2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),854,bidi.containsValue(newValue2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),855,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),856,bidi.get(key2));
            verify();
            try {
                it.setValue(newValue1);
            } catch (final IllegalArgumentException ex) {
                return ;
            }
            confirmed.put(key2, newValue1);
            org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),857,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),858,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),859,bidi.containsKey(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),860,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),861,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),862,bidi.get(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),863,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),864,bidi.containsValue(newValue2));
            verify();
            it.next();
            if (isRemoveSupported()) {
                it.remove();
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiMapIteratorSet_add430() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiMapIteratorSet_add430");
            final V newValue1 = getOtherValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,newValue1);
            final V newValue2 = getOtherValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),866,newValue2);
            resetFull();
            final BidiMap<K, V> bidi = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,bidi);
            final MapIterator<K, V> it = bidi.mapIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,it.hasNext());
            final K key1 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,key1);
            if (!(isSetValueSupported())) {
                try {
                    it.setValue(newValue1);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),838,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,bidi.get(key1));
            verify();
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,bidi.get(key1));
            verify();
            final K key2 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,key2);
            it.setValue(newValue2);
            it.setValue(newValue2);
            confirmed.put(key2, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,key2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),852,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),853,bidi.containsKey(key2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),854,bidi.containsValue(newValue2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),855,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),856,bidi.get(key2));
            verify();
            try {
                it.setValue(newValue1);
            } catch (final IllegalArgumentException ex) {
                return ;
            }
            confirmed.put(key2, newValue1);
            org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),857,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),858,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),859,bidi.containsKey(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),860,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),861,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),862,bidi.get(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),863,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),864,bidi.containsValue(newValue2));
            verify();
            it.next();
            if (isRemoveSupported()) {
                it.remove();
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiMapIteratorSet_add431() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiMapIteratorSet_add431");
            final V newValue1 = getOtherValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,newValue1);
            final V newValue2 = getOtherValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),866,newValue2);
            resetFull();
            final BidiMap<K, V> bidi = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,bidi);
            final MapIterator<K, V> it = bidi.mapIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,it.hasNext());
            final K key1 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,key1);
            if (!(isSetValueSupported())) {
                try {
                    it.setValue(newValue1);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),838,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,bidi.get(key1));
            verify();
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,bidi.get(key1));
            verify();
            final K key2 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,key2);
            it.setValue(newValue2);
            confirmed.put(key2, newValue2);
            confirmed.put(key2, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,key2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),852,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),853,bidi.containsKey(key2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),854,bidi.containsValue(newValue2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),855,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),856,bidi.get(key2));
            verify();
            try {
                it.setValue(newValue1);
            } catch (final IllegalArgumentException ex) {
                return ;
            }
            confirmed.put(key2, newValue1);
            org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),857,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),858,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),859,bidi.containsKey(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),860,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),861,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),862,bidi.get(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),863,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),864,bidi.containsValue(newValue2));
            verify();
            it.next();
            if (isRemoveSupported()) {
                it.remove();
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiMapIteratorSet_add432() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiMapIteratorSet_add432");
            final V newValue1 = getOtherValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,newValue1);
            final V newValue2 = getOtherValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),866,newValue2);
            resetFull();
            final BidiMap<K, V> bidi = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,bidi);
            final MapIterator<K, V> it = bidi.mapIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,it.hasNext());
            final K key1 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,key1);
            if (!(isSetValueSupported())) {
                try {
                    it.setValue(newValue1);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),838,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,bidi.get(key1));
            verify();
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,bidi.get(key1));
            verify();
            final K key2 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,key2);
            it.setValue(newValue2);
            confirmed.put(key2, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,key2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),852,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),853,bidi.containsKey(key2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),854,bidi.containsValue(newValue2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),855,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),856,bidi.get(key2));
            verify();
            verify();
            try {
                it.setValue(newValue1);
            } catch (final IllegalArgumentException ex) {
                return ;
            }
            confirmed.put(key2, newValue1);
            org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),857,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),858,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),859,bidi.containsKey(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),860,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),861,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),862,bidi.get(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),863,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),864,bidi.containsValue(newValue2));
            verify();
            it.next();
            if (isRemoveSupported()) {
                it.remove();
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiMapIteratorSet_add433() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiMapIteratorSet_add433");
            final V newValue1 = getOtherValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,newValue1);
            final V newValue2 = getOtherValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),866,newValue2);
            resetFull();
            final BidiMap<K, V> bidi = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,bidi);
            final MapIterator<K, V> it = bidi.mapIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,it.hasNext());
            final K key1 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,key1);
            if (!(isSetValueSupported())) {
                try {
                    it.setValue(newValue1);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),838,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,bidi.get(key1));
            verify();
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,bidi.get(key1));
            verify();
            final K key2 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,key2);
            it.setValue(newValue2);
            confirmed.put(key2, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,key2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),852,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),853,bidi.containsKey(key2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),854,bidi.containsValue(newValue2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),855,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),856,bidi.get(key2));
            verify();
            try {
                it.setValue(newValue1);
                it.setValue(newValue1);
            } catch (final IllegalArgumentException ex) {
                return ;
            }
            confirmed.put(key2, newValue1);
            org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),857,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),858,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),859,bidi.containsKey(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),860,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),861,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),862,bidi.get(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),863,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),864,bidi.containsValue(newValue2));
            verify();
            it.next();
            if (isRemoveSupported()) {
                it.remove();
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiMapIteratorSet_add434() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiMapIteratorSet_add434");
            final V newValue1 = getOtherValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,newValue1);
            final V newValue2 = getOtherValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),866,newValue2);
            resetFull();
            final BidiMap<K, V> bidi = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,bidi);
            final MapIterator<K, V> it = bidi.mapIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,it.hasNext());
            final K key1 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,key1);
            if (!(isSetValueSupported())) {
                try {
                    it.setValue(newValue1);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),838,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,bidi.get(key1));
            verify();
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,bidi.get(key1));
            verify();
            final K key2 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,key2);
            it.setValue(newValue2);
            confirmed.put(key2, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,key2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),852,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),853,bidi.containsKey(key2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),854,bidi.containsValue(newValue2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),855,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),856,bidi.get(key2));
            verify();
            try {
                it.setValue(newValue1);
            } catch (final IllegalArgumentException ex) {
                return ;
            }
            confirmed.put(key2, newValue1);
            confirmed.put(key2, newValue1);
            org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),857,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),858,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),859,bidi.containsKey(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),860,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),861,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),862,bidi.get(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),863,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),864,bidi.containsValue(newValue2));
            verify();
            it.next();
            if (isRemoveSupported()) {
                it.remove();
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiMapIteratorSet_add435() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiMapIteratorSet_add435");
            final V newValue1 = getOtherValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,newValue1);
            final V newValue2 = getOtherValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),866,newValue2);
            resetFull();
            final BidiMap<K, V> bidi = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,bidi);
            final MapIterator<K, V> it = bidi.mapIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,it.hasNext());
            final K key1 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,key1);
            if (!(isSetValueSupported())) {
                try {
                    it.setValue(newValue1);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),838,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,bidi.get(key1));
            verify();
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,bidi.get(key1));
            verify();
            final K key2 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,key2);
            it.setValue(newValue2);
            confirmed.put(key2, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,key2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),852,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),853,bidi.containsKey(key2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),854,bidi.containsValue(newValue2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),855,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),856,bidi.get(key2));
            verify();
            try {
                it.setValue(newValue1);
            } catch (final IllegalArgumentException ex) {
                return ;
            }
            confirmed.put(key2, newValue1);
            org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
            org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),857,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),858,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),859,bidi.containsKey(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),860,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),861,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),862,bidi.get(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),863,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),864,bidi.containsValue(newValue2));
            verify();
            it.next();
            if (isRemoveSupported()) {
                it.remove();
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiMapIteratorSet_add436() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiMapIteratorSet_add436");
            final V newValue1 = getOtherValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,newValue1);
            final V newValue2 = getOtherValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),866,newValue2);
            resetFull();
            final BidiMap<K, V> bidi = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,bidi);
            final MapIterator<K, V> it = bidi.mapIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,it.hasNext());
            final K key1 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,key1);
            if (!(isSetValueSupported())) {
                try {
                    it.setValue(newValue1);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),838,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,bidi.get(key1));
            verify();
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,bidi.get(key1));
            verify();
            final K key2 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,key2);
            it.setValue(newValue2);
            confirmed.put(key2, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,key2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),852,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),853,bidi.containsKey(key2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),854,bidi.containsValue(newValue2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),855,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),856,bidi.get(key2));
            verify();
            try {
                it.setValue(newValue1);
            } catch (final IllegalArgumentException ex) {
                return ;
            }
            confirmed.put(key2, newValue1);
            org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),857,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),858,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),859,bidi.containsKey(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),860,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),861,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),862,bidi.get(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),863,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),864,bidi.containsValue(newValue2));
            verify();
            verify();
            it.next();
            if (isRemoveSupported()) {
                it.remove();
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiMapIteratorSet_add437() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiMapIteratorSet_add437");
            final V newValue1 = getOtherValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,newValue1);
            final V newValue2 = getOtherValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),866,newValue2);
            resetFull();
            final BidiMap<K, V> bidi = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,bidi);
            final MapIterator<K, V> it = bidi.mapIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,it.hasNext());
            final K key1 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,key1);
            if (!(isSetValueSupported())) {
                try {
                    it.setValue(newValue1);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),838,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,bidi.get(key1));
            verify();
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,bidi.get(key1));
            verify();
            final K key2 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,key2);
            it.setValue(newValue2);
            confirmed.put(key2, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,key2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),852,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),853,bidi.containsKey(key2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),854,bidi.containsValue(newValue2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),855,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),856,bidi.get(key2));
            verify();
            try {
                it.setValue(newValue1);
            } catch (final IllegalArgumentException ex) {
                return ;
            }
            confirmed.put(key2, newValue1);
            org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),857,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),858,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),859,bidi.containsKey(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),860,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),861,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),862,bidi.get(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),863,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),864,bidi.containsValue(newValue2));
            verify();
            it.next();
            it.next();
            if (isRemoveSupported()) {
                it.remove();
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiMapIteratorSet_add438() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiMapIteratorSet_add438");
            final V newValue1 = getOtherValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,newValue1);
            final V newValue2 = getOtherValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),866,newValue2);
            resetFull();
            final BidiMap<K, V> bidi = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,bidi);
            final MapIterator<K, V> it = bidi.mapIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,it.hasNext());
            final K key1 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,key1);
            if (!(isSetValueSupported())) {
                try {
                    it.setValue(newValue1);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),838,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,bidi.get(key1));
            verify();
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,bidi.get(key1));
            verify();
            final K key2 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,key2);
            it.setValue(newValue2);
            confirmed.put(key2, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,key2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),852,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),853,bidi.containsKey(key2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),854,bidi.containsValue(newValue2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),855,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),856,bidi.get(key2));
            verify();
            try {
                it.setValue(newValue1);
            } catch (final IllegalArgumentException ex) {
                return ;
            }
            confirmed.put(key2, newValue1);
            org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),857,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),858,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),859,bidi.containsKey(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),860,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),861,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),862,bidi.get(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),863,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),864,bidi.containsValue(newValue2));
            verify();
            it.next();
            if (isRemoveSupported()) {
                it.remove();
                it.remove();
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiMapIteratorSet() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiMapIteratorSet");
            final V newValue1 = getOtherValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,newValue1);
            final V newValue2 = getOtherValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),866,newValue2);
            resetFull();
            final BidiMap<K, V> bidi = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,bidi);
            final MapIterator<K, V> it = bidi.mapIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,it.hasNext());
            final K key1 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,key1);
            if (!(isSetValueSupported())) {
                try {
                    it.setValue(newValue1);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),838,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,bidi.get(key1));
            verify();
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,bidi.get(key1));
            verify();
            final K key2 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,key2);
            it.setValue(newValue2);
            confirmed.put(key2, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,key2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),852,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),853,bidi.containsKey(key2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),854,bidi.containsValue(newValue2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),855,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),856,bidi.get(key2));
            verify();
            try {
                it.setValue(newValue1);
            } catch (final IllegalArgumentException ex) {
                return ;
            }
            confirmed.put(key2, newValue1);
            org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),857,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),858,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),859,bidi.containsKey(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),860,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),861,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),862,bidi.get(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),863,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),864,bidi.containsValue(newValue2));
            verify();
            it.next();
            if (isRemoveSupported()) {
                it.remove();
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiMapIteratorSet_literalMutation478() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiMapIteratorSet_literalMutation478");
            final V newValue1 = getOtherValues()[-1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,newValue1);
            final V newValue2 = getOtherValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),866,newValue2);
            resetFull();
            final BidiMap<K, V> bidi = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,bidi);
            final MapIterator<K, V> it = bidi.mapIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,it.hasNext());
            final K key1 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,key1);
            if (!(isSetValueSupported())) {
                try {
                    it.setValue(newValue1);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),838,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,bidi.get(key1));
            verify();
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,bidi.get(key1));
            verify();
            final K key2 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,key2);
            it.setValue(newValue2);
            confirmed.put(key2, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,key2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),852,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),853,bidi.containsKey(key2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),854,bidi.containsValue(newValue2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),855,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),856,bidi.get(key2));
            verify();
            try {
                it.setValue(newValue1);
            } catch (final IllegalArgumentException ex) {
                return ;
            }
            confirmed.put(key2, newValue1);
            org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),857,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),858,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),859,bidi.containsKey(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),860,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),861,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),862,bidi.get(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),863,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),864,bidi.containsValue(newValue2));
            verify();
            it.next();
            if (isRemoveSupported()) {
                it.remove();
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiMapIteratorSet_literalMutation479() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiMapIteratorSet_literalMutation479");
            final V newValue1 = getOtherValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,newValue1);
            final V newValue2 = getOtherValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),866,newValue2);
            resetFull();
            final BidiMap<K, V> bidi = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,bidi);
            final MapIterator<K, V> it = bidi.mapIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,it.hasNext());
            final K key1 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,key1);
            if (!(isSetValueSupported())) {
                try {
                    it.setValue(newValue1);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),838,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,bidi.get(key1));
            verify();
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,bidi.get(key1));
            verify();
            final K key2 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,key2);
            it.setValue(newValue2);
            confirmed.put(key2, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,key2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),852,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),853,bidi.containsKey(key2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),854,bidi.containsValue(newValue2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),855,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),856,bidi.get(key2));
            verify();
            try {
                it.setValue(newValue1);
            } catch (final IllegalArgumentException ex) {
                return ;
            }
            confirmed.put(key2, newValue1);
            org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),857,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),858,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),859,bidi.containsKey(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),860,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),861,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),862,bidi.get(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),863,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),864,bidi.containsValue(newValue2));
            verify();
            it.next();
            if (isRemoveSupported()) {
                it.remove();
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiMapIteratorSet_literalMutation481() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiMapIteratorSet_literalMutation481");
            final V newValue1 = getOtherValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,newValue1);
            final V newValue2 = getOtherValues()[2];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),866,newValue2);
            resetFull();
            final BidiMap<K, V> bidi = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,bidi);
            final MapIterator<K, V> it = bidi.mapIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,it.hasNext());
            final K key1 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,key1);
            if (!(isSetValueSupported())) {
                try {
                    it.setValue(newValue1);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),838,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,bidi.get(key1));
            verify();
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,bidi.get(key1));
            verify();
            final K key2 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,key2);
            it.setValue(newValue2);
            confirmed.put(key2, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,key2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),852,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),853,bidi.containsKey(key2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),854,bidi.containsValue(newValue2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),855,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),856,bidi.get(key2));
            verify();
            try {
                it.setValue(newValue1);
            } catch (final IllegalArgumentException ex) {
                return ;
            }
            confirmed.put(key2, newValue1);
            org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),857,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),858,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),859,bidi.containsKey(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),860,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),861,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),862,bidi.get(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),863,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),864,bidi.containsValue(newValue2));
            verify();
            it.next();
            if (isRemoveSupported()) {
                it.remove();
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiMapIteratorSet_literalMutation482() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiMapIteratorSet_literalMutation482");
            final V newValue1 = getOtherValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,newValue1);
            final V newValue2 = getOtherValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),866,newValue2);
            resetFull();
            final BidiMap<K, V> bidi = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,bidi);
            final MapIterator<K, V> it = bidi.mapIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,it.hasNext());
            final K key1 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,key1);
            if (!(isSetValueSupported())) {
                try {
                    it.setValue(newValue1);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),838,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,bidi.get(key1));
            verify();
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,bidi.get(key1));
            verify();
            final K key2 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,key2);
            it.setValue(newValue2);
            confirmed.put(key2, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,key2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),852,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),853,bidi.containsKey(key2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),854,bidi.containsValue(newValue2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),855,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),856,bidi.get(key2));
            verify();
            try {
                it.setValue(newValue1);
            } catch (final IllegalArgumentException ex) {
                return ;
            }
            confirmed.put(key2, newValue1);
            org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),857,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),858,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),859,bidi.containsKey(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),860,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),861,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),862,bidi.get(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),863,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),864,bidi.containsValue(newValue2));
            verify();
            it.next();
            if (isRemoveSupported()) {
                it.remove();
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBidiMapIteratorSet_literalMutation483() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiMapIteratorSet_literalMutation483");
            final V newValue1 = getOtherValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,newValue1);
            final V newValue2 = getOtherValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),866,newValue2);
            resetFull();
            final BidiMap<K, V> bidi = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,bidi);
            final MapIterator<K, V> it = bidi.mapIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,it.hasNext());
            final K key1 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,key1);
            if (!(isSetValueSupported())) {
                try {
                    it.setValue(newValue1);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),838,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,bidi.get(key1));
            verify();
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,bidi.get(key1));
            verify();
            final K key2 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,key2);
            it.setValue(newValue2);
            confirmed.put(key2, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,key2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),852,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),853,bidi.containsKey(key2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),854,bidi.containsValue(newValue2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),855,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),856,bidi.get(key2));
            verify();
            try {
                it.setValue(newValue1);
            } catch (final IllegalArgumentException ex) {
                return ;
            }
            confirmed.put(key2, newValue1);
            org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),857,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),858,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),859,bidi.containsKey(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),860,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),861,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),862,bidi.get(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),863,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),864,bidi.containsValue(newValue2));
            verify();
            it.next();
            if (isRemoveSupported()) {
                it.remove();
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiMapIteratorSet_remove323() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiMapIteratorSet_remove323");
            final V newValue1 = getOtherValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,newValue1);
            final V newValue2 = getOtherValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),866,newValue2);
            final BidiMap<K, V> bidi = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,bidi);
            final MapIterator<K, V> it = bidi.mapIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,it.hasNext());
            final K key1 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,key1);
            if (!(isSetValueSupported())) {
                try {
                    it.setValue(newValue1);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),838,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,bidi.get(key1));
            verify();
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,bidi.get(key1));
            verify();
            final K key2 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,key2);
            it.setValue(newValue2);
            confirmed.put(key2, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,key2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),852,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),853,bidi.containsKey(key2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),854,bidi.containsValue(newValue2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),855,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),856,bidi.get(key2));
            verify();
            try {
                it.setValue(newValue1);
            } catch (final IllegalArgumentException ex) {
                return ;
            }
            confirmed.put(key2, newValue1);
            org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),857,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),858,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),859,bidi.containsKey(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),860,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),861,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),862,bidi.get(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),863,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),864,bidi.containsValue(newValue2));
            verify();
            it.next();
            if (isRemoveSupported()) {
                it.remove();
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiMapIteratorSet_remove324() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiMapIteratorSet_remove324");
            final V newValue1 = getOtherValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,newValue1);
            final V newValue2 = getOtherValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),866,newValue2);
            resetFull();
            final BidiMap<K, V> bidi = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,bidi);
            final MapIterator<K, V> it = bidi.mapIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,it.hasNext());
            final K key1 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,key1);
            if (!(isSetValueSupported())) {
                try {
                    it.setValue(newValue1);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),838,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,bidi.get(key1));
            verify();
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,bidi.get(key1));
            verify();
            final K key2 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,key2);
            it.setValue(newValue2);
            confirmed.put(key2, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,key2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),852,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),853,bidi.containsKey(key2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),854,bidi.containsValue(newValue2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),855,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),856,bidi.get(key2));
            verify();
            try {
                it.setValue(newValue1);
            } catch (final IllegalArgumentException ex) {
                return ;
            }
            confirmed.put(key2, newValue1);
            org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),857,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),858,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),859,bidi.containsKey(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),860,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),861,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),862,bidi.get(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),863,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),864,bidi.containsValue(newValue2));
            verify();
            it.next();
            if (isRemoveSupported()) {
                it.remove();
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiMapIteratorSet_remove325() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiMapIteratorSet_remove325");
            final V newValue1 = getOtherValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,newValue1);
            final V newValue2 = getOtherValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),866,newValue2);
            resetFull();
            final BidiMap<K, V> bidi = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,bidi);
            final MapIterator<K, V> it = bidi.mapIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,it.hasNext());
            final K key1 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,key1);
            if (!(isSetValueSupported())) {
                try {
                    it.setValue(newValue1);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.setValue(newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),838,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,bidi.get(key1));
            verify();
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,bidi.get(key1));
            verify();
            final K key2 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,key2);
            it.setValue(newValue2);
            confirmed.put(key2, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,key2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),852,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),853,bidi.containsKey(key2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),854,bidi.containsValue(newValue2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),855,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),856,bidi.get(key2));
            verify();
            try {
                it.setValue(newValue1);
            } catch (final IllegalArgumentException ex) {
                return ;
            }
            confirmed.put(key2, newValue1);
            org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),857,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),858,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),859,bidi.containsKey(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),860,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),861,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),862,bidi.get(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),863,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),864,bidi.containsValue(newValue2));
            verify();
            it.next();
            if (isRemoveSupported()) {
                it.remove();
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiMapIteratorSet_remove326() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiMapIteratorSet_remove326");
            final V newValue1 = getOtherValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,newValue1);
            final V newValue2 = getOtherValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),866,newValue2);
            resetFull();
            final BidiMap<K, V> bidi = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,bidi);
            final MapIterator<K, V> it = bidi.mapIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,it.hasNext());
            final K key1 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,key1);
            if (!(isSetValueSupported())) {
                try {
                    it.setValue(newValue1);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),838,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,bidi.get(key1));
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,bidi.get(key1));
            verify();
            final K key2 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,key2);
            it.setValue(newValue2);
            confirmed.put(key2, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,key2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),852,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),853,bidi.containsKey(key2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),854,bidi.containsValue(newValue2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),855,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),856,bidi.get(key2));
            verify();
            try {
                it.setValue(newValue1);
            } catch (final IllegalArgumentException ex) {
                return ;
            }
            confirmed.put(key2, newValue1);
            org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),857,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),858,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),859,bidi.containsKey(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),860,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),861,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),862,bidi.get(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),863,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),864,bidi.containsValue(newValue2));
            verify();
            it.next();
            if (isRemoveSupported()) {
                it.remove();
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiMapIteratorSet_remove327() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiMapIteratorSet_remove327");
            final V newValue1 = getOtherValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,newValue1);
            final V newValue2 = getOtherValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),866,newValue2);
            resetFull();
            final BidiMap<K, V> bidi = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,bidi);
            final MapIterator<K, V> it = bidi.mapIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,it.hasNext());
            final K key1 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,key1);
            if (!(isSetValueSupported())) {
                try {
                    it.setValue(newValue1);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),838,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,bidi.get(key1));
            verify();
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,bidi.get(key1));
            verify();
            final K key2 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,key2);
            it.setValue(newValue2);
            confirmed.put(key2, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,key2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),852,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),853,bidi.containsKey(key2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),854,bidi.containsValue(newValue2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),855,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),856,bidi.get(key2));
            verify();
            try {
                it.setValue(newValue1);
            } catch (final IllegalArgumentException ex) {
                return ;
            }
            confirmed.put(key2, newValue1);
            org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),857,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),858,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),859,bidi.containsKey(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),860,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),861,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),862,bidi.get(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),863,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),864,bidi.containsValue(newValue2));
            verify();
            it.next();
            if (isRemoveSupported()) {
                it.remove();
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiMapIteratorSet_remove328() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiMapIteratorSet_remove328");
            final V newValue1 = getOtherValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,newValue1);
            final V newValue2 = getOtherValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),866,newValue2);
            resetFull();
            final BidiMap<K, V> bidi = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,bidi);
            final MapIterator<K, V> it = bidi.mapIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,it.hasNext());
            final K key1 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,key1);
            if (!(isSetValueSupported())) {
                try {
                    it.setValue(newValue1);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.setValue(newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),838,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,bidi.get(key1));
            verify();
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,bidi.get(key1));
            verify();
            final K key2 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,key2);
            it.setValue(newValue2);
            confirmed.put(key2, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,key2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),852,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),853,bidi.containsKey(key2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),854,bidi.containsValue(newValue2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),855,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),856,bidi.get(key2));
            verify();
            try {
                it.setValue(newValue1);
            } catch (final IllegalArgumentException ex) {
                return ;
            }
            confirmed.put(key2, newValue1);
            org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),857,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),858,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),859,bidi.containsKey(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),860,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),861,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),862,bidi.get(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),863,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),864,bidi.containsValue(newValue2));
            verify();
            it.next();
            if (isRemoveSupported()) {
                it.remove();
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiMapIteratorSet_remove329() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiMapIteratorSet_remove329");
            final V newValue1 = getOtherValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,newValue1);
            final V newValue2 = getOtherValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),866,newValue2);
            resetFull();
            final BidiMap<K, V> bidi = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,bidi);
            final MapIterator<K, V> it = bidi.mapIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,it.hasNext());
            final K key1 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,key1);
            if (!(isSetValueSupported())) {
                try {
                    it.setValue(newValue1);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),838,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,bidi.get(key1));
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,bidi.get(key1));
            verify();
            final K key2 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,key2);
            it.setValue(newValue2);
            confirmed.put(key2, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,key2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),852,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),853,bidi.containsKey(key2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),854,bidi.containsValue(newValue2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),855,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),856,bidi.get(key2));
            verify();
            try {
                it.setValue(newValue1);
            } catch (final IllegalArgumentException ex) {
                return ;
            }
            confirmed.put(key2, newValue1);
            org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),857,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),858,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),859,bidi.containsKey(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),860,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),861,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),862,bidi.get(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),863,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),864,bidi.containsValue(newValue2));
            verify();
            it.next();
            if (isRemoveSupported()) {
                it.remove();
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiMapIteratorSet_remove330() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiMapIteratorSet_remove330");
            final V newValue1 = getOtherValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,newValue1);
            final V newValue2 = getOtherValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),866,newValue2);
            resetFull();
            final BidiMap<K, V> bidi = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,bidi);
            final MapIterator<K, V> it = bidi.mapIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,it.hasNext());
            final K key1 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,key1);
            if (!(isSetValueSupported())) {
                try {
                    it.setValue(newValue1);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),838,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,bidi.get(key1));
            verify();
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,bidi.get(key1));
            verify();
            final K key2 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,key2);
            it.setValue(newValue2);
            confirmed.put(key2, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,key2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),852,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),853,bidi.containsKey(key2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),854,bidi.containsValue(newValue2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),855,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),856,bidi.get(key2));
            verify();
            try {
                it.setValue(newValue1);
            } catch (final IllegalArgumentException ex) {
                return ;
            }
            confirmed.put(key2, newValue1);
            org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),857,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),858,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),859,bidi.containsKey(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),860,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),861,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),862,bidi.get(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),863,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),864,bidi.containsValue(newValue2));
            verify();
            it.next();
            if (isRemoveSupported()) {
                it.remove();
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiMapIteratorSet_remove331() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiMapIteratorSet_remove331");
            final V newValue1 = getOtherValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,newValue1);
            final V newValue2 = getOtherValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),866,newValue2);
            resetFull();
            final BidiMap<K, V> bidi = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,bidi);
            final MapIterator<K, V> it = bidi.mapIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,it.hasNext());
            final K key1 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,key1);
            if (!(isSetValueSupported())) {
                try {
                    it.setValue(newValue1);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.setValue(newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),838,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,bidi.get(key1));
            verify();
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,bidi.get(key1));
            verify();
            final K key2 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,key2);
            it.setValue(newValue2);
            confirmed.put(key2, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,key2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),852,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),853,bidi.containsKey(key2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),854,bidi.containsValue(newValue2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),855,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),856,bidi.get(key2));
            verify();
            try {
                it.setValue(newValue1);
            } catch (final IllegalArgumentException ex) {
                return ;
            }
            confirmed.put(key2, newValue1);
            org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),857,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),858,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),859,bidi.containsKey(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),860,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),861,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),862,bidi.get(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),863,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),864,bidi.containsValue(newValue2));
            verify();
            it.next();
            if (isRemoveSupported()) {
                it.remove();
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiMapIteratorSet_remove332() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiMapIteratorSet_remove332");
            final V newValue1 = getOtherValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,newValue1);
            final V newValue2 = getOtherValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),866,newValue2);
            resetFull();
            final BidiMap<K, V> bidi = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,bidi);
            final MapIterator<K, V> it = bidi.mapIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,it.hasNext());
            final K key1 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,key1);
            if (!(isSetValueSupported())) {
                try {
                    it.setValue(newValue1);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),838,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,bidi.get(key1));
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,bidi.get(key1));
            verify();
            final K key2 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,key2);
            it.setValue(newValue2);
            confirmed.put(key2, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,key2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),852,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),853,bidi.containsKey(key2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),854,bidi.containsValue(newValue2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),855,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),856,bidi.get(key2));
            verify();
            try {
                it.setValue(newValue1);
            } catch (final IllegalArgumentException ex) {
                return ;
            }
            confirmed.put(key2, newValue1);
            org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),857,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),858,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),859,bidi.containsKey(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),860,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),861,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),862,bidi.get(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),863,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),864,bidi.containsValue(newValue2));
            verify();
            it.next();
            if (isRemoveSupported()) {
                it.remove();
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiMapIteratorSet_remove333() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiMapIteratorSet_remove333");
            final V newValue1 = getOtherValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,newValue1);
            final V newValue2 = getOtherValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),866,newValue2);
            resetFull();
            final BidiMap<K, V> bidi = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,bidi);
            final MapIterator<K, V> it = bidi.mapIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,it.hasNext());
            final K key1 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,key1);
            if (!(isSetValueSupported())) {
                try {
                    it.setValue(newValue1);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.setValue(newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),838,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,bidi.get(key1));
            verify();
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,bidi.get(key1));
            verify();
            final K key2 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,key2);
            it.setValue(newValue2);
            confirmed.put(key2, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,key2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),852,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),853,bidi.containsKey(key2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),854,bidi.containsValue(newValue2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),855,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),856,bidi.get(key2));
            verify();
            try {
                it.setValue(newValue1);
            } catch (final IllegalArgumentException ex) {
                return ;
            }
            confirmed.put(key2, newValue1);
            org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),857,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),858,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),859,bidi.containsKey(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),860,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),861,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),862,bidi.get(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),863,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),864,bidi.containsValue(newValue2));
            verify();
            it.next();
            if (isRemoveSupported()) {
                it.remove();
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiMapIteratorSet_remove334() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiMapIteratorSet_remove334");
            final V newValue1 = getOtherValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,newValue1);
            final V newValue2 = getOtherValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),866,newValue2);
            resetFull();
            final BidiMap<K, V> bidi = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,bidi);
            final MapIterator<K, V> it = bidi.mapIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,it.hasNext());
            final K key1 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,key1);
            if (!(isSetValueSupported())) {
                try {
                    it.setValue(newValue1);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),838,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,bidi.get(key1));
            verify();
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,bidi.get(key1));
            verify();
            final K key2 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,key2);
            it.setValue(newValue2);
            confirmed.put(key2, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,key2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),852,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),853,bidi.containsKey(key2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),854,bidi.containsValue(newValue2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),855,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),856,bidi.get(key2));
            verify();
            try {
                it.setValue(newValue1);
            } catch (final IllegalArgumentException ex) {
                return ;
            }
            confirmed.put(key2, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),857,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),858,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),859,bidi.containsKey(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),860,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),861,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),862,bidi.get(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),863,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),864,bidi.containsValue(newValue2));
            verify();
            it.next();
            if (isRemoveSupported()) {
                it.remove();
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiMapIteratorSet_remove335() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiMapIteratorSet_remove335");
            final V newValue1 = getOtherValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,newValue1);
            final V newValue2 = getOtherValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),866,newValue2);
            resetFull();
            final BidiMap<K, V> bidi = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,bidi);
            final MapIterator<K, V> it = bidi.mapIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,it.hasNext());
            final K key1 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,key1);
            if (!(isSetValueSupported())) {
                try {
                    it.setValue(newValue1);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),838,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,bidi.get(key1));
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,bidi.get(key1));
            verify();
            final K key2 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,key2);
            it.setValue(newValue2);
            confirmed.put(key2, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,key2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),852,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),853,bidi.containsKey(key2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),854,bidi.containsValue(newValue2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),855,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),856,bidi.get(key2));
            verify();
            try {
                it.setValue(newValue1);
            } catch (final IllegalArgumentException ex) {
                return ;
            }
            confirmed.put(key2, newValue1);
            org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),857,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),858,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),859,bidi.containsKey(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),860,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),861,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),862,bidi.get(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),863,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),864,bidi.containsValue(newValue2));
            verify();
            it.next();
            if (isRemoveSupported()) {
                it.remove();
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBidiMapIteratorSet_remove336() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBidiMapIteratorSet_remove336");
            final V newValue1 = getOtherValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,newValue1);
            final V newValue2 = getOtherValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),866,newValue2);
            resetFull();
            final BidiMap<K, V> bidi = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,bidi);
            final MapIterator<K, V> it = bidi.mapIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),832,it.hasNext());
            final K key1 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,key1);
            if (!(isSetValueSupported())) {
                try {
                    it.setValue(newValue1);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),833,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),834,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),835,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),836,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),837,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),838,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),839,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),840,bidi.get(key1));
            verify();
            it.setValue(newValue1);
            confirmed.put(key1, newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),841,key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),842,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),843,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),844,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),845,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),846,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),847,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),848,bidi.get(key1));
            verify();
            final K key2 = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,key2);
            it.setValue(newValue2);
            confirmed.put(key2, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),849,key2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),850,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),851,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),852,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),853,bidi.containsKey(key2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),854,bidi.containsValue(newValue2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),855,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),856,bidi.get(key2));
            verify();
            try {
                it.setValue(newValue1);
            } catch (final IllegalArgumentException ex) {
                return ;
            }
            confirmed.put(key2, newValue1);
            org.apache.commons.collections4.bidimap.AbstractBidiMapTest.this.getConfirmed().remove(key1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),857,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),858,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),859,bidi.containsKey(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),860,bidi.containsValue(newValue1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),861,newValue1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),862,bidi.get(it.getKey()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),863,bidi.containsKey(key1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),864,bidi.containsValue(newValue2));
            verify();
            it.next();
            if (isRemoveSupported()) {
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }
}

