package org.apache.commons.io.filefilter;

import java.io.File;
import org.apache.commons.io.testtools.FileBasedTestCase;
import org.apache.commons.io.IOCase;
import java.util.regex.Pattern;
import org.junit.Test;

/** 
 * Used to test RegexFileFilterUtils.
 */
public class RegexFileFilterTestCase extends FileBasedTestCase {
    public RegexFileFilterTestCase(String name) {
        super(name);
    }

    @Override
    public void setUp() {
        FileBasedTestCase.getTestDirectory().mkdirs();
    }

    @Override
    public void tearDown() throws Exception {
        org.apache.commons.io.FileUtils.deleteDirectory(FileBasedTestCase.getTestDirectory());
    }

    public void assertFiltering(IOFileFilter filter, File file, boolean expected) throws Exception {
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),0,((((("Filter(File) " + (filter.getClass().getName())) + " not ") + expected) + " for ") + file));
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1,expected);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2,filter.accept(file));
        if ((file != null) && ((file.getParentFile()) != null)) {
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),3,((((("Filter(File, String) " + (filter.getClass().getName())) + " not ") + expected) + " for ") + file));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),4,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),5,filter.accept(file.getParentFile(), file.getName()));
        } else if (file == null) {
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),6,(((("Filter(File, String) " + (filter.getClass().getName())) + " not ") + expected) + " for null"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),7,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),8,filter.accept(file));
        } 
    }

    @Test(timeout = 1000)
    public void testRegex_add1() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_add1");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRegex_add10() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_add10");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRegex_add11() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_add11");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRegex_add12() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_add12");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRegex_add13() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_add13");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRegex_add14() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_add14");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRegex_add15() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_add15");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRegex_add2() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_add2");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRegex_add3() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_add3");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRegex_add4() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_add4");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRegex_add5() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_add5");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRegex_add6() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_add6");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRegex_add7() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_add7");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRegex_add8() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_add8");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRegex_add9() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_add9");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.jaZa$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation10() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation10");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-1.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation12() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation12");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.6ava"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation13() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation13");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test¤-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation14() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation14");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("tes-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation15() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation15");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), true);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation16() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation16");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.jaa$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation17() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation17");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt÷]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation18() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation18");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.jaa$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation19() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation19");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("TestTjava"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation2() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation2");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.j·ava$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation20() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation20");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation21() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation21");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Tst.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation23() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation23");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("tst.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation24() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation24");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.±java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation25() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation25");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("tst.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation27() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation27");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tESTjava"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation28() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation28");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation29() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation29");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tES.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation3() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation3");
            IOFileFilter filter = new RegexFileFilter("^.[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation30() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation30");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation31() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation31");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^tes®.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation32() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation32");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^teKst.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation33() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation33");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^tet.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation34() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation34");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.éava"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation35() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation35");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.jvava"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation36() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation36");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.ava"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation38() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation38");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("te.t.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation39() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation39");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation4() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation4");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Tes£.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation40() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation40");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("testjava"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation42() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation42");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tESTjava"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation43() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation43");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST¡.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation44() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation44");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tES.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation46() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation46");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^testEjava$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation47() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation47");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^tesºt.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation48() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation48");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^tst.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation49() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation49");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.jÆva"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation5() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation5");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.jtava"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation50() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation50");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Testù.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation51() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation51");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Testjava"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation53() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation53");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("t`st.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation54() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation54");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation55() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation55");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.jaa"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation57() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation57");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.ava"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation58() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation58");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.ja¦va"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation59() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation59");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.ava"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation6() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation6");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Tet.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation61() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation61");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.jzva$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation62() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation62");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^ùtest.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation63() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation63");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^tet.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation64() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation64");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Tes.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation65() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation65");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation66() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation66");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Tes.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation68() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation68");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("teÓt.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation69() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation69");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("tesºt.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation70() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation70");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.jaa"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation72() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation72");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.ava"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation73() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation73");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tESÀT.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation74() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation74");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tES.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation8() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation8");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10.jva"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegex_literalMutation9() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_literalMutation9");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test-10U.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRegex_remove1() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_remove1");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRegex_remove10() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_remove10");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRegex_remove11() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_remove11");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRegex_remove12() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_remove12");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRegex_remove13() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_remove13");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRegex_remove14() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_remove14");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRegex_remove15() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_remove15");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRegex_remove2() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_remove2");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRegex_remove3() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_remove3");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRegex_remove4() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_remove4");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRegex_remove5() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_remove5");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRegex_remove6() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_remove6");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRegex_remove7() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_remove7");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRegex_remove8() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_remove8");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRegex_remove9() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegex_remove9");
            IOFileFilter filter = new RegexFileFilter("^.*[tT]est(-\\d+)?\\.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,filter);
            assertFiltering(filter, new File("test-10.java"), true);
            assertFiltering(filter, new File("test-.java"), false);
            filter = new RegexFileFilter("^[Tt]est.java$");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), false);
            filter = new RegexFileFilter(Pattern.compile("^test.java$", Pattern.CASE_INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , Pattern.CASE_INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            filter = new RegexFileFilter("^test.java$" , IOCase.INSENSITIVE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,filter);
            assertFiltering(filter, new File("Test.java"), true);
            assertFiltering(filter, new File("test.java"), true);
            assertFiltering(filter, new File("tEST.java"), true);
            try {
                new RegexFileFilter(((String)(null)));
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , Pattern.CASE_INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((String)(null)) , IOCase.INSENSITIVE);
            } catch (IllegalArgumentException ex) {
            }
            try {
                new RegexFileFilter(((Pattern)(null)));
            } catch (IllegalArgumentException ex) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }
}

