package com.google.gson.functional;

import java.util.Date;
import com.google.gson.Gson;
import com.google.gson.GsonBuilder;
import java.util.HashMap;
import java.util.HashSet;
import com.google.gson.InstanceCreator;
import com.google.gson.JsonDeserializationContext;
import com.google.gson.JsonDeserializer;
import com.google.gson.JsonElement;
import com.google.gson.JsonObject;
import com.google.gson.JsonParseException;
import com.google.gson.JsonPrimitive;
import com.google.gson.JsonSerializationContext;
import com.google.gson.JsonSerializer;
import java.util.Map;
import java.util.Set;
import org.junit.Test;
import junit.framework.TestCase;
import com.google.gson.common.TestTypes;
import java.lang.reflect.Type;
import com.google.gson.reflect.TypeToken;

/** 
 * Functional tests for the support of custom serializer and deserializers.
 * 
 * @author Inderjeet Singh
 * @author Joel Leitch
 */
public class CustomTypeAdaptersTest extends TestCase {
    private GsonBuilder builder;

    @Override
    protected void setUp() throws Exception {
        super.setUp();
        builder = new GsonBuilder();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),353,builder);
    }

    @Test(timeout = 1000)
    public void testCustomSerializers_add79() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomSerializers_add79");
            Gson gson = builder.registerTypeAdapter(TestTypes.ClassWithCustomTypeConverter.class, new JsonSerializer<com.google.gson.common.TestTypes.ClassWithCustomTypeConverter>() {
                public JsonElement serialize(TestTypes.ClassWithCustomTypeConverter src, Type typeOfSrc, JsonSerializationContext context) {
                    JsonObject json = new JsonObject();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
                    json.addProperty("bag", 5);
                    json.addProperty("value", 25);
                    return json;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            TestTypes.ClassWithCustomTypeConverter target = new TestTypes.ClassWithCustomTypeConverter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),234,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),427,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomSerializers_add80() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomSerializers_add80");
            Gson gson = builder.registerTypeAdapter(TestTypes.ClassWithCustomTypeConverter.class, new JsonSerializer<com.google.gson.common.TestTypes.ClassWithCustomTypeConverter>() {
                public JsonElement serialize(TestTypes.ClassWithCustomTypeConverter src, Type typeOfSrc, JsonSerializationContext context) {
                    JsonObject json = new JsonObject();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
                    json.addProperty("bag", 5);
                    json.addProperty("bag", 5);
                    json.addProperty("value", 25);
                    return json;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            TestTypes.ClassWithCustomTypeConverter target = new TestTypes.ClassWithCustomTypeConverter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),234,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),427,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomSerializers_add81() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomSerializers_add81");
            Gson gson = builder.registerTypeAdapter(TestTypes.ClassWithCustomTypeConverter.class, new JsonSerializer<com.google.gson.common.TestTypes.ClassWithCustomTypeConverter>() {
                public JsonElement serialize(TestTypes.ClassWithCustomTypeConverter src, Type typeOfSrc, JsonSerializationContext context) {
                    JsonObject json = new JsonObject();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
                    json.addProperty("bag", 5);
                    json.addProperty("value", 25);
                    json.addProperty("value", 25);
                    return json;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            TestTypes.ClassWithCustomTypeConverter target = new TestTypes.ClassWithCustomTypeConverter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),234,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),427,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomSerializers() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomSerializers");
            Gson gson = builder.registerTypeAdapter(TestTypes.ClassWithCustomTypeConverter.class, new JsonSerializer<com.google.gson.common.TestTypes.ClassWithCustomTypeConverter>() {
                public JsonElement serialize(TestTypes.ClassWithCustomTypeConverter src, Type typeOfSrc, JsonSerializationContext context) {
                    JsonObject json = new JsonObject();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
                    json.addProperty("ëag", 5);
                    json.addProperty("value", 25);
                    return json;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            TestTypes.ClassWithCustomTypeConverter target = new TestTypes.ClassWithCustomTypeConverter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),234,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),427,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomSerializers_literalMutation860() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomSerializers_literalMutation860");
            Gson gson = builder.registerTypeAdapter(TestTypes.ClassWithCustomTypeConverter.class, new JsonSerializer<com.google.gson.common.TestTypes.ClassWithCustomTypeConverter>() {
                public JsonElement serialize(TestTypes.ClassWithCustomTypeConverter src, Type typeOfSrc, JsonSerializationContext context) {
                    JsonObject json = new JsonObject();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
                    json.addProperty("b ag", 5);
                    json.addProperty("value", 25);
                    return json;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            TestTypes.ClassWithCustomTypeConverter target = new TestTypes.ClassWithCustomTypeConverter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),234,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),427,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomSerializers_literalMutation861() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomSerializers_literalMutation861");
            Gson gson = builder.registerTypeAdapter(TestTypes.ClassWithCustomTypeConverter.class, new JsonSerializer<com.google.gson.common.TestTypes.ClassWithCustomTypeConverter>() {
                public JsonElement serialize(TestTypes.ClassWithCustomTypeConverter src, Type typeOfSrc, JsonSerializationContext context) {
                    JsonObject json = new JsonObject();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
                    json.addProperty("bg", 5);
                    json.addProperty("value", 25);
                    return json;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            TestTypes.ClassWithCustomTypeConverter target = new TestTypes.ClassWithCustomTypeConverter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),234,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),427,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomSerializers_literalMutation862() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomSerializers_literalMutation862");
            Gson gson = builder.registerTypeAdapter(TestTypes.ClassWithCustomTypeConverter.class, new JsonSerializer<com.google.gson.common.TestTypes.ClassWithCustomTypeConverter>() {
                public JsonElement serialize(TestTypes.ClassWithCustomTypeConverter src, Type typeOfSrc, JsonSerializationContext context) {
                    JsonObject json = new JsonObject();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
                    json.addProperty("bag", 4);
                    json.addProperty("value", 25);
                    return json;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            TestTypes.ClassWithCustomTypeConverter target = new TestTypes.ClassWithCustomTypeConverter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),234,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),427,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomSerializers_literalMutation863() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomSerializers_literalMutation863");
            Gson gson = builder.registerTypeAdapter(TestTypes.ClassWithCustomTypeConverter.class, new JsonSerializer<com.google.gson.common.TestTypes.ClassWithCustomTypeConverter>() {
                public JsonElement serialize(TestTypes.ClassWithCustomTypeConverter src, Type typeOfSrc, JsonSerializationContext context) {
                    JsonObject json = new JsonObject();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
                    json.addProperty("bag", 2);
                    json.addProperty("value", 25);
                    return json;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            TestTypes.ClassWithCustomTypeConverter target = new TestTypes.ClassWithCustomTypeConverter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),234,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),427,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomSerializers_literalMutation864() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomSerializers_literalMutation864");
            Gson gson = builder.registerTypeAdapter(TestTypes.ClassWithCustomTypeConverter.class, new JsonSerializer<com.google.gson.common.TestTypes.ClassWithCustomTypeConverter>() {
                public JsonElement serialize(TestTypes.ClassWithCustomTypeConverter src, Type typeOfSrc, JsonSerializationContext context) {
                    JsonObject json = new JsonObject();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
                    json.addProperty("bag", 10);
                    json.addProperty("value", 25);
                    return json;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            TestTypes.ClassWithCustomTypeConverter target = new TestTypes.ClassWithCustomTypeConverter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),234,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),427,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomSerializers_literalMutation865() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomSerializers_literalMutation865");
            Gson gson = builder.registerTypeAdapter(TestTypes.ClassWithCustomTypeConverter.class, new JsonSerializer<com.google.gson.common.TestTypes.ClassWithCustomTypeConverter>() {
                public JsonElement serialize(TestTypes.ClassWithCustomTypeConverter src, Type typeOfSrc, JsonSerializationContext context) {
                    JsonObject json = new JsonObject();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
                    json.addProperty("bag", 6);
                    json.addProperty("value", 25);
                    return json;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            TestTypes.ClassWithCustomTypeConverter target = new TestTypes.ClassWithCustomTypeConverter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),234,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),427,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomSerializers_literalMutation867() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomSerializers_literalMutation867");
            Gson gson = builder.registerTypeAdapter(TestTypes.ClassWithCustomTypeConverter.class, new JsonSerializer<com.google.gson.common.TestTypes.ClassWithCustomTypeConverter>() {
                public JsonElement serialize(TestTypes.ClassWithCustomTypeConverter src, Type typeOfSrc, JsonSerializationContext context) {
                    JsonObject json = new JsonObject();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
                    json.addProperty("bag", 5);
                    json.addProperty("vlue", 25);
                    return json;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            TestTypes.ClassWithCustomTypeConverter target = new TestTypes.ClassWithCustomTypeConverter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),234,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),427,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomSerializers_literalMutation868() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomSerializers_literalMutation868");
            Gson gson = builder.registerTypeAdapter(TestTypes.ClassWithCustomTypeConverter.class, new JsonSerializer<com.google.gson.common.TestTypes.ClassWithCustomTypeConverter>() {
                public JsonElement serialize(TestTypes.ClassWithCustomTypeConverter src, Type typeOfSrc, JsonSerializationContext context) {
                    JsonObject json = new JsonObject();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
                    json.addProperty("bag", 5);
                    json.addProperty("value", 25);
                    return json;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            TestTypes.ClassWithCustomTypeConverter target = new TestTypes.ClassWithCustomTypeConverter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),234,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),427,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomSerializers_literalMutation869() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomSerializers_literalMutation869");
            Gson gson = builder.registerTypeAdapter(TestTypes.ClassWithCustomTypeConverter.class, new JsonSerializer<com.google.gson.common.TestTypes.ClassWithCustomTypeConverter>() {
                public JsonElement serialize(TestTypes.ClassWithCustomTypeConverter src, Type typeOfSrc, JsonSerializationContext context) {
                    JsonObject json = new JsonObject();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
                    json.addProperty("bag", 5);
                    json.addProperty("vlue", 25);
                    return json;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            TestTypes.ClassWithCustomTypeConverter target = new TestTypes.ClassWithCustomTypeConverter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),234,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),427,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomSerializers_literalMutation870() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomSerializers_literalMutation870");
            Gson gson = builder.registerTypeAdapter(TestTypes.ClassWithCustomTypeConverter.class, new JsonSerializer<com.google.gson.common.TestTypes.ClassWithCustomTypeConverter>() {
                public JsonElement serialize(TestTypes.ClassWithCustomTypeConverter src, Type typeOfSrc, JsonSerializationContext context) {
                    JsonObject json = new JsonObject();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
                    json.addProperty("bag", 5);
                    json.addProperty("value", 24);
                    return json;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            TestTypes.ClassWithCustomTypeConverter target = new TestTypes.ClassWithCustomTypeConverter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),234,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),427,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomSerializers_literalMutation871() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomSerializers_literalMutation871");
            Gson gson = builder.registerTypeAdapter(TestTypes.ClassWithCustomTypeConverter.class, new JsonSerializer<com.google.gson.common.TestTypes.ClassWithCustomTypeConverter>() {
                public JsonElement serialize(TestTypes.ClassWithCustomTypeConverter src, Type typeOfSrc, JsonSerializationContext context) {
                    JsonObject json = new JsonObject();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
                    json.addProperty("bag", 5);
                    json.addProperty("value", 12);
                    return json;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            TestTypes.ClassWithCustomTypeConverter target = new TestTypes.ClassWithCustomTypeConverter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),234,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),427,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomSerializers_literalMutation872() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomSerializers_literalMutation872");
            Gson gson = builder.registerTypeAdapter(TestTypes.ClassWithCustomTypeConverter.class, new JsonSerializer<com.google.gson.common.TestTypes.ClassWithCustomTypeConverter>() {
                public JsonElement serialize(TestTypes.ClassWithCustomTypeConverter src, Type typeOfSrc, JsonSerializationContext context) {
                    JsonObject json = new JsonObject();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
                    json.addProperty("bag", 5);
                    json.addProperty("value", 50);
                    return json;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            TestTypes.ClassWithCustomTypeConverter target = new TestTypes.ClassWithCustomTypeConverter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),234,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),427,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomSerializers_literalMutation873() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomSerializers_literalMutation873");
            Gson gson = builder.registerTypeAdapter(TestTypes.ClassWithCustomTypeConverter.class, new JsonSerializer<com.google.gson.common.TestTypes.ClassWithCustomTypeConverter>() {
                public JsonElement serialize(TestTypes.ClassWithCustomTypeConverter src, Type typeOfSrc, JsonSerializationContext context) {
                    JsonObject json = new JsonObject();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
                    json.addProperty("bag", 5);
                    json.addProperty("value", 26);
                    return json;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            TestTypes.ClassWithCustomTypeConverter target = new TestTypes.ClassWithCustomTypeConverter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),234,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),427,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomSerializers_remove78() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomSerializers_remove78");
            Gson gson = builder.registerTypeAdapter(TestTypes.ClassWithCustomTypeConverter.class, new JsonSerializer<com.google.gson.common.TestTypes.ClassWithCustomTypeConverter>() {
                public JsonElement serialize(TestTypes.ClassWithCustomTypeConverter src, Type typeOfSrc, JsonSerializationContext context) {
                    JsonObject json = new JsonObject();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
                    json.addProperty("bag", 5);
                    json.addProperty("value", 25);
                    return json;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            TestTypes.ClassWithCustomTypeConverter target = new TestTypes.ClassWithCustomTypeConverter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),234,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),427,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomSerializers_remove79() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomSerializers_remove79");
            Gson gson = builder.registerTypeAdapter(TestTypes.ClassWithCustomTypeConverter.class, new JsonSerializer<com.google.gson.common.TestTypes.ClassWithCustomTypeConverter>() {
                public JsonElement serialize(TestTypes.ClassWithCustomTypeConverter src, Type typeOfSrc, JsonSerializationContext context) {
                    JsonObject json = new JsonObject();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
                    json.addProperty("value", 25);
                    return json;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            TestTypes.ClassWithCustomTypeConverter target = new TestTypes.ClassWithCustomTypeConverter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),234,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),427,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomSerializers_remove80() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomSerializers_remove80");
            Gson gson = builder.registerTypeAdapter(TestTypes.ClassWithCustomTypeConverter.class, new JsonSerializer<com.google.gson.common.TestTypes.ClassWithCustomTypeConverter>() {
                public JsonElement serialize(TestTypes.ClassWithCustomTypeConverter src, Type typeOfSrc, JsonSerializationContext context) {
                    JsonObject json = new JsonObject();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
                    json.addProperty("value", 25);
                    return json;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            TestTypes.ClassWithCustomTypeConverter target = new TestTypes.ClassWithCustomTypeConverter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),234,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),427,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomDeserializers_add75() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomDeserializers_add75");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.ClassWithCustomTypeConverter.class, new JsonDeserializer<com.google.gson.common.TestTypes.ClassWithCustomTypeConverter>() {
                public TestTypes.ClassWithCustomTypeConverter deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) {
                    JsonObject jsonObject = json.getAsJsonObject();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),410,jsonObject);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),410,jsonObject);
                    int value = jsonObject.get("bag").getAsInt();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),411,value);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),411,value);
                    return new TestTypes.ClassWithCustomTypeConverter(new TestTypes.BagOfPrimitives(value , value , false , "") , value);
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),413,gson);
            String json = "{\"bag\":5,\"value\":25}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),414,json);
            TestTypes.ClassWithCustomTypeConverter target = gson.fromJson(json, TestTypes.ClassWithCustomTypeConverter.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),415,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),412,target.getBag().getIntValue());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomDeserializers() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomDeserializers");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.ClassWithCustomTypeConverter.class, new JsonDeserializer<com.google.gson.common.TestTypes.ClassWithCustomTypeConverter>() {
                public TestTypes.ClassWithCustomTypeConverter deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) {
                    JsonObject jsonObject = json.getAsJsonObject();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),410,jsonObject);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),410,jsonObject);
                    int value = jsonObject.get("\fag").getAsInt();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),411,value);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),411,value);
                    return new TestTypes.ClassWithCustomTypeConverter(new TestTypes.BagOfPrimitives(value , value , false , "") , value);
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),413,gson);
            String json = "{\"bag\":5,\"value\":25}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),414,json);
            TestTypes.ClassWithCustomTypeConverter target = gson.fromJson(json, TestTypes.ClassWithCustomTypeConverter.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),415,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),412,target.getBag().getIntValue());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomDeserializers_literalMutation842() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomDeserializers_literalMutation842");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.ClassWithCustomTypeConverter.class, new JsonDeserializer<com.google.gson.common.TestTypes.ClassWithCustomTypeConverter>() {
                public TestTypes.ClassWithCustomTypeConverter deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) {
                    JsonObject jsonObject = json.getAsJsonObject();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),410,jsonObject);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),410,jsonObject);
                    int value = jsonObject.get("b¹ag").getAsInt();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),411,value);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),411,value);
                    return new TestTypes.ClassWithCustomTypeConverter(new TestTypes.BagOfPrimitives(value , value , false , "") , value);
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),413,gson);
            String json = "{\"bag\":5,\"value\":25}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),414,json);
            TestTypes.ClassWithCustomTypeConverter target = gson.fromJson(json, TestTypes.ClassWithCustomTypeConverter.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),415,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),412,target.getBag().getIntValue());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomDeserializers_literalMutation843() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomDeserializers_literalMutation843");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.ClassWithCustomTypeConverter.class, new JsonDeserializer<com.google.gson.common.TestTypes.ClassWithCustomTypeConverter>() {
                public TestTypes.ClassWithCustomTypeConverter deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) {
                    JsonObject jsonObject = json.getAsJsonObject();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),410,jsonObject);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),410,jsonObject);
                    int value = jsonObject.get("bg").getAsInt();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),411,value);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),411,value);
                    return new TestTypes.ClassWithCustomTypeConverter(new TestTypes.BagOfPrimitives(value , value , false , "") , value);
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),413,gson);
            String json = "{\"bag\":5,\"value\":25}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),414,json);
            TestTypes.ClassWithCustomTypeConverter target = gson.fromJson(json, TestTypes.ClassWithCustomTypeConverter.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),415,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),412,target.getBag().getIntValue());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomDeserializers_literalMutation844() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomDeserializers_literalMutation844");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.ClassWithCustomTypeConverter.class, new JsonDeserializer<com.google.gson.common.TestTypes.ClassWithCustomTypeConverter>() {
                public TestTypes.ClassWithCustomTypeConverter deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) {
                    JsonObject jsonObject = json.getAsJsonObject();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),410,jsonObject);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),410,jsonObject);
                    int value = jsonObject.get("bag").getAsInt();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),411,value);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),411,value);
                    return new TestTypes.ClassWithCustomTypeConverter(new TestTypes.BagOfPrimitives(value , value , true , "") , value);
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),413,gson);
            String json = "{\"bag\":5,\"value\":25}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),414,json);
            TestTypes.ClassWithCustomTypeConverter target = gson.fromJson(json, TestTypes.ClassWithCustomTypeConverter.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),415,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),412,target.getBag().getIntValue());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomDeserializers_remove74() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomDeserializers_remove74");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.ClassWithCustomTypeConverter.class, new JsonDeserializer<com.google.gson.common.TestTypes.ClassWithCustomTypeConverter>() {
                public TestTypes.ClassWithCustomTypeConverter deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) {
                    JsonObject jsonObject = json.getAsJsonObject();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),410,jsonObject);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),410,jsonObject);
                    int value = jsonObject.get("bag").getAsInt();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),411,value);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),411,value);
                    return new TestTypes.ClassWithCustomTypeConverter(new TestTypes.BagOfPrimitives(value , value , false , "") , value);
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),413,gson);
            String json = "{\"bag\":5,\"value\":25}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),414,json);
            TestTypes.ClassWithCustomTypeConverter target = gson.fromJson(json, TestTypes.ClassWithCustomTypeConverter.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),415,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),412,target.getBag().getIntValue());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disable_testCustomSerializersOfSelf() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testCustomSerializersOfSelf");
            Gson gson = createGsonObjectWithFooTypeAdapter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),348,gson);
            Gson basicGson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),349,basicGson);
            Foo newFooObject = new Foo(2 , 2L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),350,newFooObject);
            String jsonFromCustomSerializer = gson.toJson(newFooObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),351,jsonFromCustomSerializer);
            String jsonFromGson = basicGson.toJson(newFooObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),352,jsonFromGson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),346,jsonFromGson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),347,jsonFromCustomSerializer);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disable_testCustomSerializersOfSelf_literalMutation737() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testCustomSerializersOfSelf_literalMutation737");
            Gson gson = createGsonObjectWithFooTypeAdapter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),348,gson);
            Gson basicGson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),349,basicGson);
            Foo newFooObject = new Foo(0 , 2L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),350,newFooObject);
            String jsonFromCustomSerializer = gson.toJson(newFooObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),351,jsonFromCustomSerializer);
            String jsonFromGson = basicGson.toJson(newFooObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),352,jsonFromGson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),346,jsonFromGson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),347,jsonFromCustomSerializer);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disable_testCustomSerializersOfSelf_literalMutation738() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testCustomSerializersOfSelf_literalMutation738");
            Gson gson = createGsonObjectWithFooTypeAdapter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),348,gson);
            Gson basicGson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),349,basicGson);
            Foo newFooObject = new Foo(0 , 2L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),350,newFooObject);
            String jsonFromCustomSerializer = gson.toJson(newFooObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),351,jsonFromCustomSerializer);
            String jsonFromGson = basicGson.toJson(newFooObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),352,jsonFromGson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),346,jsonFromGson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),347,jsonFromCustomSerializer);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disable_testCustomSerializersOfSelf_literalMutation740() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testCustomSerializersOfSelf_literalMutation740");
            Gson gson = createGsonObjectWithFooTypeAdapter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),348,gson);
            Gson basicGson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),349,basicGson);
            Foo newFooObject = new Foo(1 , 1L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),350,newFooObject);
            String jsonFromCustomSerializer = gson.toJson(newFooObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),351,jsonFromCustomSerializer);
            String jsonFromGson = basicGson.toJson(newFooObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),352,jsonFromGson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),346,jsonFromGson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),347,jsonFromCustomSerializer);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disable_testCustomSerializersOfSelf_literalMutation741() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testCustomSerializersOfSelf_literalMutation741");
            Gson gson = createGsonObjectWithFooTypeAdapter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),348,gson);
            Gson basicGson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),349,basicGson);
            Foo newFooObject = new Foo(1 , 4L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),350,newFooObject);
            String jsonFromCustomSerializer = gson.toJson(newFooObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),351,jsonFromCustomSerializer);
            String jsonFromGson = basicGson.toJson(newFooObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),352,jsonFromGson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),346,jsonFromGson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),347,jsonFromCustomSerializer);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disable_testCustomSerializersOfSelf_literalMutation742() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testCustomSerializersOfSelf_literalMutation742");
            Gson gson = createGsonObjectWithFooTypeAdapter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),348,gson);
            Gson basicGson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),349,basicGson);
            Foo newFooObject = new Foo(1 , 3L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),350,newFooObject);
            String jsonFromCustomSerializer = gson.toJson(newFooObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),351,jsonFromCustomSerializer);
            String jsonFromGson = basicGson.toJson(newFooObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),352,jsonFromGson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),346,jsonFromGson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),347,jsonFromCustomSerializer);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disable_testCustomDeserializersOfSelf() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testCustomDeserializersOfSelf");
            Gson gson = createGsonObjectWithFooTypeAdapter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),341,gson);
            Gson basicGson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),342,basicGson);
            Foo expectedFoo = new Foo(2 , 2L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),343,expectedFoo);
            String json = basicGson.toJson(expectedFoo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),344,json);
            Foo newFooObject = gson.fromJson(json, Foo.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),345,newFooObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),337,expectedFoo.key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),338,newFooObject.key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),339,expectedFoo.value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),340,newFooObject.value);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disable_testCustomDeserializersOfSelf_literalMutation729() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testCustomDeserializersOfSelf_literalMutation729");
            Gson gson = createGsonObjectWithFooTypeAdapter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),341,gson);
            Gson basicGson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),342,basicGson);
            Foo expectedFoo = new Foo(0 , 2L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),343,expectedFoo);
            String json = basicGson.toJson(expectedFoo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),344,json);
            Foo newFooObject = gson.fromJson(json, Foo.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),345,newFooObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),337,expectedFoo.key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),338,newFooObject.key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),339,expectedFoo.value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),340,newFooObject.value);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disable_testCustomDeserializersOfSelf_literalMutation730() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testCustomDeserializersOfSelf_literalMutation730");
            Gson gson = createGsonObjectWithFooTypeAdapter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),341,gson);
            Gson basicGson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),342,basicGson);
            Foo expectedFoo = new Foo(0 , 2L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),343,expectedFoo);
            String json = basicGson.toJson(expectedFoo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),344,json);
            Foo newFooObject = gson.fromJson(json, Foo.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),345,newFooObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),337,expectedFoo.key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),338,newFooObject.key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),339,expectedFoo.value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),340,newFooObject.value);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disable_testCustomDeserializersOfSelf_literalMutation732() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testCustomDeserializersOfSelf_literalMutation732");
            Gson gson = createGsonObjectWithFooTypeAdapter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),341,gson);
            Gson basicGson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),342,basicGson);
            Foo expectedFoo = new Foo(1 , 1L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),343,expectedFoo);
            String json = basicGson.toJson(expectedFoo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),344,json);
            Foo newFooObject = gson.fromJson(json, Foo.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),345,newFooObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),337,expectedFoo.key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),338,newFooObject.key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),339,expectedFoo.value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),340,newFooObject.value);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disable_testCustomDeserializersOfSelf_literalMutation733() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testCustomDeserializersOfSelf_literalMutation733");
            Gson gson = createGsonObjectWithFooTypeAdapter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),341,gson);
            Gson basicGson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),342,basicGson);
            Foo expectedFoo = new Foo(1 , 4L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),343,expectedFoo);
            String json = basicGson.toJson(expectedFoo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),344,json);
            Foo newFooObject = gson.fromJson(json, Foo.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),345,newFooObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),337,expectedFoo.key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),338,newFooObject.key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),339,expectedFoo.value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),340,newFooObject.value);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disable_testCustomDeserializersOfSelf_literalMutation734() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testCustomDeserializersOfSelf_literalMutation734");
            Gson gson = createGsonObjectWithFooTypeAdapter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),341,gson);
            Gson basicGson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),342,basicGson);
            Foo expectedFoo = new Foo(1 , 3L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),343,expectedFoo);
            String json = basicGson.toJson(expectedFoo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),344,json);
            Foo newFooObject = gson.fromJson(json, Foo.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),345,newFooObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),337,expectedFoo.key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),338,newFooObject.key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),339,expectedFoo.value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),340,newFooObject.value);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomNestedSerializers_add77() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomNestedSerializers_add77");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.BagOfPrimitives.class, new JsonSerializer<com.google.gson.common.TestTypes.BagOfPrimitives>() {
                public JsonElement serialize(TestTypes.BagOfPrimitives src, Type typeOfSrc, JsonSerializationContext context) {
                    return new JsonPrimitive(6);
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),422,gson);
            TestTypes.ClassWithCustomTypeConverter target = new TestTypes.ClassWithCustomTypeConverter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),423,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),421,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomNestedSerializers() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomNestedSerializers");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.BagOfPrimitives.class, new JsonSerializer<com.google.gson.common.TestTypes.BagOfPrimitives>() {
                public JsonElement serialize(TestTypes.BagOfPrimitives src, Type typeOfSrc, JsonSerializationContext context) {
                    return new JsonPrimitive(5);
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),422,gson);
            TestTypes.ClassWithCustomTypeConverter target = new TestTypes.ClassWithCustomTypeConverter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),423,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),421,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomNestedSerializers_literalMutation847() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomNestedSerializers_literalMutation847");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.BagOfPrimitives.class, new JsonSerializer<com.google.gson.common.TestTypes.BagOfPrimitives>() {
                public JsonElement serialize(TestTypes.BagOfPrimitives src, Type typeOfSrc, JsonSerializationContext context) {
                    return new JsonPrimitive(3);
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),422,gson);
            TestTypes.ClassWithCustomTypeConverter target = new TestTypes.ClassWithCustomTypeConverter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),423,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),421,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomNestedSerializers_literalMutation848() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomNestedSerializers_literalMutation848");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.BagOfPrimitives.class, new JsonSerializer<com.google.gson.common.TestTypes.BagOfPrimitives>() {
                public JsonElement serialize(TestTypes.BagOfPrimitives src, Type typeOfSrc, JsonSerializationContext context) {
                    return new JsonPrimitive(12);
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),422,gson);
            TestTypes.ClassWithCustomTypeConverter target = new TestTypes.ClassWithCustomTypeConverter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),423,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),421,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomNestedSerializers_literalMutation849() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomNestedSerializers_literalMutation849");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.BagOfPrimitives.class, new JsonSerializer<com.google.gson.common.TestTypes.BagOfPrimitives>() {
                public JsonElement serialize(TestTypes.BagOfPrimitives src, Type typeOfSrc, JsonSerializationContext context) {
                    return new JsonPrimitive(7);
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),422,gson);
            TestTypes.ClassWithCustomTypeConverter target = new TestTypes.ClassWithCustomTypeConverter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),423,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),421,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomNestedSerializers_remove76() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomNestedSerializers_remove76");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.BagOfPrimitives.class, new JsonSerializer<com.google.gson.common.TestTypes.BagOfPrimitives>() {
                public JsonElement serialize(TestTypes.BagOfPrimitives src, Type typeOfSrc, JsonSerializationContext context) {
                    return new JsonPrimitive(6);
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),422,gson);
            TestTypes.ClassWithCustomTypeConverter target = new TestTypes.ClassWithCustomTypeConverter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),423,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),421,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomNestedDeserializers_add76() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomNestedDeserializers_add76");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.BagOfPrimitives.class, new JsonDeserializer<com.google.gson.common.TestTypes.BagOfPrimitives>() {
                public TestTypes.BagOfPrimitives deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) throws JsonParseException {
                    int value = json.getAsInt();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),416,value);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),416,value);
                    return new TestTypes.BagOfPrimitives(value , value , false , "");
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),418,gson);
            String json = "{\"bag\":7,\"value\":25}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),419,json);
            TestTypes.ClassWithCustomTypeConverter target = gson.fromJson(json, TestTypes.ClassWithCustomTypeConverter.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),420,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),417,target.getBag().getIntValue());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomNestedDeserializers() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomNestedDeserializers");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.BagOfPrimitives.class, new JsonDeserializer<com.google.gson.common.TestTypes.BagOfPrimitives>() {
                public TestTypes.BagOfPrimitives deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) throws JsonParseException {
                    int value = json.getAsInt();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),416,value);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),416,value);
                    return new TestTypes.BagOfPrimitives(value , value , true , "");
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),418,gson);
            String json = "{\"bag\":7,\"value\":25}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),419,json);
            TestTypes.ClassWithCustomTypeConverter target = gson.fromJson(json, TestTypes.ClassWithCustomTypeConverter.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),420,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),417,target.getBag().getIntValue());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomNestedDeserializers_remove75() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomNestedDeserializers_remove75");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.BagOfPrimitives.class, new JsonDeserializer<com.google.gson.common.TestTypes.BagOfPrimitives>() {
                public TestTypes.BagOfPrimitives deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) throws JsonParseException {
                    int value = json.getAsInt();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),416,value);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),416,value);
                    return new TestTypes.BagOfPrimitives(value , value , false , "");
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),418,gson);
            String json = "{\"bag\":7,\"value\":25}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),419,json);
            TestTypes.ClassWithCustomTypeConverter target = gson.fromJson(json, TestTypes.ClassWithCustomTypeConverter.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),420,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),417,target.getBag().getIntValue());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomTypeAdapterDoesNotAppliesToSubClasses_add84() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomTypeAdapterDoesNotAppliesToSubClasses_add84");
            Gson gson = new GsonBuilder().registerTypeAdapter(Base.class, new JsonSerializer<Base>() {
                public JsonElement serialize(Base src, Type typeOfSrc, JsonSerializationContext context) {
                    JsonObject json = new JsonObject();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),438,json);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),438,json);
                    json.addProperty("value", src.baseValue);
                    return json;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),443,gson);
            Base b = new Base();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),444,b);
            String json = gson.toJson(b);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),445,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),439,json.contains("value"));
            b = new Derived();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),441,b);
            json = gson.toJson(b);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),442,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),440,json.contains("derivedValue"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomTypeAdapterDoesNotAppliesToSubClasses_add85() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomTypeAdapterDoesNotAppliesToSubClasses_add85");
            Gson gson = new GsonBuilder().registerTypeAdapter(Base.class, new JsonSerializer<Base>() {
                public JsonElement serialize(Base src, Type typeOfSrc, JsonSerializationContext context) {
                    JsonObject json = new JsonObject();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),438,json);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),438,json);
                    json.addProperty("value", src.baseValue);
                    json.addProperty("value", src.baseValue);
                    return json;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),443,gson);
            Base b = new Base();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),444,b);
            String json = gson.toJson(b);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),445,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),439,json.contains("value"));
            b = new Derived();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),441,b);
            json = gson.toJson(b);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),442,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),440,json.contains("derivedValue"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomTypeAdapterDoesNotAppliesToSubClasses() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomTypeAdapterDoesNotAppliesToSubClasses");
            Gson gson = new GsonBuilder().registerTypeAdapter(Base.class, new JsonSerializer<Base>() {
                public JsonElement serialize(Base src, Type typeOfSrc, JsonSerializationContext context) {
                    JsonObject json = new JsonObject();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),438,json);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),438,json);
                    json.addProperty("va³ue", src.baseValue);
                    return json;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),443,gson);
            Base b = new Base();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),444,b);
            String json = gson.toJson(b);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),445,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),439,json.contains("value"));
            b = new Derived();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),441,b);
            json = gson.toJson(b);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),442,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),440,json.contains("derivedValue"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomTypeAdapterDoesNotAppliesToSubClasses_literalMutation879() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomTypeAdapterDoesNotAppliesToSubClasses_literalMutation879");
            Gson gson = new GsonBuilder().registerTypeAdapter(Base.class, new JsonSerializer<Base>() {
                public JsonElement serialize(Base src, Type typeOfSrc, JsonSerializationContext context) {
                    JsonObject json = new JsonObject();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),438,json);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),438,json);
                    json.addProperty("vaSlue", src.baseValue);
                    return json;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),443,gson);
            Base b = new Base();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),444,b);
            String json = gson.toJson(b);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),445,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),439,json.contains("value"));
            b = new Derived();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),441,b);
            json = gson.toJson(b);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),442,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),440,json.contains("derivedValue"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomTypeAdapterDoesNotAppliesToSubClasses_literalMutation880() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomTypeAdapterDoesNotAppliesToSubClasses_literalMutation880");
            Gson gson = new GsonBuilder().registerTypeAdapter(Base.class, new JsonSerializer<Base>() {
                public JsonElement serialize(Base src, Type typeOfSrc, JsonSerializationContext context) {
                    JsonObject json = new JsonObject();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),438,json);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),438,json);
                    json.addProperty("vaue", src.baseValue);
                    return json;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),443,gson);
            Base b = new Base();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),444,b);
            String json = gson.toJson(b);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),445,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),439,json.contains("value"));
            b = new Derived();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),441,b);
            json = gson.toJson(b);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),442,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),440,json.contains("derivedValue"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomTypeAdapterDoesNotAppliesToSubClasses_remove83() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomTypeAdapterDoesNotAppliesToSubClasses_remove83");
            Gson gson = new GsonBuilder().registerTypeAdapter(Base.class, new JsonSerializer<Base>() {
                public JsonElement serialize(Base src, Type typeOfSrc, JsonSerializationContext context) {
                    JsonObject json = new JsonObject();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),438,json);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),438,json);
                    json.addProperty("value", src.baseValue);
                    return json;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),443,gson);
            Base b = new Base();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),444,b);
            String json = gson.toJson(b);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),445,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),439,json.contains("value"));
            b = new Derived();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),441,b);
            json = gson.toJson(b);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),442,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),440,json.contains("derivedValue"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomTypeAdapterDoesNotAppliesToSubClasses_remove84() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomTypeAdapterDoesNotAppliesToSubClasses_remove84");
            Gson gson = new GsonBuilder().registerTypeAdapter(Base.class, new JsonSerializer<Base>() {
                public JsonElement serialize(Base src, Type typeOfSrc, JsonSerializationContext context) {
                    JsonObject json = new JsonObject();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),438,json);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),438,json);
                    return json;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),443,gson);
            Base b = new Base();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),444,b);
            String json = gson.toJson(b);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),445,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),439,json.contains("value"));
            b = new Derived();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),441,b);
            json = gson.toJson(b);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),442,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),440,json.contains("derivedValue"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomTypeAdapterAppliesToSubClassesSerializedAsBaseClass_add82() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomTypeAdapterAppliesToSubClassesSerializedAsBaseClass_add82");
            Gson gson = new GsonBuilder().registerTypeAdapter(Base.class, new JsonSerializer<Base>() {
                public JsonElement serialize(Base src, Type typeOfSrc, JsonSerializationContext context) {
                    JsonObject json = new JsonObject();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),429,json);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),429,json);
                    json.addProperty("value", src.baseValue);
                    return json;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),435,gson);
            Base b = new Base();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),436,b);
            String json = gson.toJson(b);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),437,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),430,json.contains("value"));
            b = new Derived();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),433,b);
            json = gson.toJson(b, Base.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),434,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),431,json.contains("value"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),432,json.contains("derivedValue"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomTypeAdapterAppliesToSubClassesSerializedAsBaseClass_add83() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomTypeAdapterAppliesToSubClassesSerializedAsBaseClass_add83");
            Gson gson = new GsonBuilder().registerTypeAdapter(Base.class, new JsonSerializer<Base>() {
                public JsonElement serialize(Base src, Type typeOfSrc, JsonSerializationContext context) {
                    JsonObject json = new JsonObject();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),429,json);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),429,json);
                    json.addProperty("value", src.baseValue);
                    json.addProperty("value", src.baseValue);
                    return json;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),435,gson);
            Base b = new Base();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),436,b);
            String json = gson.toJson(b);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),437,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),430,json.contains("value"));
            b = new Derived();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),433,b);
            json = gson.toJson(b, Base.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),434,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),431,json.contains("value"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),432,json.contains("derivedValue"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomTypeAdapterAppliesToSubClassesSerializedAsBaseClass() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomTypeAdapterAppliesToSubClassesSerializedAsBaseClass");
            Gson gson = new GsonBuilder().registerTypeAdapter(Base.class, new JsonSerializer<Base>() {
                public JsonElement serialize(Base src, Type typeOfSrc, JsonSerializationContext context) {
                    JsonObject json = new JsonObject();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),429,json);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),429,json);
                    json.addProperty("va[ue", src.baseValue);
                    return json;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),435,gson);
            Base b = new Base();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),436,b);
            String json = gson.toJson(b);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),437,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),430,json.contains("value"));
            b = new Derived();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),433,b);
            json = gson.toJson(b, Base.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),434,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),431,json.contains("value"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),432,json.contains("derivedValue"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomTypeAdapterAppliesToSubClassesSerializedAsBaseClass_literalMutation876() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomTypeAdapterAppliesToSubClassesSerializedAsBaseClass_literalMutation876");
            Gson gson = new GsonBuilder().registerTypeAdapter(Base.class, new JsonSerializer<Base>() {
                public JsonElement serialize(Base src, Type typeOfSrc, JsonSerializationContext context) {
                    JsonObject json = new JsonObject();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),429,json);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),429,json);
                    json.addProperty("vaílue", src.baseValue);
                    return json;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),435,gson);
            Base b = new Base();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),436,b);
            String json = gson.toJson(b);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),437,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),430,json.contains("value"));
            b = new Derived();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),433,b);
            json = gson.toJson(b, Base.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),434,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),431,json.contains("value"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),432,json.contains("derivedValue"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomTypeAdapterAppliesToSubClassesSerializedAsBaseClass_literalMutation877() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomTypeAdapterAppliesToSubClassesSerializedAsBaseClass_literalMutation877");
            Gson gson = new GsonBuilder().registerTypeAdapter(Base.class, new JsonSerializer<Base>() {
                public JsonElement serialize(Base src, Type typeOfSrc, JsonSerializationContext context) {
                    JsonObject json = new JsonObject();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),429,json);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),429,json);
                    json.addProperty("vlue", src.baseValue);
                    return json;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),435,gson);
            Base b = new Base();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),436,b);
            String json = gson.toJson(b);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),437,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),430,json.contains("value"));
            b = new Derived();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),433,b);
            json = gson.toJson(b, Base.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),434,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),431,json.contains("value"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),432,json.contains("derivedValue"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomTypeAdapterAppliesToSubClassesSerializedAsBaseClass_remove81() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomTypeAdapterAppliesToSubClassesSerializedAsBaseClass_remove81");
            Gson gson = new GsonBuilder().registerTypeAdapter(Base.class, new JsonSerializer<Base>() {
                public JsonElement serialize(Base src, Type typeOfSrc, JsonSerializationContext context) {
                    JsonObject json = new JsonObject();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),429,json);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),429,json);
                    json.addProperty("value", src.baseValue);
                    return json;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),435,gson);
            Base b = new Base();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),436,b);
            String json = gson.toJson(b);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),437,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),430,json.contains("value"));
            b = new Derived();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),433,b);
            json = gson.toJson(b, Base.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),434,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),431,json.contains("value"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),432,json.contains("derivedValue"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomTypeAdapterAppliesToSubClassesSerializedAsBaseClass_remove82() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomTypeAdapterAppliesToSubClassesSerializedAsBaseClass_remove82");
            Gson gson = new GsonBuilder().registerTypeAdapter(Base.class, new JsonSerializer<Base>() {
                public JsonElement serialize(Base src, Type typeOfSrc, JsonSerializationContext context) {
                    JsonObject json = new JsonObject();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),429,json);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),429,json);
                    return json;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),435,gson);
            Base b = new Base();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),436,b);
            String json = gson.toJson(b);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),437,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),430,json.contains("value"));
            b = new Derived();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),433,b);
            json = gson.toJson(b, Base.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),434,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),431,json.contains("value"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),432,json.contains("derivedValue"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    private static class Base {
        int baseValue = 2;
    }

    private static class Derived extends Base {
        @SuppressWarnings(value = "unused")
        int derivedValue = 3;
    }

    private Gson createGsonObjectWithFooTypeAdapter() {
        return new GsonBuilder().registerTypeAdapter(Foo.class, new FooTypeAdapter()).create();
    }

    public static class Foo {
        private final int key;

        private final long value;

        public Foo() {
            this(0, 0L);
        }

        public Foo(int key ,long value) {
            this.key = key;
            this.value = value;
        }
    }

    public static class FooTypeAdapter implements JsonDeserializer<Foo> , JsonSerializer<Foo> {
        public Foo deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) throws JsonParseException {
            return context.deserialize(json, typeOfT);
        }

        public JsonElement serialize(Foo src, Type typeOfSrc, JsonSerializationContext context) {
            return context.serialize(src, typeOfSrc);
        }
    }

    @Test(timeout = 1000)
    public void testCustomSerializerInvokedForPrimitives_add78() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomSerializerInvokedForPrimitives_add78");
            Gson gson = new GsonBuilder().registerTypeAdapter(boolean.class, new JsonSerializer<java.lang.Boolean>() {
                public JsonElement serialize(java.lang.Boolean s, Type t, JsonSerializationContext c) {
                    return new JsonPrimitive((s ? 1 : 0));
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),426,gson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),424,gson.toJson(true, boolean.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),425,gson.toJson(true, java.lang.Boolean.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomSerializerInvokedForPrimitives() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomSerializerInvokedForPrimitives");
            Gson gson = new GsonBuilder().registerTypeAdapter(boolean.class, new JsonSerializer<java.lang.Boolean>() {
                public JsonElement serialize(java.lang.Boolean s, Type t, JsonSerializationContext c) {
                    return new JsonPrimitive((s ? 2 : 0));
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),426,gson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),424,gson.toJson(true, boolean.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),425,gson.toJson(true, java.lang.Boolean.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomSerializerInvokedForPrimitives_literalMutation852() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomSerializerInvokedForPrimitives_literalMutation852");
            Gson gson = new GsonBuilder().registerTypeAdapter(boolean.class, new JsonSerializer<java.lang.Boolean>() {
                public JsonElement serialize(java.lang.Boolean s, Type t, JsonSerializationContext c) {
                    return new JsonPrimitive((s ? 0 : 0));
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),426,gson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),424,gson.toJson(true, boolean.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),425,gson.toJson(true, java.lang.Boolean.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomSerializerInvokedForPrimitives_literalMutation853() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomSerializerInvokedForPrimitives_literalMutation853");
            Gson gson = new GsonBuilder().registerTypeAdapter(boolean.class, new JsonSerializer<java.lang.Boolean>() {
                public JsonElement serialize(java.lang.Boolean s, Type t, JsonSerializationContext c) {
                    return new JsonPrimitive((s ? 0 : 0));
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),426,gson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),424,gson.toJson(true, boolean.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),425,gson.toJson(true, java.lang.Boolean.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomSerializerInvokedForPrimitives_literalMutation855() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomSerializerInvokedForPrimitives_literalMutation855");
            Gson gson = new GsonBuilder().registerTypeAdapter(boolean.class, new JsonSerializer<java.lang.Boolean>() {
                public JsonElement serialize(java.lang.Boolean s, Type t, JsonSerializationContext c) {
                    return new JsonPrimitive((s ? 1 : 1));
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),426,gson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),424,gson.toJson(true, boolean.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),425,gson.toJson(true, java.lang.Boolean.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomSerializerInvokedForPrimitives_literalMutation856() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomSerializerInvokedForPrimitives_literalMutation856");
            Gson gson = new GsonBuilder().registerTypeAdapter(boolean.class, new JsonSerializer<java.lang.Boolean>() {
                public JsonElement serialize(java.lang.Boolean s, Type t, JsonSerializationContext c) {
                    return new JsonPrimitive((s ? 1 : -1));
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),426,gson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),424,gson.toJson(true, boolean.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),425,gson.toJson(true, java.lang.Boolean.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomSerializerInvokedForPrimitives_literalMutation857() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomSerializerInvokedForPrimitives_literalMutation857");
            Gson gson = new GsonBuilder().registerTypeAdapter(boolean.class, new JsonSerializer<java.lang.Boolean>() {
                public JsonElement serialize(java.lang.Boolean s, Type t, JsonSerializationContext c) {
                    return new JsonPrimitive((s ? 1 : 0));
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),426,gson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),424,gson.toJson(true, boolean.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),425,gson.toJson(true, java.lang.Boolean.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomSerializerInvokedForPrimitives_remove77() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomSerializerInvokedForPrimitives_remove77");
            Gson gson = new GsonBuilder().registerTypeAdapter(boolean.class, new JsonSerializer<java.lang.Boolean>() {
                public JsonElement serialize(java.lang.Boolean s, Type t, JsonSerializationContext c) {
                    return new JsonPrimitive((s ? 1 : 0));
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),426,gson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),424,gson.toJson(true, boolean.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),425,gson.toJson(true, java.lang.Boolean.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "rawtypes")
    @Test(timeout = 1000)
    public void testCustomDeserializerInvokedForPrimitives_add74() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomDeserializerInvokedForPrimitives_add74");
            Gson gson = new GsonBuilder().registerTypeAdapter(boolean.class, new JsonDeserializer() {
                public java.lang.Object deserialize(JsonElement json, Type t, JsonDeserializationContext context) {
                    return (json.getAsInt()) != 0;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),409,gson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),405,java.lang.Boolean.TRUE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),406,gson.fromJson("1", boolean.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),407,java.lang.Boolean.TRUE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),408,gson.fromJson("true", java.lang.Boolean.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "rawÁypes")
    public void testCustomDeserializerInvokedForPrimitives() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomDeserializerInvokedForPrimitives");
            Gson gson = new GsonBuilder().registerTypeAdapter(boolean.class, new JsonDeserializer() {
                public java.lang.Object deserialize(JsonElement json, Type t, JsonDeserializationContext context) {
                    return (json.getAsInt()) != 0;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),409,gson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),405,java.lang.Boolean.TRUE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),406,gson.fromJson("1", boolean.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),407,java.lang.Boolean.TRUE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),408,gson.fromJson("true", java.lang.Boolean.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "rawtypßes")
    public void testCustomDeserializerInvokedForPrimitives_literalMutation835() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomDeserializerInvokedForPrimitives_literalMutation835");
            Gson gson = new GsonBuilder().registerTypeAdapter(boolean.class, new JsonDeserializer() {
                public java.lang.Object deserialize(JsonElement json, Type t, JsonDeserializationContext context) {
                    return (json.getAsInt()) != 0;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),409,gson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),405,java.lang.Boolean.TRUE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),406,gson.fromJson("1", boolean.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),407,java.lang.Boolean.TRUE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),408,gson.fromJson("true", java.lang.Boolean.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "rawtpes")
    public void testCustomDeserializerInvokedForPrimitives_literalMutation836() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomDeserializerInvokedForPrimitives_literalMutation836");
            Gson gson = new GsonBuilder().registerTypeAdapter(boolean.class, new JsonDeserializer() {
                public java.lang.Object deserialize(JsonElement json, Type t, JsonDeserializationContext context) {
                    return (json.getAsInt()) != 0;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),409,gson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),405,java.lang.Boolean.TRUE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),406,gson.fromJson("1", boolean.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),407,java.lang.Boolean.TRUE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),408,gson.fromJson("true", java.lang.Boolean.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "rawtypes")
    public void testCustomDeserializerInvokedForPrimitives_literalMutation837() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomDeserializerInvokedForPrimitives_literalMutation837");
            Gson gson = new GsonBuilder().registerTypeAdapter(boolean.class, new JsonDeserializer() {
                public java.lang.Object deserialize(JsonElement json, Type t, JsonDeserializationContext context) {
                    return (json.getAsInt()) != 1;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),409,gson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),405,java.lang.Boolean.TRUE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),406,gson.fromJson("1", boolean.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),407,java.lang.Boolean.TRUE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),408,gson.fromJson("true", java.lang.Boolean.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "rawtypes")
    public void testCustomDeserializerInvokedForPrimitives_literalMutation838() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomDeserializerInvokedForPrimitives_literalMutation838");
            Gson gson = new GsonBuilder().registerTypeAdapter(boolean.class, new JsonDeserializer() {
                public java.lang.Object deserialize(JsonElement json, Type t, JsonDeserializationContext context) {
                    return (json.getAsInt()) != -1;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),409,gson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),405,java.lang.Boolean.TRUE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),406,gson.fromJson("1", boolean.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),407,java.lang.Boolean.TRUE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),408,gson.fromJson("true", java.lang.Boolean.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "rawtypes")
    public void testCustomDeserializerInvokedForPrimitives_literalMutation839() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomDeserializerInvokedForPrimitives_literalMutation839");
            Gson gson = new GsonBuilder().registerTypeAdapter(boolean.class, new JsonDeserializer() {
                public java.lang.Object deserialize(JsonElement json, Type t, JsonDeserializationContext context) {
                    return (json.getAsInt()) != 0;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),409,gson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),405,java.lang.Boolean.TRUE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),406,gson.fromJson("1", boolean.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),407,java.lang.Boolean.TRUE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),408,gson.fromJson("true", java.lang.Boolean.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "rawtypes")
    @Test(timeout = 1000)
    public void testCustomDeserializerInvokedForPrimitives_remove73() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomDeserializerInvokedForPrimitives_remove73");
            Gson gson = new GsonBuilder().registerTypeAdapter(boolean.class, new JsonDeserializer() {
                public java.lang.Object deserialize(JsonElement json, Type t, JsonDeserializationContext context) {
                    return (json.getAsInt()) != 0;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),409,gson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),405,java.lang.Boolean.TRUE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),406,gson.fromJson("1", boolean.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),407,java.lang.Boolean.TRUE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),408,gson.fromJson("true", java.lang.Boolean.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomByteArraySerializer_add72() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArraySerializer_add72");
            Gson gson = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonSerializer<byte[]>() {
                public JsonElement serialize(byte[] src, Type typeOfSrc, JsonSerializationContext context) {
                    java.lang.StringBuilder sb = new java.lang.StringBuilder(src.length);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    for (byte b : src) {
                        sb.append(b);
                    }
                    return new JsonPrimitive(sb.toString());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,gson);
            byte[] data = new byte[]{ 0 , 1 , 2 , 3 , 4 , 5 , 6 , 7 , 8 , 9 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,data);
            String json = gson.toJson(data);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),401,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomByteArraySerializer_add73() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArraySerializer_add73");
            Gson gson = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonSerializer<byte[]>() {
                public JsonElement serialize(byte[] src, Type typeOfSrc, JsonSerializationContext context) {
                    java.lang.StringBuilder sb = new java.lang.StringBuilder(src.length);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    for (byte b : src) {
                        sb.append(b);
                        sb.append(b);
                    }
                    return new JsonPrimitive(sb.toString());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,gson);
            byte[] data = new byte[]{ 0 , 1 , 2 , 3 , 4 , 5 , 6 , 7 , 8 , 9 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,data);
            String json = gson.toJson(data);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),401,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomByteArraySerializer() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArraySerializer");
            Gson gson = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonSerializer<byte[]>() {
                public JsonElement serialize(byte[] src, Type typeOfSrc, JsonSerializationContext context) {
                    java.lang.StringBuilder sb = new java.lang.StringBuilder(src.length);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    for (byte b : src) {
                        sb.append(b);
                    }
                    return new JsonPrimitive(sb.toString());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,gson);
            byte[] data = new byte[]{ 1 , 1 , 2 , 3 , 4 , 5 , 6 , 7 , 8 , 9 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,data);
            String json = gson.toJson(data);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),401,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomByteArraySerializer_literalMutation788() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArraySerializer_literalMutation788");
            Gson gson = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonSerializer<byte[]>() {
                public JsonElement serialize(byte[] src, Type typeOfSrc, JsonSerializationContext context) {
                    java.lang.StringBuilder sb = new java.lang.StringBuilder(src.length);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    for (byte b : src) {
                        sb.append(b);
                    }
                    return new JsonPrimitive(sb.toString());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,gson);
            byte[] data = new byte[]{ -1 , 1 , 2 , 3 , 4 , 5 , 6 , 7 , 8 , 9 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,data);
            String json = gson.toJson(data);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),401,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomByteArraySerializer_literalMutation789() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArraySerializer_literalMutation789");
            Gson gson = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonSerializer<byte[]>() {
                public JsonElement serialize(byte[] src, Type typeOfSrc, JsonSerializationContext context) {
                    java.lang.StringBuilder sb = new java.lang.StringBuilder(src.length);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    for (byte b : src) {
                        sb.append(b);
                    }
                    return new JsonPrimitive(sb.toString());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,gson);
            byte[] data = new byte[]{ 0 , 1 , 2 , 3 , 4 , 5 , 6 , 7 , 8 , 9 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,data);
            String json = gson.toJson(data);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),401,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomByteArraySerializer_literalMutation791() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArraySerializer_literalMutation791");
            Gson gson = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonSerializer<byte[]>() {
                public JsonElement serialize(byte[] src, Type typeOfSrc, JsonSerializationContext context) {
                    java.lang.StringBuilder sb = new java.lang.StringBuilder(src.length);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    for (byte b : src) {
                        sb.append(b);
                    }
                    return new JsonPrimitive(sb.toString());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,gson);
            byte[] data = new byte[]{ 0 , 2 , 2 , 3 , 4 , 5 , 6 , 7 , 8 , 9 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,data);
            String json = gson.toJson(data);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),401,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomByteArraySerializer_literalMutation792() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArraySerializer_literalMutation792");
            Gson gson = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonSerializer<byte[]>() {
                public JsonElement serialize(byte[] src, Type typeOfSrc, JsonSerializationContext context) {
                    java.lang.StringBuilder sb = new java.lang.StringBuilder(src.length);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    for (byte b : src) {
                        sb.append(b);
                    }
                    return new JsonPrimitive(sb.toString());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,gson);
            byte[] data = new byte[]{ 0 , 0 , 2 , 3 , 4 , 5 , 6 , 7 , 8 , 9 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,data);
            String json = gson.toJson(data);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),401,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomByteArraySerializer_literalMutation793() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArraySerializer_literalMutation793");
            Gson gson = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonSerializer<byte[]>() {
                public JsonElement serialize(byte[] src, Type typeOfSrc, JsonSerializationContext context) {
                    java.lang.StringBuilder sb = new java.lang.StringBuilder(src.length);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    for (byte b : src) {
                        sb.append(b);
                    }
                    return new JsonPrimitive(sb.toString());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,gson);
            byte[] data = new byte[]{ 0 , 0 , 2 , 3 , 4 , 5 , 6 , 7 , 8 , 9 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,data);
            String json = gson.toJson(data);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),401,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomByteArraySerializer_literalMutation795() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArraySerializer_literalMutation795");
            Gson gson = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonSerializer<byte[]>() {
                public JsonElement serialize(byte[] src, Type typeOfSrc, JsonSerializationContext context) {
                    java.lang.StringBuilder sb = new java.lang.StringBuilder(src.length);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    for (byte b : src) {
                        sb.append(b);
                    }
                    return new JsonPrimitive(sb.toString());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,gson);
            byte[] data = new byte[]{ 0 , 1 , 1 , 3 , 4 , 5 , 6 , 7 , 8 , 9 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,data);
            String json = gson.toJson(data);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),401,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomByteArraySerializer_literalMutation796() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArraySerializer_literalMutation796");
            Gson gson = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonSerializer<byte[]>() {
                public JsonElement serialize(byte[] src, Type typeOfSrc, JsonSerializationContext context) {
                    java.lang.StringBuilder sb = new java.lang.StringBuilder(src.length);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    for (byte b : src) {
                        sb.append(b);
                    }
                    return new JsonPrimitive(sb.toString());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,gson);
            byte[] data = new byte[]{ 0 , 1 , 4 , 3 , 4 , 5 , 6 , 7 , 8 , 9 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,data);
            String json = gson.toJson(data);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),401,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomByteArraySerializer_literalMutation797() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArraySerializer_literalMutation797");
            Gson gson = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonSerializer<byte[]>() {
                public JsonElement serialize(byte[] src, Type typeOfSrc, JsonSerializationContext context) {
                    java.lang.StringBuilder sb = new java.lang.StringBuilder(src.length);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    for (byte b : src) {
                        sb.append(b);
                    }
                    return new JsonPrimitive(sb.toString());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,gson);
            byte[] data = new byte[]{ 0 , 1 , 3 , 3 , 4 , 5 , 6 , 7 , 8 , 9 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,data);
            String json = gson.toJson(data);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),401,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomByteArraySerializer_literalMutation799() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArraySerializer_literalMutation799");
            Gson gson = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonSerializer<byte[]>() {
                public JsonElement serialize(byte[] src, Type typeOfSrc, JsonSerializationContext context) {
                    java.lang.StringBuilder sb = new java.lang.StringBuilder(src.length);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    for (byte b : src) {
                        sb.append(b);
                    }
                    return new JsonPrimitive(sb.toString());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,gson);
            byte[] data = new byte[]{ 0 , 1 , 2 , 4 , 4 , 5 , 6 , 7 , 8 , 9 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,data);
            String json = gson.toJson(data);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),401,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomByteArraySerializer_literalMutation800() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArraySerializer_literalMutation800");
            Gson gson = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonSerializer<byte[]>() {
                public JsonElement serialize(byte[] src, Type typeOfSrc, JsonSerializationContext context) {
                    java.lang.StringBuilder sb = new java.lang.StringBuilder(src.length);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    for (byte b : src) {
                        sb.append(b);
                    }
                    return new JsonPrimitive(sb.toString());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,gson);
            byte[] data = new byte[]{ 0 , 1 , 2 , 2 , 4 , 5 , 6 , 7 , 8 , 9 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,data);
            String json = gson.toJson(data);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),401,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomByteArraySerializer_literalMutation801() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArraySerializer_literalMutation801");
            Gson gson = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonSerializer<byte[]>() {
                public JsonElement serialize(byte[] src, Type typeOfSrc, JsonSerializationContext context) {
                    java.lang.StringBuilder sb = new java.lang.StringBuilder(src.length);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    for (byte b : src) {
                        sb.append(b);
                    }
                    return new JsonPrimitive(sb.toString());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,gson);
            byte[] data = new byte[]{ 0 , 1 , 2 , 1 , 4 , 5 , 6 , 7 , 8 , 9 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,data);
            String json = gson.toJson(data);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),401,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomByteArraySerializer_literalMutation802() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArraySerializer_literalMutation802");
            Gson gson = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonSerializer<byte[]>() {
                public JsonElement serialize(byte[] src, Type typeOfSrc, JsonSerializationContext context) {
                    java.lang.StringBuilder sb = new java.lang.StringBuilder(src.length);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    for (byte b : src) {
                        sb.append(b);
                    }
                    return new JsonPrimitive(sb.toString());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,gson);
            byte[] data = new byte[]{ 0 , 1 , 2 , 6 , 4 , 5 , 6 , 7 , 8 , 9 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,data);
            String json = gson.toJson(data);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),401,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomByteArraySerializer_literalMutation804() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArraySerializer_literalMutation804");
            Gson gson = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonSerializer<byte[]>() {
                public JsonElement serialize(byte[] src, Type typeOfSrc, JsonSerializationContext context) {
                    java.lang.StringBuilder sb = new java.lang.StringBuilder(src.length);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    for (byte b : src) {
                        sb.append(b);
                    }
                    return new JsonPrimitive(sb.toString());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,gson);
            byte[] data = new byte[]{ 0 , 1 , 2 , 3 , 2 , 5 , 6 , 7 , 8 , 9 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,data);
            String json = gson.toJson(data);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),401,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomByteArraySerializer_literalMutation805() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArraySerializer_literalMutation805");
            Gson gson = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonSerializer<byte[]>() {
                public JsonElement serialize(byte[] src, Type typeOfSrc, JsonSerializationContext context) {
                    java.lang.StringBuilder sb = new java.lang.StringBuilder(src.length);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    for (byte b : src) {
                        sb.append(b);
                    }
                    return new JsonPrimitive(sb.toString());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,gson);
            byte[] data = new byte[]{ 0 , 1 , 2 , 3 , 8 , 5 , 6 , 7 , 8 , 9 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,data);
            String json = gson.toJson(data);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),401,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomByteArraySerializer_literalMutation806() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArraySerializer_literalMutation806");
            Gson gson = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonSerializer<byte[]>() {
                public JsonElement serialize(byte[] src, Type typeOfSrc, JsonSerializationContext context) {
                    java.lang.StringBuilder sb = new java.lang.StringBuilder(src.length);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    for (byte b : src) {
                        sb.append(b);
                    }
                    return new JsonPrimitive(sb.toString());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,gson);
            byte[] data = new byte[]{ 0 , 1 , 2 , 3 , 5 , 5 , 6 , 7 , 8 , 9 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,data);
            String json = gson.toJson(data);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),401,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomByteArraySerializer_literalMutation807() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArraySerializer_literalMutation807");
            Gson gson = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonSerializer<byte[]>() {
                public JsonElement serialize(byte[] src, Type typeOfSrc, JsonSerializationContext context) {
                    java.lang.StringBuilder sb = new java.lang.StringBuilder(src.length);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    for (byte b : src) {
                        sb.append(b);
                    }
                    return new JsonPrimitive(sb.toString());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,gson);
            byte[] data = new byte[]{ 0 , 1 , 2 , 3 , 3 , 5 , 6 , 7 , 8 , 9 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,data);
            String json = gson.toJson(data);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),401,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomByteArraySerializer_literalMutation809() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArraySerializer_literalMutation809");
            Gson gson = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonSerializer<byte[]>() {
                public JsonElement serialize(byte[] src, Type typeOfSrc, JsonSerializationContext context) {
                    java.lang.StringBuilder sb = new java.lang.StringBuilder(src.length);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    for (byte b : src) {
                        sb.append(b);
                    }
                    return new JsonPrimitive(sb.toString());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,gson);
            byte[] data = new byte[]{ 0 , 1 , 2 , 3 , 4 , 4 , 6 , 7 , 8 , 9 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,data);
            String json = gson.toJson(data);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),401,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomByteArraySerializer_literalMutation810() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArraySerializer_literalMutation810");
            Gson gson = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonSerializer<byte[]>() {
                public JsonElement serialize(byte[] src, Type typeOfSrc, JsonSerializationContext context) {
                    java.lang.StringBuilder sb = new java.lang.StringBuilder(src.length);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    for (byte b : src) {
                        sb.append(b);
                    }
                    return new JsonPrimitive(sb.toString());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,gson);
            byte[] data = new byte[]{ 0 , 1 , 2 , 3 , 4 , 2 , 6 , 7 , 8 , 9 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,data);
            String json = gson.toJson(data);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),401,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomByteArraySerializer_literalMutation811() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArraySerializer_literalMutation811");
            Gson gson = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonSerializer<byte[]>() {
                public JsonElement serialize(byte[] src, Type typeOfSrc, JsonSerializationContext context) {
                    java.lang.StringBuilder sb = new java.lang.StringBuilder(src.length);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    for (byte b : src) {
                        sb.append(b);
                    }
                    return new JsonPrimitive(sb.toString());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,gson);
            byte[] data = new byte[]{ 0 , 1 , 2 , 3 , 4 , 10 , 6 , 7 , 8 , 9 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,data);
            String json = gson.toJson(data);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),401,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomByteArraySerializer_literalMutation812() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArraySerializer_literalMutation812");
            Gson gson = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonSerializer<byte[]>() {
                public JsonElement serialize(byte[] src, Type typeOfSrc, JsonSerializationContext context) {
                    java.lang.StringBuilder sb = new java.lang.StringBuilder(src.length);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    for (byte b : src) {
                        sb.append(b);
                    }
                    return new JsonPrimitive(sb.toString());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,gson);
            byte[] data = new byte[]{ 0 , 1 , 2 , 3 , 4 , 6 , 6 , 7 , 8 , 9 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,data);
            String json = gson.toJson(data);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),401,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomByteArraySerializer_literalMutation814() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArraySerializer_literalMutation814");
            Gson gson = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonSerializer<byte[]>() {
                public JsonElement serialize(byte[] src, Type typeOfSrc, JsonSerializationContext context) {
                    java.lang.StringBuilder sb = new java.lang.StringBuilder(src.length);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    for (byte b : src) {
                        sb.append(b);
                    }
                    return new JsonPrimitive(sb.toString());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,gson);
            byte[] data = new byte[]{ 0 , 1 , 2 , 3 , 4 , 5 , 5 , 7 , 8 , 9 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,data);
            String json = gson.toJson(data);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),401,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomByteArraySerializer_literalMutation815() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArraySerializer_literalMutation815");
            Gson gson = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonSerializer<byte[]>() {
                public JsonElement serialize(byte[] src, Type typeOfSrc, JsonSerializationContext context) {
                    java.lang.StringBuilder sb = new java.lang.StringBuilder(src.length);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    for (byte b : src) {
                        sb.append(b);
                    }
                    return new JsonPrimitive(sb.toString());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,gson);
            byte[] data = new byte[]{ 0 , 1 , 2 , 3 , 4 , 5 , 3 , 7 , 8 , 9 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,data);
            String json = gson.toJson(data);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),401,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomByteArraySerializer_literalMutation816() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArraySerializer_literalMutation816");
            Gson gson = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonSerializer<byte[]>() {
                public JsonElement serialize(byte[] src, Type typeOfSrc, JsonSerializationContext context) {
                    java.lang.StringBuilder sb = new java.lang.StringBuilder(src.length);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    for (byte b : src) {
                        sb.append(b);
                    }
                    return new JsonPrimitive(sb.toString());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,gson);
            byte[] data = new byte[]{ 0 , 1 , 2 , 3 , 4 , 5 , 12 , 7 , 8 , 9 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,data);
            String json = gson.toJson(data);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),401,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomByteArraySerializer_literalMutation817() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArraySerializer_literalMutation817");
            Gson gson = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonSerializer<byte[]>() {
                public JsonElement serialize(byte[] src, Type typeOfSrc, JsonSerializationContext context) {
                    java.lang.StringBuilder sb = new java.lang.StringBuilder(src.length);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    for (byte b : src) {
                        sb.append(b);
                    }
                    return new JsonPrimitive(sb.toString());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,gson);
            byte[] data = new byte[]{ 0 , 1 , 2 , 3 , 4 , 5 , 7 , 7 , 8 , 9 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,data);
            String json = gson.toJson(data);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),401,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomByteArraySerializer_literalMutation819() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArraySerializer_literalMutation819");
            Gson gson = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonSerializer<byte[]>() {
                public JsonElement serialize(byte[] src, Type typeOfSrc, JsonSerializationContext context) {
                    java.lang.StringBuilder sb = new java.lang.StringBuilder(src.length);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    for (byte b : src) {
                        sb.append(b);
                    }
                    return new JsonPrimitive(sb.toString());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,gson);
            byte[] data = new byte[]{ 0 , 1 , 2 , 3 , 4 , 5 , 6 , 8 , 8 , 9 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,data);
            String json = gson.toJson(data);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),401,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomByteArraySerializer_literalMutation820() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArraySerializer_literalMutation820");
            Gson gson = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonSerializer<byte[]>() {
                public JsonElement serialize(byte[] src, Type typeOfSrc, JsonSerializationContext context) {
                    java.lang.StringBuilder sb = new java.lang.StringBuilder(src.length);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    for (byte b : src) {
                        sb.append(b);
                    }
                    return new JsonPrimitive(sb.toString());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,gson);
            byte[] data = new byte[]{ 0 , 1 , 2 , 3 , 4 , 5 , 6 , 6 , 8 , 9 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,data);
            String json = gson.toJson(data);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),401,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomByteArraySerializer_literalMutation821() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArraySerializer_literalMutation821");
            Gson gson = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonSerializer<byte[]>() {
                public JsonElement serialize(byte[] src, Type typeOfSrc, JsonSerializationContext context) {
                    java.lang.StringBuilder sb = new java.lang.StringBuilder(src.length);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    for (byte b : src) {
                        sb.append(b);
                    }
                    return new JsonPrimitive(sb.toString());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,gson);
            byte[] data = new byte[]{ 0 , 1 , 2 , 3 , 4 , 5 , 6 , 3 , 8 , 9 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,data);
            String json = gson.toJson(data);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),401,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomByteArraySerializer_literalMutation822() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArraySerializer_literalMutation822");
            Gson gson = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonSerializer<byte[]>() {
                public JsonElement serialize(byte[] src, Type typeOfSrc, JsonSerializationContext context) {
                    java.lang.StringBuilder sb = new java.lang.StringBuilder(src.length);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    for (byte b : src) {
                        sb.append(b);
                    }
                    return new JsonPrimitive(sb.toString());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,gson);
            byte[] data = new byte[]{ 0 , 1 , 2 , 3 , 4 , 5 , 6 , 14 , 8 , 9 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,data);
            String json = gson.toJson(data);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),401,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomByteArraySerializer_literalMutation824() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArraySerializer_literalMutation824");
            Gson gson = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonSerializer<byte[]>() {
                public JsonElement serialize(byte[] src, Type typeOfSrc, JsonSerializationContext context) {
                    java.lang.StringBuilder sb = new java.lang.StringBuilder(src.length);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    for (byte b : src) {
                        sb.append(b);
                    }
                    return new JsonPrimitive(sb.toString());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,gson);
            byte[] data = new byte[]{ 0 , 1 , 2 , 3 , 4 , 5 , 6 , 7 , 4 , 9 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,data);
            String json = gson.toJson(data);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),401,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomByteArraySerializer_literalMutation825() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArraySerializer_literalMutation825");
            Gson gson = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonSerializer<byte[]>() {
                public JsonElement serialize(byte[] src, Type typeOfSrc, JsonSerializationContext context) {
                    java.lang.StringBuilder sb = new java.lang.StringBuilder(src.length);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    for (byte b : src) {
                        sb.append(b);
                    }
                    return new JsonPrimitive(sb.toString());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,gson);
            byte[] data = new byte[]{ 0 , 1 , 2 , 3 , 4 , 5 , 6 , 7 , 16 , 9 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,data);
            String json = gson.toJson(data);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),401,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomByteArraySerializer_literalMutation826() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArraySerializer_literalMutation826");
            Gson gson = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonSerializer<byte[]>() {
                public JsonElement serialize(byte[] src, Type typeOfSrc, JsonSerializationContext context) {
                    java.lang.StringBuilder sb = new java.lang.StringBuilder(src.length);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    for (byte b : src) {
                        sb.append(b);
                    }
                    return new JsonPrimitive(sb.toString());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,gson);
            byte[] data = new byte[]{ 0 , 1 , 2 , 3 , 4 , 5 , 6 , 7 , 9 , 9 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,data);
            String json = gson.toJson(data);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),401,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomByteArraySerializer_literalMutation827() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArraySerializer_literalMutation827");
            Gson gson = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonSerializer<byte[]>() {
                public JsonElement serialize(byte[] src, Type typeOfSrc, JsonSerializationContext context) {
                    java.lang.StringBuilder sb = new java.lang.StringBuilder(src.length);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    for (byte b : src) {
                        sb.append(b);
                    }
                    return new JsonPrimitive(sb.toString());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,gson);
            byte[] data = new byte[]{ 0 , 1 , 2 , 3 , 4 , 5 , 6 , 7 , 7 , 9 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,data);
            String json = gson.toJson(data);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),401,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomByteArraySerializer_literalMutation829() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArraySerializer_literalMutation829");
            Gson gson = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonSerializer<byte[]>() {
                public JsonElement serialize(byte[] src, Type typeOfSrc, JsonSerializationContext context) {
                    java.lang.StringBuilder sb = new java.lang.StringBuilder(src.length);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    for (byte b : src) {
                        sb.append(b);
                    }
                    return new JsonPrimitive(sb.toString());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,gson);
            byte[] data = new byte[]{ 0 , 1 , 2 , 3 , 4 , 5 , 6 , 7 , 8 , 8 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,data);
            String json = gson.toJson(data);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),401,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomByteArraySerializer_literalMutation830() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArraySerializer_literalMutation830");
            Gson gson = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonSerializer<byte[]>() {
                public JsonElement serialize(byte[] src, Type typeOfSrc, JsonSerializationContext context) {
                    java.lang.StringBuilder sb = new java.lang.StringBuilder(src.length);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    for (byte b : src) {
                        sb.append(b);
                    }
                    return new JsonPrimitive(sb.toString());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,gson);
            byte[] data = new byte[]{ 0 , 1 , 2 , 3 , 4 , 5 , 6 , 7 , 8 , 4 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,data);
            String json = gson.toJson(data);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),401,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomByteArraySerializer_literalMutation831() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArraySerializer_literalMutation831");
            Gson gson = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonSerializer<byte[]>() {
                public JsonElement serialize(byte[] src, Type typeOfSrc, JsonSerializationContext context) {
                    java.lang.StringBuilder sb = new java.lang.StringBuilder(src.length);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    for (byte b : src) {
                        sb.append(b);
                    }
                    return new JsonPrimitive(sb.toString());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,gson);
            byte[] data = new byte[]{ 0 , 1 , 2 , 3 , 4 , 5 , 6 , 7 , 8 , 18 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,data);
            String json = gson.toJson(data);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),401,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomByteArraySerializer_literalMutation832() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArraySerializer_literalMutation832");
            Gson gson = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonSerializer<byte[]>() {
                public JsonElement serialize(byte[] src, Type typeOfSrc, JsonSerializationContext context) {
                    java.lang.StringBuilder sb = new java.lang.StringBuilder(src.length);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    for (byte b : src) {
                        sb.append(b);
                    }
                    return new JsonPrimitive(sb.toString());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,gson);
            byte[] data = new byte[]{ 0 , 1 , 2 , 3 , 4 , 5 , 6 , 7 , 8 , 10 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,data);
            String json = gson.toJson(data);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),401,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomByteArraySerializer_remove71() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArraySerializer_remove71");
            Gson gson = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonSerializer<byte[]>() {
                public JsonElement serialize(byte[] src, Type typeOfSrc, JsonSerializationContext context) {
                    java.lang.StringBuilder sb = new java.lang.StringBuilder(src.length);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    for (byte b : src) {
                        sb.append(b);
                    }
                    return new JsonPrimitive(sb.toString());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,gson);
            byte[] data = new byte[]{ 0 , 1 , 2 , 3 , 4 , 5 , 6 , 7 , 8 , 9 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,data);
            String json = gson.toJson(data);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),401,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomByteArraySerializer_remove72() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArraySerializer_remove72");
            Gson gson = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonSerializer<byte[]>() {
                public JsonElement serialize(byte[] src, Type typeOfSrc, JsonSerializationContext context) {
                    java.lang.StringBuilder sb = new java.lang.StringBuilder(src.length);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),400,sb);
                    for (byte b : src) {
                    }
                    return new JsonPrimitive(sb.toString());
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,gson);
            byte[] data = new byte[]{ 0 , 1 , 2 , 3 , 4 , 5 , 6 , 7 , 8 , 9 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,data);
            String json = gson.toJson(data);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),401,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomByteArrayDeserializerAndInstanceCreator_add71() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArrayDeserializerAndInstanceCreator_add71");
            GsonBuilder gsonBuilder = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonDeserializer<byte[]>() {
                public byte[] deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) throws JsonParseException {
                    String str = json.getAsString();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),391,str);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),391,str);
                    byte[] data = new byte[str.length()];
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),392,data);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),392,data);
                    for (int i = 0 ; i < (data.length) ; ++i) {
                        data[i] = java.lang.Byte.parseByte(("" + (str.charAt(i))));
                        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),390,data[i]);
                        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),390,data[i]);
                    }
                    return data;
                }
            });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),395,gsonBuilder);
            Gson gson = gsonBuilder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),396,gson);
            String json = "\'0123456789\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),397,json);
            byte[] actual = gson.fromJson(json, byte[].class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),398,actual);
            byte[] expected = new byte[]{ 0 , 1 , 2 , 3 , 4 , 5 , 6 , 7 , 8 , 9 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),399,expected);
            for (int i = 0 ; i < (actual.length) ; ++i) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),393,expected[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),394,actual[i]);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomByteArrayDeserializerAndInstanceCreator() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArrayDeserializerAndInstanceCreator");
            GsonBuilder gsonBuilder = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonDeserializer<byte[]>() {
                public byte[] deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) throws JsonParseException {
                    String str = json.getAsString();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),391,str);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),391,str);
                    byte[] data = new byte[str.length()];
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),392,data);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),392,data);
                    for (int i = 1 ; i < (data.length) ; ++i) {
                        data[i] = java.lang.Byte.parseByte(("" + (str.charAt(i))));
                        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),390,data[i]);
                        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),390,data[i]);
                    }
                    return data;
                }
            });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),395,gsonBuilder);
            Gson gson = gsonBuilder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),396,gson);
            String json = "\'0123456789\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),397,json);
            byte[] actual = gson.fromJson(json, byte[].class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),398,actual);
            byte[] expected = new byte[]{ 0 , 1 , 2 , 3 , 4 , 5 , 6 , 7 , 8 , 9 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),399,expected);
            for (int i = 0 ; i < (actual.length) ; ++i) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),393,expected[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),394,actual[i]);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomByteArrayDeserializerAndInstanceCreator_literalMutation784() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArrayDeserializerAndInstanceCreator_literalMutation784");
            GsonBuilder gsonBuilder = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonDeserializer<byte[]>() {
                public byte[] deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) throws JsonParseException {
                    String str = json.getAsString();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),391,str);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),391,str);
                    byte[] data = new byte[str.length()];
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),392,data);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),392,data);
                    for (int i = -1 ; i < (data.length) ; ++i) {
                        data[i] = java.lang.Byte.parseByte(("" + (str.charAt(i))));
                        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),390,data[i]);
                        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),390,data[i]);
                    }
                    return data;
                }
            });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),395,gsonBuilder);
            Gson gson = gsonBuilder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),396,gson);
            String json = "\'0123456789\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),397,json);
            byte[] actual = gson.fromJson(json, byte[].class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),398,actual);
            byte[] expected = new byte[]{ 0 , 1 , 2 , 3 , 4 , 5 , 6 , 7 , 8 , 9 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),399,expected);
            for (int i = 0 ; i < (actual.length) ; ++i) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),393,expected[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),394,actual[i]);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomByteArrayDeserializerAndInstanceCreator_literalMutation785() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArrayDeserializerAndInstanceCreator_literalMutation785");
            GsonBuilder gsonBuilder = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonDeserializer<byte[]>() {
                public byte[] deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) throws JsonParseException {
                    String str = json.getAsString();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),391,str);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),391,str);
                    byte[] data = new byte[str.length()];
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),392,data);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),392,data);
                    for (int i = 0 ; i < (data.length) ; ++i) {
                        data[i] = java.lang.Byte.parseByte(("" + (str.charAt(i))));
                        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),390,data[i]);
                        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),390,data[i]);
                    }
                    return data;
                }
            });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),395,gsonBuilder);
            Gson gson = gsonBuilder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),396,gson);
            String json = "\'0123456789\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),397,json);
            byte[] actual = gson.fromJson(json, byte[].class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),398,actual);
            byte[] expected = new byte[]{ 0 , 1 , 2 , 3 , 4 , 5 , 6 , 7 , 8 , 9 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),399,expected);
            for (int i = 0 ; i < (actual.length) ; ++i) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),393,expected[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),394,actual[i]);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomByteArrayDeserializerAndInstanceCreator_remove70() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomByteArrayDeserializerAndInstanceCreator_remove70");
            GsonBuilder gsonBuilder = new GsonBuilder().registerTypeAdapter(byte[].class, new JsonDeserializer<byte[]>() {
                public byte[] deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) throws JsonParseException {
                    String str = json.getAsString();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),391,str);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),391,str);
                    byte[] data = new byte[str.length()];
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),392,data);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),392,data);
                    for (int i = 0 ; i < (data.length) ; ++i) {
                        data[i] = java.lang.Byte.parseByte(("" + (str.charAt(i))));
                        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),390,data[i]);
                        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),390,data[i]);
                    }
                    return data;
                }
            });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),395,gsonBuilder);
            Gson gson = gsonBuilder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),396,gson);
            String json = "\'0123456789\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),397,json);
            byte[] actual = gson.fromJson(json, byte[].class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),398,actual);
            byte[] expected = new byte[]{ 0 , 1 , 2 , 3 , 4 , 5 , 6 , 7 , 8 , 9 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),399,expected);
            for (int i = 0 ; i < (actual.length) ; ++i) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),393,expected[i]);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),394,actual[i]);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    private static class StringHolder {
        String part1;

        String part2;

        public StringHolder(String string) {
            String[] parts = string.split(":");
            part1 = parts[0];
            part2 = parts[1];
        }

        public StringHolder(String part1 ,String part2) {
            this.part1 = part1;
            this.part2 = part2;
        }
    }

    private static class StringHolderTypeAdapter implements InstanceCreator<StringHolder> , JsonDeserializer<StringHolder> , JsonSerializer<StringHolder> {
        public StringHolder createInstance(Type type) {
            return new StringHolder("unknown:thing");
        }

        public StringHolder deserialize(JsonElement src, Type type, JsonDeserializationContext context) {
            return new StringHolder(src.getAsString());
        }

        public JsonElement serialize(StringHolder src, Type typeOfSrc, JsonSerializationContext context) {
            String contents = ((src.part1) + ':') + (src.part2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),336,contents);
            return new JsonPrimitive(contents);
        }
    }

    @Test(timeout = 1000)
    public void testCustomAdapterInvokedForCollectionElementSerializationWithType_add65() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForCollectionElementSerializationWithType_add65");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),362,gson);
            Type setType = new TypeToken<java.util.Set<StringHolder>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),363,setType);
            StringHolder holder = new StringHolder("Jacob" , "Tomaw");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),364,holder);
            Set<StringHolder> setOfHolders = new HashSet<StringHolder>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),365,setOfHolders);
            setOfHolders.add(holder);
            String json = gson.toJson(setOfHolders, setType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),366,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),361,json.contains("Jacob:Tomaw"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomAdapterInvokedForCollectionElementSerializationWithType_add66() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForCollectionElementSerializationWithType_add66");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),362,gson);
            Type setType = new TypeToken<java.util.Set<StringHolder>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),363,setType);
            StringHolder holder = new StringHolder("Jacob" , "Tomaw");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),364,holder);
            Set<StringHolder> setOfHolders = new HashSet<StringHolder>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),365,setOfHolders);
            setOfHolders.add(holder);
            setOfHolders.add(holder);
            String json = gson.toJson(setOfHolders, setType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),366,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),361,json.contains("Jacob:Tomaw"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomAdapterInvokedForCollectionElementSerializationWithType() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForCollectionElementSerializationWithType");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),362,gson);
            Type setType = new TypeToken<java.util.Set<StringHolder>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),363,setType);
            StringHolder holder = new StringHolder("·acob" , "Tomaw");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),364,holder);
            Set<StringHolder> setOfHolders = new HashSet<StringHolder>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),365,setOfHolders);
            setOfHolders.add(holder);
            String json = gson.toJson(setOfHolders, setType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),366,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),361,json.contains("Jacob:Tomaw"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomAdapterInvokedForCollectionElementSerializationWithType_literalMutation754() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForCollectionElementSerializationWithType_literalMutation754");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),362,gson);
            Type setType = new TypeToken<java.util.Set<StringHolder>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),363,setType);
            StringHolder holder = new StringHolder("Jacôob" , "Tomaw");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),364,holder);
            Set<StringHolder> setOfHolders = new HashSet<StringHolder>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),365,setOfHolders);
            setOfHolders.add(holder);
            String json = gson.toJson(setOfHolders, setType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),366,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),361,json.contains("Jacob:Tomaw"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomAdapterInvokedForCollectionElementSerializationWithType_literalMutation755() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForCollectionElementSerializationWithType_literalMutation755");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),362,gson);
            Type setType = new TypeToken<java.util.Set<StringHolder>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),363,setType);
            StringHolder holder = new StringHolder("Jcob" , "Tomaw");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),364,holder);
            Set<StringHolder> setOfHolders = new HashSet<StringHolder>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),365,setOfHolders);
            setOfHolders.add(holder);
            String json = gson.toJson(setOfHolders, setType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),366,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),361,json.contains("Jacob:Tomaw"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomAdapterInvokedForCollectionElementSerializationWithType_literalMutation756() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForCollectionElementSerializationWithType_literalMutation756");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),362,gson);
            Type setType = new TypeToken<java.util.Set<StringHolder>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),363,setType);
            StringHolder holder = new StringHolder("Jacob" , "æomaw");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),364,holder);
            Set<StringHolder> setOfHolders = new HashSet<StringHolder>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),365,setOfHolders);
            setOfHolders.add(holder);
            String json = gson.toJson(setOfHolders, setType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),366,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),361,json.contains("Jacob:Tomaw"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomAdapterInvokedForCollectionElementSerializationWithType_literalMutation757() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForCollectionElementSerializationWithType_literalMutation757");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),362,gson);
            Type setType = new TypeToken<java.util.Set<StringHolder>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),363,setType);
            StringHolder holder = new StringHolder("Jacob" , "Tuomaw");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),364,holder);
            Set<StringHolder> setOfHolders = new HashSet<StringHolder>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),365,setOfHolders);
            setOfHolders.add(holder);
            String json = gson.toJson(setOfHolders, setType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),366,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),361,json.contains("Jacob:Tomaw"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomAdapterInvokedForCollectionElementSerializationWithType_literalMutation758() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForCollectionElementSerializationWithType_literalMutation758");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),362,gson);
            Type setType = new TypeToken<java.util.Set<StringHolder>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),363,setType);
            StringHolder holder = new StringHolder("Jacob" , "Tmaw");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),364,holder);
            Set<StringHolder> setOfHolders = new HashSet<StringHolder>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),365,setOfHolders);
            setOfHolders.add(holder);
            String json = gson.toJson(setOfHolders, setType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),366,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),361,json.contains("Jacob:Tomaw"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomAdapterInvokedForCollectionElementSerializationWithType_remove64() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForCollectionElementSerializationWithType_remove64");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),362,gson);
            Type setType = new TypeToken<java.util.Set<StringHolder>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),363,setType);
            StringHolder holder = new StringHolder("Jacob" , "Tomaw");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),364,holder);
            Set<StringHolder> setOfHolders = new HashSet<StringHolder>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),365,setOfHolders);
            setOfHolders.add(holder);
            String json = gson.toJson(setOfHolders, setType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),366,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),361,json.contains("Jacob:Tomaw"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomAdapterInvokedForCollectionElementSerializationWithType_remove65() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForCollectionElementSerializationWithType_remove65");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),362,gson);
            Type setType = new TypeToken<java.util.Set<StringHolder>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),363,setType);
            StringHolder holder = new StringHolder("Jacob" , "Tomaw");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),364,holder);
            Set<StringHolder> setOfHolders = new HashSet<StringHolder>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),365,setOfHolders);
            String json = gson.toJson(setOfHolders, setType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),366,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),361,json.contains("Jacob:Tomaw"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomAdapterInvokedForCollectionElementSerialization_add64() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForCollectionElementSerialization_add64");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),368,gson);
            StringHolder holder = new StringHolder("Jacob" , "Tomaw");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),369,holder);
            Set<StringHolder> setOfHolders = new HashSet<StringHolder>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),370,setOfHolders);
            setOfHolders.add(holder);
            setOfHolders.add(holder);
            String json = gson.toJson(setOfHolders);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),371,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),367,json.contains("Jacob:Tomaw"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomAdapterInvokedForCollectionElementSerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForCollectionElementSerialization");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),368,gson);
            StringHolder holder = new StringHolder("acob" , "Tomaw");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),369,holder);
            Set<StringHolder> setOfHolders = new HashSet<StringHolder>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),370,setOfHolders);
            setOfHolders.add(holder);
            String json = gson.toJson(setOfHolders);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),371,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),367,json.contains("Jacob:Tomaw"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomAdapterInvokedForCollectionElementSerialization_literalMutation748() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForCollectionElementSerialization_literalMutation748");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),368,gson);
            StringHolder holder = new StringHolder("Ja5cob" , "Tomaw");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),369,holder);
            Set<StringHolder> setOfHolders = new HashSet<StringHolder>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),370,setOfHolders);
            setOfHolders.add(holder);
            String json = gson.toJson(setOfHolders);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),371,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),367,json.contains("Jacob:Tomaw"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomAdapterInvokedForCollectionElementSerialization_literalMutation749() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForCollectionElementSerialization_literalMutation749");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),368,gson);
            StringHolder holder = new StringHolder("Jaob" , "Tomaw");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),369,holder);
            Set<StringHolder> setOfHolders = new HashSet<StringHolder>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),370,setOfHolders);
            setOfHolders.add(holder);
            String json = gson.toJson(setOfHolders);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),371,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),367,json.contains("Jacob:Tomaw"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomAdapterInvokedForCollectionElementSerialization_literalMutation750() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForCollectionElementSerialization_literalMutation750");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),368,gson);
            StringHolder holder = new StringHolder("Jacob" , "Toaw");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),369,holder);
            Set<StringHolder> setOfHolders = new HashSet<StringHolder>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),370,setOfHolders);
            setOfHolders.add(holder);
            String json = gson.toJson(setOfHolders);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),371,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),367,json.contains("Jacob:Tomaw"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomAdapterInvokedForCollectionElementSerialization_literalMutation751() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForCollectionElementSerialization_literalMutation751");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),368,gson);
            StringHolder holder = new StringHolder("Jacob" , "Tomaw");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),369,holder);
            Set<StringHolder> setOfHolders = new HashSet<StringHolder>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),370,setOfHolders);
            setOfHolders.add(holder);
            String json = gson.toJson(setOfHolders);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),371,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),367,json.contains("Jacob:Tomaw"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomAdapterInvokedForCollectionElementSerialization_literalMutation752() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForCollectionElementSerialization_literalMutation752");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),368,gson);
            StringHolder holder = new StringHolder("Jacob" , "Tmaw");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),369,holder);
            Set<StringHolder> setOfHolders = new HashSet<StringHolder>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),370,setOfHolders);
            setOfHolders.add(holder);
            String json = gson.toJson(setOfHolders);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),371,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),367,json.contains("Jacob:Tomaw"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomAdapterInvokedForCollectionElementSerialization_remove63() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForCollectionElementSerialization_remove63");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),368,gson);
            StringHolder holder = new StringHolder("Jacob" , "Tomaw");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),369,holder);
            Set<StringHolder> setOfHolders = new HashSet<StringHolder>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),370,setOfHolders);
            String json = gson.toJson(setOfHolders);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),371,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),367,json.contains("Jacob:Tomaw"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomAdapterInvokedForCollectionElementDeserialization_add63() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForCollectionElementDeserialization_add63");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),357,gson);
            Type setType = new TypeToken<java.util.Set<StringHolder>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),358,setType);
            Set<StringHolder> setOfHolders = gson.fromJson("[\'Jacob:Tomaw\']", setType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),359,setOfHolders);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),354,setOfHolders.size());
            StringHolder foo = setOfHolders.iterator().next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),360,foo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),355,foo.part1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),356,foo.part2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomAdapterInvokedForCollectionElementDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForCollectionElementDeserialization");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),357,gson);
            Type setType = new TypeToken<java.util.Set<StringHolder>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),358,setType);
            Set<StringHolder> setOfHolders = gson.fromJson("[\'Jacob:Toma¢\']", setType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),359,setOfHolders);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),354,setOfHolders.size());
            StringHolder foo = setOfHolders.iterator().next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),360,foo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),355,foo.part1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),356,foo.part2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomAdapterInvokedForCollectionElementDeserialization_literalMutation745() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForCollectionElementDeserialization_literalMutation745");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),357,gson);
            Type setType = new TypeToken<java.util.Set<StringHolder>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),358,setType);
            Set<StringHolder> setOfHolders = gson.fromJson("[\'VJacob:Tomaw\']", setType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),359,setOfHolders);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),354,setOfHolders.size());
            StringHolder foo = setOfHolders.iterator().next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),360,foo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),355,foo.part1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),356,foo.part2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomAdapterInvokedForCollectionElementDeserialization_literalMutation746() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForCollectionElementDeserialization_literalMutation746");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),357,gson);
            Type setType = new TypeToken<java.util.Set<StringHolder>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),358,setType);
            Set<StringHolder> setOfHolders = gson.fromJson("[\'acob:Tomaw\']", setType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),359,setOfHolders);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),354,setOfHolders.size());
            StringHolder foo = setOfHolders.iterator().next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),360,foo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),355,foo.part1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),356,foo.part2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomAdapterInvokedForCollectionElementDeserialization_remove62() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForCollectionElementDeserialization_remove62");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),357,gson);
            Type setType = new TypeToken<java.util.Set<StringHolder>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),358,setType);
            Set<StringHolder> setOfHolders = gson.fromJson("[\'Jacob:Tomaw\']", setType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),359,setOfHolders);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),354,setOfHolders.size());
            StringHolder foo = setOfHolders.iterator().next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),360,foo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),355,foo.part1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),356,foo.part2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomAdapterInvokedForMapElementSerializationWithType_add69() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForMapElementSerializationWithType_add69");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),380,gson);
            Type mapType = new TypeToken<java.util.Map<java.lang.String, StringHolder>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),381,mapType);
            StringHolder holder = new StringHolder("Jacob" , "Tomaw");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),382,holder);
            Map<java.lang.String, StringHolder> mapOfHolders = new HashMap<java.lang.String, StringHolder>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),383,mapOfHolders);
            mapOfHolders.put("foo", holder);
            String json = gson.toJson(mapOfHolders, mapType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),384,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),379,json.contains("\"foo\":\"Jacob:Tomaw\""));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomAdapterInvokedForMapElementSerializationWithType_add70() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForMapElementSerializationWithType_add70");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),380,gson);
            Type mapType = new TypeToken<java.util.Map<java.lang.String, StringHolder>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),381,mapType);
            StringHolder holder = new StringHolder("Jacob" , "Tomaw");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),382,holder);
            Map<java.lang.String, StringHolder> mapOfHolders = new HashMap<java.lang.String, StringHolder>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),383,mapOfHolders);
            mapOfHolders.put("foo", holder);
            mapOfHolders.put("foo", holder);
            String json = gson.toJson(mapOfHolders, mapType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),384,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),379,json.contains("\"foo\":\"Jacob:Tomaw\""));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomAdapterInvokedForMapElementSerializationWithType() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForMapElementSerializationWithType");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),380,gson);
            Type mapType = new TypeToken<java.util.Map<java.lang.String, StringHolder>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),381,mapType);
            StringHolder holder = new StringHolder("«acob" , "Tomaw");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),382,holder);
            Map<java.lang.String, StringHolder> mapOfHolders = new HashMap<java.lang.String, StringHolder>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),383,mapOfHolders);
            mapOfHolders.put("foo", holder);
            String json = gson.toJson(mapOfHolders, mapType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),384,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),379,json.contains("\"foo\":\"Jacob:Tomaw\""));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomAdapterInvokedForMapElementSerializationWithType_literalMutation775() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForMapElementSerializationWithType_literalMutation775");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),380,gson);
            Type mapType = new TypeToken<java.util.Map<java.lang.String, StringHolder>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),381,mapType);
            StringHolder holder = new StringHolder("JaËcob" , "Tomaw");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),382,holder);
            Map<java.lang.String, StringHolder> mapOfHolders = new HashMap<java.lang.String, StringHolder>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),383,mapOfHolders);
            mapOfHolders.put("foo", holder);
            String json = gson.toJson(mapOfHolders, mapType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),384,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),379,json.contains("\"foo\":\"Jacob:Tomaw\""));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomAdapterInvokedForMapElementSerializationWithType_literalMutation776() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForMapElementSerializationWithType_literalMutation776");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),380,gson);
            Type mapType = new TypeToken<java.util.Map<java.lang.String, StringHolder>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),381,mapType);
            StringHolder holder = new StringHolder("Jacb" , "Tomaw");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),382,holder);
            Map<java.lang.String, StringHolder> mapOfHolders = new HashMap<java.lang.String, StringHolder>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),383,mapOfHolders);
            mapOfHolders.put("foo", holder);
            String json = gson.toJson(mapOfHolders, mapType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),384,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),379,json.contains("\"foo\":\"Jacob:Tomaw\""));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomAdapterInvokedForMapElementSerializationWithType_literalMutation777() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForMapElementSerializationWithType_literalMutation777");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),380,gson);
            Type mapType = new TypeToken<java.util.Map<java.lang.String, StringHolder>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),381,mapType);
            StringHolder holder = new StringHolder("Jacob" , "T£maw");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),382,holder);
            Map<java.lang.String, StringHolder> mapOfHolders = new HashMap<java.lang.String, StringHolder>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),383,mapOfHolders);
            mapOfHolders.put("foo", holder);
            String json = gson.toJson(mapOfHolders, mapType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),384,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),379,json.contains("\"foo\":\"Jacob:Tomaw\""));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomAdapterInvokedForMapElementSerializationWithType_literalMutation778() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForMapElementSerializationWithType_literalMutation778");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),380,gson);
            Type mapType = new TypeToken<java.util.Map<java.lang.String, StringHolder>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),381,mapType);
            StringHolder holder = new StringHolder("Jacob" , "TVomaw");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),382,holder);
            Map<java.lang.String, StringHolder> mapOfHolders = new HashMap<java.lang.String, StringHolder>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),383,mapOfHolders);
            mapOfHolders.put("foo", holder);
            String json = gson.toJson(mapOfHolders, mapType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),384,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),379,json.contains("\"foo\":\"Jacob:Tomaw\""));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomAdapterInvokedForMapElementSerializationWithType_literalMutation779() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForMapElementSerializationWithType_literalMutation779");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),380,gson);
            Type mapType = new TypeToken<java.util.Map<java.lang.String, StringHolder>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),381,mapType);
            StringHolder holder = new StringHolder("Jacob" , "Toaw");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),382,holder);
            Map<java.lang.String, StringHolder> mapOfHolders = new HashMap<java.lang.String, StringHolder>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),383,mapOfHolders);
            mapOfHolders.put("foo", holder);
            String json = gson.toJson(mapOfHolders, mapType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),384,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),379,json.contains("\"foo\":\"Jacob:Tomaw\""));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomAdapterInvokedForMapElementSerializationWithType_literalMutation780() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForMapElementSerializationWithType_literalMutation780");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),380,gson);
            Type mapType = new TypeToken<java.util.Map<java.lang.String, StringHolder>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),381,mapType);
            StringHolder holder = new StringHolder("Jacob" , "Tomaw");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),382,holder);
            Map<java.lang.String, StringHolder> mapOfHolders = new HashMap<java.lang.String, StringHolder>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),383,mapOfHolders);
            mapOfHolders.put("oo", holder);
            String json = gson.toJson(mapOfHolders, mapType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),384,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),379,json.contains("\"foo\":\"Jacob:Tomaw\""));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomAdapterInvokedForMapElementSerializationWithType_literalMutation781() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForMapElementSerializationWithType_literalMutation781");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),380,gson);
            Type mapType = new TypeToken<java.util.Map<java.lang.String, StringHolder>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),381,mapType);
            StringHolder holder = new StringHolder("Jacob" , "Tomaw");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),382,holder);
            Map<java.lang.String, StringHolder> mapOfHolders = new HashMap<java.lang.String, StringHolder>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),383,mapOfHolders);
            mapOfHolders.put("foo", holder);
            String json = gson.toJson(mapOfHolders, mapType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),384,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),379,json.contains("\"foo\":\"Jacob:Tomaw\""));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomAdapterInvokedForMapElementSerializationWithType_literalMutation782() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForMapElementSerializationWithType_literalMutation782");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),380,gson);
            Type mapType = new TypeToken<java.util.Map<java.lang.String, StringHolder>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),381,mapType);
            StringHolder holder = new StringHolder("Jacob" , "Tomaw");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),382,holder);
            Map<java.lang.String, StringHolder> mapOfHolders = new HashMap<java.lang.String, StringHolder>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),383,mapOfHolders);
            mapOfHolders.put("fo", holder);
            String json = gson.toJson(mapOfHolders, mapType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),384,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),379,json.contains("\"foo\":\"Jacob:Tomaw\""));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomAdapterInvokedForMapElementSerializationWithType_remove68() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForMapElementSerializationWithType_remove68");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),380,gson);
            Type mapType = new TypeToken<java.util.Map<java.lang.String, StringHolder>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),381,mapType);
            StringHolder holder = new StringHolder("Jacob" , "Tomaw");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),382,holder);
            Map<java.lang.String, StringHolder> mapOfHolders = new HashMap<java.lang.String, StringHolder>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),383,mapOfHolders);
            mapOfHolders.put("foo", holder);
            String json = gson.toJson(mapOfHolders, mapType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),384,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),379,json.contains("\"foo\":\"Jacob:Tomaw\""));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomAdapterInvokedForMapElementSerializationWithType_remove69() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForMapElementSerializationWithType_remove69");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),380,gson);
            Type mapType = new TypeToken<java.util.Map<java.lang.String, StringHolder>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),381,mapType);
            StringHolder holder = new StringHolder("Jacob" , "Tomaw");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),382,holder);
            Map<java.lang.String, StringHolder> mapOfHolders = new HashMap<java.lang.String, StringHolder>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),383,mapOfHolders);
            String json = gson.toJson(mapOfHolders, mapType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),384,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),379,json.contains("\"foo\":\"Jacob:Tomaw\""));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomAdapterInvokedForMapElementSerialization_add68() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForMapElementSerialization_add68");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),386,gson);
            StringHolder holder = new StringHolder("Jacob" , "Tomaw");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),387,holder);
            Map<java.lang.String, StringHolder> mapOfHolders = new HashMap<java.lang.String, StringHolder>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),388,mapOfHolders);
            mapOfHolders.put("foo", holder);
            mapOfHolders.put("foo", holder);
            String json = gson.toJson(mapOfHolders);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),389,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),385,json.contains("\"foo\":\"Jacob:Tomaw\""));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomAdapterInvokedForMapElementSerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForMapElementSerialization");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),386,gson);
            StringHolder holder = new StringHolder("Jìcob" , "Tomaw");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),387,holder);
            Map<java.lang.String, StringHolder> mapOfHolders = new HashMap<java.lang.String, StringHolder>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),388,mapOfHolders);
            mapOfHolders.put("foo", holder);
            String json = gson.toJson(mapOfHolders);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),389,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),385,json.contains("\"foo\":\"Jacob:Tomaw\""));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomAdapterInvokedForMapElementSerialization_literalMutation766() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForMapElementSerialization_literalMutation766");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),386,gson);
            StringHolder holder = new StringHolder("J¢acob" , "Tomaw");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),387,holder);
            Map<java.lang.String, StringHolder> mapOfHolders = new HashMap<java.lang.String, StringHolder>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),388,mapOfHolders);
            mapOfHolders.put("foo", holder);
            String json = gson.toJson(mapOfHolders);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),389,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),385,json.contains("\"foo\":\"Jacob:Tomaw\""));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomAdapterInvokedForMapElementSerialization_literalMutation767() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForMapElementSerialization_literalMutation767");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),386,gson);
            StringHolder holder = new StringHolder("Jaob" , "Tomaw");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),387,holder);
            Map<java.lang.String, StringHolder> mapOfHolders = new HashMap<java.lang.String, StringHolder>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),388,mapOfHolders);
            mapOfHolders.put("foo", holder);
            String json = gson.toJson(mapOfHolders);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),389,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),385,json.contains("\"foo\":\"Jacob:Tomaw\""));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomAdapterInvokedForMapElementSerialization_literalMutation768() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForMapElementSerialization_literalMutation768");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),386,gson);
            StringHolder holder = new StringHolder("Jacob" , "Toaw");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),387,holder);
            Map<java.lang.String, StringHolder> mapOfHolders = new HashMap<java.lang.String, StringHolder>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),388,mapOfHolders);
            mapOfHolders.put("foo", holder);
            String json = gson.toJson(mapOfHolders);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),389,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),385,json.contains("\"foo\":\"Jacob:Tomaw\""));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomAdapterInvokedForMapElementSerialization_literalMutation769() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForMapElementSerialization_literalMutation769");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),386,gson);
            StringHolder holder = new StringHolder("Jacob" , "Tomaw");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),387,holder);
            Map<java.lang.String, StringHolder> mapOfHolders = new HashMap<java.lang.String, StringHolder>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),388,mapOfHolders);
            mapOfHolders.put("foo", holder);
            String json = gson.toJson(mapOfHolders);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),389,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),385,json.contains("\"foo\":\"Jacob:Tomaw\""));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomAdapterInvokedForMapElementSerialization_literalMutation770() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForMapElementSerialization_literalMutation770");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),386,gson);
            StringHolder holder = new StringHolder("Jacob" , "Toaw");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),387,holder);
            Map<java.lang.String, StringHolder> mapOfHolders = new HashMap<java.lang.String, StringHolder>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),388,mapOfHolders);
            mapOfHolders.put("foo", holder);
            String json = gson.toJson(mapOfHolders);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),389,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),385,json.contains("\"foo\":\"Jacob:Tomaw\""));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomAdapterInvokedForMapElementSerialization_literalMutation771() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForMapElementSerialization_literalMutation771");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),386,gson);
            StringHolder holder = new StringHolder("Jacob" , "Tomaw");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),387,holder);
            Map<java.lang.String, StringHolder> mapOfHolders = new HashMap<java.lang.String, StringHolder>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),388,mapOfHolders);
            mapOfHolders.put("oo", holder);
            String json = gson.toJson(mapOfHolders);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),389,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),385,json.contains("\"foo\":\"Jacob:Tomaw\""));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomAdapterInvokedForMapElementSerialization_literalMutation772() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForMapElementSerialization_literalMutation772");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),386,gson);
            StringHolder holder = new StringHolder("Jacob" , "Tomaw");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),387,holder);
            Map<java.lang.String, StringHolder> mapOfHolders = new HashMap<java.lang.String, StringHolder>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),388,mapOfHolders);
            mapOfHolders.put("fFoo", holder);
            String json = gson.toJson(mapOfHolders);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),389,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),385,json.contains("\"foo\":\"Jacob:Tomaw\""));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomAdapterInvokedForMapElementSerialization_literalMutation773() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForMapElementSerialization_literalMutation773");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),386,gson);
            StringHolder holder = new StringHolder("Jacob" , "Tomaw");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),387,holder);
            Map<java.lang.String, StringHolder> mapOfHolders = new HashMap<java.lang.String, StringHolder>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),388,mapOfHolders);
            mapOfHolders.put("fo", holder);
            String json = gson.toJson(mapOfHolders);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),389,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),385,json.contains("\"foo\":\"Jacob:Tomaw\""));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomAdapterInvokedForMapElementSerialization_remove67() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForMapElementSerialization_remove67");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),386,gson);
            StringHolder holder = new StringHolder("Jacob" , "Tomaw");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),387,holder);
            Map<java.lang.String, StringHolder> mapOfHolders = new HashMap<java.lang.String, StringHolder>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),388,mapOfHolders);
            String json = gson.toJson(mapOfHolders);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),389,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),385,json.contains("\"foo\":\"Jacob:Tomaw\""));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomAdapterInvokedForMapElementDeserialization_add67() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForMapElementDeserialization_add67");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),375,gson);
            Type mapType = new TypeToken<java.util.Map<java.lang.String, StringHolder>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),376,mapType);
            Map<java.lang.String, StringHolder> mapOfFoo = gson.fromJson("{\'foo\':\'Jacob:Tomaw\'}", mapType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),377,mapOfFoo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),372,mapOfFoo.size());
            StringHolder foo = mapOfFoo.get("foo");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),378,foo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),373,foo.part1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),374,foo.part2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomAdapterInvokedForMapElementDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForMapElementDeserialization");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),375,gson);
            Type mapType = new TypeToken<java.util.Map<java.lang.String, StringHolder>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),376,mapType);
            Map<java.lang.String, StringHolder> mapOfFoo = gson.fromJson("{\'foo\':\'Jalob:Tomaw\'}", mapType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),377,mapOfFoo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),372,mapOfFoo.size());
            StringHolder foo = mapOfFoo.get("foo");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),378,foo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),373,foo.part1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),374,foo.part2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomAdapterInvokedForMapElementDeserialization_literalMutation760() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForMapElementDeserialization_literalMutation760");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),375,gson);
            Type mapType = new TypeToken<java.util.Map<java.lang.String, StringHolder>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),376,mapType);
            Map<java.lang.String, StringHolder> mapOfFoo = gson.fromJson("{Á\'foo\':\'Jacob:Tomaw\'}", mapType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),377,mapOfFoo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),372,mapOfFoo.size());
            StringHolder foo = mapOfFoo.get("foo");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),378,foo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),373,foo.part1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),374,foo.part2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomAdapterInvokedForMapElementDeserialization_literalMutation761() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForMapElementDeserialization_literalMutation761");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),375,gson);
            Type mapType = new TypeToken<java.util.Map<java.lang.String, StringHolder>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),376,mapType);
            Map<java.lang.String, StringHolder> mapOfFoo = gson.fromJson("{\'foo\':Jacob:Tomaw\'}", mapType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),377,mapOfFoo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),372,mapOfFoo.size());
            StringHolder foo = mapOfFoo.get("foo");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),378,foo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),373,foo.part1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),374,foo.part2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomAdapterInvokedForMapElementDeserialization_literalMutation762() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForMapElementDeserialization_literalMutation762");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),375,gson);
            Type mapType = new TypeToken<java.util.Map<java.lang.String, StringHolder>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),376,mapType);
            Map<java.lang.String, StringHolder> mapOfFoo = gson.fromJson("{\'foo\':\'Jacob:Tomaw\'}", mapType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),377,mapOfFoo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),372,mapOfFoo.size());
            StringHolder foo = mapOfFoo.get("Óoo");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),378,foo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),373,foo.part1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),374,foo.part2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomAdapterInvokedForMapElementDeserialization_literalMutation763() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForMapElementDeserialization_literalMutation763");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),375,gson);
            Type mapType = new TypeToken<java.util.Map<java.lang.String, StringHolder>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),376,mapType);
            Map<java.lang.String, StringHolder> mapOfFoo = gson.fromJson("{\'foo\':\'Jacob:Tomaw\'}", mapType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),377,mapOfFoo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),372,mapOfFoo.size());
            StringHolder foo = mapOfFoo.get("foo");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),378,foo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),373,foo.part1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),374,foo.part2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCustomAdapterInvokedForMapElementDeserialization_literalMutation764() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForMapElementDeserialization_literalMutation764");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),375,gson);
            Type mapType = new TypeToken<java.util.Map<java.lang.String, StringHolder>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),376,mapType);
            Map<java.lang.String, StringHolder> mapOfFoo = gson.fromJson("{\'foo\':\'Jacob:Tomaw\'}", mapType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),377,mapOfFoo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),372,mapOfFoo.size());
            StringHolder foo = mapOfFoo.get("fo");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),378,foo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),373,foo.part1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),374,foo.part2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testCustomAdapterInvokedForMapElementDeserialization_remove66() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCustomAdapterInvokedForMapElementDeserialization_remove66");
            Gson gson = new GsonBuilder().registerTypeAdapter(StringHolder.class, new StringHolderTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),375,gson);
            Type mapType = new TypeToken<java.util.Map<java.lang.String, StringHolder>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),376,mapType);
            Map<java.lang.String, StringHolder> mapOfFoo = gson.fromJson("{\'foo\':\'Jacob:Tomaw\'}", mapType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),377,mapOfFoo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),372,mapOfFoo.size());
            StringHolder foo = mapOfFoo.get("foo");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),378,foo);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),373,foo.part1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),374,foo.part2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEnsureCustomSerializerNotInvokedForNullValues() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEnsureCustomSerializerNotInvokedForNullValues");
            Gson gson = new GsonBuilder().registerTypeAdapter(DataHolder.class, new DataHolderSerializer()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),451,gson);
            DataHolderWrapper target = new DataHolderWrapper(new DataHolder(";bc"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),452,target);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),453,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),450,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEnsureCustomSerializerNotInvokedForNullValues_literalMutation885() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEnsureCustomSerializerNotInvokedForNullValues_literalMutation885");
            Gson gson = new GsonBuilder().registerTypeAdapter(DataHolder.class, new DataHolderSerializer()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),451,gson);
            DataHolderWrapper target = new DataHolderWrapper(new DataHolder("abc"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),452,target);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),453,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),450,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEnsureCustomSerializerNotInvokedForNullValues_literalMutation886() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEnsureCustomSerializerNotInvokedForNullValues_literalMutation886");
            Gson gson = new GsonBuilder().registerTypeAdapter(DataHolder.class, new DataHolderSerializer()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),451,gson);
            DataHolderWrapper target = new DataHolderWrapper(new DataHolder("ac"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),452,target);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),453,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),450,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEnsureCustomDeserializerNotInvokedForNullValues() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEnsureCustomDeserializerNotInvokedForNullValues");
            Gson gson = new GsonBuilder().registerTypeAdapter(DataHolder.class, new DataHolderDeserializer()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),447,gson);
            String json = "{wrappedDa¿a:null}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),448,json);
            DataHolderWrapper actual = gson.fromJson(json, DataHolderWrapper.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),449,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),446,actual.wrappedData);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEnsureCustomDeserializerNotInvokedForNullValues_literalMutation882() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEnsureCustomDeserializerNotInvokedForNullValues_literalMutation882");
            Gson gson = new GsonBuilder().registerTypeAdapter(DataHolder.class, new DataHolderDeserializer()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),447,gson);
            String json = "{wrappedData:null}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),448,json);
            DataHolderWrapper actual = gson.fromJson(json, DataHolderWrapper.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),449,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),446,actual.wrappedData);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEnsureCustomDeserializerNotInvokedForNullValues_literalMutation883() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEnsureCustomDeserializerNotInvokedForNullValues_literalMutation883");
            Gson gson = new GsonBuilder().registerTypeAdapter(DataHolder.class, new DataHolderDeserializer()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),447,gson);
            String json = "{wrappedData:ull}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),448,json);
            DataHolderWrapper actual = gson.fromJson(json, DataHolderWrapper.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),449,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),446,actual.wrappedData);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegisterHierarchyAdapterForDate() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegisterHierarchyAdapterForDate");
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Date.class, new DateTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),460,gson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),454,gson.toJson(new java.util.Date(0)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),455,gson.toJson(new java.sql.Date(0)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),456,new java.util.Date(0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),457,gson.fromJson("0", java.util.Date.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),458,new java.sql.Date(0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),459,gson.fromJson("0", java.sql.Date.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    private static class DataHolder {
        final String data;

        public DataHolder(String data) {
            this.data = data;
        }
    }

    private static class DataHolderWrapper {
        final DataHolder wrappedData;

        public DataHolderWrapper(DataHolder data) {
            this.wrappedData = data;
        }
    }

    private static class DataHolderSerializer implements JsonSerializer<DataHolder> {
        public JsonElement serialize(DataHolder src, Type typeOfSrc, JsonSerializationContext context) {
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),335,obj);
            obj.addProperty("myData", src.data);
            return obj;
        }
    }

    private static class DataHolderDeserializer implements JsonDeserializer<DataHolder> {
        public DataHolder deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) throws JsonParseException {
            JsonObject jsonObj = json.getAsJsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),333,jsonObj);
            JsonElement jsonElement = jsonObj.get("data");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),334,jsonElement);
            if ((jsonElement == null) || (jsonElement.isJsonNull())) {
                return new DataHolder(null);
            } 
            return new DataHolder(jsonElement.getAsString());
        }
    }

    private static class DateTypeAdapter implements JsonDeserializer<java.util.Date> , JsonSerializer<java.util.Date> {
        public Date deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) throws JsonParseException {
            return typeOfT == (Date.class) ? new Date(json.getAsLong()) : new java.sql.Date(json.getAsLong());
        }

        public JsonElement serialize(Date src, Type typeOfSrc, JsonSerializationContext context) {
            return new JsonPrimitive(src.getTime());
        }
    }
}

